import type { Paginator } from "@smithy/types";
import { ListDevicesCommandInput, ListDevicesCommandOutput } from "../commands/ListDevicesCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListDevices: (config: SageMakerPaginationConfiguration, input: ListDevicesCommandInput, ...rest: any[]) => Paginator<ListDevicesCommandOutput>;
