import { createPaginator } from "@smithy/core";
import { ListInferenceRecommendationsJobsCommand, } from "../commands/ListInferenceRecommendationsJobsCommand";
import { SageMakerClient } from "../SageMakerClient";
export const paginateListInferenceRecommendationsJobs = createPaginator(SageMakerClient, ListInferenceRecommendationsJobsCommand, "NextToken", "NextToken", "MaxResults");
