import { Paginator } from "@smithy/types";
import {
  ListImagesCommandInput,
  ListImagesCommandOutput,
} from "../commands/ListImagesCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
export declare const paginateListImages: (
  config: SageMakerPaginationConfiguration,
  input: ListImagesCommandInput,
  ...rest: any[]
) => Paginator<ListImagesCommandOutput>;
