import { createPaginator } from "@smithy/core";
import { ListInferenceRecommendationsJobStepsCommand, } from "../commands/ListInferenceRecommendationsJobStepsCommand";
import { SageMakerClient } from "../SageMakerClient";
export const paginateListInferenceRecommendationsJobSteps = createPaginator(SageMakerClient, ListInferenceRecommendationsJobStepsCommand, "NextToken", "NextToken", "MaxResults");
