import type { Paginator } from "@smithy/types";
import { ListModelsCommandInput, ListModelsCommandOutput } from "../commands/ListModelsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListModels: (config: SageMakerPaginationConfiguration, input: ListModelsCommandInput, ...rest: any[]) => Paginator<ListModelsCommandOutput>;
