import type { Paginator } from "@smithy/types";
import { ListModelPackagesCommandInput, ListModelPackagesCommandOutput } from "../commands/ListModelPackagesCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListModelPackages: (config: SageMakerPaginationConfiguration, input: ListModelPackagesCommandInput, ...rest: any[]) => Paginator<ListModelPackagesCommandOutput>;
