import { Paginator } from "@smithy/types";
import {
  ListDevicesCommandInput,
  ListDevicesCommandOutput,
} from "../commands/ListDevicesCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
export declare const paginateListDevices: (
  config: SageMakerPaginationConfiguration,
  input: ListDevicesCommandInput,
  ...rest: any[]
) => Paginator<ListDevicesCommandOutput>;
