import type { Paginator } from "@smithy/types";
import { ListSpacesCommandInput, ListSpacesCommandOutput } from "../commands/ListSpacesCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListSpaces: (config: SageMakerPaginationConfiguration, input: ListSpacesCommandInput, ...rest: any[]) => Paginator<ListSpacesCommandOutput>;
