import type { Paginator } from "@smithy/types";
import { ListPipelineExecutionStepsCommandInput, ListPipelineExecutionStepsCommandOutput } from "../commands/ListPipelineExecutionStepsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListPipelineExecutionSteps: (config: SageMakerPaginationConfiguration, input: ListPipelineExecutionStepsCommandInput, ...rest: any[]) => Paginator<ListPipelineExecutionStepsCommandOutput>;
