import { createPaginator } from "@smithy/core";
import { ListModelCardExportJobsCommand, } from "../commands/ListModelCardExportJobsCommand";
import { SageMakerClient } from "../SageMakerClient";
export const paginateListModelCardExportJobs = createPaginator(SageMakerClient, ListModelCardExportJobsCommand, "NextToken", "NextToken", "MaxResults");
