import { createPaginator } from "@smithy/core";
import { CreateHubContentPresignedUrlsCommand, } from "../commands/CreateHubContentPresignedUrlsCommand";
import { SageMakerClient } from "../SageMakerClient";
export const paginateCreateHubContentPresignedUrls = createPaginator(SageMakerClient, CreateHubContentPresignedUrlsCommand, "NextToken", "NextToken", "MaxResults");
