import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  CreateHubContentPresignedUrlsRequest,
  CreateHubContentPresignedUrlsResponse,
} from "../models/models_1";
import {
  SageMakerClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../SageMakerClient";
export { __MetadataBearer };
export { $Command };
export interface CreateHubContentPresignedUrlsCommandInput
  extends CreateHubContentPresignedUrlsRequest {}
export interface CreateHubContentPresignedUrlsCommandOutput
  extends CreateHubContentPresignedUrlsResponse,
    __MetadataBearer {}
declare const CreateHubContentPresignedUrlsCommand_base: {
  new (
    input: CreateHubContentPresignedUrlsCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    CreateHubContentPresignedUrlsCommandInput,
    CreateHubContentPresignedUrlsCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: CreateHubContentPresignedUrlsCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    CreateHubContentPresignedUrlsCommandInput,
    CreateHubContentPresignedUrlsCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class CreateHubContentPresignedUrlsCommand extends CreateHubContentPresignedUrlsCommand_base {
  protected static __types: {
    api: {
      input: CreateHubContentPresignedUrlsRequest;
      output: CreateHubContentPresignedUrlsResponse;
    };
    sdk: {
      input: CreateHubContentPresignedUrlsCommandInput;
      output: CreateHubContentPresignedUrlsCommandOutput;
    };
  };
}
