import { createPaginator } from "@smithy/core";
import { ListDataQualityJobDefinitionsCommand, } from "../commands/ListDataQualityJobDefinitionsCommand";
import { SageMakerClient } from "../SageMakerClient";
export const paginateListDataQualityJobDefinitions = createPaginator(SageMakerClient, ListDataQualityJobDefinitionsCommand, "NextToken", "NextToken", "MaxResults");
