import type { Paginator } from "@smithy/types";
import { ListTrainingJobsCommandInput, ListTrainingJobsCommandOutput } from "../commands/ListTrainingJobsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListTrainingJobs: (config: SageMakerPaginationConfiguration, input: ListTrainingJobsCommandInput, ...rest: any[]) => Paginator<ListTrainingJobsCommandOutput>;
