import { createPaginator } from "@smithy/core";
import { ListCandidatesForAutoMLJobCommand, } from "../commands/ListCandidatesForAutoMLJobCommand";
import { SageMakerClient } from "../SageMakerClient";
export const paginateListCandidatesForAutoMLJob = createPaginator(SageMakerClient, ListCandidatesForAutoMLJobCommand, "NextToken", "NextToken", "MaxResults");
