import type { Paginator } from "@smithy/types";
import { ListClusterSchedulerConfigsCommandInput, ListClusterSchedulerConfigsCommandOutput } from "../commands/ListClusterSchedulerConfigsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListClusterSchedulerConfigs: (config: SageMakerPaginationConfiguration, input: ListClusterSchedulerConfigsCommandInput, ...rest: any[]) => Paginator<ListClusterSchedulerConfigsCommandOutput>;
