import { createPaginator } from "@smithy/core";
import { ListNotebookInstanceLifecycleConfigsCommand, } from "../commands/ListNotebookInstanceLifecycleConfigsCommand";
import { SageMakerClient } from "../SageMakerClient";
export const paginateListNotebookInstanceLifecycleConfigs = createPaginator(SageMakerClient, ListNotebookInstanceLifecycleConfigsCommand, "NextToken", "NextToken", "MaxResults");
