import { createPaginator } from "@smithy/core";
import { ListModelQualityJobDefinitionsCommand, } from "../commands/ListModelQualityJobDefinitionsCommand";
import { SageMakerClient } from "../SageMakerClient";
export const paginateListModelQualityJobDefinitions = createPaginator(SageMakerClient, ListModelQualityJobDefinitionsCommand, "NextToken", "NextToken", "MaxResults");
