import { createPaginator } from "@smithy/core";
import { ListStudioLifecycleConfigsCommand, } from "../commands/ListStudioLifecycleConfigsCommand";
import { SageMakerClient } from "../SageMakerClient";
export const paginateListStudioLifecycleConfigs = createPaginator(SageMakerClient, ListStudioLifecycleConfigsCommand, "NextToken", "NextToken", "MaxResults");
