import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  ListClusterEventsRequest,
  ListClusterEventsResponse,
} from "../models/models_3";
import {
  SageMakerClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../SageMakerClient";
export { __MetadataBearer };
export { $Command };
export interface ListClusterEventsCommandInput
  extends ListClusterEventsRequest {}
export interface ListClusterEventsCommandOutput
  extends ListClusterEventsResponse,
    __MetadataBearer {}
declare const ListClusterEventsCommand_base: {
  new (
    input: ListClusterEventsCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    ListClusterEventsCommandInput,
    ListClusterEventsCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: ListClusterEventsCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    ListClusterEventsCommandInput,
    ListClusterEventsCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class ListClusterEventsCommand extends ListClusterEventsCommand_base {
  protected static __types: {
    api: {
      input: ListClusterEventsRequest;
      output: ListClusterEventsResponse;
    };
    sdk: {
      input: ListClusterEventsCommandInput;
      output: ListClusterEventsCommandOutput;
    };
  };
}
