import type { Paginator } from "@smithy/types";
import { ListAppImageConfigsCommandInput, ListAppImageConfigsCommandOutput } from "../commands/ListAppImageConfigsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListAppImageConfigs: (config: SageMakerPaginationConfiguration, input: ListAppImageConfigsCommandInput, ...rest: any[]) => Paginator<ListAppImageConfigsCommandOutput>;
