import type { Paginator } from "@smithy/types";
import { SearchCommandInput, SearchCommandOutput } from "../commands/SearchCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateSearch: (config: SageMakerPaginationConfiguration, input: SearchCommandInput, ...rest: any[]) => Paginator<SearchCommandOutput>;
