import type { PaginationConfiguration } from "@smithy/types";
import { SageMakerClient } from "../SageMakerClient";
/**
 * @public
 */
export interface SageMakerPaginationConfiguration extends PaginationConfiguration {
    client: SageMakerClient;
}
