import type { Paginator } from "@smithy/types";
import { ListModelQualityJobDefinitionsCommandInput, ListModelQualityJobDefinitionsCommandOutput } from "../commands/ListModelQualityJobDefinitionsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListModelQualityJobDefinitions: (config: SageMakerPaginationConfiguration, input: ListModelQualityJobDefinitionsCommandInput, ...rest: any[]) => Paginator<ListModelQualityJobDefinitionsCommandOutput>;
