import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  CreateMlflowAppRequest,
  CreateMlflowAppResponse,
} from "../models/models_1";
import {
  SageMakerClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../SageMakerClient";
export { __MetadataBearer };
export { $Command };
export interface CreateMlflowAppCommandInput extends CreateMlflowAppRequest {}
export interface CreateMlflowAppCommandOutput
  extends CreateMlflowAppResponse,
    __MetadataBearer {}
declare const CreateMlflowAppCommand_base: {
  new (
    input: CreateMlflowAppCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    CreateMlflowAppCommandInput,
    CreateMlflowAppCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: CreateMlflowAppCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    CreateMlflowAppCommandInput,
    CreateMlflowAppCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class CreateMlflowAppCommand extends CreateMlflowAppCommand_base {
  protected static __types: {
    api: {
      input: CreateMlflowAppRequest;
      output: CreateMlflowAppResponse;
    };
    sdk: {
      input: CreateMlflowAppCommandInput;
      output: CreateMlflowAppCommandOutput;
    };
  };
}
