import { PaginationConfiguration } from "@smithy/types";
import { SageMakerClient } from "../SageMakerClient";
export interface SageMakerPaginationConfiguration
  extends PaginationConfiguration {
  client: SageMakerClient;
}
