import { Paginator } from "@smithy/types";
import {
  ListAliasesCommandInput,
  ListAliasesCommandOutput,
} from "../commands/ListAliasesCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
export declare const paginateListAliases: (
  config: SageMakerPaginationConfiguration,
  input: ListAliasesCommandInput,
  ...rest: any[]
) => Paginator<ListAliasesCommandOutput>;
