import type { Paginator } from "@smithy/types";
import { ListDeviceFleetsCommandInput, ListDeviceFleetsCommandOutput } from "../commands/ListDeviceFleetsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListDeviceFleets: (config: SageMakerPaginationConfiguration, input: ListDeviceFleetsCommandInput, ...rest: any[]) => Paginator<ListDeviceFleetsCommandOutput>;
