import type { Paginator } from "@smithy/types";
import { ListClusterEventsCommandInput, ListClusterEventsCommandOutput } from "../commands/ListClusterEventsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListClusterEvents: (config: SageMakerPaginationConfiguration, input: ListClusterEventsCommandInput, ...rest: any[]) => Paginator<ListClusterEventsCommandOutput>;
