import { Paginator } from "@smithy/types";
import {
  CreateHubContentPresignedUrlsCommandInput,
  CreateHubContentPresignedUrlsCommandOutput,
} from "../commands/CreateHubContentPresignedUrlsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
export declare const paginateCreateHubContentPresignedUrls: (
  config: SageMakerPaginationConfiguration,
  input: CreateHubContentPresignedUrlsCommandInput,
  ...rest: any[]
) => Paginator<CreateHubContentPresignedUrlsCommandOutput>;
