import { TypeRegistry } from "@smithy/core/schema";
import {
  StaticErrorSchema,
  StaticOperationSchema,
  StaticStructureSchema,
  StaticUnionSchema,
} from "@smithy/types";
export declare var SageMakerServiceException$: StaticErrorSchema;
export declare var ConflictException$: StaticErrorSchema;
export declare var ResourceInUse$: StaticErrorSchema;
export declare var ResourceLimitExceeded$: StaticErrorSchema;
export declare var ResourceNotFound$: StaticErrorSchema;
export declare const errorTypeRegistries: TypeRegistry[];
export declare var AcceleratorPartitionConfig$: StaticStructureSchema;
export declare var ActionSource$: StaticStructureSchema;
export declare var ActionSummary$: StaticStructureSchema;
export declare var AddAssociationRequest$: StaticStructureSchema;
export declare var AddAssociationResponse$: StaticStructureSchema;
export declare var AddClusterNodeSpecification$: StaticStructureSchema;
export declare var AdditionalEnis$: StaticStructureSchema;
export declare var AdditionalInferenceSpecificationDefinition$: StaticStructureSchema;
export declare var AdditionalModelDataSource$: StaticStructureSchema;
export declare var AdditionalS3DataSource$: StaticStructureSchema;
export declare var AddTagsInput$: StaticStructureSchema;
export declare var AddTagsOutput$: StaticStructureSchema;
export declare var AgentVersion$: StaticStructureSchema;
export declare var Alarm$: StaticStructureSchema;
export declare var AlarmDetails$: StaticStructureSchema;
export declare var AlgorithmSpecification$: StaticStructureSchema;
export declare var AlgorithmStatusDetails$: StaticStructureSchema;
export declare var AlgorithmStatusItem$: StaticStructureSchema;
export declare var AlgorithmSummary$: StaticStructureSchema;
export declare var AlgorithmValidationProfile$: StaticStructureSchema;
export declare var AlgorithmValidationSpecification$: StaticStructureSchema;
export declare var AmazonQSettings$: StaticStructureSchema;
export declare var AnnotationConsolidationConfig$: StaticStructureSchema;
export declare var AppDetails$: StaticStructureSchema;
export declare var AppImageConfigDetails$: StaticStructureSchema;
export declare var AppLifecycleManagement$: StaticStructureSchema;
export declare var AppSpecification$: StaticStructureSchema;
export declare var ArtifactSource$: StaticStructureSchema;
export declare var ArtifactSourceType$: StaticStructureSchema;
export declare var ArtifactSummary$: StaticStructureSchema;
export declare var AssociateTrialComponentRequest$: StaticStructureSchema;
export declare var AssociateTrialComponentResponse$: StaticStructureSchema;
export declare var AssociationInfo$: StaticStructureSchema;
export declare var AssociationSummary$: StaticStructureSchema;
export declare var AsyncInferenceClientConfig$: StaticStructureSchema;
export declare var AsyncInferenceConfig$: StaticStructureSchema;
export declare var AsyncInferenceNotificationConfig$: StaticStructureSchema;
export declare var AsyncInferenceOutputConfig$: StaticStructureSchema;
export declare var AthenaDatasetDefinition$: StaticStructureSchema;
export declare var AttachClusterNodeVolumeRequest$: StaticStructureSchema;
export declare var AttachClusterNodeVolumeResponse$: StaticStructureSchema;
export declare var AuthorizedUrl$: StaticStructureSchema;
export declare var AutoMLAlgorithmConfig$: StaticStructureSchema;
export declare var AutoMLCandidate$: StaticStructureSchema;
export declare var AutoMLCandidateGenerationConfig$: StaticStructureSchema;
export declare var AutoMLCandidateStep$: StaticStructureSchema;
export declare var AutoMLChannel$: StaticStructureSchema;
export declare var AutoMLComputeConfig$: StaticStructureSchema;
export declare var AutoMLContainerDefinition$: StaticStructureSchema;
export declare var AutoMLDataSource$: StaticStructureSchema;
export declare var AutoMLDataSplitConfig$: StaticStructureSchema;
export declare var AutoMLJobArtifacts$: StaticStructureSchema;
export declare var AutoMLJobChannel$: StaticStructureSchema;
export declare var AutoMLJobCompletionCriteria$: StaticStructureSchema;
export declare var AutoMLJobConfig$: StaticStructureSchema;
export declare var AutoMLJobObjective$: StaticStructureSchema;
export declare var AutoMLJobStepMetadata$: StaticStructureSchema;
export declare var AutoMLJobSummary$: StaticStructureSchema;
export declare var AutoMLOutputDataConfig$: StaticStructureSchema;
export declare var AutoMLPartialFailureReason$: StaticStructureSchema;
export declare var AutoMLResolvedAttributes$: StaticStructureSchema;
export declare var AutoMLS3DataSource$: StaticStructureSchema;
export declare var AutoMLSecurityConfig$: StaticStructureSchema;
export declare var AutoParameter$: StaticStructureSchema;
export declare var AutoRollbackConfig$: StaticStructureSchema;
export declare var Autotune$: StaticStructureSchema;
export declare var AvailableUpgrade$: StaticStructureSchema;
export declare var BaseModel$: StaticStructureSchema;
export declare var BatchAddClusterNodesError$: StaticStructureSchema;
export declare var BatchAddClusterNodesRequest$: StaticStructureSchema;
export declare var BatchAddClusterNodesResponse$: StaticStructureSchema;
export declare var BatchDataCaptureConfig$: StaticStructureSchema;
export declare var BatchDeleteClusterNodeLogicalIdsError$: StaticStructureSchema;
export declare var BatchDeleteClusterNodesError$: StaticStructureSchema;
export declare var BatchDeleteClusterNodesRequest$: StaticStructureSchema;
export declare var BatchDeleteClusterNodesResponse$: StaticStructureSchema;
export declare var BatchDescribeModelPackageError$: StaticStructureSchema;
export declare var BatchDescribeModelPackageInput$: StaticStructureSchema;
export declare var BatchDescribeModelPackageOutput$: StaticStructureSchema;
export declare var BatchDescribeModelPackageSummary$: StaticStructureSchema;
export declare var BatchRebootClusterNodeLogicalIdsError$: StaticStructureSchema;
export declare var BatchRebootClusterNodesError$: StaticStructureSchema;
export declare var BatchRebootClusterNodesRequest$: StaticStructureSchema;
export declare var BatchRebootClusterNodesResponse$: StaticStructureSchema;
export declare var BatchReplaceClusterNodeLogicalIdsError$: StaticStructureSchema;
export declare var BatchReplaceClusterNodesError$: StaticStructureSchema;
export declare var BatchReplaceClusterNodesRequest$: StaticStructureSchema;
export declare var BatchReplaceClusterNodesResponse$: StaticStructureSchema;
export declare var BatchTransformInput$: StaticStructureSchema;
export declare var BedrockCustomModelDeploymentMetadata$: StaticStructureSchema;
export declare var BedrockCustomModelMetadata$: StaticStructureSchema;
export declare var BedrockModelImportMetadata$: StaticStructureSchema;
export declare var BedrockProvisionedModelThroughputMetadata$: StaticStructureSchema;
export declare var BestObjectiveNotImproving$: StaticStructureSchema;
export declare var Bias$: StaticStructureSchema;
export declare var BlueGreenUpdatePolicy$: StaticStructureSchema;
export declare var CacheHitResult$: StaticStructureSchema;
export declare var CallbackStepMetadata$: StaticStructureSchema;
export declare var CandidateArtifactLocations$: StaticStructureSchema;
export declare var CandidateGenerationConfig$: StaticStructureSchema;
export declare var CandidateProperties$: StaticStructureSchema;
export declare var CanvasAppSettings$: StaticStructureSchema;
export declare var CapacityReservation$: StaticStructureSchema;
export declare var CapacitySize$: StaticStructureSchema;
export declare var CapacitySizeConfig$: StaticStructureSchema;
export declare var CaptureContentTypeHeader$: StaticStructureSchema;
export declare var CaptureOption$: StaticStructureSchema;
export declare var CategoricalParameter$: StaticStructureSchema;
export declare var CategoricalParameterRange$: StaticStructureSchema;
export declare var CategoricalParameterRangeSpecification$: StaticStructureSchema;
export declare var CfnCreateTemplateProvider$: StaticStructureSchema;
export declare var CfnStackCreateParameter$: StaticStructureSchema;
export declare var CfnStackDetail$: StaticStructureSchema;
export declare var CfnStackParameter$: StaticStructureSchema;
export declare var CfnStackUpdateParameter$: StaticStructureSchema;
export declare var CfnTemplateProviderDetail$: StaticStructureSchema;
export declare var CfnUpdateTemplateProvider$: StaticStructureSchema;
export declare var Channel$: StaticStructureSchema;
export declare var ChannelSpecification$: StaticStructureSchema;
export declare var CheckpointConfig$: StaticStructureSchema;
export declare var ClarifyCheckStepMetadata$: StaticStructureSchema;
export declare var ClarifyExplainerConfig$: StaticStructureSchema;
export declare var ClarifyInferenceConfig$: StaticStructureSchema;
export declare var ClarifyShapBaselineConfig$: StaticStructureSchema;
export declare var ClarifyShapConfig$: StaticStructureSchema;
export declare var ClarifyTextConfig$: StaticStructureSchema;
export declare var ClusterAutoScalingConfig$: StaticStructureSchema;
export declare var ClusterAutoScalingConfigOutput$: StaticStructureSchema;
export declare var ClusterCapacityRequirements$: StaticStructureSchema;
export declare var ClusterEbsVolumeConfig$: StaticStructureSchema;
export declare var ClusterEventDetail$: StaticStructureSchema;
export declare var ClusterEventSummary$: StaticStructureSchema;
export declare var ClusterFsxLustreConfig$: StaticStructureSchema;
export declare var ClusterFsxOpenZfsConfig$: StaticStructureSchema;
export declare var ClusterInstanceGroupDetails$: StaticStructureSchema;
export declare var ClusterInstanceGroupSpecification$: StaticStructureSchema;
export declare var ClusterInstancePlacement$: StaticStructureSchema;
export declare var ClusterInstanceStatusDetails$: StaticStructureSchema;
export declare var ClusterKubernetesConfig$: StaticStructureSchema;
export declare var ClusterKubernetesConfigDetails$: StaticStructureSchema;
export declare var ClusterKubernetesConfigNodeDetails$: StaticStructureSchema;
export declare var ClusterKubernetesTaint$: StaticStructureSchema;
export declare var ClusterLifeCycleConfig$: StaticStructureSchema;
export declare var ClusterMetadata$: StaticStructureSchema;
export declare var ClusterNodeDetails$: StaticStructureSchema;
export declare var ClusterNodeSummary$: StaticStructureSchema;
export declare var ClusterOnDemandOptions$: StaticStructureSchema;
export declare var ClusterOrchestrator$: StaticStructureSchema;
export declare var ClusterOrchestratorEksConfig$: StaticStructureSchema;
export declare var ClusterOrchestratorSlurmConfig$: StaticStructureSchema;
export declare var ClusterRestrictedInstanceGroupDetails$: StaticStructureSchema;
export declare var ClusterRestrictedInstanceGroupSpecification$: StaticStructureSchema;
export declare var ClusterSchedulerConfigSummary$: StaticStructureSchema;
export declare var ClusterSlurmConfig$: StaticStructureSchema;
export declare var ClusterSlurmConfigDetails$: StaticStructureSchema;
export declare var ClusterSpotOptions$: StaticStructureSchema;
export declare var ClusterSummary$: StaticStructureSchema;
export declare var ClusterTieredStorageConfig$: StaticStructureSchema;
export declare var CodeEditorAppImageConfig$: StaticStructureSchema;
export declare var CodeEditorAppSettings$: StaticStructureSchema;
export declare var CodeRepository$: StaticStructureSchema;
export declare var CodeRepositorySummary$: StaticStructureSchema;
export declare var CognitoConfig$: StaticStructureSchema;
export declare var CognitoMemberDefinition$: StaticStructureSchema;
export declare var CollectionConfiguration$: StaticStructureSchema;
export declare var CompilationJobSummary$: StaticStructureSchema;
export declare var ComputeQuotaConfig$: StaticStructureSchema;
export declare var ComputeQuotaResourceConfig$: StaticStructureSchema;
export declare var ComputeQuotaSummary$: StaticStructureSchema;
export declare var ComputeQuotaTarget$: StaticStructureSchema;
export declare var ConditionStepMetadata$: StaticStructureSchema;
export declare var ContainerConfig$: StaticStructureSchema;
export declare var ContainerDefinition$: StaticStructureSchema;
export declare var ContextSource$: StaticStructureSchema;
export declare var ContextSummary$: StaticStructureSchema;
export declare var ContinuousParameterRange$: StaticStructureSchema;
export declare var ContinuousParameterRangeSpecification$: StaticStructureSchema;
export declare var ConvergenceDetected$: StaticStructureSchema;
export declare var CreateActionRequest$: StaticStructureSchema;
export declare var CreateActionResponse$: StaticStructureSchema;
export declare var CreateAlgorithmInput$: StaticStructureSchema;
export declare var CreateAlgorithmOutput$: StaticStructureSchema;
export declare var CreateAppImageConfigRequest$: StaticStructureSchema;
export declare var CreateAppImageConfigResponse$: StaticStructureSchema;
export declare var CreateAppRequest$: StaticStructureSchema;
export declare var CreateAppResponse$: StaticStructureSchema;
export declare var CreateArtifactRequest$: StaticStructureSchema;
export declare var CreateArtifactResponse$: StaticStructureSchema;
export declare var CreateAutoMLJobRequest$: StaticStructureSchema;
export declare var CreateAutoMLJobResponse$: StaticStructureSchema;
export declare var CreateAutoMLJobV2Request$: StaticStructureSchema;
export declare var CreateAutoMLJobV2Response$: StaticStructureSchema;
export declare var CreateClusterRequest$: StaticStructureSchema;
export declare var CreateClusterResponse$: StaticStructureSchema;
export declare var CreateClusterSchedulerConfigRequest$: StaticStructureSchema;
export declare var CreateClusterSchedulerConfigResponse$: StaticStructureSchema;
export declare var CreateCodeRepositoryInput$: StaticStructureSchema;
export declare var CreateCodeRepositoryOutput$: StaticStructureSchema;
export declare var CreateCompilationJobRequest$: StaticStructureSchema;
export declare var CreateCompilationJobResponse$: StaticStructureSchema;
export declare var CreateComputeQuotaRequest$: StaticStructureSchema;
export declare var CreateComputeQuotaResponse$: StaticStructureSchema;
export declare var CreateContextRequest$: StaticStructureSchema;
export declare var CreateContextResponse$: StaticStructureSchema;
export declare var CreateDataQualityJobDefinitionRequest$: StaticStructureSchema;
export declare var CreateDataQualityJobDefinitionResponse$: StaticStructureSchema;
export declare var CreateDeviceFleetRequest$: StaticStructureSchema;
export declare var CreateDomainRequest$: StaticStructureSchema;
export declare var CreateDomainResponse$: StaticStructureSchema;
export declare var CreateEdgeDeploymentPlanRequest$: StaticStructureSchema;
export declare var CreateEdgeDeploymentPlanResponse$: StaticStructureSchema;
export declare var CreateEdgeDeploymentStageRequest$: StaticStructureSchema;
export declare var CreateEdgePackagingJobRequest$: StaticStructureSchema;
export declare var CreateEndpointConfigInput$: StaticStructureSchema;
export declare var CreateEndpointConfigOutput$: StaticStructureSchema;
export declare var CreateEndpointInput$: StaticStructureSchema;
export declare var CreateEndpointOutput$: StaticStructureSchema;
export declare var CreateExperimentRequest$: StaticStructureSchema;
export declare var CreateExperimentResponse$: StaticStructureSchema;
export declare var CreateFeatureGroupRequest$: StaticStructureSchema;
export declare var CreateFeatureGroupResponse$: StaticStructureSchema;
export declare var CreateFlowDefinitionRequest$: StaticStructureSchema;
export declare var CreateFlowDefinitionResponse$: StaticStructureSchema;
export declare var CreateHubContentPresignedUrlsRequest$: StaticStructureSchema;
export declare var CreateHubContentPresignedUrlsResponse$: StaticStructureSchema;
export declare var CreateHubContentReferenceRequest$: StaticStructureSchema;
export declare var CreateHubContentReferenceResponse$: StaticStructureSchema;
export declare var CreateHubRequest$: StaticStructureSchema;
export declare var CreateHubResponse$: StaticStructureSchema;
export declare var CreateHumanTaskUiRequest$: StaticStructureSchema;
export declare var CreateHumanTaskUiResponse$: StaticStructureSchema;
export declare var CreateHyperParameterTuningJobRequest$: StaticStructureSchema;
export declare var CreateHyperParameterTuningJobResponse$: StaticStructureSchema;
export declare var CreateImageRequest$: StaticStructureSchema;
export declare var CreateImageResponse$: StaticStructureSchema;
export declare var CreateImageVersionRequest$: StaticStructureSchema;
export declare var CreateImageVersionResponse$: StaticStructureSchema;
export declare var CreateInferenceComponentInput$: StaticStructureSchema;
export declare var CreateInferenceComponentOutput$: StaticStructureSchema;
export declare var CreateInferenceExperimentRequest$: StaticStructureSchema;
export declare var CreateInferenceExperimentResponse$: StaticStructureSchema;
export declare var CreateInferenceRecommendationsJobRequest$: StaticStructureSchema;
export declare var CreateInferenceRecommendationsJobResponse$: StaticStructureSchema;
export declare var CreateLabelingJobRequest$: StaticStructureSchema;
export declare var CreateLabelingJobResponse$: StaticStructureSchema;
export declare var CreateMlflowAppRequest$: StaticStructureSchema;
export declare var CreateMlflowAppResponse$: StaticStructureSchema;
export declare var CreateMlflowTrackingServerRequest$: StaticStructureSchema;
export declare var CreateMlflowTrackingServerResponse$: StaticStructureSchema;
export declare var CreateModelBiasJobDefinitionRequest$: StaticStructureSchema;
export declare var CreateModelBiasJobDefinitionResponse$: StaticStructureSchema;
export declare var CreateModelCardExportJobRequest$: StaticStructureSchema;
export declare var CreateModelCardExportJobResponse$: StaticStructureSchema;
export declare var CreateModelCardRequest$: StaticStructureSchema;
export declare var CreateModelCardResponse$: StaticStructureSchema;
export declare var CreateModelExplainabilityJobDefinitionRequest$: StaticStructureSchema;
export declare var CreateModelExplainabilityJobDefinitionResponse$: StaticStructureSchema;
export declare var CreateModelInput$: StaticStructureSchema;
export declare var CreateModelOutput$: StaticStructureSchema;
export declare var CreateModelPackageGroupInput$: StaticStructureSchema;
export declare var CreateModelPackageGroupOutput$: StaticStructureSchema;
export declare var CreateModelPackageInput$: StaticStructureSchema;
export declare var CreateModelPackageOutput$: StaticStructureSchema;
export declare var CreateModelQualityJobDefinitionRequest$: StaticStructureSchema;
export declare var CreateModelQualityJobDefinitionResponse$: StaticStructureSchema;
export declare var CreateMonitoringScheduleRequest$: StaticStructureSchema;
export declare var CreateMonitoringScheduleResponse$: StaticStructureSchema;
export declare var CreateNotebookInstanceInput$: StaticStructureSchema;
export declare var CreateNotebookInstanceLifecycleConfigInput$: StaticStructureSchema;
export declare var CreateNotebookInstanceLifecycleConfigOutput$: StaticStructureSchema;
export declare var CreateNotebookInstanceOutput$: StaticStructureSchema;
export declare var CreateOptimizationJobRequest$: StaticStructureSchema;
export declare var CreateOptimizationJobResponse$: StaticStructureSchema;
export declare var CreatePartnerAppPresignedUrlRequest$: StaticStructureSchema;
export declare var CreatePartnerAppPresignedUrlResponse$: StaticStructureSchema;
export declare var CreatePartnerAppRequest$: StaticStructureSchema;
export declare var CreatePartnerAppResponse$: StaticStructureSchema;
export declare var CreatePipelineRequest$: StaticStructureSchema;
export declare var CreatePipelineResponse$: StaticStructureSchema;
export declare var CreatePresignedDomainUrlRequest$: StaticStructureSchema;
export declare var CreatePresignedDomainUrlResponse$: StaticStructureSchema;
export declare var CreatePresignedMlflowAppUrlRequest$: StaticStructureSchema;
export declare var CreatePresignedMlflowAppUrlResponse$: StaticStructureSchema;
export declare var CreatePresignedMlflowTrackingServerUrlRequest$: StaticStructureSchema;
export declare var CreatePresignedMlflowTrackingServerUrlResponse$: StaticStructureSchema;
export declare var CreatePresignedNotebookInstanceUrlInput$: StaticStructureSchema;
export declare var CreatePresignedNotebookInstanceUrlOutput$: StaticStructureSchema;
export declare var CreateProcessingJobRequest$: StaticStructureSchema;
export declare var CreateProcessingJobResponse$: StaticStructureSchema;
export declare var CreateProjectInput$: StaticStructureSchema;
export declare var CreateProjectOutput$: StaticStructureSchema;
export declare var CreateSpaceRequest$: StaticStructureSchema;
export declare var CreateSpaceResponse$: StaticStructureSchema;
export declare var CreateStudioLifecycleConfigRequest$: StaticStructureSchema;
export declare var CreateStudioLifecycleConfigResponse$: StaticStructureSchema;
export declare var CreateTemplateProvider$: StaticStructureSchema;
export declare var CreateTrainingJobRequest$: StaticStructureSchema;
export declare var CreateTrainingJobResponse$: StaticStructureSchema;
export declare var CreateTrainingPlanRequest$: StaticStructureSchema;
export declare var CreateTrainingPlanResponse$: StaticStructureSchema;
export declare var CreateTransformJobRequest$: StaticStructureSchema;
export declare var CreateTransformJobResponse$: StaticStructureSchema;
export declare var CreateTrialComponentRequest$: StaticStructureSchema;
export declare var CreateTrialComponentResponse$: StaticStructureSchema;
export declare var CreateTrialRequest$: StaticStructureSchema;
export declare var CreateTrialResponse$: StaticStructureSchema;
export declare var CreateUserProfileRequest$: StaticStructureSchema;
export declare var CreateUserProfileResponse$: StaticStructureSchema;
export declare var CreateWorkforceRequest$: StaticStructureSchema;
export declare var CreateWorkforceResponse$: StaticStructureSchema;
export declare var CreateWorkteamRequest$: StaticStructureSchema;
export declare var CreateWorkteamResponse$: StaticStructureSchema;
export declare var CustomImage$: StaticStructureSchema;
export declare var CustomizedMetricSpecification$: StaticStructureSchema;
export declare var CustomPosixUserConfig$: StaticStructureSchema;
export declare var DataCaptureConfig$: StaticStructureSchema;
export declare var DataCaptureConfigSummary$: StaticStructureSchema;
export declare var DataCatalogConfig$: StaticStructureSchema;
export declare var DataProcessing$: StaticStructureSchema;
export declare var DataQualityAppSpecification$: StaticStructureSchema;
export declare var DataQualityBaselineConfig$: StaticStructureSchema;
export declare var DataQualityJobInput$: StaticStructureSchema;
export declare var DatasetDefinition$: StaticStructureSchema;
export declare var DatasetSource$: StaticStructureSchema;
export declare var DataSource$: StaticStructureSchema;
export declare var DebugHookConfig$: StaticStructureSchema;
export declare var DebugRuleConfiguration$: StaticStructureSchema;
export declare var DebugRuleEvaluationStatus$: StaticStructureSchema;
export declare var DefaultEbsStorageSettings$: StaticStructureSchema;
export declare var DefaultSpaceSettings$: StaticStructureSchema;
export declare var DefaultSpaceStorageSettings$: StaticStructureSchema;
export declare var DeleteActionRequest$: StaticStructureSchema;
export declare var DeleteActionResponse$: StaticStructureSchema;
export declare var DeleteAlgorithmInput$: StaticStructureSchema;
export declare var DeleteAppImageConfigRequest$: StaticStructureSchema;
export declare var DeleteAppRequest$: StaticStructureSchema;
export declare var DeleteArtifactRequest$: StaticStructureSchema;
export declare var DeleteArtifactResponse$: StaticStructureSchema;
export declare var DeleteAssociationRequest$: StaticStructureSchema;
export declare var DeleteAssociationResponse$: StaticStructureSchema;
export declare var DeleteClusterRequest$: StaticStructureSchema;
export declare var DeleteClusterResponse$: StaticStructureSchema;
export declare var DeleteClusterSchedulerConfigRequest$: StaticStructureSchema;
export declare var DeleteCodeRepositoryInput$: StaticStructureSchema;
export declare var DeleteCompilationJobRequest$: StaticStructureSchema;
export declare var DeleteComputeQuotaRequest$: StaticStructureSchema;
export declare var DeleteContextRequest$: StaticStructureSchema;
export declare var DeleteContextResponse$: StaticStructureSchema;
export declare var DeleteDataQualityJobDefinitionRequest$: StaticStructureSchema;
export declare var DeleteDeviceFleetRequest$: StaticStructureSchema;
export declare var DeleteDomainRequest$: StaticStructureSchema;
export declare var DeleteEdgeDeploymentPlanRequest$: StaticStructureSchema;
export declare var DeleteEdgeDeploymentStageRequest$: StaticStructureSchema;
export declare var DeleteEndpointConfigInput$: StaticStructureSchema;
export declare var DeleteEndpointInput$: StaticStructureSchema;
export declare var DeleteExperimentRequest$: StaticStructureSchema;
export declare var DeleteExperimentResponse$: StaticStructureSchema;
export declare var DeleteFeatureGroupRequest$: StaticStructureSchema;
export declare var DeleteFlowDefinitionRequest$: StaticStructureSchema;
export declare var DeleteFlowDefinitionResponse$: StaticStructureSchema;
export declare var DeleteHubContentReferenceRequest$: StaticStructureSchema;
export declare var DeleteHubContentRequest$: StaticStructureSchema;
export declare var DeleteHubRequest$: StaticStructureSchema;
export declare var DeleteHumanTaskUiRequest$: StaticStructureSchema;
export declare var DeleteHumanTaskUiResponse$: StaticStructureSchema;
export declare var DeleteHyperParameterTuningJobRequest$: StaticStructureSchema;
export declare var DeleteImageRequest$: StaticStructureSchema;
export declare var DeleteImageResponse$: StaticStructureSchema;
export declare var DeleteImageVersionRequest$: StaticStructureSchema;
export declare var DeleteImageVersionResponse$: StaticStructureSchema;
export declare var DeleteInferenceComponentInput$: StaticStructureSchema;
export declare var DeleteInferenceExperimentRequest$: StaticStructureSchema;
export declare var DeleteInferenceExperimentResponse$: StaticStructureSchema;
export declare var DeleteMlflowAppRequest$: StaticStructureSchema;
export declare var DeleteMlflowAppResponse$: StaticStructureSchema;
export declare var DeleteMlflowTrackingServerRequest$: StaticStructureSchema;
export declare var DeleteMlflowTrackingServerResponse$: StaticStructureSchema;
export declare var DeleteModelBiasJobDefinitionRequest$: StaticStructureSchema;
export declare var DeleteModelCardRequest$: StaticStructureSchema;
export declare var DeleteModelExplainabilityJobDefinitionRequest$: StaticStructureSchema;
export declare var DeleteModelInput$: StaticStructureSchema;
export declare var DeleteModelPackageGroupInput$: StaticStructureSchema;
export declare var DeleteModelPackageGroupPolicyInput$: StaticStructureSchema;
export declare var DeleteModelPackageInput$: StaticStructureSchema;
export declare var DeleteModelQualityJobDefinitionRequest$: StaticStructureSchema;
export declare var DeleteMonitoringScheduleRequest$: StaticStructureSchema;
export declare var DeleteNotebookInstanceInput$: StaticStructureSchema;
export declare var DeleteNotebookInstanceLifecycleConfigInput$: StaticStructureSchema;
export declare var DeleteOptimizationJobRequest$: StaticStructureSchema;
export declare var DeletePartnerAppRequest$: StaticStructureSchema;
export declare var DeletePartnerAppResponse$: StaticStructureSchema;
export declare var DeletePipelineRequest$: StaticStructureSchema;
export declare var DeletePipelineResponse$: StaticStructureSchema;
export declare var DeleteProcessingJobRequest$: StaticStructureSchema;
export declare var DeleteProjectInput$: StaticStructureSchema;
export declare var DeleteSpaceRequest$: StaticStructureSchema;
export declare var DeleteStudioLifecycleConfigRequest$: StaticStructureSchema;
export declare var DeleteTagsInput$: StaticStructureSchema;
export declare var DeleteTagsOutput$: StaticStructureSchema;
export declare var DeleteTrainingJobRequest$: StaticStructureSchema;
export declare var DeleteTrialComponentRequest$: StaticStructureSchema;
export declare var DeleteTrialComponentResponse$: StaticStructureSchema;
export declare var DeleteTrialRequest$: StaticStructureSchema;
export declare var DeleteTrialResponse$: StaticStructureSchema;
export declare var DeleteUserProfileRequest$: StaticStructureSchema;
export declare var DeleteWorkforceRequest$: StaticStructureSchema;
export declare var DeleteWorkforceResponse$: StaticStructureSchema;
export declare var DeleteWorkteamRequest$: StaticStructureSchema;
export declare var DeleteWorkteamResponse$: StaticStructureSchema;
export declare var DeployedImage$: StaticStructureSchema;
export declare var DeploymentConfig$: StaticStructureSchema;
export declare var DeploymentConfiguration$: StaticStructureSchema;
export declare var DeploymentRecommendation$: StaticStructureSchema;
export declare var DeploymentStage$: StaticStructureSchema;
export declare var DeploymentStageStatusSummary$: StaticStructureSchema;
export declare var DeregisterDevicesRequest$: StaticStructureSchema;
export declare var DerivedInformation$: StaticStructureSchema;
export declare var DescribeActionRequest$: StaticStructureSchema;
export declare var DescribeActionResponse$: StaticStructureSchema;
export declare var DescribeAlgorithmInput$: StaticStructureSchema;
export declare var DescribeAlgorithmOutput$: StaticStructureSchema;
export declare var DescribeAppImageConfigRequest$: StaticStructureSchema;
export declare var DescribeAppImageConfigResponse$: StaticStructureSchema;
export declare var DescribeAppRequest$: StaticStructureSchema;
export declare var DescribeAppResponse$: StaticStructureSchema;
export declare var DescribeArtifactRequest$: StaticStructureSchema;
export declare var DescribeArtifactResponse$: StaticStructureSchema;
export declare var DescribeAutoMLJobRequest$: StaticStructureSchema;
export declare var DescribeAutoMLJobResponse$: StaticStructureSchema;
export declare var DescribeAutoMLJobV2Request$: StaticStructureSchema;
export declare var DescribeAutoMLJobV2Response$: StaticStructureSchema;
export declare var DescribeClusterEventRequest$: StaticStructureSchema;
export declare var DescribeClusterEventResponse$: StaticStructureSchema;
export declare var DescribeClusterNodeRequest$: StaticStructureSchema;
export declare var DescribeClusterNodeResponse$: StaticStructureSchema;
export declare var DescribeClusterRequest$: StaticStructureSchema;
export declare var DescribeClusterResponse$: StaticStructureSchema;
export declare var DescribeClusterSchedulerConfigRequest$: StaticStructureSchema;
export declare var DescribeClusterSchedulerConfigResponse$: StaticStructureSchema;
export declare var DescribeCodeRepositoryInput$: StaticStructureSchema;
export declare var DescribeCodeRepositoryOutput$: StaticStructureSchema;
export declare var DescribeCompilationJobRequest$: StaticStructureSchema;
export declare var DescribeCompilationJobResponse$: StaticStructureSchema;
export declare var DescribeComputeQuotaRequest$: StaticStructureSchema;
export declare var DescribeComputeQuotaResponse$: StaticStructureSchema;
export declare var DescribeContextRequest$: StaticStructureSchema;
export declare var DescribeContextResponse$: StaticStructureSchema;
export declare var DescribeDataQualityJobDefinitionRequest$: StaticStructureSchema;
export declare var DescribeDataQualityJobDefinitionResponse$: StaticStructureSchema;
export declare var DescribeDeviceFleetRequest$: StaticStructureSchema;
export declare var DescribeDeviceFleetResponse$: StaticStructureSchema;
export declare var DescribeDeviceRequest$: StaticStructureSchema;
export declare var DescribeDeviceResponse$: StaticStructureSchema;
export declare var DescribeDomainRequest$: StaticStructureSchema;
export declare var DescribeDomainResponse$: StaticStructureSchema;
export declare var DescribeEdgeDeploymentPlanRequest$: StaticStructureSchema;
export declare var DescribeEdgeDeploymentPlanResponse$: StaticStructureSchema;
export declare var DescribeEdgePackagingJobRequest$: StaticStructureSchema;
export declare var DescribeEdgePackagingJobResponse$: StaticStructureSchema;
export declare var DescribeEndpointConfigInput$: StaticStructureSchema;
export declare var DescribeEndpointConfigOutput$: StaticStructureSchema;
export declare var DescribeEndpointInput$: StaticStructureSchema;
export declare var DescribeEndpointOutput$: StaticStructureSchema;
export declare var DescribeExperimentRequest$: StaticStructureSchema;
export declare var DescribeExperimentResponse$: StaticStructureSchema;
export declare var DescribeFeatureGroupRequest$: StaticStructureSchema;
export declare var DescribeFeatureGroupResponse$: StaticStructureSchema;
export declare var DescribeFeatureMetadataRequest$: StaticStructureSchema;
export declare var DescribeFeatureMetadataResponse$: StaticStructureSchema;
export declare var DescribeFlowDefinitionRequest$: StaticStructureSchema;
export declare var DescribeFlowDefinitionResponse$: StaticStructureSchema;
export declare var DescribeHubContentRequest$: StaticStructureSchema;
export declare var DescribeHubContentResponse$: StaticStructureSchema;
export declare var DescribeHubRequest$: StaticStructureSchema;
export declare var DescribeHubResponse$: StaticStructureSchema;
export declare var DescribeHumanTaskUiRequest$: StaticStructureSchema;
export declare var DescribeHumanTaskUiResponse$: StaticStructureSchema;
export declare var DescribeHyperParameterTuningJobRequest$: StaticStructureSchema;
export declare var DescribeHyperParameterTuningJobResponse$: StaticStructureSchema;
export declare var DescribeImageRequest$: StaticStructureSchema;
export declare var DescribeImageResponse$: StaticStructureSchema;
export declare var DescribeImageVersionRequest$: StaticStructureSchema;
export declare var DescribeImageVersionResponse$: StaticStructureSchema;
export declare var DescribeInferenceComponentInput$: StaticStructureSchema;
export declare var DescribeInferenceComponentOutput$: StaticStructureSchema;
export declare var DescribeInferenceExperimentRequest$: StaticStructureSchema;
export declare var DescribeInferenceExperimentResponse$: StaticStructureSchema;
export declare var DescribeInferenceRecommendationsJobRequest$: StaticStructureSchema;
export declare var DescribeInferenceRecommendationsJobResponse$: StaticStructureSchema;
export declare var DescribeLabelingJobRequest$: StaticStructureSchema;
export declare var DescribeLabelingJobResponse$: StaticStructureSchema;
export declare var DescribeLineageGroupRequest$: StaticStructureSchema;
export declare var DescribeLineageGroupResponse$: StaticStructureSchema;
export declare var DescribeMlflowAppRequest$: StaticStructureSchema;
export declare var DescribeMlflowAppResponse$: StaticStructureSchema;
export declare var DescribeMlflowTrackingServerRequest$: StaticStructureSchema;
export declare var DescribeMlflowTrackingServerResponse$: StaticStructureSchema;
export declare var DescribeModelBiasJobDefinitionRequest$: StaticStructureSchema;
export declare var DescribeModelBiasJobDefinitionResponse$: StaticStructureSchema;
export declare var DescribeModelCardExportJobRequest$: StaticStructureSchema;
export declare var DescribeModelCardExportJobResponse$: StaticStructureSchema;
export declare var DescribeModelCardRequest$: StaticStructureSchema;
export declare var DescribeModelCardResponse$: StaticStructureSchema;
export declare var DescribeModelExplainabilityJobDefinitionRequest$: StaticStructureSchema;
export declare var DescribeModelExplainabilityJobDefinitionResponse$: StaticStructureSchema;
export declare var DescribeModelInput$: StaticStructureSchema;
export declare var DescribeModelOutput$: StaticStructureSchema;
export declare var DescribeModelPackageGroupInput$: StaticStructureSchema;
export declare var DescribeModelPackageGroupOutput$: StaticStructureSchema;
export declare var DescribeModelPackageInput$: StaticStructureSchema;
export declare var DescribeModelPackageOutput$: StaticStructureSchema;
export declare var DescribeModelQualityJobDefinitionRequest$: StaticStructureSchema;
export declare var DescribeModelQualityJobDefinitionResponse$: StaticStructureSchema;
export declare var DescribeMonitoringScheduleRequest$: StaticStructureSchema;
export declare var DescribeMonitoringScheduleResponse$: StaticStructureSchema;
export declare var DescribeNotebookInstanceInput$: StaticStructureSchema;
export declare var DescribeNotebookInstanceLifecycleConfigInput$: StaticStructureSchema;
export declare var DescribeNotebookInstanceLifecycleConfigOutput$: StaticStructureSchema;
export declare var DescribeNotebookInstanceOutput$: StaticStructureSchema;
export declare var DescribeOptimizationJobRequest$: StaticStructureSchema;
export declare var DescribeOptimizationJobResponse$: StaticStructureSchema;
export declare var DescribePartnerAppRequest$: StaticStructureSchema;
export declare var DescribePartnerAppResponse$: StaticStructureSchema;
export declare var DescribePipelineDefinitionForExecutionRequest$: StaticStructureSchema;
export declare var DescribePipelineDefinitionForExecutionResponse$: StaticStructureSchema;
export declare var DescribePipelineExecutionRequest$: StaticStructureSchema;
export declare var DescribePipelineExecutionResponse$: StaticStructureSchema;
export declare var DescribePipelineRequest$: StaticStructureSchema;
export declare var DescribePipelineResponse$: StaticStructureSchema;
export declare var DescribeProcessingJobRequest$: StaticStructureSchema;
export declare var DescribeProcessingJobResponse$: StaticStructureSchema;
export declare var DescribeProjectInput$: StaticStructureSchema;
export declare var DescribeProjectOutput$: StaticStructureSchema;
export declare var DescribeReservedCapacityRequest$: StaticStructureSchema;
export declare var DescribeReservedCapacityResponse$: StaticStructureSchema;
export declare var DescribeSpaceRequest$: StaticStructureSchema;
export declare var DescribeSpaceResponse$: StaticStructureSchema;
export declare var DescribeStudioLifecycleConfigRequest$: StaticStructureSchema;
export declare var DescribeStudioLifecycleConfigResponse$: StaticStructureSchema;
export declare var DescribeSubscribedWorkteamRequest$: StaticStructureSchema;
export declare var DescribeSubscribedWorkteamResponse$: StaticStructureSchema;
export declare var DescribeTrainingJobRequest$: StaticStructureSchema;
export declare var DescribeTrainingJobResponse$: StaticStructureSchema;
export declare var DescribeTrainingPlanRequest$: StaticStructureSchema;
export declare var DescribeTrainingPlanResponse$: StaticStructureSchema;
export declare var DescribeTransformJobRequest$: StaticStructureSchema;
export declare var DescribeTransformJobResponse$: StaticStructureSchema;
export declare var DescribeTrialComponentRequest$: StaticStructureSchema;
export declare var DescribeTrialComponentResponse$: StaticStructureSchema;
export declare var DescribeTrialRequest$: StaticStructureSchema;
export declare var DescribeTrialResponse$: StaticStructureSchema;
export declare var DescribeUserProfileRequest$: StaticStructureSchema;
export declare var DescribeUserProfileResponse$: StaticStructureSchema;
export declare var DescribeWorkforceRequest$: StaticStructureSchema;
export declare var DescribeWorkforceResponse$: StaticStructureSchema;
export declare var DescribeWorkteamRequest$: StaticStructureSchema;
export declare var DescribeWorkteamResponse$: StaticStructureSchema;
export declare var DesiredWeightAndCapacity$: StaticStructureSchema;
export declare var DetachClusterNodeVolumeRequest$: StaticStructureSchema;
export declare var DetachClusterNodeVolumeResponse$: StaticStructureSchema;
export declare var Device$: StaticStructureSchema;
export declare var DeviceDeploymentSummary$: StaticStructureSchema;
export declare var DeviceFleetSummary$: StaticStructureSchema;
export declare var DeviceSelectionConfig$: StaticStructureSchema;
export declare var DeviceStats$: StaticStructureSchema;
export declare var DeviceSummary$: StaticStructureSchema;
export declare var DirectDeploySettings$: StaticStructureSchema;
export declare var DisableSagemakerServicecatalogPortfolioInput$: StaticStructureSchema;
export declare var DisableSagemakerServicecatalogPortfolioOutput$: StaticStructureSchema;
export declare var DisassociateTrialComponentRequest$: StaticStructureSchema;
export declare var DisassociateTrialComponentResponse$: StaticStructureSchema;
export declare var DockerSettings$: StaticStructureSchema;
export declare var DomainDetails$: StaticStructureSchema;
export declare var DomainSettings$: StaticStructureSchema;
export declare var DomainSettingsForUpdate$: StaticStructureSchema;
export declare var DriftCheckBaselines$: StaticStructureSchema;
export declare var DriftCheckBias$: StaticStructureSchema;
export declare var DriftCheckExplainability$: StaticStructureSchema;
export declare var DriftCheckModelDataQuality$: StaticStructureSchema;
export declare var DriftCheckModelQuality$: StaticStructureSchema;
export declare var DynamicScalingConfiguration$: StaticStructureSchema;
export declare var EbsStorageSettings$: StaticStructureSchema;
export declare var Ec2CapacityReservation$: StaticStructureSchema;
export declare var Edge$: StaticStructureSchema;
export declare var EdgeDeploymentConfig$: StaticStructureSchema;
export declare var EdgeDeploymentModelConfig$: StaticStructureSchema;
export declare var EdgeDeploymentPlanSummary$: StaticStructureSchema;
export declare var EdgeDeploymentStatus$: StaticStructureSchema;
export declare var EdgeModel$: StaticStructureSchema;
export declare var EdgeModelStat$: StaticStructureSchema;
export declare var EdgeModelSummary$: StaticStructureSchema;
export declare var EdgeOutputConfig$: StaticStructureSchema;
export declare var EdgePackagingJobSummary$: StaticStructureSchema;
export declare var EdgePresetDeploymentOutput$: StaticStructureSchema;
export declare var EFSFileSystem$: StaticStructureSchema;
export declare var EFSFileSystemConfig$: StaticStructureSchema;
export declare var EmrServerlessComputeConfig$: StaticStructureSchema;
export declare var EmrServerlessSettings$: StaticStructureSchema;
export declare var EmrSettings$: StaticStructureSchema;
export declare var EMRStepMetadata$: StaticStructureSchema;
export declare var EnableSagemakerServicecatalogPortfolioInput$: StaticStructureSchema;
export declare var EnableSagemakerServicecatalogPortfolioOutput$: StaticStructureSchema;
export declare var Endpoint$: StaticStructureSchema;
export declare var EndpointConfigStepMetadata$: StaticStructureSchema;
export declare var EndpointConfigSummary$: StaticStructureSchema;
export declare var EndpointInfo$: StaticStructureSchema;
export declare var EndpointInput$: StaticStructureSchema;
export declare var EndpointInputConfiguration$: StaticStructureSchema;
export declare var EndpointMetadata$: StaticStructureSchema;
export declare var EndpointOutputConfiguration$: StaticStructureSchema;
export declare var EndpointPerformance$: StaticStructureSchema;
export declare var EndpointStepMetadata$: StaticStructureSchema;
export declare var EndpointSummary$: StaticStructureSchema;
export declare var EnvironmentConfig$: StaticStructureSchema;
export declare var EnvironmentConfigDetails$: StaticStructureSchema;
export declare var EnvironmentParameter$: StaticStructureSchema;
export declare var EnvironmentParameterRanges$: StaticStructureSchema;
export declare var ErrorInfo$: StaticStructureSchema;
export declare var EventDetails$: StaticStructureSchema;
export declare var Experiment$: StaticStructureSchema;
export declare var ExperimentConfig$: StaticStructureSchema;
export declare var ExperimentSource$: StaticStructureSchema;
export declare var ExperimentSummary$: StaticStructureSchema;
export declare var Explainability$: StaticStructureSchema;
export declare var ExplainerConfig$: StaticStructureSchema;
export declare var FailStepMetadata$: StaticStructureSchema;
export declare var FeatureDefinition$: StaticStructureSchema;
export declare var FeatureGroup$: StaticStructureSchema;
export declare var FeatureGroupSummary$: StaticStructureSchema;
export declare var FeatureMetadata$: StaticStructureSchema;
export declare var FeatureParameter$: StaticStructureSchema;
export declare var FileSource$: StaticStructureSchema;
export declare var FileSystemConfig$: StaticStructureSchema;
export declare var FileSystemDataSource$: StaticStructureSchema;
export declare var Filter$: StaticStructureSchema;
export declare var FinalAutoMLJobObjectiveMetric$: StaticStructureSchema;
export declare var FinalHyperParameterTuningJobObjectiveMetric$: StaticStructureSchema;
export declare var FlowDefinitionOutputConfig$: StaticStructureSchema;
export declare var FlowDefinitionSummary$: StaticStructureSchema;
export declare var FSxLustreConfig$: StaticStructureSchema;
export declare var FSxLustreFileSystem$: StaticStructureSchema;
export declare var FSxLustreFileSystemConfig$: StaticStructureSchema;
export declare var GenerativeAiSettings$: StaticStructureSchema;
export declare var GetDeviceFleetReportRequest$: StaticStructureSchema;
export declare var GetDeviceFleetReportResponse$: StaticStructureSchema;
export declare var GetLineageGroupPolicyRequest$: StaticStructureSchema;
export declare var GetLineageGroupPolicyResponse$: StaticStructureSchema;
export declare var GetModelPackageGroupPolicyInput$: StaticStructureSchema;
export declare var GetModelPackageGroupPolicyOutput$: StaticStructureSchema;
export declare var GetSagemakerServicecatalogPortfolioStatusInput$: StaticStructureSchema;
export declare var GetSagemakerServicecatalogPortfolioStatusOutput$: StaticStructureSchema;
export declare var GetScalingConfigurationRecommendationRequest$: StaticStructureSchema;
export declare var GetScalingConfigurationRecommendationResponse$: StaticStructureSchema;
export declare var GetSearchSuggestionsRequest$: StaticStructureSchema;
export declare var GetSearchSuggestionsResponse$: StaticStructureSchema;
export declare var GitConfig$: StaticStructureSchema;
export declare var GitConfigForUpdate$: StaticStructureSchema;
export declare var HiddenSageMakerImage$: StaticStructureSchema;
export declare var HolidayConfigAttributes$: StaticStructureSchema;
export declare var HubAccessConfig$: StaticStructureSchema;
export declare var HubContentDependency$: StaticStructureSchema;
export declare var HubContentInfo$: StaticStructureSchema;
export declare var HubInfo$: StaticStructureSchema;
export declare var HubS3StorageConfig$: StaticStructureSchema;
export declare var HumanLoopActivationConditionsConfig$: StaticStructureSchema;
export declare var HumanLoopActivationConfig$: StaticStructureSchema;
export declare var HumanLoopConfig$: StaticStructureSchema;
export declare var HumanLoopRequestSource$: StaticStructureSchema;
export declare var HumanTaskConfig$: StaticStructureSchema;
export declare var HumanTaskUiSummary$: StaticStructureSchema;
export declare var HyperbandStrategyConfig$: StaticStructureSchema;
export declare var HyperParameterAlgorithmSpecification$: StaticStructureSchema;
export declare var HyperParameterSpecification$: StaticStructureSchema;
export declare var HyperParameterTrainingJobDefinition$: StaticStructureSchema;
export declare var HyperParameterTrainingJobSummary$: StaticStructureSchema;
export declare var HyperParameterTuningInstanceConfig$: StaticStructureSchema;
export declare var HyperParameterTuningJobCompletionDetails$: StaticStructureSchema;
export declare var HyperParameterTuningJobConfig$: StaticStructureSchema;
export declare var HyperParameterTuningJobConsumedResources$: StaticStructureSchema;
export declare var HyperParameterTuningJobObjective$: StaticStructureSchema;
export declare var HyperParameterTuningJobSearchEntity$: StaticStructureSchema;
export declare var HyperParameterTuningJobStrategyConfig$: StaticStructureSchema;
export declare var HyperParameterTuningJobSummary$: StaticStructureSchema;
export declare var HyperParameterTuningJobWarmStartConfig$: StaticStructureSchema;
export declare var HyperParameterTuningResourceConfig$: StaticStructureSchema;
export declare var IamIdentity$: StaticStructureSchema;
export declare var IamPolicyConstraints$: StaticStructureSchema;
export declare var IdentityProviderOAuthSetting$: StaticStructureSchema;
export declare var IdleSettings$: StaticStructureSchema;
export declare var Image$: StaticStructureSchema;
export declare var ImageClassificationJobConfig$: StaticStructureSchema;
export declare var ImageConfig$: StaticStructureSchema;
export declare var ImageVersion$: StaticStructureSchema;
export declare var ImportHubContentRequest$: StaticStructureSchema;
export declare var ImportHubContentResponse$: StaticStructureSchema;
export declare var InferenceComponentCapacitySize$: StaticStructureSchema;
export declare var InferenceComponentComputeResourceRequirements$: StaticStructureSchema;
export declare var InferenceComponentContainerSpecification$: StaticStructureSchema;
export declare var InferenceComponentContainerSpecificationSummary$: StaticStructureSchema;
export declare var InferenceComponentDataCacheConfig$: StaticStructureSchema;
export declare var InferenceComponentDataCacheConfigSummary$: StaticStructureSchema;
export declare var InferenceComponentDeploymentConfig$: StaticStructureSchema;
export declare var InferenceComponentMetadata$: StaticStructureSchema;
export declare var InferenceComponentRollingUpdatePolicy$: StaticStructureSchema;
export declare var InferenceComponentRuntimeConfig$: StaticStructureSchema;
export declare var InferenceComponentRuntimeConfigSummary$: StaticStructureSchema;
export declare var InferenceComponentSpecification$: StaticStructureSchema;
export declare var InferenceComponentSpecificationSummary$: StaticStructureSchema;
export declare var InferenceComponentStartupParameters$: StaticStructureSchema;
export declare var InferenceComponentSummary$: StaticStructureSchema;
export declare var InferenceExecutionConfig$: StaticStructureSchema;
export declare var InferenceExperimentDataStorageConfig$: StaticStructureSchema;
export declare var InferenceExperimentSchedule$: StaticStructureSchema;
export declare var InferenceExperimentSummary$: StaticStructureSchema;
export declare var InferenceHubAccessConfig$: StaticStructureSchema;
export declare var InferenceMetrics$: StaticStructureSchema;
export declare var InferenceRecommendation$: StaticStructureSchema;
export declare var InferenceRecommendationsJob$: StaticStructureSchema;
export declare var InferenceRecommendationsJobStep$: StaticStructureSchema;
export declare var InferenceSpecification$: StaticStructureSchema;
export declare var InfraCheckConfig$: StaticStructureSchema;
export declare var InputConfig$: StaticStructureSchema;
export declare var InstanceGroup$: StaticStructureSchema;
export declare var InstanceGroupMetadata$: StaticStructureSchema;
export declare var InstanceGroupScalingMetadata$: StaticStructureSchema;
export declare var InstanceMetadata$: StaticStructureSchema;
export declare var InstanceMetadataServiceConfiguration$: StaticStructureSchema;
export declare var InstancePlacementConfig$: StaticStructureSchema;
export declare var IntegerParameterRange$: StaticStructureSchema;
export declare var IntegerParameterRangeSpecification$: StaticStructureSchema;
export declare var JupyterLabAppImageConfig$: StaticStructureSchema;
export declare var JupyterLabAppSettings$: StaticStructureSchema;
export declare var JupyterServerAppSettings$: StaticStructureSchema;
export declare var KendraSettings$: StaticStructureSchema;
export declare var KernelGatewayAppSettings$: StaticStructureSchema;
export declare var KernelGatewayImageConfig$: StaticStructureSchema;
export declare var KernelSpec$: StaticStructureSchema;
export declare var LabelCounters$: StaticStructureSchema;
export declare var LabelCountersForWorkteam$: StaticStructureSchema;
export declare var LabelingJobAlgorithmsConfig$: StaticStructureSchema;
export declare var LabelingJobDataAttributes$: StaticStructureSchema;
export declare var LabelingJobDataSource$: StaticStructureSchema;
export declare var LabelingJobForWorkteamSummary$: StaticStructureSchema;
export declare var LabelingJobInputConfig$: StaticStructureSchema;
export declare var LabelingJobOutput$: StaticStructureSchema;
export declare var LabelingJobOutputConfig$: StaticStructureSchema;
export declare var LabelingJobResourceConfig$: StaticStructureSchema;
export declare var LabelingJobS3DataSource$: StaticStructureSchema;
export declare var LabelingJobSnsDataSource$: StaticStructureSchema;
export declare var LabelingJobStoppingConditions$: StaticStructureSchema;
export declare var LabelingJobSummary$: StaticStructureSchema;
export declare var LambdaStepMetadata$: StaticStructureSchema;
export declare var LastUpdateStatus$: StaticStructureSchema;
export declare var LineageGroupSummary$: StaticStructureSchema;
export declare var LineageMetadata$: StaticStructureSchema;
export declare var ListActionsRequest$: StaticStructureSchema;
export declare var ListActionsResponse$: StaticStructureSchema;
export declare var ListAlgorithmsInput$: StaticStructureSchema;
export declare var ListAlgorithmsOutput$: StaticStructureSchema;
export declare var ListAliasesRequest$: StaticStructureSchema;
export declare var ListAliasesResponse$: StaticStructureSchema;
export declare var ListAppImageConfigsRequest$: StaticStructureSchema;
export declare var ListAppImageConfigsResponse$: StaticStructureSchema;
export declare var ListAppsRequest$: StaticStructureSchema;
export declare var ListAppsResponse$: StaticStructureSchema;
export declare var ListArtifactsRequest$: StaticStructureSchema;
export declare var ListArtifactsResponse$: StaticStructureSchema;
export declare var ListAssociationsRequest$: StaticStructureSchema;
export declare var ListAssociationsResponse$: StaticStructureSchema;
export declare var ListAutoMLJobsRequest$: StaticStructureSchema;
export declare var ListAutoMLJobsResponse$: StaticStructureSchema;
export declare var ListCandidatesForAutoMLJobRequest$: StaticStructureSchema;
export declare var ListCandidatesForAutoMLJobResponse$: StaticStructureSchema;
export declare var ListClusterEventsRequest$: StaticStructureSchema;
export declare var ListClusterEventsResponse$: StaticStructureSchema;
export declare var ListClusterNodesRequest$: StaticStructureSchema;
export declare var ListClusterNodesResponse$: StaticStructureSchema;
export declare var ListClusterSchedulerConfigsRequest$: StaticStructureSchema;
export declare var ListClusterSchedulerConfigsResponse$: StaticStructureSchema;
export declare var ListClustersRequest$: StaticStructureSchema;
export declare var ListClustersResponse$: StaticStructureSchema;
export declare var ListCodeRepositoriesInput$: StaticStructureSchema;
export declare var ListCodeRepositoriesOutput$: StaticStructureSchema;
export declare var ListCompilationJobsRequest$: StaticStructureSchema;
export declare var ListCompilationJobsResponse$: StaticStructureSchema;
export declare var ListComputeQuotasRequest$: StaticStructureSchema;
export declare var ListComputeQuotasResponse$: StaticStructureSchema;
export declare var ListContextsRequest$: StaticStructureSchema;
export declare var ListContextsResponse$: StaticStructureSchema;
export declare var ListDataQualityJobDefinitionsRequest$: StaticStructureSchema;
export declare var ListDataQualityJobDefinitionsResponse$: StaticStructureSchema;
export declare var ListDeviceFleetsRequest$: StaticStructureSchema;
export declare var ListDeviceFleetsResponse$: StaticStructureSchema;
export declare var ListDevicesRequest$: StaticStructureSchema;
export declare var ListDevicesResponse$: StaticStructureSchema;
export declare var ListDomainsRequest$: StaticStructureSchema;
export declare var ListDomainsResponse$: StaticStructureSchema;
export declare var ListEdgeDeploymentPlansRequest$: StaticStructureSchema;
export declare var ListEdgeDeploymentPlansResponse$: StaticStructureSchema;
export declare var ListEdgePackagingJobsRequest$: StaticStructureSchema;
export declare var ListEdgePackagingJobsResponse$: StaticStructureSchema;
export declare var ListEndpointConfigsInput$: StaticStructureSchema;
export declare var ListEndpointConfigsOutput$: StaticStructureSchema;
export declare var ListEndpointsInput$: StaticStructureSchema;
export declare var ListEndpointsOutput$: StaticStructureSchema;
export declare var ListExperimentsRequest$: StaticStructureSchema;
export declare var ListExperimentsResponse$: StaticStructureSchema;
export declare var ListFeatureGroupsRequest$: StaticStructureSchema;
export declare var ListFeatureGroupsResponse$: StaticStructureSchema;
export declare var ListFlowDefinitionsRequest$: StaticStructureSchema;
export declare var ListFlowDefinitionsResponse$: StaticStructureSchema;
export declare var ListHubContentsRequest$: StaticStructureSchema;
export declare var ListHubContentsResponse$: StaticStructureSchema;
export declare var ListHubContentVersionsRequest$: StaticStructureSchema;
export declare var ListHubContentVersionsResponse$: StaticStructureSchema;
export declare var ListHubsRequest$: StaticStructureSchema;
export declare var ListHubsResponse$: StaticStructureSchema;
export declare var ListHumanTaskUisRequest$: StaticStructureSchema;
export declare var ListHumanTaskUisResponse$: StaticStructureSchema;
export declare var ListHyperParameterTuningJobsRequest$: StaticStructureSchema;
export declare var ListHyperParameterTuningJobsResponse$: StaticStructureSchema;
export declare var ListImagesRequest$: StaticStructureSchema;
export declare var ListImagesResponse$: StaticStructureSchema;
export declare var ListImageVersionsRequest$: StaticStructureSchema;
export declare var ListImageVersionsResponse$: StaticStructureSchema;
export declare var ListInferenceComponentsInput$: StaticStructureSchema;
export declare var ListInferenceComponentsOutput$: StaticStructureSchema;
export declare var ListInferenceExperimentsRequest$: StaticStructureSchema;
export declare var ListInferenceExperimentsResponse$: StaticStructureSchema;
export declare var ListInferenceRecommendationsJobsRequest$: StaticStructureSchema;
export declare var ListInferenceRecommendationsJobsResponse$: StaticStructureSchema;
export declare var ListInferenceRecommendationsJobStepsRequest$: StaticStructureSchema;
export declare var ListInferenceRecommendationsJobStepsResponse$: StaticStructureSchema;
export declare var ListLabelingJobsForWorkteamRequest$: StaticStructureSchema;
export declare var ListLabelingJobsForWorkteamResponse$: StaticStructureSchema;
export declare var ListLabelingJobsRequest$: StaticStructureSchema;
export declare var ListLabelingJobsResponse$: StaticStructureSchema;
export declare var ListLineageGroupsRequest$: StaticStructureSchema;
export declare var ListLineageGroupsResponse$: StaticStructureSchema;
export declare var ListMlflowAppsRequest$: StaticStructureSchema;
export declare var ListMlflowAppsResponse$: StaticStructureSchema;
export declare var ListMlflowTrackingServersRequest$: StaticStructureSchema;
export declare var ListMlflowTrackingServersResponse$: StaticStructureSchema;
export declare var ListModelBiasJobDefinitionsRequest$: StaticStructureSchema;
export declare var ListModelBiasJobDefinitionsResponse$: StaticStructureSchema;
export declare var ListModelCardExportJobsRequest$: StaticStructureSchema;
export declare var ListModelCardExportJobsResponse$: StaticStructureSchema;
export declare var ListModelCardsRequest$: StaticStructureSchema;
export declare var ListModelCardsResponse$: StaticStructureSchema;
export declare var ListModelCardVersionsRequest$: StaticStructureSchema;
export declare var ListModelCardVersionsResponse$: StaticStructureSchema;
export declare var ListModelExplainabilityJobDefinitionsRequest$: StaticStructureSchema;
export declare var ListModelExplainabilityJobDefinitionsResponse$: StaticStructureSchema;
export declare var ListModelMetadataRequest$: StaticStructureSchema;
export declare var ListModelMetadataResponse$: StaticStructureSchema;
export declare var ListModelPackageGroupsInput$: StaticStructureSchema;
export declare var ListModelPackageGroupsOutput$: StaticStructureSchema;
export declare var ListModelPackagesInput$: StaticStructureSchema;
export declare var ListModelPackagesOutput$: StaticStructureSchema;
export declare var ListModelQualityJobDefinitionsRequest$: StaticStructureSchema;
export declare var ListModelQualityJobDefinitionsResponse$: StaticStructureSchema;
export declare var ListModelsInput$: StaticStructureSchema;
export declare var ListModelsOutput$: StaticStructureSchema;
export declare var ListMonitoringAlertHistoryRequest$: StaticStructureSchema;
export declare var ListMonitoringAlertHistoryResponse$: StaticStructureSchema;
export declare var ListMonitoringAlertsRequest$: StaticStructureSchema;
export declare var ListMonitoringAlertsResponse$: StaticStructureSchema;
export declare var ListMonitoringExecutionsRequest$: StaticStructureSchema;
export declare var ListMonitoringExecutionsResponse$: StaticStructureSchema;
export declare var ListMonitoringSchedulesRequest$: StaticStructureSchema;
export declare var ListMonitoringSchedulesResponse$: StaticStructureSchema;
export declare var ListNotebookInstanceLifecycleConfigsInput$: StaticStructureSchema;
export declare var ListNotebookInstanceLifecycleConfigsOutput$: StaticStructureSchema;
export declare var ListNotebookInstancesInput$: StaticStructureSchema;
export declare var ListNotebookInstancesOutput$: StaticStructureSchema;
export declare var ListOptimizationJobsRequest$: StaticStructureSchema;
export declare var ListOptimizationJobsResponse$: StaticStructureSchema;
export declare var ListPartnerAppsRequest$: StaticStructureSchema;
export declare var ListPartnerAppsResponse$: StaticStructureSchema;
export declare var ListPipelineExecutionsRequest$: StaticStructureSchema;
export declare var ListPipelineExecutionsResponse$: StaticStructureSchema;
export declare var ListPipelineExecutionStepsRequest$: StaticStructureSchema;
export declare var ListPipelineExecutionStepsResponse$: StaticStructureSchema;
export declare var ListPipelineParametersForExecutionRequest$: StaticStructureSchema;
export declare var ListPipelineParametersForExecutionResponse$: StaticStructureSchema;
export declare var ListPipelinesRequest$: StaticStructureSchema;
export declare var ListPipelinesResponse$: StaticStructureSchema;
export declare var ListPipelineVersionsRequest$: StaticStructureSchema;
export declare var ListPipelineVersionsResponse$: StaticStructureSchema;
export declare var ListProcessingJobsRequest$: StaticStructureSchema;
export declare var ListProcessingJobsResponse$: StaticStructureSchema;
export declare var ListProjectsInput$: StaticStructureSchema;
export declare var ListProjectsOutput$: StaticStructureSchema;
export declare var ListResourceCatalogsRequest$: StaticStructureSchema;
export declare var ListResourceCatalogsResponse$: StaticStructureSchema;
export declare var ListSpacesRequest$: StaticStructureSchema;
export declare var ListSpacesResponse$: StaticStructureSchema;
export declare var ListStageDevicesRequest$: StaticStructureSchema;
export declare var ListStageDevicesResponse$: StaticStructureSchema;
export declare var ListStudioLifecycleConfigsRequest$: StaticStructureSchema;
export declare var ListStudioLifecycleConfigsResponse$: StaticStructureSchema;
export declare var ListSubscribedWorkteamsRequest$: StaticStructureSchema;
export declare var ListSubscribedWorkteamsResponse$: StaticStructureSchema;
export declare var ListTagsInput$: StaticStructureSchema;
export declare var ListTagsOutput$: StaticStructureSchema;
export declare var ListTrainingJobsForHyperParameterTuningJobRequest$: StaticStructureSchema;
export declare var ListTrainingJobsForHyperParameterTuningJobResponse$: StaticStructureSchema;
export declare var ListTrainingJobsRequest$: StaticStructureSchema;
export declare var ListTrainingJobsResponse$: StaticStructureSchema;
export declare var ListTrainingPlansRequest$: StaticStructureSchema;
export declare var ListTrainingPlansResponse$: StaticStructureSchema;
export declare var ListTransformJobsRequest$: StaticStructureSchema;
export declare var ListTransformJobsResponse$: StaticStructureSchema;
export declare var ListTrialComponentsRequest$: StaticStructureSchema;
export declare var ListTrialComponentsResponse$: StaticStructureSchema;
export declare var ListTrialsRequest$: StaticStructureSchema;
export declare var ListTrialsResponse$: StaticStructureSchema;
export declare var ListUltraServersByReservedCapacityRequest$: StaticStructureSchema;
export declare var ListUltraServersByReservedCapacityResponse$: StaticStructureSchema;
export declare var ListUserProfilesRequest$: StaticStructureSchema;
export declare var ListUserProfilesResponse$: StaticStructureSchema;
export declare var ListWorkforcesRequest$: StaticStructureSchema;
export declare var ListWorkforcesResponse$: StaticStructureSchema;
export declare var ListWorkteamsRequest$: StaticStructureSchema;
export declare var ListWorkteamsResponse$: StaticStructureSchema;
export declare var MemberDefinition$: StaticStructureSchema;
export declare var MetadataProperties$: StaticStructureSchema;
export declare var MetricData$: StaticStructureSchema;
export declare var MetricDatum$: StaticStructureSchema;
export declare var MetricDefinition$: StaticStructureSchema;
export declare var MetricsConfig$: StaticStructureSchema;
export declare var MetricsSource$: StaticStructureSchema;
export declare var MlflowAppSummary$: StaticStructureSchema;
export declare var MlflowConfig$: StaticStructureSchema;
export declare var MLflowConfiguration$: StaticStructureSchema;
export declare var MlflowDetails$: StaticStructureSchema;
export declare var Model$: StaticStructureSchema;
export declare var ModelAccessConfig$: StaticStructureSchema;
export declare var ModelArtifacts$: StaticStructureSchema;
export declare var ModelBiasAppSpecification$: StaticStructureSchema;
export declare var ModelBiasBaselineConfig$: StaticStructureSchema;
export declare var ModelBiasJobInput$: StaticStructureSchema;
export declare var ModelCard$: StaticStructureSchema;
export declare var ModelCardExportArtifacts$: StaticStructureSchema;
export declare var ModelCardExportJobSummary$: StaticStructureSchema;
export declare var ModelCardExportOutputConfig$: StaticStructureSchema;
export declare var ModelCardSecurityConfig$: StaticStructureSchema;
export declare var ModelCardSummary$: StaticStructureSchema;
export declare var ModelCardVersionSummary$: StaticStructureSchema;
export declare var ModelClientConfig$: StaticStructureSchema;
export declare var ModelCompilationConfig$: StaticStructureSchema;
export declare var ModelConfiguration$: StaticStructureSchema;
export declare var ModelDashboardEndpoint$: StaticStructureSchema;
export declare var ModelDashboardIndicatorAction$: StaticStructureSchema;
export declare var ModelDashboardModel$: StaticStructureSchema;
export declare var ModelDashboardModelCard$: StaticStructureSchema;
export declare var ModelDashboardMonitoringSchedule$: StaticStructureSchema;
export declare var ModelDataQuality$: StaticStructureSchema;
export declare var ModelDataSource$: StaticStructureSchema;
export declare var ModelDeployConfig$: StaticStructureSchema;
export declare var ModelDeployResult$: StaticStructureSchema;
export declare var ModelDigests$: StaticStructureSchema;
export declare var ModelExplainabilityAppSpecification$: StaticStructureSchema;
export declare var ModelExplainabilityBaselineConfig$: StaticStructureSchema;
export declare var ModelExplainabilityJobInput$: StaticStructureSchema;
export declare var ModelInfrastructureConfig$: StaticStructureSchema;
export declare var ModelInput$: StaticStructureSchema;
export declare var ModelLatencyThreshold$: StaticStructureSchema;
export declare var ModelLifeCycle$: StaticStructureSchema;
export declare var ModelMetadataFilter$: StaticStructureSchema;
export declare var ModelMetadataSearchExpression$: StaticStructureSchema;
export declare var ModelMetadataSummary$: StaticStructureSchema;
export declare var ModelMetrics$: StaticStructureSchema;
export declare var ModelPackage$: StaticStructureSchema;
export declare var ModelPackageConfig$: StaticStructureSchema;
export declare var ModelPackageContainerDefinition$: StaticStructureSchema;
export declare var ModelPackageGroup$: StaticStructureSchema;
export declare var ModelPackageGroupSummary$: StaticStructureSchema;
export declare var ModelPackageModelCard$: StaticStructureSchema;
export declare var ModelPackageSecurityConfig$: StaticStructureSchema;
export declare var ModelPackageStatusDetails$: StaticStructureSchema;
export declare var ModelPackageStatusItem$: StaticStructureSchema;
export declare var ModelPackageSummary$: StaticStructureSchema;
export declare var ModelPackageValidationProfile$: StaticStructureSchema;
export declare var ModelPackageValidationSpecification$: StaticStructureSchema;
export declare var ModelQuality$: StaticStructureSchema;
export declare var ModelQualityAppSpecification$: StaticStructureSchema;
export declare var ModelQualityBaselineConfig$: StaticStructureSchema;
export declare var ModelQualityJobInput$: StaticStructureSchema;
export declare var ModelQuantizationConfig$: StaticStructureSchema;
export declare var ModelRegisterSettings$: StaticStructureSchema;
export declare var ModelShardingConfig$: StaticStructureSchema;
export declare var ModelSpeculativeDecodingConfig$: StaticStructureSchema;
export declare var ModelSpeculativeDecodingTrainingDataSource$: StaticStructureSchema;
export declare var ModelStepMetadata$: StaticStructureSchema;
export declare var ModelSummary$: StaticStructureSchema;
export declare var ModelVariantConfig$: StaticStructureSchema;
export declare var ModelVariantConfigSummary$: StaticStructureSchema;
export declare var MonitoringAlertActions$: StaticStructureSchema;
export declare var MonitoringAlertHistorySummary$: StaticStructureSchema;
export declare var MonitoringAlertSummary$: StaticStructureSchema;
export declare var MonitoringAppSpecification$: StaticStructureSchema;
export declare var MonitoringBaselineConfig$: StaticStructureSchema;
export declare var MonitoringClusterConfig$: StaticStructureSchema;
export declare var MonitoringConstraintsResource$: StaticStructureSchema;
export declare var MonitoringCsvDatasetFormat$: StaticStructureSchema;
export declare var MonitoringDatasetFormat$: StaticStructureSchema;
export declare var MonitoringExecutionSummary$: StaticStructureSchema;
export declare var MonitoringGroundTruthS3Input$: StaticStructureSchema;
export declare var MonitoringInput$: StaticStructureSchema;
export declare var MonitoringJobDefinition$: StaticStructureSchema;
export declare var MonitoringJobDefinitionSummary$: StaticStructureSchema;
export declare var MonitoringJsonDatasetFormat$: StaticStructureSchema;
export declare var MonitoringNetworkConfig$: StaticStructureSchema;
export declare var MonitoringOutput$: StaticStructureSchema;
export declare var MonitoringOutputConfig$: StaticStructureSchema;
export declare var MonitoringParquetDatasetFormat$: StaticStructureSchema;
export declare var MonitoringResources$: StaticStructureSchema;
export declare var MonitoringS3Output$: StaticStructureSchema;
export declare var MonitoringSchedule$: StaticStructureSchema;
export declare var MonitoringScheduleConfig$: StaticStructureSchema;
export declare var MonitoringScheduleSummary$: StaticStructureSchema;
export declare var MonitoringStatisticsResource$: StaticStructureSchema;
export declare var MonitoringStoppingCondition$: StaticStructureSchema;
export declare var MultiModelConfig$: StaticStructureSchema;
export declare var NeoVpcConfig$: StaticStructureSchema;
export declare var NestedFilters$: StaticStructureSchema;
export declare var NetworkConfig$: StaticStructureSchema;
export declare var NodeAdditionResult$: StaticStructureSchema;
export declare var NotebookInstanceLifecycleConfigSummary$: StaticStructureSchema;
export declare var NotebookInstanceLifecycleHook$: StaticStructureSchema;
export declare var NotebookInstanceSummary$: StaticStructureSchema;
export declare var NotificationConfiguration$: StaticStructureSchema;
export declare var ObjectiveStatusCounters$: StaticStructureSchema;
export declare var OfflineStoreConfig$: StaticStructureSchema;
export declare var OfflineStoreStatus$: StaticStructureSchema;
export declare var OidcConfig$: StaticStructureSchema;
export declare var OidcConfigForResponse$: StaticStructureSchema;
export declare var OidcMemberDefinition$: StaticStructureSchema;
export declare var OnlineStoreConfig$: StaticStructureSchema;
export declare var OnlineStoreConfigUpdate$: StaticStructureSchema;
export declare var OnlineStoreSecurityConfig$: StaticStructureSchema;
export declare var OptimizationJobModelSource$: StaticStructureSchema;
export declare var OptimizationJobModelSourceS3$: StaticStructureSchema;
export declare var OptimizationJobOutputConfig$: StaticStructureSchema;
export declare var OptimizationJobSummary$: StaticStructureSchema;
export declare var OptimizationModelAccessConfig$: StaticStructureSchema;
export declare var OptimizationOutput$: StaticStructureSchema;
export declare var OptimizationSageMakerModel$: StaticStructureSchema;
export declare var OptimizationVpcConfig$: StaticStructureSchema;
export declare var OutputConfig$: StaticStructureSchema;
export declare var OutputDataConfig$: StaticStructureSchema;
export declare var OutputParameter$: StaticStructureSchema;
export declare var OwnershipSettings$: StaticStructureSchema;
export declare var OwnershipSettingsSummary$: StaticStructureSchema;
export declare var ParallelismConfiguration$: StaticStructureSchema;
export declare var Parameter$: StaticStructureSchema;
export declare var ParameterRange$: StaticStructureSchema;
export declare var ParameterRanges$: StaticStructureSchema;
export declare var Parent$: StaticStructureSchema;
export declare var ParentHyperParameterTuningJob$: StaticStructureSchema;
export declare var PartnerAppConfig$: StaticStructureSchema;
export declare var PartnerAppMaintenanceConfig$: StaticStructureSchema;
export declare var PartnerAppSummary$: StaticStructureSchema;
export declare var PendingDeploymentSummary$: StaticStructureSchema;
export declare var PendingProductionVariantSummary$: StaticStructureSchema;
export declare var Phase$: StaticStructureSchema;
export declare var Pipeline$: StaticStructureSchema;
export declare var PipelineDefinitionS3Location$: StaticStructureSchema;
export declare var PipelineExecution$: StaticStructureSchema;
export declare var PipelineExecutionStep$: StaticStructureSchema;
export declare var PipelineExecutionStepMetadata$: StaticStructureSchema;
export declare var PipelineExecutionSummary$: StaticStructureSchema;
export declare var PipelineExperimentConfig$: StaticStructureSchema;
export declare var PipelineSummary$: StaticStructureSchema;
export declare var PipelineVersion$: StaticStructureSchema;
export declare var PipelineVersionSummary$: StaticStructureSchema;
export declare var PlacementSpecification$: StaticStructureSchema;
export declare var PredefinedMetricSpecification$: StaticStructureSchema;
export declare var PresignedUrlAccessConfig$: StaticStructureSchema;
export declare var PriorityClass$: StaticStructureSchema;
export declare var ProcessingClusterConfig$: StaticStructureSchema;
export declare var ProcessingFeatureStoreOutput$: StaticStructureSchema;
export declare var ProcessingInput$: StaticStructureSchema;
export declare var ProcessingJob$: StaticStructureSchema;
export declare var ProcessingJobStepMetadata$: StaticStructureSchema;
export declare var ProcessingJobSummary$: StaticStructureSchema;
export declare var ProcessingOutput$: StaticStructureSchema;
export declare var ProcessingOutputConfig$: StaticStructureSchema;
export declare var ProcessingResources$: StaticStructureSchema;
export declare var ProcessingS3Input$: StaticStructureSchema;
export declare var ProcessingS3Output$: StaticStructureSchema;
export declare var ProcessingStoppingCondition$: StaticStructureSchema;
export declare var ProductionVariant$: StaticStructureSchema;
export declare var ProductionVariantCapacityReservationConfig$: StaticStructureSchema;
export declare var ProductionVariantCapacityReservationSummary$: StaticStructureSchema;
export declare var ProductionVariantCoreDumpConfig$: StaticStructureSchema;
export declare var ProductionVariantManagedInstanceScaling$: StaticStructureSchema;
export declare var ProductionVariantRoutingConfig$: StaticStructureSchema;
export declare var ProductionVariantServerlessConfig$: StaticStructureSchema;
export declare var ProductionVariantServerlessUpdateConfig$: StaticStructureSchema;
export declare var ProductionVariantStatus$: StaticStructureSchema;
export declare var ProductionVariantSummary$: StaticStructureSchema;
export declare var ProfilerConfig$: StaticStructureSchema;
export declare var ProfilerConfigForUpdate$: StaticStructureSchema;
export declare var ProfilerRuleConfiguration$: StaticStructureSchema;
export declare var ProfilerRuleEvaluationStatus$: StaticStructureSchema;
export declare var Project$: StaticStructureSchema;
export declare var ProjectSummary$: StaticStructureSchema;
export declare var PropertyNameQuery$: StaticStructureSchema;
export declare var PropertyNameSuggestion$: StaticStructureSchema;
export declare var ProvisioningParameter$: StaticStructureSchema;
export declare var PublicWorkforceTaskPrice$: StaticStructureSchema;
export declare var PutModelPackageGroupPolicyInput$: StaticStructureSchema;
export declare var PutModelPackageGroupPolicyOutput$: StaticStructureSchema;
export declare var QualityCheckStepMetadata$: StaticStructureSchema;
export declare var QueryFilters$: StaticStructureSchema;
export declare var QueryLineageRequest$: StaticStructureSchema;
export declare var QueryLineageResponse$: StaticStructureSchema;
export declare var RealTimeInferenceConfig$: StaticStructureSchema;
export declare var RealTimeInferenceRecommendation$: StaticStructureSchema;
export declare var RecommendationJobCompiledOutputConfig$: StaticStructureSchema;
export declare var RecommendationJobContainerConfig$: StaticStructureSchema;
export declare var RecommendationJobInferenceBenchmark$: StaticStructureSchema;
export declare var RecommendationJobInputConfig$: StaticStructureSchema;
export declare var RecommendationJobOutputConfig$: StaticStructureSchema;
export declare var RecommendationJobPayloadConfig$: StaticStructureSchema;
export declare var RecommendationJobResourceLimit$: StaticStructureSchema;
export declare var RecommendationJobStoppingConditions$: StaticStructureSchema;
export declare var RecommendationJobVpcConfig$: StaticStructureSchema;
export declare var RecommendationMetrics$: StaticStructureSchema;
export declare var RedshiftDatasetDefinition$: StaticStructureSchema;
export declare var RegisterDevicesRequest$: StaticStructureSchema;
export declare var RegisterModelStepMetadata$: StaticStructureSchema;
export declare var RemoteDebugConfig$: StaticStructureSchema;
export declare var RemoteDebugConfigForUpdate$: StaticStructureSchema;
export declare var RenderableTask$: StaticStructureSchema;
export declare var RenderingError$: StaticStructureSchema;
export declare var RenderUiTemplateRequest$: StaticStructureSchema;
export declare var RenderUiTemplateResponse$: StaticStructureSchema;
export declare var RepositoryAuthConfig$: StaticStructureSchema;
export declare var ReservedCapacityOffering$: StaticStructureSchema;
export declare var ReservedCapacitySummary$: StaticStructureSchema;
export declare var ResolvedAttributes$: StaticStructureSchema;
export declare var ResourceCatalog$: StaticStructureSchema;
export declare var ResourceConfig$: StaticStructureSchema;
export declare var ResourceConfigForUpdate$: StaticStructureSchema;
export declare var ResourceLimits$: StaticStructureSchema;
export declare var ResourceSharingConfig$: StaticStructureSchema;
export declare var ResourceSpec$: StaticStructureSchema;
export declare var RetentionPolicy$: StaticStructureSchema;
export declare var RetryPipelineExecutionRequest$: StaticStructureSchema;
export declare var RetryPipelineExecutionResponse$: StaticStructureSchema;
export declare var RetryStrategy$: StaticStructureSchema;
export declare var RoleGroupAssignment$: StaticStructureSchema;
export declare var RollingDeploymentPolicy$: StaticStructureSchema;
export declare var RollingUpdatePolicy$: StaticStructureSchema;
export declare var RSessionAppSettings$: StaticStructureSchema;
export declare var RStudioServerProAppSettings$: StaticStructureSchema;
export declare var RStudioServerProDomainSettings$: StaticStructureSchema;
export declare var RStudioServerProDomainSettingsForUpdate$: StaticStructureSchema;
export declare var S3DataSource$: StaticStructureSchema;
export declare var S3FileSystem$: StaticStructureSchema;
export declare var S3FileSystemConfig$: StaticStructureSchema;
export declare var S3ModelDataSource$: StaticStructureSchema;
export declare var S3Presign$: StaticStructureSchema;
export declare var S3StorageConfig$: StaticStructureSchema;
export declare var ScalingPolicyMetric$: StaticStructureSchema;
export declare var ScalingPolicyObjective$: StaticStructureSchema;
export declare var ScheduleConfig$: StaticStructureSchema;
export declare var ScheduledUpdateConfig$: StaticStructureSchema;
export declare var SchedulerConfig$: StaticStructureSchema;
export declare var SearchExpression$: StaticStructureSchema;
export declare var SearchRecord$: StaticStructureSchema;
export declare var SearchRequest$: StaticStructureSchema;
export declare var SearchResponse$: StaticStructureSchema;
export declare var SearchTrainingPlanOfferingsRequest$: StaticStructureSchema;
export declare var SearchTrainingPlanOfferingsResponse$: StaticStructureSchema;
export declare var SecondaryStatusTransition$: StaticStructureSchema;
export declare var SelectedStep$: StaticStructureSchema;
export declare var SelectiveExecutionConfig$: StaticStructureSchema;
export declare var SelectiveExecutionResult$: StaticStructureSchema;
export declare var SendPipelineExecutionStepFailureRequest$: StaticStructureSchema;
export declare var SendPipelineExecutionStepFailureResponse$: StaticStructureSchema;
export declare var SendPipelineExecutionStepSuccessRequest$: StaticStructureSchema;
export declare var SendPipelineExecutionStepSuccessResponse$: StaticStructureSchema;
export declare var ServerlessJobConfig$: StaticStructureSchema;
export declare var ServiceCatalogProvisionedProductDetails$: StaticStructureSchema;
export declare var ServiceCatalogProvisioningDetails$: StaticStructureSchema;
export declare var ServiceCatalogProvisioningUpdateDetails$: StaticStructureSchema;
export declare var SessionChainingConfig$: StaticStructureSchema;
export declare var ShadowModeConfig$: StaticStructureSchema;
export declare var ShadowModelVariantConfig$: StaticStructureSchema;
export declare var SharingSettings$: StaticStructureSchema;
export declare var ShuffleConfig$: StaticStructureSchema;
export declare var SourceAlgorithm$: StaticStructureSchema;
export declare var SourceAlgorithmSpecification$: StaticStructureSchema;
export declare var SourceIpConfig$: StaticStructureSchema;
export declare var SpaceAppLifecycleManagement$: StaticStructureSchema;
export declare var SpaceCodeEditorAppSettings$: StaticStructureSchema;
export declare var SpaceDetails$: StaticStructureSchema;
export declare var SpaceIdleSettings$: StaticStructureSchema;
export declare var SpaceJupyterLabAppSettings$: StaticStructureSchema;
export declare var SpaceSettings$: StaticStructureSchema;
export declare var SpaceSettingsSummary$: StaticStructureSchema;
export declare var SpaceSharingSettings$: StaticStructureSchema;
export declare var SpaceSharingSettingsSummary$: StaticStructureSchema;
export declare var SpaceStorageSettings$: StaticStructureSchema;
export declare var Stairs$: StaticStructureSchema;
export declare var StartEdgeDeploymentStageRequest$: StaticStructureSchema;
export declare var StartInferenceExperimentRequest$: StaticStructureSchema;
export declare var StartInferenceExperimentResponse$: StaticStructureSchema;
export declare var StartMlflowTrackingServerRequest$: StaticStructureSchema;
export declare var StartMlflowTrackingServerResponse$: StaticStructureSchema;
export declare var StartMonitoringScheduleRequest$: StaticStructureSchema;
export declare var StartNotebookInstanceInput$: StaticStructureSchema;
export declare var StartPipelineExecutionRequest$: StaticStructureSchema;
export declare var StartPipelineExecutionResponse$: StaticStructureSchema;
export declare var StartSessionRequest$: StaticStructureSchema;
export declare var StartSessionResponse$: StaticStructureSchema;
export declare var StopAutoMLJobRequest$: StaticStructureSchema;
export declare var StopCompilationJobRequest$: StaticStructureSchema;
export declare var StopEdgeDeploymentStageRequest$: StaticStructureSchema;
export declare var StopEdgePackagingJobRequest$: StaticStructureSchema;
export declare var StopHyperParameterTuningJobRequest$: StaticStructureSchema;
export declare var StopInferenceExperimentRequest$: StaticStructureSchema;
export declare var StopInferenceExperimentResponse$: StaticStructureSchema;
export declare var StopInferenceRecommendationsJobRequest$: StaticStructureSchema;
export declare var StopLabelingJobRequest$: StaticStructureSchema;
export declare var StopMlflowTrackingServerRequest$: StaticStructureSchema;
export declare var StopMlflowTrackingServerResponse$: StaticStructureSchema;
export declare var StopMonitoringScheduleRequest$: StaticStructureSchema;
export declare var StopNotebookInstanceInput$: StaticStructureSchema;
export declare var StopOptimizationJobRequest$: StaticStructureSchema;
export declare var StoppingCondition$: StaticStructureSchema;
export declare var StopPipelineExecutionRequest$: StaticStructureSchema;
export declare var StopPipelineExecutionResponse$: StaticStructureSchema;
export declare var StopProcessingJobRequest$: StaticStructureSchema;
export declare var StopTrainingJobRequest$: StaticStructureSchema;
export declare var StopTransformJobRequest$: StaticStructureSchema;
export declare var StudioLifecycleConfigDetails$: StaticStructureSchema;
export declare var StudioWebPortalSettings$: StaticStructureSchema;
export declare var SubscribedWorkteam$: StaticStructureSchema;
export declare var SuggestionQuery$: StaticStructureSchema;
export declare var TabularJobConfig$: StaticStructureSchema;
export declare var TabularResolvedAttributes$: StaticStructureSchema;
export declare var Tag$: StaticStructureSchema;
export declare var TargetPlatform$: StaticStructureSchema;
export declare var TargetTrackingScalingPolicyConfiguration$: StaticStructureSchema;
export declare var TemplateProviderDetail$: StaticStructureSchema;
export declare var TensorBoardAppSettings$: StaticStructureSchema;
export declare var TensorBoardOutputConfig$: StaticStructureSchema;
export declare var TextClassificationJobConfig$: StaticStructureSchema;
export declare var TextGenerationJobConfig$: StaticStructureSchema;
export declare var TextGenerationResolvedAttributes$: StaticStructureSchema;
export declare var ThroughputConfig$: StaticStructureSchema;
export declare var ThroughputConfigDescription$: StaticStructureSchema;
export declare var ThroughputConfigUpdate$: StaticStructureSchema;
export declare var TimeSeriesConfig$: StaticStructureSchema;
export declare var TimeSeriesForecastingJobConfig$: StaticStructureSchema;
export declare var TimeSeriesForecastingSettings$: StaticStructureSchema;
export declare var TimeSeriesTransformations$: StaticStructureSchema;
export declare var TotalHits$: StaticStructureSchema;
export declare var TrackingServerSummary$: StaticStructureSchema;
export declare var TrafficPattern$: StaticStructureSchema;
export declare var TrafficRoutingConfig$: StaticStructureSchema;
export declare var TrainingImageConfig$: StaticStructureSchema;
export declare var TrainingJob$: StaticStructureSchema;
export declare var TrainingJobDefinition$: StaticStructureSchema;
export declare var TrainingJobStatusCounters$: StaticStructureSchema;
export declare var TrainingJobStepMetadata$: StaticStructureSchema;
export declare var TrainingJobSummary$: StaticStructureSchema;
export declare var TrainingPlanFilter$: StaticStructureSchema;
export declare var TrainingPlanOffering$: StaticStructureSchema;
export declare var TrainingPlanSummary$: StaticStructureSchema;
export declare var TrainingProgressInfo$: StaticStructureSchema;
export declare var TrainingRepositoryAuthConfig$: StaticStructureSchema;
export declare var TrainingSpecification$: StaticStructureSchema;
export declare var TransformDataSource$: StaticStructureSchema;
export declare var TransformInput$: StaticStructureSchema;
export declare var TransformJob$: StaticStructureSchema;
export declare var TransformJobDefinition$: StaticStructureSchema;
export declare var TransformJobStepMetadata$: StaticStructureSchema;
export declare var TransformJobSummary$: StaticStructureSchema;
export declare var TransformOutput$: StaticStructureSchema;
export declare var TransformResources$: StaticStructureSchema;
export declare var TransformS3DataSource$: StaticStructureSchema;
export declare var Trial$: StaticStructureSchema;
export declare var TrialComponent$: StaticStructureSchema;
export declare var TrialComponentArtifact$: StaticStructureSchema;
export declare var TrialComponentMetricSummary$: StaticStructureSchema;
export declare var TrialComponentSimpleSummary$: StaticStructureSchema;
export declare var TrialComponentSource$: StaticStructureSchema;
export declare var TrialComponentSourceDetail$: StaticStructureSchema;
export declare var TrialComponentStatus$: StaticStructureSchema;
export declare var TrialComponentSummary$: StaticStructureSchema;
export declare var TrialSource$: StaticStructureSchema;
export declare var TrialSummary$: StaticStructureSchema;
export declare var TrustedIdentityPropagationSettings$: StaticStructureSchema;
export declare var TtlDuration$: StaticStructureSchema;
export declare var TuningJobCompletionCriteria$: StaticStructureSchema;
export declare var TuningJobStepMetaData$: StaticStructureSchema;
export declare var UiConfig$: StaticStructureSchema;
export declare var UiTemplate$: StaticStructureSchema;
export declare var UiTemplateInfo$: StaticStructureSchema;
export declare var UltraServer$: StaticStructureSchema;
export declare var UltraServerInfo$: StaticStructureSchema;
export declare var UltraServerSummary$: StaticStructureSchema;
export declare var UnifiedStudioSettings$: StaticStructureSchema;
export declare var UpdateActionRequest$: StaticStructureSchema;
export declare var UpdateActionResponse$: StaticStructureSchema;
export declare var UpdateAppImageConfigRequest$: StaticStructureSchema;
export declare var UpdateAppImageConfigResponse$: StaticStructureSchema;
export declare var UpdateArtifactRequest$: StaticStructureSchema;
export declare var UpdateArtifactResponse$: StaticStructureSchema;
export declare var UpdateClusterRequest$: StaticStructureSchema;
export declare var UpdateClusterResponse$: StaticStructureSchema;
export declare var UpdateClusterSchedulerConfigRequest$: StaticStructureSchema;
export declare var UpdateClusterSchedulerConfigResponse$: StaticStructureSchema;
export declare var UpdateClusterSoftwareInstanceGroupSpecification$: StaticStructureSchema;
export declare var UpdateClusterSoftwareRequest$: StaticStructureSchema;
export declare var UpdateClusterSoftwareResponse$: StaticStructureSchema;
export declare var UpdateCodeRepositoryInput$: StaticStructureSchema;
export declare var UpdateCodeRepositoryOutput$: StaticStructureSchema;
export declare var UpdateComputeQuotaRequest$: StaticStructureSchema;
export declare var UpdateComputeQuotaResponse$: StaticStructureSchema;
export declare var UpdateContextRequest$: StaticStructureSchema;
export declare var UpdateContextResponse$: StaticStructureSchema;
export declare var UpdateDeviceFleetRequest$: StaticStructureSchema;
export declare var UpdateDevicesRequest$: StaticStructureSchema;
export declare var UpdateDomainRequest$: StaticStructureSchema;
export declare var UpdateDomainResponse$: StaticStructureSchema;
export declare var UpdateEndpointInput$: StaticStructureSchema;
export declare var UpdateEndpointOutput$: StaticStructureSchema;
export declare var UpdateEndpointWeightsAndCapacitiesInput$: StaticStructureSchema;
export declare var UpdateEndpointWeightsAndCapacitiesOutput$: StaticStructureSchema;
export declare var UpdateExperimentRequest$: StaticStructureSchema;
export declare var UpdateExperimentResponse$: StaticStructureSchema;
export declare var UpdateFeatureGroupRequest$: StaticStructureSchema;
export declare var UpdateFeatureGroupResponse$: StaticStructureSchema;
export declare var UpdateFeatureMetadataRequest$: StaticStructureSchema;
export declare var UpdateHubContentReferenceRequest$: StaticStructureSchema;
export declare var UpdateHubContentReferenceResponse$: StaticStructureSchema;
export declare var UpdateHubContentRequest$: StaticStructureSchema;
export declare var UpdateHubContentResponse$: StaticStructureSchema;
export declare var UpdateHubRequest$: StaticStructureSchema;
export declare var UpdateHubResponse$: StaticStructureSchema;
export declare var UpdateImageRequest$: StaticStructureSchema;
export declare var UpdateImageResponse$: StaticStructureSchema;
export declare var UpdateImageVersionRequest$: StaticStructureSchema;
export declare var UpdateImageVersionResponse$: StaticStructureSchema;
export declare var UpdateInferenceComponentInput$: StaticStructureSchema;
export declare var UpdateInferenceComponentOutput$: StaticStructureSchema;
export declare var UpdateInferenceComponentRuntimeConfigInput$: StaticStructureSchema;
export declare var UpdateInferenceComponentRuntimeConfigOutput$: StaticStructureSchema;
export declare var UpdateInferenceExperimentRequest$: StaticStructureSchema;
export declare var UpdateInferenceExperimentResponse$: StaticStructureSchema;
export declare var UpdateMlflowAppRequest$: StaticStructureSchema;
export declare var UpdateMlflowAppResponse$: StaticStructureSchema;
export declare var UpdateMlflowTrackingServerRequest$: StaticStructureSchema;
export declare var UpdateMlflowTrackingServerResponse$: StaticStructureSchema;
export declare var UpdateModelCardRequest$: StaticStructureSchema;
export declare var UpdateModelCardResponse$: StaticStructureSchema;
export declare var UpdateModelPackageInput$: StaticStructureSchema;
export declare var UpdateModelPackageOutput$: StaticStructureSchema;
export declare var UpdateMonitoringAlertRequest$: StaticStructureSchema;
export declare var UpdateMonitoringAlertResponse$: StaticStructureSchema;
export declare var UpdateMonitoringScheduleRequest$: StaticStructureSchema;
export declare var UpdateMonitoringScheduleResponse$: StaticStructureSchema;
export declare var UpdateNotebookInstanceInput$: StaticStructureSchema;
export declare var UpdateNotebookInstanceLifecycleConfigInput$: StaticStructureSchema;
export declare var UpdateNotebookInstanceLifecycleConfigOutput$: StaticStructureSchema;
export declare var UpdateNotebookInstanceOutput$: StaticStructureSchema;
export declare var UpdatePartnerAppRequest$: StaticStructureSchema;
export declare var UpdatePartnerAppResponse$: StaticStructureSchema;
export declare var UpdatePipelineExecutionRequest$: StaticStructureSchema;
export declare var UpdatePipelineExecutionResponse$: StaticStructureSchema;
export declare var UpdatePipelineRequest$: StaticStructureSchema;
export declare var UpdatePipelineResponse$: StaticStructureSchema;
export declare var UpdatePipelineVersionRequest$: StaticStructureSchema;
export declare var UpdatePipelineVersionResponse$: StaticStructureSchema;
export declare var UpdateProjectInput$: StaticStructureSchema;
export declare var UpdateProjectOutput$: StaticStructureSchema;
export declare var UpdateSpaceRequest$: StaticStructureSchema;
export declare var UpdateSpaceResponse$: StaticStructureSchema;
export declare var UpdateTemplateProvider$: StaticStructureSchema;
export declare var UpdateTrainingJobRequest$: StaticStructureSchema;
export declare var UpdateTrainingJobResponse$: StaticStructureSchema;
export declare var UpdateTrialComponentRequest$: StaticStructureSchema;
export declare var UpdateTrialComponentResponse$: StaticStructureSchema;
export declare var UpdateTrialRequest$: StaticStructureSchema;
export declare var UpdateTrialResponse$: StaticStructureSchema;
export declare var UpdateUserProfileRequest$: StaticStructureSchema;
export declare var UpdateUserProfileResponse$: StaticStructureSchema;
export declare var UpdateWorkforceRequest$: StaticStructureSchema;
export declare var UpdateWorkforceResponse$: StaticStructureSchema;
export declare var UpdateWorkteamRequest$: StaticStructureSchema;
export declare var UpdateWorkteamResponse$: StaticStructureSchema;
export declare var USD$: StaticStructureSchema;
export declare var UserContext$: StaticStructureSchema;
export declare var UserProfileDetails$: StaticStructureSchema;
export declare var UserSettings$: StaticStructureSchema;
export declare var VariantProperty$: StaticStructureSchema;
export declare var VectorConfig$: StaticStructureSchema;
export declare var Vertex$: StaticStructureSchema;
export declare var VisibilityConditions$: StaticStructureSchema;
export declare var VpcConfig$: StaticStructureSchema;
export declare var WarmPoolStatus$: StaticStructureSchema;
export declare var WorkerAccessConfiguration$: StaticStructureSchema;
export declare var Workforce$: StaticStructureSchema;
export declare var WorkforceVpcConfigRequest$: StaticStructureSchema;
export declare var WorkforceVpcConfigResponse$: StaticStructureSchema;
export declare var WorkspaceSettings$: StaticStructureSchema;
export declare var Workteam$: StaticStructureSchema;
export declare var AutoMLProblemTypeConfig$: StaticUnionSchema;
export declare var AutoMLProblemTypeResolvedAttributes$: StaticUnionSchema;
export declare var ClusterInstanceStorageConfig$: StaticUnionSchema;
export declare var CollectionConfig$: StaticUnionSchema;
export declare var CustomFileSystem$: StaticUnionSchema;
export declare var CustomFileSystemConfig$: StaticUnionSchema;
export declare var EventMetadata$: StaticUnionSchema;
export declare var MetricSpecification$: StaticUnionSchema;
export declare var OptimizationConfig$: StaticUnionSchema;
export declare var ScalingPolicy$: StaticUnionSchema;
export declare var TrialComponentParameterValue$: StaticUnionSchema;
export declare var AddAssociation$: StaticOperationSchema;
export declare var AddTags$: StaticOperationSchema;
export declare var AssociateTrialComponent$: StaticOperationSchema;
export declare var AttachClusterNodeVolume$: StaticOperationSchema;
export declare var BatchAddClusterNodes$: StaticOperationSchema;
export declare var BatchDeleteClusterNodes$: StaticOperationSchema;
export declare var BatchDescribeModelPackage$: StaticOperationSchema;
export declare var BatchRebootClusterNodes$: StaticOperationSchema;
export declare var BatchReplaceClusterNodes$: StaticOperationSchema;
export declare var CreateAction$: StaticOperationSchema;
export declare var CreateAlgorithm$: StaticOperationSchema;
export declare var CreateApp$: StaticOperationSchema;
export declare var CreateAppImageConfig$: StaticOperationSchema;
export declare var CreateArtifact$: StaticOperationSchema;
export declare var CreateAutoMLJob$: StaticOperationSchema;
export declare var CreateAutoMLJobV2$: StaticOperationSchema;
export declare var CreateCluster$: StaticOperationSchema;
export declare var CreateClusterSchedulerConfig$: StaticOperationSchema;
export declare var CreateCodeRepository$: StaticOperationSchema;
export declare var CreateCompilationJob$: StaticOperationSchema;
export declare var CreateComputeQuota$: StaticOperationSchema;
export declare var CreateContext$: StaticOperationSchema;
export declare var CreateDataQualityJobDefinition$: StaticOperationSchema;
export declare var CreateDeviceFleet$: StaticOperationSchema;
export declare var CreateDomain$: StaticOperationSchema;
export declare var CreateEdgeDeploymentPlan$: StaticOperationSchema;
export declare var CreateEdgeDeploymentStage$: StaticOperationSchema;
export declare var CreateEdgePackagingJob$: StaticOperationSchema;
export declare var CreateEndpoint$: StaticOperationSchema;
export declare var CreateEndpointConfig$: StaticOperationSchema;
export declare var CreateExperiment$: StaticOperationSchema;
export declare var CreateFeatureGroup$: StaticOperationSchema;
export declare var CreateFlowDefinition$: StaticOperationSchema;
export declare var CreateHub$: StaticOperationSchema;
export declare var CreateHubContentPresignedUrls$: StaticOperationSchema;
export declare var CreateHubContentReference$: StaticOperationSchema;
export declare var CreateHumanTaskUi$: StaticOperationSchema;
export declare var CreateHyperParameterTuningJob$: StaticOperationSchema;
export declare var CreateImage$: StaticOperationSchema;
export declare var CreateImageVersion$: StaticOperationSchema;
export declare var CreateInferenceComponent$: StaticOperationSchema;
export declare var CreateInferenceExperiment$: StaticOperationSchema;
export declare var CreateInferenceRecommendationsJob$: StaticOperationSchema;
export declare var CreateLabelingJob$: StaticOperationSchema;
export declare var CreateMlflowApp$: StaticOperationSchema;
export declare var CreateMlflowTrackingServer$: StaticOperationSchema;
export declare var CreateModel$: StaticOperationSchema;
export declare var CreateModelBiasJobDefinition$: StaticOperationSchema;
export declare var CreateModelCard$: StaticOperationSchema;
export declare var CreateModelCardExportJob$: StaticOperationSchema;
export declare var CreateModelExplainabilityJobDefinition$: StaticOperationSchema;
export declare var CreateModelPackage$: StaticOperationSchema;
export declare var CreateModelPackageGroup$: StaticOperationSchema;
export declare var CreateModelQualityJobDefinition$: StaticOperationSchema;
export declare var CreateMonitoringSchedule$: StaticOperationSchema;
export declare var CreateNotebookInstance$: StaticOperationSchema;
export declare var CreateNotebookInstanceLifecycleConfig$: StaticOperationSchema;
export declare var CreateOptimizationJob$: StaticOperationSchema;
export declare var CreatePartnerApp$: StaticOperationSchema;
export declare var CreatePartnerAppPresignedUrl$: StaticOperationSchema;
export declare var CreatePipeline$: StaticOperationSchema;
export declare var CreatePresignedDomainUrl$: StaticOperationSchema;
export declare var CreatePresignedMlflowAppUrl$: StaticOperationSchema;
export declare var CreatePresignedMlflowTrackingServerUrl$: StaticOperationSchema;
export declare var CreatePresignedNotebookInstanceUrl$: StaticOperationSchema;
export declare var CreateProcessingJob$: StaticOperationSchema;
export declare var CreateProject$: StaticOperationSchema;
export declare var CreateSpace$: StaticOperationSchema;
export declare var CreateStudioLifecycleConfig$: StaticOperationSchema;
export declare var CreateTrainingJob$: StaticOperationSchema;
export declare var CreateTrainingPlan$: StaticOperationSchema;
export declare var CreateTransformJob$: StaticOperationSchema;
export declare var CreateTrial$: StaticOperationSchema;
export declare var CreateTrialComponent$: StaticOperationSchema;
export declare var CreateUserProfile$: StaticOperationSchema;
export declare var CreateWorkforce$: StaticOperationSchema;
export declare var CreateWorkteam$: StaticOperationSchema;
export declare var DeleteAction$: StaticOperationSchema;
export declare var DeleteAlgorithm$: StaticOperationSchema;
export declare var DeleteApp$: StaticOperationSchema;
export declare var DeleteAppImageConfig$: StaticOperationSchema;
export declare var DeleteArtifact$: StaticOperationSchema;
export declare var DeleteAssociation$: StaticOperationSchema;
export declare var DeleteCluster$: StaticOperationSchema;
export declare var DeleteClusterSchedulerConfig$: StaticOperationSchema;
export declare var DeleteCodeRepository$: StaticOperationSchema;
export declare var DeleteCompilationJob$: StaticOperationSchema;
export declare var DeleteComputeQuota$: StaticOperationSchema;
export declare var DeleteContext$: StaticOperationSchema;
export declare var DeleteDataQualityJobDefinition$: StaticOperationSchema;
export declare var DeleteDeviceFleet$: StaticOperationSchema;
export declare var DeleteDomain$: StaticOperationSchema;
export declare var DeleteEdgeDeploymentPlan$: StaticOperationSchema;
export declare var DeleteEdgeDeploymentStage$: StaticOperationSchema;
export declare var DeleteEndpoint$: StaticOperationSchema;
export declare var DeleteEndpointConfig$: StaticOperationSchema;
export declare var DeleteExperiment$: StaticOperationSchema;
export declare var DeleteFeatureGroup$: StaticOperationSchema;
export declare var DeleteFlowDefinition$: StaticOperationSchema;
export declare var DeleteHub$: StaticOperationSchema;
export declare var DeleteHubContent$: StaticOperationSchema;
export declare var DeleteHubContentReference$: StaticOperationSchema;
export declare var DeleteHumanTaskUi$: StaticOperationSchema;
export declare var DeleteHyperParameterTuningJob$: StaticOperationSchema;
export declare var DeleteImage$: StaticOperationSchema;
export declare var DeleteImageVersion$: StaticOperationSchema;
export declare var DeleteInferenceComponent$: StaticOperationSchema;
export declare var DeleteInferenceExperiment$: StaticOperationSchema;
export declare var DeleteMlflowApp$: StaticOperationSchema;
export declare var DeleteMlflowTrackingServer$: StaticOperationSchema;
export declare var DeleteModel$: StaticOperationSchema;
export declare var DeleteModelBiasJobDefinition$: StaticOperationSchema;
export declare var DeleteModelCard$: StaticOperationSchema;
export declare var DeleteModelExplainabilityJobDefinition$: StaticOperationSchema;
export declare var DeleteModelPackage$: StaticOperationSchema;
export declare var DeleteModelPackageGroup$: StaticOperationSchema;
export declare var DeleteModelPackageGroupPolicy$: StaticOperationSchema;
export declare var DeleteModelQualityJobDefinition$: StaticOperationSchema;
export declare var DeleteMonitoringSchedule$: StaticOperationSchema;
export declare var DeleteNotebookInstance$: StaticOperationSchema;
export declare var DeleteNotebookInstanceLifecycleConfig$: StaticOperationSchema;
export declare var DeleteOptimizationJob$: StaticOperationSchema;
export declare var DeletePartnerApp$: StaticOperationSchema;
export declare var DeletePipeline$: StaticOperationSchema;
export declare var DeleteProcessingJob$: StaticOperationSchema;
export declare var DeleteProject$: StaticOperationSchema;
export declare var DeleteSpace$: StaticOperationSchema;
export declare var DeleteStudioLifecycleConfig$: StaticOperationSchema;
export declare var DeleteTags$: StaticOperationSchema;
export declare var DeleteTrainingJob$: StaticOperationSchema;
export declare var DeleteTrial$: StaticOperationSchema;
export declare var DeleteTrialComponent$: StaticOperationSchema;
export declare var DeleteUserProfile$: StaticOperationSchema;
export declare var DeleteWorkforce$: StaticOperationSchema;
export declare var DeleteWorkteam$: StaticOperationSchema;
export declare var DeregisterDevices$: StaticOperationSchema;
export declare var DescribeAction$: StaticOperationSchema;
export declare var DescribeAlgorithm$: StaticOperationSchema;
export declare var DescribeApp$: StaticOperationSchema;
export declare var DescribeAppImageConfig$: StaticOperationSchema;
export declare var DescribeArtifact$: StaticOperationSchema;
export declare var DescribeAutoMLJob$: StaticOperationSchema;
export declare var DescribeAutoMLJobV2$: StaticOperationSchema;
export declare var DescribeCluster$: StaticOperationSchema;
export declare var DescribeClusterEvent$: StaticOperationSchema;
export declare var DescribeClusterNode$: StaticOperationSchema;
export declare var DescribeClusterSchedulerConfig$: StaticOperationSchema;
export declare var DescribeCodeRepository$: StaticOperationSchema;
export declare var DescribeCompilationJob$: StaticOperationSchema;
export declare var DescribeComputeQuota$: StaticOperationSchema;
export declare var DescribeContext$: StaticOperationSchema;
export declare var DescribeDataQualityJobDefinition$: StaticOperationSchema;
export declare var DescribeDevice$: StaticOperationSchema;
export declare var DescribeDeviceFleet$: StaticOperationSchema;
export declare var DescribeDomain$: StaticOperationSchema;
export declare var DescribeEdgeDeploymentPlan$: StaticOperationSchema;
export declare var DescribeEdgePackagingJob$: StaticOperationSchema;
export declare var DescribeEndpoint$: StaticOperationSchema;
export declare var DescribeEndpointConfig$: StaticOperationSchema;
export declare var DescribeExperiment$: StaticOperationSchema;
export declare var DescribeFeatureGroup$: StaticOperationSchema;
export declare var DescribeFeatureMetadata$: StaticOperationSchema;
export declare var DescribeFlowDefinition$: StaticOperationSchema;
export declare var DescribeHub$: StaticOperationSchema;
export declare var DescribeHubContent$: StaticOperationSchema;
export declare var DescribeHumanTaskUi$: StaticOperationSchema;
export declare var DescribeHyperParameterTuningJob$: StaticOperationSchema;
export declare var DescribeImage$: StaticOperationSchema;
export declare var DescribeImageVersion$: StaticOperationSchema;
export declare var DescribeInferenceComponent$: StaticOperationSchema;
export declare var DescribeInferenceExperiment$: StaticOperationSchema;
export declare var DescribeInferenceRecommendationsJob$: StaticOperationSchema;
export declare var DescribeLabelingJob$: StaticOperationSchema;
export declare var DescribeLineageGroup$: StaticOperationSchema;
export declare var DescribeMlflowApp$: StaticOperationSchema;
export declare var DescribeMlflowTrackingServer$: StaticOperationSchema;
export declare var DescribeModel$: StaticOperationSchema;
export declare var DescribeModelBiasJobDefinition$: StaticOperationSchema;
export declare var DescribeModelCard$: StaticOperationSchema;
export declare var DescribeModelCardExportJob$: StaticOperationSchema;
export declare var DescribeModelExplainabilityJobDefinition$: StaticOperationSchema;
export declare var DescribeModelPackage$: StaticOperationSchema;
export declare var DescribeModelPackageGroup$: StaticOperationSchema;
export declare var DescribeModelQualityJobDefinition$: StaticOperationSchema;
export declare var DescribeMonitoringSchedule$: StaticOperationSchema;
export declare var DescribeNotebookInstance$: StaticOperationSchema;
export declare var DescribeNotebookInstanceLifecycleConfig$: StaticOperationSchema;
export declare var DescribeOptimizationJob$: StaticOperationSchema;
export declare var DescribePartnerApp$: StaticOperationSchema;
export declare var DescribePipeline$: StaticOperationSchema;
export declare var DescribePipelineDefinitionForExecution$: StaticOperationSchema;
export declare var DescribePipelineExecution$: StaticOperationSchema;
export declare var DescribeProcessingJob$: StaticOperationSchema;
export declare var DescribeProject$: StaticOperationSchema;
export declare var DescribeReservedCapacity$: StaticOperationSchema;
export declare var DescribeSpace$: StaticOperationSchema;
export declare var DescribeStudioLifecycleConfig$: StaticOperationSchema;
export declare var DescribeSubscribedWorkteam$: StaticOperationSchema;
export declare var DescribeTrainingJob$: StaticOperationSchema;
export declare var DescribeTrainingPlan$: StaticOperationSchema;
export declare var DescribeTransformJob$: StaticOperationSchema;
export declare var DescribeTrial$: StaticOperationSchema;
export declare var DescribeTrialComponent$: StaticOperationSchema;
export declare var DescribeUserProfile$: StaticOperationSchema;
export declare var DescribeWorkforce$: StaticOperationSchema;
export declare var DescribeWorkteam$: StaticOperationSchema;
export declare var DetachClusterNodeVolume$: StaticOperationSchema;
export declare var DisableSagemakerServicecatalogPortfolio$: StaticOperationSchema;
export declare var DisassociateTrialComponent$: StaticOperationSchema;
export declare var EnableSagemakerServicecatalogPortfolio$: StaticOperationSchema;
export declare var GetDeviceFleetReport$: StaticOperationSchema;
export declare var GetLineageGroupPolicy$: StaticOperationSchema;
export declare var GetModelPackageGroupPolicy$: StaticOperationSchema;
export declare var GetSagemakerServicecatalogPortfolioStatus$: StaticOperationSchema;
export declare var GetScalingConfigurationRecommendation$: StaticOperationSchema;
export declare var GetSearchSuggestions$: StaticOperationSchema;
export declare var ImportHubContent$: StaticOperationSchema;
export declare var ListActions$: StaticOperationSchema;
export declare var ListAlgorithms$: StaticOperationSchema;
export declare var ListAliases$: StaticOperationSchema;
export declare var ListAppImageConfigs$: StaticOperationSchema;
export declare var ListApps$: StaticOperationSchema;
export declare var ListArtifacts$: StaticOperationSchema;
export declare var ListAssociations$: StaticOperationSchema;
export declare var ListAutoMLJobs$: StaticOperationSchema;
export declare var ListCandidatesForAutoMLJob$: StaticOperationSchema;
export declare var ListClusterEvents$: StaticOperationSchema;
export declare var ListClusterNodes$: StaticOperationSchema;
export declare var ListClusters$: StaticOperationSchema;
export declare var ListClusterSchedulerConfigs$: StaticOperationSchema;
export declare var ListCodeRepositories$: StaticOperationSchema;
export declare var ListCompilationJobs$: StaticOperationSchema;
export declare var ListComputeQuotas$: StaticOperationSchema;
export declare var ListContexts$: StaticOperationSchema;
export declare var ListDataQualityJobDefinitions$: StaticOperationSchema;
export declare var ListDeviceFleets$: StaticOperationSchema;
export declare var ListDevices$: StaticOperationSchema;
export declare var ListDomains$: StaticOperationSchema;
export declare var ListEdgeDeploymentPlans$: StaticOperationSchema;
export declare var ListEdgePackagingJobs$: StaticOperationSchema;
export declare var ListEndpointConfigs$: StaticOperationSchema;
export declare var ListEndpoints$: StaticOperationSchema;
export declare var ListExperiments$: StaticOperationSchema;
export declare var ListFeatureGroups$: StaticOperationSchema;
export declare var ListFlowDefinitions$: StaticOperationSchema;
export declare var ListHubContents$: StaticOperationSchema;
export declare var ListHubContentVersions$: StaticOperationSchema;
export declare var ListHubs$: StaticOperationSchema;
export declare var ListHumanTaskUis$: StaticOperationSchema;
export declare var ListHyperParameterTuningJobs$: StaticOperationSchema;
export declare var ListImages$: StaticOperationSchema;
export declare var ListImageVersions$: StaticOperationSchema;
export declare var ListInferenceComponents$: StaticOperationSchema;
export declare var ListInferenceExperiments$: StaticOperationSchema;
export declare var ListInferenceRecommendationsJobs$: StaticOperationSchema;
export declare var ListInferenceRecommendationsJobSteps$: StaticOperationSchema;
export declare var ListLabelingJobs$: StaticOperationSchema;
export declare var ListLabelingJobsForWorkteam$: StaticOperationSchema;
export declare var ListLineageGroups$: StaticOperationSchema;
export declare var ListMlflowApps$: StaticOperationSchema;
export declare var ListMlflowTrackingServers$: StaticOperationSchema;
export declare var ListModelBiasJobDefinitions$: StaticOperationSchema;
export declare var ListModelCardExportJobs$: StaticOperationSchema;
export declare var ListModelCards$: StaticOperationSchema;
export declare var ListModelCardVersions$: StaticOperationSchema;
export declare var ListModelExplainabilityJobDefinitions$: StaticOperationSchema;
export declare var ListModelMetadata$: StaticOperationSchema;
export declare var ListModelPackageGroups$: StaticOperationSchema;
export declare var ListModelPackages$: StaticOperationSchema;
export declare var ListModelQualityJobDefinitions$: StaticOperationSchema;
export declare var ListModels$: StaticOperationSchema;
export declare var ListMonitoringAlertHistory$: StaticOperationSchema;
export declare var ListMonitoringAlerts$: StaticOperationSchema;
export declare var ListMonitoringExecutions$: StaticOperationSchema;
export declare var ListMonitoringSchedules$: StaticOperationSchema;
export declare var ListNotebookInstanceLifecycleConfigs$: StaticOperationSchema;
export declare var ListNotebookInstances$: StaticOperationSchema;
export declare var ListOptimizationJobs$: StaticOperationSchema;
export declare var ListPartnerApps$: StaticOperationSchema;
export declare var ListPipelineExecutions$: StaticOperationSchema;
export declare var ListPipelineExecutionSteps$: StaticOperationSchema;
export declare var ListPipelineParametersForExecution$: StaticOperationSchema;
export declare var ListPipelines$: StaticOperationSchema;
export declare var ListPipelineVersions$: StaticOperationSchema;
export declare var ListProcessingJobs$: StaticOperationSchema;
export declare var ListProjects$: StaticOperationSchema;
export declare var ListResourceCatalogs$: StaticOperationSchema;
export declare var ListSpaces$: StaticOperationSchema;
export declare var ListStageDevices$: StaticOperationSchema;
export declare var ListStudioLifecycleConfigs$: StaticOperationSchema;
export declare var ListSubscribedWorkteams$: StaticOperationSchema;
export declare var ListTags$: StaticOperationSchema;
export declare var ListTrainingJobs$: StaticOperationSchema;
export declare var ListTrainingJobsForHyperParameterTuningJob$: StaticOperationSchema;
export declare var ListTrainingPlans$: StaticOperationSchema;
export declare var ListTransformJobs$: StaticOperationSchema;
export declare var ListTrialComponents$: StaticOperationSchema;
export declare var ListTrials$: StaticOperationSchema;
export declare var ListUltraServersByReservedCapacity$: StaticOperationSchema;
export declare var ListUserProfiles$: StaticOperationSchema;
export declare var ListWorkforces$: StaticOperationSchema;
export declare var ListWorkteams$: StaticOperationSchema;
export declare var PutModelPackageGroupPolicy$: StaticOperationSchema;
export declare var QueryLineage$: StaticOperationSchema;
export declare var RegisterDevices$: StaticOperationSchema;
export declare var RenderUiTemplate$: StaticOperationSchema;
export declare var RetryPipelineExecution$: StaticOperationSchema;
export declare var Search$: StaticOperationSchema;
export declare var SearchTrainingPlanOfferings$: StaticOperationSchema;
export declare var SendPipelineExecutionStepFailure$: StaticOperationSchema;
export declare var SendPipelineExecutionStepSuccess$: StaticOperationSchema;
export declare var StartEdgeDeploymentStage$: StaticOperationSchema;
export declare var StartInferenceExperiment$: StaticOperationSchema;
export declare var StartMlflowTrackingServer$: StaticOperationSchema;
export declare var StartMonitoringSchedule$: StaticOperationSchema;
export declare var StartNotebookInstance$: StaticOperationSchema;
export declare var StartPipelineExecution$: StaticOperationSchema;
export declare var StartSession$: StaticOperationSchema;
export declare var StopAutoMLJob$: StaticOperationSchema;
export declare var StopCompilationJob$: StaticOperationSchema;
export declare var StopEdgeDeploymentStage$: StaticOperationSchema;
export declare var StopEdgePackagingJob$: StaticOperationSchema;
export declare var StopHyperParameterTuningJob$: StaticOperationSchema;
export declare var StopInferenceExperiment$: StaticOperationSchema;
export declare var StopInferenceRecommendationsJob$: StaticOperationSchema;
export declare var StopLabelingJob$: StaticOperationSchema;
export declare var StopMlflowTrackingServer$: StaticOperationSchema;
export declare var StopMonitoringSchedule$: StaticOperationSchema;
export declare var StopNotebookInstance$: StaticOperationSchema;
export declare var StopOptimizationJob$: StaticOperationSchema;
export declare var StopPipelineExecution$: StaticOperationSchema;
export declare var StopProcessingJob$: StaticOperationSchema;
export declare var StopTrainingJob$: StaticOperationSchema;
export declare var StopTransformJob$: StaticOperationSchema;
export declare var UpdateAction$: StaticOperationSchema;
export declare var UpdateAppImageConfig$: StaticOperationSchema;
export declare var UpdateArtifact$: StaticOperationSchema;
export declare var UpdateCluster$: StaticOperationSchema;
export declare var UpdateClusterSchedulerConfig$: StaticOperationSchema;
export declare var UpdateClusterSoftware$: StaticOperationSchema;
export declare var UpdateCodeRepository$: StaticOperationSchema;
export declare var UpdateComputeQuota$: StaticOperationSchema;
export declare var UpdateContext$: StaticOperationSchema;
export declare var UpdateDeviceFleet$: StaticOperationSchema;
export declare var UpdateDevices$: StaticOperationSchema;
export declare var UpdateDomain$: StaticOperationSchema;
export declare var UpdateEndpoint$: StaticOperationSchema;
export declare var UpdateEndpointWeightsAndCapacities$: StaticOperationSchema;
export declare var UpdateExperiment$: StaticOperationSchema;
export declare var UpdateFeatureGroup$: StaticOperationSchema;
export declare var UpdateFeatureMetadata$: StaticOperationSchema;
export declare var UpdateHub$: StaticOperationSchema;
export declare var UpdateHubContent$: StaticOperationSchema;
export declare var UpdateHubContentReference$: StaticOperationSchema;
export declare var UpdateImage$: StaticOperationSchema;
export declare var UpdateImageVersion$: StaticOperationSchema;
export declare var UpdateInferenceComponent$: StaticOperationSchema;
export declare var UpdateInferenceComponentRuntimeConfig$: StaticOperationSchema;
export declare var UpdateInferenceExperiment$: StaticOperationSchema;
export declare var UpdateMlflowApp$: StaticOperationSchema;
export declare var UpdateMlflowTrackingServer$: StaticOperationSchema;
export declare var UpdateModelCard$: StaticOperationSchema;
export declare var UpdateModelPackage$: StaticOperationSchema;
export declare var UpdateMonitoringAlert$: StaticOperationSchema;
export declare var UpdateMonitoringSchedule$: StaticOperationSchema;
export declare var UpdateNotebookInstance$: StaticOperationSchema;
export declare var UpdateNotebookInstanceLifecycleConfig$: StaticOperationSchema;
export declare var UpdatePartnerApp$: StaticOperationSchema;
export declare var UpdatePipeline$: StaticOperationSchema;
export declare var UpdatePipelineExecution$: StaticOperationSchema;
export declare var UpdatePipelineVersion$: StaticOperationSchema;
export declare var UpdateProject$: StaticOperationSchema;
export declare var UpdateSpace$: StaticOperationSchema;
export declare var UpdateTrainingJob$: StaticOperationSchema;
export declare var UpdateTrial$: StaticOperationSchema;
export declare var UpdateTrialComponent$: StaticOperationSchema;
export declare var UpdateUserProfile$: StaticOperationSchema;
export declare var UpdateWorkforce$: StaticOperationSchema;
export declare var UpdateWorkteam$: StaticOperationSchema;
