import { Paginator } from "@smithy/types";
import {
  ListModelsCommandInput,
  ListModelsCommandOutput,
} from "../commands/ListModelsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
export declare const paginateListModels: (
  config: SageMakerPaginationConfiguration,
  input: ListModelsCommandInput,
  ...rest: any[]
) => Paginator<ListModelsCommandOutput>;
