import { Paginator } from "@smithy/types";
import {
  ListActionsCommandInput,
  ListActionsCommandOutput,
} from "../commands/ListActionsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
export declare const paginateListActions: (
  config: SageMakerPaginationConfiguration,
  input: ListActionsCommandInput,
  ...rest: any[]
) => Paginator<ListActionsCommandOutput>;
