import type { Paginator } from "@smithy/types";
import { ListStudioLifecycleConfigsCommandInput, ListStudioLifecycleConfigsCommandOutput } from "../commands/ListStudioLifecycleConfigsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListStudioLifecycleConfigs: (config: SageMakerPaginationConfiguration, input: ListStudioLifecycleConfigsCommandInput, ...rest: any[]) => Paginator<ListStudioLifecycleConfigsCommandOutput>;
