import type { Paginator } from "@smithy/types";
import { ListAppsCommandInput, ListAppsCommandOutput } from "../commands/ListAppsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListApps: (config: SageMakerPaginationConfiguration, input: ListAppsCommandInput, ...rest: any[]) => Paginator<ListAppsCommandOutput>;
