import type { Paginator } from "@smithy/types";
import { ListAliasesCommandInput, ListAliasesCommandOutput } from "../commands/ListAliasesCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListAliases: (config: SageMakerPaginationConfiguration, input: ListAliasesCommandInput, ...rest: any[]) => Paginator<ListAliasesCommandOutput>;
