import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  BatchReplaceClusterNodesRequest,
  BatchReplaceClusterNodesResponse,
} from "../models/models_0";
import {
  SageMakerClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../SageMakerClient";
export { __MetadataBearer };
export { $Command };
export interface BatchReplaceClusterNodesCommandInput
  extends BatchReplaceClusterNodesRequest {}
export interface BatchReplaceClusterNodesCommandOutput
  extends BatchReplaceClusterNodesResponse,
    __MetadataBearer {}
declare const BatchReplaceClusterNodesCommand_base: {
  new (
    input: BatchReplaceClusterNodesCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    BatchReplaceClusterNodesCommandInput,
    BatchReplaceClusterNodesCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: BatchReplaceClusterNodesCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    BatchReplaceClusterNodesCommandInput,
    BatchReplaceClusterNodesCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class BatchReplaceClusterNodesCommand extends BatchReplaceClusterNodesCommand_base {
  protected static __types: {
    api: {
      input: BatchReplaceClusterNodesRequest;
      output: BatchReplaceClusterNodesResponse;
    };
    sdk: {
      input: BatchReplaceClusterNodesCommandInput;
      output: BatchReplaceClusterNodesCommandOutput;
    };
  };
}
