import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  DetachClusterNodeVolumeRequest,
  DetachClusterNodeVolumeResponse,
} from "../models/models_3";
import {
  SageMakerClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../SageMakerClient";
export { __MetadataBearer };
export { $Command };
export interface DetachClusterNodeVolumeCommandInput
  extends DetachClusterNodeVolumeRequest {}
export interface DetachClusterNodeVolumeCommandOutput
  extends DetachClusterNodeVolumeResponse,
    __MetadataBearer {}
declare const DetachClusterNodeVolumeCommand_base: {
  new (
    input: DetachClusterNodeVolumeCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    DetachClusterNodeVolumeCommandInput,
    DetachClusterNodeVolumeCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: DetachClusterNodeVolumeCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    DetachClusterNodeVolumeCommandInput,
    DetachClusterNodeVolumeCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class DetachClusterNodeVolumeCommand extends DetachClusterNodeVolumeCommand_base {
  protected static __types: {
    api: {
      input: DetachClusterNodeVolumeRequest;
      output: DetachClusterNodeVolumeResponse;
    };
    sdk: {
      input: DetachClusterNodeVolumeCommandInput;
      output: DetachClusterNodeVolumeCommandOutput;
    };
  };
}
