import type { Paginator } from "@smithy/types";
import { ListExperimentsCommandInput, ListExperimentsCommandOutput } from "../commands/ListExperimentsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListExperiments: (config: SageMakerPaginationConfiguration, input: ListExperimentsCommandInput, ...rest: any[]) => Paginator<ListExperimentsCommandOutput>;
