import type { Paginator } from "@smithy/types";
import { ListTrialsCommandInput, ListTrialsCommandOutput } from "../commands/ListTrialsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListTrials: (config: SageMakerPaginationConfiguration, input: ListTrialsCommandInput, ...rest: any[]) => Paginator<ListTrialsCommandOutput>;
