import { Paginator } from "@smithy/types";
import {
  ListMlflowAppsCommandInput,
  ListMlflowAppsCommandOutput,
} from "../commands/ListMlflowAppsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
export declare const paginateListMlflowApps: (
  config: SageMakerPaginationConfiguration,
  input: ListMlflowAppsCommandInput,
  ...rest: any[]
) => Paginator<ListMlflowAppsCommandOutput>;
