import { createAggregatedClient } from "@smithy/smithy-client";
import { AddAssociationCommand, } from "./commands/AddAssociationCommand";
import { AddTagsCommand } from "./commands/AddTagsCommand";
import { AssociateTrialComponentCommand, } from "./commands/AssociateTrialComponentCommand";
import { AttachClusterNodeVolumeCommand, } from "./commands/AttachClusterNodeVolumeCommand";
import { BatchAddClusterNodesCommand, } from "./commands/BatchAddClusterNodesCommand";
import { BatchDeleteClusterNodesCommand, } from "./commands/BatchDeleteClusterNodesCommand";
import { BatchDescribeModelPackageCommand, } from "./commands/BatchDescribeModelPackageCommand";
import { BatchRebootClusterNodesCommand, } from "./commands/BatchRebootClusterNodesCommand";
import { BatchReplaceClusterNodesCommand, } from "./commands/BatchReplaceClusterNodesCommand";
import { CreateActionCommand, } from "./commands/CreateActionCommand";
import { CreateAlgorithmCommand, } from "./commands/CreateAlgorithmCommand";
import { CreateAppCommand } from "./commands/CreateAppCommand";
import { CreateAppImageConfigCommand, } from "./commands/CreateAppImageConfigCommand";
import { CreateArtifactCommand, } from "./commands/CreateArtifactCommand";
import { CreateAutoMLJobCommand, } from "./commands/CreateAutoMLJobCommand";
import { CreateAutoMLJobV2Command, } from "./commands/CreateAutoMLJobV2Command";
import { CreateClusterCommand, } from "./commands/CreateClusterCommand";
import { CreateClusterSchedulerConfigCommand, } from "./commands/CreateClusterSchedulerConfigCommand";
import { CreateCodeRepositoryCommand, } from "./commands/CreateCodeRepositoryCommand";
import { CreateCompilationJobCommand, } from "./commands/CreateCompilationJobCommand";
import { CreateComputeQuotaCommand, } from "./commands/CreateComputeQuotaCommand";
import { CreateContextCommand, } from "./commands/CreateContextCommand";
import { CreateDataQualityJobDefinitionCommand, } from "./commands/CreateDataQualityJobDefinitionCommand";
import { CreateDeviceFleetCommand, } from "./commands/CreateDeviceFleetCommand";
import { CreateDomainCommand, } from "./commands/CreateDomainCommand";
import { CreateEdgeDeploymentPlanCommand, } from "./commands/CreateEdgeDeploymentPlanCommand";
import { CreateEdgeDeploymentStageCommand, } from "./commands/CreateEdgeDeploymentStageCommand";
import { CreateEdgePackagingJobCommand, } from "./commands/CreateEdgePackagingJobCommand";
import { CreateEndpointCommand, } from "./commands/CreateEndpointCommand";
import { CreateEndpointConfigCommand, } from "./commands/CreateEndpointConfigCommand";
import { CreateExperimentCommand, } from "./commands/CreateExperimentCommand";
import { CreateFeatureGroupCommand, } from "./commands/CreateFeatureGroupCommand";
import { CreateFlowDefinitionCommand, } from "./commands/CreateFlowDefinitionCommand";
import { CreateHubCommand } from "./commands/CreateHubCommand";
import { CreateHubContentPresignedUrlsCommand, } from "./commands/CreateHubContentPresignedUrlsCommand";
import { CreateHubContentReferenceCommand, } from "./commands/CreateHubContentReferenceCommand";
import { CreateHumanTaskUiCommand, } from "./commands/CreateHumanTaskUiCommand";
import { CreateHyperParameterTuningJobCommand, } from "./commands/CreateHyperParameterTuningJobCommand";
import { CreateImageCommand } from "./commands/CreateImageCommand";
import { CreateImageVersionCommand, } from "./commands/CreateImageVersionCommand";
import { CreateInferenceComponentCommand, } from "./commands/CreateInferenceComponentCommand";
import { CreateInferenceExperimentCommand, } from "./commands/CreateInferenceExperimentCommand";
import { CreateInferenceRecommendationsJobCommand, } from "./commands/CreateInferenceRecommendationsJobCommand";
import { CreateLabelingJobCommand, } from "./commands/CreateLabelingJobCommand";
import { CreateMlflowAppCommand, } from "./commands/CreateMlflowAppCommand";
import { CreateMlflowTrackingServerCommand, } from "./commands/CreateMlflowTrackingServerCommand";
import { CreateModelBiasJobDefinitionCommand, } from "./commands/CreateModelBiasJobDefinitionCommand";
import { CreateModelCardCommand, } from "./commands/CreateModelCardCommand";
import { CreateModelCardExportJobCommand, } from "./commands/CreateModelCardExportJobCommand";
import { CreateModelCommand } from "./commands/CreateModelCommand";
import { CreateModelExplainabilityJobDefinitionCommand, } from "./commands/CreateModelExplainabilityJobDefinitionCommand";
import { CreateModelPackageCommand, } from "./commands/CreateModelPackageCommand";
import { CreateModelPackageGroupCommand, } from "./commands/CreateModelPackageGroupCommand";
import { CreateModelQualityJobDefinitionCommand, } from "./commands/CreateModelQualityJobDefinitionCommand";
import { CreateMonitoringScheduleCommand, } from "./commands/CreateMonitoringScheduleCommand";
import { CreateNotebookInstanceCommand, } from "./commands/CreateNotebookInstanceCommand";
import { CreateNotebookInstanceLifecycleConfigCommand, } from "./commands/CreateNotebookInstanceLifecycleConfigCommand";
import { CreateOptimizationJobCommand, } from "./commands/CreateOptimizationJobCommand";
import { CreatePartnerAppCommand, } from "./commands/CreatePartnerAppCommand";
import { CreatePartnerAppPresignedUrlCommand, } from "./commands/CreatePartnerAppPresignedUrlCommand";
import { CreatePipelineCommand, } from "./commands/CreatePipelineCommand";
import { CreatePresignedDomainUrlCommand, } from "./commands/CreatePresignedDomainUrlCommand";
import { CreatePresignedMlflowAppUrlCommand, } from "./commands/CreatePresignedMlflowAppUrlCommand";
import { CreatePresignedMlflowTrackingServerUrlCommand, } from "./commands/CreatePresignedMlflowTrackingServerUrlCommand";
import { CreatePresignedNotebookInstanceUrlCommand, } from "./commands/CreatePresignedNotebookInstanceUrlCommand";
import { CreateProcessingJobCommand, } from "./commands/CreateProcessingJobCommand";
import { CreateProjectCommand, } from "./commands/CreateProjectCommand";
import { CreateSpaceCommand } from "./commands/CreateSpaceCommand";
import { CreateStudioLifecycleConfigCommand, } from "./commands/CreateStudioLifecycleConfigCommand";
import { CreateTrainingJobCommand, } from "./commands/CreateTrainingJobCommand";
import { CreateTrainingPlanCommand, } from "./commands/CreateTrainingPlanCommand";
import { CreateTransformJobCommand, } from "./commands/CreateTransformJobCommand";
import { CreateTrialCommand } from "./commands/CreateTrialCommand";
import { CreateTrialComponentCommand, } from "./commands/CreateTrialComponentCommand";
import { CreateUserProfileCommand, } from "./commands/CreateUserProfileCommand";
import { CreateWorkforceCommand, } from "./commands/CreateWorkforceCommand";
import { CreateWorkteamCommand, } from "./commands/CreateWorkteamCommand";
import { DeleteActionCommand, } from "./commands/DeleteActionCommand";
import { DeleteAlgorithmCommand, } from "./commands/DeleteAlgorithmCommand";
import { DeleteAppCommand } from "./commands/DeleteAppCommand";
import { DeleteAppImageConfigCommand, } from "./commands/DeleteAppImageConfigCommand";
import { DeleteArtifactCommand, } from "./commands/DeleteArtifactCommand";
import { DeleteAssociationCommand, } from "./commands/DeleteAssociationCommand";
import { DeleteClusterCommand, } from "./commands/DeleteClusterCommand";
import { DeleteClusterSchedulerConfigCommand, } from "./commands/DeleteClusterSchedulerConfigCommand";
import { DeleteCodeRepositoryCommand, } from "./commands/DeleteCodeRepositoryCommand";
import { DeleteCompilationJobCommand, } from "./commands/DeleteCompilationJobCommand";
import { DeleteComputeQuotaCommand, } from "./commands/DeleteComputeQuotaCommand";
import { DeleteContextCommand, } from "./commands/DeleteContextCommand";
import { DeleteDataQualityJobDefinitionCommand, } from "./commands/DeleteDataQualityJobDefinitionCommand";
import { DeleteDeviceFleetCommand, } from "./commands/DeleteDeviceFleetCommand";
import { DeleteDomainCommand, } from "./commands/DeleteDomainCommand";
import { DeleteEdgeDeploymentPlanCommand, } from "./commands/DeleteEdgeDeploymentPlanCommand";
import { DeleteEdgeDeploymentStageCommand, } from "./commands/DeleteEdgeDeploymentStageCommand";
import { DeleteEndpointCommand, } from "./commands/DeleteEndpointCommand";
import { DeleteEndpointConfigCommand, } from "./commands/DeleteEndpointConfigCommand";
import { DeleteExperimentCommand, } from "./commands/DeleteExperimentCommand";
import { DeleteFeatureGroupCommand, } from "./commands/DeleteFeatureGroupCommand";
import { DeleteFlowDefinitionCommand, } from "./commands/DeleteFlowDefinitionCommand";
import { DeleteHubCommand } from "./commands/DeleteHubCommand";
import { DeleteHubContentCommand, } from "./commands/DeleteHubContentCommand";
import { DeleteHubContentReferenceCommand, } from "./commands/DeleteHubContentReferenceCommand";
import { DeleteHumanTaskUiCommand, } from "./commands/DeleteHumanTaskUiCommand";
import { DeleteHyperParameterTuningJobCommand, } from "./commands/DeleteHyperParameterTuningJobCommand";
import { DeleteImageCommand } from "./commands/DeleteImageCommand";
import { DeleteImageVersionCommand, } from "./commands/DeleteImageVersionCommand";
import { DeleteInferenceComponentCommand, } from "./commands/DeleteInferenceComponentCommand";
import { DeleteInferenceExperimentCommand, } from "./commands/DeleteInferenceExperimentCommand";
import { DeleteMlflowAppCommand, } from "./commands/DeleteMlflowAppCommand";
import { DeleteMlflowTrackingServerCommand, } from "./commands/DeleteMlflowTrackingServerCommand";
import { DeleteModelBiasJobDefinitionCommand, } from "./commands/DeleteModelBiasJobDefinitionCommand";
import { DeleteModelCardCommand, } from "./commands/DeleteModelCardCommand";
import { DeleteModelCommand } from "./commands/DeleteModelCommand";
import { DeleteModelExplainabilityJobDefinitionCommand, } from "./commands/DeleteModelExplainabilityJobDefinitionCommand";
import { DeleteModelPackageCommand, } from "./commands/DeleteModelPackageCommand";
import { DeleteModelPackageGroupCommand, } from "./commands/DeleteModelPackageGroupCommand";
import { DeleteModelPackageGroupPolicyCommand, } from "./commands/DeleteModelPackageGroupPolicyCommand";
import { DeleteModelQualityJobDefinitionCommand, } from "./commands/DeleteModelQualityJobDefinitionCommand";
import { DeleteMonitoringScheduleCommand, } from "./commands/DeleteMonitoringScheduleCommand";
import { DeleteNotebookInstanceCommand, } from "./commands/DeleteNotebookInstanceCommand";
import { DeleteNotebookInstanceLifecycleConfigCommand, } from "./commands/DeleteNotebookInstanceLifecycleConfigCommand";
import { DeleteOptimizationJobCommand, } from "./commands/DeleteOptimizationJobCommand";
import { DeletePartnerAppCommand, } from "./commands/DeletePartnerAppCommand";
import { DeletePipelineCommand, } from "./commands/DeletePipelineCommand";
import { DeleteProcessingJobCommand, } from "./commands/DeleteProcessingJobCommand";
import { DeleteProjectCommand, } from "./commands/DeleteProjectCommand";
import { DeleteSpaceCommand } from "./commands/DeleteSpaceCommand";
import { DeleteStudioLifecycleConfigCommand, } from "./commands/DeleteStudioLifecycleConfigCommand";
import { DeleteTagsCommand } from "./commands/DeleteTagsCommand";
import { DeleteTrainingJobCommand, } from "./commands/DeleteTrainingJobCommand";
import { DeleteTrialCommand } from "./commands/DeleteTrialCommand";
import { DeleteTrialComponentCommand, } from "./commands/DeleteTrialComponentCommand";
import { DeleteUserProfileCommand, } from "./commands/DeleteUserProfileCommand";
import { DeleteWorkforceCommand, } from "./commands/DeleteWorkforceCommand";
import { DeleteWorkteamCommand, } from "./commands/DeleteWorkteamCommand";
import { DeregisterDevicesCommand, } from "./commands/DeregisterDevicesCommand";
import { DescribeActionCommand, } from "./commands/DescribeActionCommand";
import { DescribeAlgorithmCommand, } from "./commands/DescribeAlgorithmCommand";
import { DescribeAppCommand } from "./commands/DescribeAppCommand";
import { DescribeAppImageConfigCommand, } from "./commands/DescribeAppImageConfigCommand";
import { DescribeArtifactCommand, } from "./commands/DescribeArtifactCommand";
import { DescribeAutoMLJobCommand, } from "./commands/DescribeAutoMLJobCommand";
import { DescribeAutoMLJobV2Command, } from "./commands/DescribeAutoMLJobV2Command";
import { DescribeClusterCommand, } from "./commands/DescribeClusterCommand";
import { DescribeClusterEventCommand, } from "./commands/DescribeClusterEventCommand";
import { DescribeClusterNodeCommand, } from "./commands/DescribeClusterNodeCommand";
import { DescribeClusterSchedulerConfigCommand, } from "./commands/DescribeClusterSchedulerConfigCommand";
import { DescribeCodeRepositoryCommand, } from "./commands/DescribeCodeRepositoryCommand";
import { DescribeCompilationJobCommand, } from "./commands/DescribeCompilationJobCommand";
import { DescribeComputeQuotaCommand, } from "./commands/DescribeComputeQuotaCommand";
import { DescribeContextCommand, } from "./commands/DescribeContextCommand";
import { DescribeDataQualityJobDefinitionCommand, } from "./commands/DescribeDataQualityJobDefinitionCommand";
import { DescribeDeviceCommand, } from "./commands/DescribeDeviceCommand";
import { DescribeDeviceFleetCommand, } from "./commands/DescribeDeviceFleetCommand";
import { DescribeDomainCommand, } from "./commands/DescribeDomainCommand";
import { DescribeEdgeDeploymentPlanCommand, } from "./commands/DescribeEdgeDeploymentPlanCommand";
import { DescribeEdgePackagingJobCommand, } from "./commands/DescribeEdgePackagingJobCommand";
import { DescribeEndpointCommand, } from "./commands/DescribeEndpointCommand";
import { DescribeEndpointConfigCommand, } from "./commands/DescribeEndpointConfigCommand";
import { DescribeExperimentCommand, } from "./commands/DescribeExperimentCommand";
import { DescribeFeatureGroupCommand, } from "./commands/DescribeFeatureGroupCommand";
import { DescribeFeatureMetadataCommand, } from "./commands/DescribeFeatureMetadataCommand";
import { DescribeFlowDefinitionCommand, } from "./commands/DescribeFlowDefinitionCommand";
import { DescribeHubCommand } from "./commands/DescribeHubCommand";
import { DescribeHubContentCommand, } from "./commands/DescribeHubContentCommand";
import { DescribeHumanTaskUiCommand, } from "./commands/DescribeHumanTaskUiCommand";
import { DescribeHyperParameterTuningJobCommand, } from "./commands/DescribeHyperParameterTuningJobCommand";
import { DescribeImageCommand, } from "./commands/DescribeImageCommand";
import { DescribeImageVersionCommand, } from "./commands/DescribeImageVersionCommand";
import { DescribeInferenceComponentCommand, } from "./commands/DescribeInferenceComponentCommand";
import { DescribeInferenceExperimentCommand, } from "./commands/DescribeInferenceExperimentCommand";
import { DescribeInferenceRecommendationsJobCommand, } from "./commands/DescribeInferenceRecommendationsJobCommand";
import { DescribeLabelingJobCommand, } from "./commands/DescribeLabelingJobCommand";
import { DescribeLineageGroupCommand, } from "./commands/DescribeLineageGroupCommand";
import { DescribeMlflowAppCommand, } from "./commands/DescribeMlflowAppCommand";
import { DescribeMlflowTrackingServerCommand, } from "./commands/DescribeMlflowTrackingServerCommand";
import { DescribeModelBiasJobDefinitionCommand, } from "./commands/DescribeModelBiasJobDefinitionCommand";
import { DescribeModelCardCommand, } from "./commands/DescribeModelCardCommand";
import { DescribeModelCardExportJobCommand, } from "./commands/DescribeModelCardExportJobCommand";
import { DescribeModelCommand, } from "./commands/DescribeModelCommand";
import { DescribeModelExplainabilityJobDefinitionCommand, } from "./commands/DescribeModelExplainabilityJobDefinitionCommand";
import { DescribeModelPackageCommand, } from "./commands/DescribeModelPackageCommand";
import { DescribeModelPackageGroupCommand, } from "./commands/DescribeModelPackageGroupCommand";
import { DescribeModelQualityJobDefinitionCommand, } from "./commands/DescribeModelQualityJobDefinitionCommand";
import { DescribeMonitoringScheduleCommand, } from "./commands/DescribeMonitoringScheduleCommand";
import { DescribeNotebookInstanceCommand, } from "./commands/DescribeNotebookInstanceCommand";
import { DescribeNotebookInstanceLifecycleConfigCommand, } from "./commands/DescribeNotebookInstanceLifecycleConfigCommand";
import { DescribeOptimizationJobCommand, } from "./commands/DescribeOptimizationJobCommand";
import { DescribePartnerAppCommand, } from "./commands/DescribePartnerAppCommand";
import { DescribePipelineCommand, } from "./commands/DescribePipelineCommand";
import { DescribePipelineDefinitionForExecutionCommand, } from "./commands/DescribePipelineDefinitionForExecutionCommand";
import { DescribePipelineExecutionCommand, } from "./commands/DescribePipelineExecutionCommand";
import { DescribeProcessingJobCommand, } from "./commands/DescribeProcessingJobCommand";
import { DescribeProjectCommand, } from "./commands/DescribeProjectCommand";
import { DescribeReservedCapacityCommand, } from "./commands/DescribeReservedCapacityCommand";
import { DescribeSpaceCommand, } from "./commands/DescribeSpaceCommand";
import { DescribeStudioLifecycleConfigCommand, } from "./commands/DescribeStudioLifecycleConfigCommand";
import { DescribeSubscribedWorkteamCommand, } from "./commands/DescribeSubscribedWorkteamCommand";
import { DescribeTrainingJobCommand, } from "./commands/DescribeTrainingJobCommand";
import { DescribeTrainingPlanCommand, } from "./commands/DescribeTrainingPlanCommand";
import { DescribeTransformJobCommand, } from "./commands/DescribeTransformJobCommand";
import { DescribeTrialCommand, } from "./commands/DescribeTrialCommand";
import { DescribeTrialComponentCommand, } from "./commands/DescribeTrialComponentCommand";
import { DescribeUserProfileCommand, } from "./commands/DescribeUserProfileCommand";
import { DescribeWorkforceCommand, } from "./commands/DescribeWorkforceCommand";
import { DescribeWorkteamCommand, } from "./commands/DescribeWorkteamCommand";
import { DetachClusterNodeVolumeCommand, } from "./commands/DetachClusterNodeVolumeCommand";
import { DisableSagemakerServicecatalogPortfolioCommand, } from "./commands/DisableSagemakerServicecatalogPortfolioCommand";
import { DisassociateTrialComponentCommand, } from "./commands/DisassociateTrialComponentCommand";
import { EnableSagemakerServicecatalogPortfolioCommand, } from "./commands/EnableSagemakerServicecatalogPortfolioCommand";
import { GetDeviceFleetReportCommand, } from "./commands/GetDeviceFleetReportCommand";
import { GetLineageGroupPolicyCommand, } from "./commands/GetLineageGroupPolicyCommand";
import { GetModelPackageGroupPolicyCommand, } from "./commands/GetModelPackageGroupPolicyCommand";
import { GetSagemakerServicecatalogPortfolioStatusCommand, } from "./commands/GetSagemakerServicecatalogPortfolioStatusCommand";
import { GetScalingConfigurationRecommendationCommand, } from "./commands/GetScalingConfigurationRecommendationCommand";
import { GetSearchSuggestionsCommand, } from "./commands/GetSearchSuggestionsCommand";
import { ImportHubContentCommand, } from "./commands/ImportHubContentCommand";
import { ListActionsCommand } from "./commands/ListActionsCommand";
import { ListAlgorithmsCommand, } from "./commands/ListAlgorithmsCommand";
import { ListAliasesCommand } from "./commands/ListAliasesCommand";
import { ListAppImageConfigsCommand, } from "./commands/ListAppImageConfigsCommand";
import { ListAppsCommand } from "./commands/ListAppsCommand";
import { ListArtifactsCommand, } from "./commands/ListArtifactsCommand";
import { ListAssociationsCommand, } from "./commands/ListAssociationsCommand";
import { ListAutoMLJobsCommand, } from "./commands/ListAutoMLJobsCommand";
import { ListCandidatesForAutoMLJobCommand, } from "./commands/ListCandidatesForAutoMLJobCommand";
import { ListClusterEventsCommand, } from "./commands/ListClusterEventsCommand";
import { ListClusterNodesCommand, } from "./commands/ListClusterNodesCommand";
import { ListClusterSchedulerConfigsCommand, } from "./commands/ListClusterSchedulerConfigsCommand";
import { ListClustersCommand, } from "./commands/ListClustersCommand";
import { ListCodeRepositoriesCommand, } from "./commands/ListCodeRepositoriesCommand";
import { ListCompilationJobsCommand, } from "./commands/ListCompilationJobsCommand";
import { ListComputeQuotasCommand, } from "./commands/ListComputeQuotasCommand";
import { ListContextsCommand, } from "./commands/ListContextsCommand";
import { ListDataQualityJobDefinitionsCommand, } from "./commands/ListDataQualityJobDefinitionsCommand";
import { ListDeviceFleetsCommand, } from "./commands/ListDeviceFleetsCommand";
import { ListDevicesCommand } from "./commands/ListDevicesCommand";
import { ListDomainsCommand } from "./commands/ListDomainsCommand";
import { ListEdgeDeploymentPlansCommand, } from "./commands/ListEdgeDeploymentPlansCommand";
import { ListEdgePackagingJobsCommand, } from "./commands/ListEdgePackagingJobsCommand";
import { ListEndpointConfigsCommand, } from "./commands/ListEndpointConfigsCommand";
import { ListEndpointsCommand, } from "./commands/ListEndpointsCommand";
import { ListExperimentsCommand, } from "./commands/ListExperimentsCommand";
import { ListFeatureGroupsCommand, } from "./commands/ListFeatureGroupsCommand";
import { ListFlowDefinitionsCommand, } from "./commands/ListFlowDefinitionsCommand";
import { ListHubContentsCommand, } from "./commands/ListHubContentsCommand";
import { ListHubContentVersionsCommand, } from "./commands/ListHubContentVersionsCommand";
import { ListHubsCommand } from "./commands/ListHubsCommand";
import { ListHumanTaskUisCommand, } from "./commands/ListHumanTaskUisCommand";
import { ListHyperParameterTuningJobsCommand, } from "./commands/ListHyperParameterTuningJobsCommand";
import { ListImagesCommand } from "./commands/ListImagesCommand";
import { ListImageVersionsCommand, } from "./commands/ListImageVersionsCommand";
import { ListInferenceComponentsCommand, } from "./commands/ListInferenceComponentsCommand";
import { ListInferenceExperimentsCommand, } from "./commands/ListInferenceExperimentsCommand";
import { ListInferenceRecommendationsJobsCommand, } from "./commands/ListInferenceRecommendationsJobsCommand";
import { ListInferenceRecommendationsJobStepsCommand, } from "./commands/ListInferenceRecommendationsJobStepsCommand";
import { ListLabelingJobsCommand, } from "./commands/ListLabelingJobsCommand";
import { ListLabelingJobsForWorkteamCommand, } from "./commands/ListLabelingJobsForWorkteamCommand";
import { ListLineageGroupsCommand, } from "./commands/ListLineageGroupsCommand";
import { ListMlflowAppsCommand, } from "./commands/ListMlflowAppsCommand";
import { ListMlflowTrackingServersCommand, } from "./commands/ListMlflowTrackingServersCommand";
import { ListModelBiasJobDefinitionsCommand, } from "./commands/ListModelBiasJobDefinitionsCommand";
import { ListModelCardExportJobsCommand, } from "./commands/ListModelCardExportJobsCommand";
import { ListModelCardsCommand, } from "./commands/ListModelCardsCommand";
import { ListModelCardVersionsCommand, } from "./commands/ListModelCardVersionsCommand";
import { ListModelExplainabilityJobDefinitionsCommand, } from "./commands/ListModelExplainabilityJobDefinitionsCommand";
import { ListModelMetadataCommand, } from "./commands/ListModelMetadataCommand";
import { ListModelPackageGroupsCommand, } from "./commands/ListModelPackageGroupsCommand";
import { ListModelPackagesCommand, } from "./commands/ListModelPackagesCommand";
import { ListModelQualityJobDefinitionsCommand, } from "./commands/ListModelQualityJobDefinitionsCommand";
import { ListModelsCommand } from "./commands/ListModelsCommand";
import { ListMonitoringAlertHistoryCommand, } from "./commands/ListMonitoringAlertHistoryCommand";
import { ListMonitoringAlertsCommand, } from "./commands/ListMonitoringAlertsCommand";
import { ListMonitoringExecutionsCommand, } from "./commands/ListMonitoringExecutionsCommand";
import { ListMonitoringSchedulesCommand, } from "./commands/ListMonitoringSchedulesCommand";
import { ListNotebookInstanceLifecycleConfigsCommand, } from "./commands/ListNotebookInstanceLifecycleConfigsCommand";
import { ListNotebookInstancesCommand, } from "./commands/ListNotebookInstancesCommand";
import { ListOptimizationJobsCommand, } from "./commands/ListOptimizationJobsCommand";
import { ListPartnerAppsCommand, } from "./commands/ListPartnerAppsCommand";
import { ListPipelineExecutionsCommand, } from "./commands/ListPipelineExecutionsCommand";
import { ListPipelineExecutionStepsCommand, } from "./commands/ListPipelineExecutionStepsCommand";
import { ListPipelineParametersForExecutionCommand, } from "./commands/ListPipelineParametersForExecutionCommand";
import { ListPipelinesCommand, } from "./commands/ListPipelinesCommand";
import { ListPipelineVersionsCommand, } from "./commands/ListPipelineVersionsCommand";
import { ListProcessingJobsCommand, } from "./commands/ListProcessingJobsCommand";
import { ListProjectsCommand, } from "./commands/ListProjectsCommand";
import { ListResourceCatalogsCommand, } from "./commands/ListResourceCatalogsCommand";
import { ListSpacesCommand } from "./commands/ListSpacesCommand";
import { ListStageDevicesCommand, } from "./commands/ListStageDevicesCommand";
import { ListStudioLifecycleConfigsCommand, } from "./commands/ListStudioLifecycleConfigsCommand";
import { ListSubscribedWorkteamsCommand, } from "./commands/ListSubscribedWorkteamsCommand";
import { ListTagsCommand } from "./commands/ListTagsCommand";
import { ListTrainingJobsCommand, } from "./commands/ListTrainingJobsCommand";
import { ListTrainingJobsForHyperParameterTuningJobCommand, } from "./commands/ListTrainingJobsForHyperParameterTuningJobCommand";
import { ListTrainingPlansCommand, } from "./commands/ListTrainingPlansCommand";
import { ListTransformJobsCommand, } from "./commands/ListTransformJobsCommand";
import { ListTrialComponentsCommand, } from "./commands/ListTrialComponentsCommand";
import { ListTrialsCommand } from "./commands/ListTrialsCommand";
import { ListUltraServersByReservedCapacityCommand, } from "./commands/ListUltraServersByReservedCapacityCommand";
import { ListUserProfilesCommand, } from "./commands/ListUserProfilesCommand";
import { ListWorkforcesCommand, } from "./commands/ListWorkforcesCommand";
import { ListWorkteamsCommand, } from "./commands/ListWorkteamsCommand";
import { PutModelPackageGroupPolicyCommand, } from "./commands/PutModelPackageGroupPolicyCommand";
import { QueryLineageCommand, } from "./commands/QueryLineageCommand";
import { RegisterDevicesCommand, } from "./commands/RegisterDevicesCommand";
import { RenderUiTemplateCommand, } from "./commands/RenderUiTemplateCommand";
import { RetryPipelineExecutionCommand, } from "./commands/RetryPipelineExecutionCommand";
import { SearchCommand } from "./commands/SearchCommand";
import { SearchTrainingPlanOfferingsCommand, } from "./commands/SearchTrainingPlanOfferingsCommand";
import { SendPipelineExecutionStepFailureCommand, } from "./commands/SendPipelineExecutionStepFailureCommand";
import { SendPipelineExecutionStepSuccessCommand, } from "./commands/SendPipelineExecutionStepSuccessCommand";
import { StartEdgeDeploymentStageCommand, } from "./commands/StartEdgeDeploymentStageCommand";
import { StartInferenceExperimentCommand, } from "./commands/StartInferenceExperimentCommand";
import { StartMlflowTrackingServerCommand, } from "./commands/StartMlflowTrackingServerCommand";
import { StartMonitoringScheduleCommand, } from "./commands/StartMonitoringScheduleCommand";
import { StartNotebookInstanceCommand, } from "./commands/StartNotebookInstanceCommand";
import { StartPipelineExecutionCommand, } from "./commands/StartPipelineExecutionCommand";
import { StartSessionCommand, } from "./commands/StartSessionCommand";
import { StopAutoMLJobCommand, } from "./commands/StopAutoMLJobCommand";
import { StopCompilationJobCommand, } from "./commands/StopCompilationJobCommand";
import { StopEdgeDeploymentStageCommand, } from "./commands/StopEdgeDeploymentStageCommand";
import { StopEdgePackagingJobCommand, } from "./commands/StopEdgePackagingJobCommand";
import { StopHyperParameterTuningJobCommand, } from "./commands/StopHyperParameterTuningJobCommand";
import { StopInferenceExperimentCommand, } from "./commands/StopInferenceExperimentCommand";
import { StopInferenceRecommendationsJobCommand, } from "./commands/StopInferenceRecommendationsJobCommand";
import { StopLabelingJobCommand, } from "./commands/StopLabelingJobCommand";
import { StopMlflowTrackingServerCommand, } from "./commands/StopMlflowTrackingServerCommand";
import { StopMonitoringScheduleCommand, } from "./commands/StopMonitoringScheduleCommand";
import { StopNotebookInstanceCommand, } from "./commands/StopNotebookInstanceCommand";
import { StopOptimizationJobCommand, } from "./commands/StopOptimizationJobCommand";
import { StopPipelineExecutionCommand, } from "./commands/StopPipelineExecutionCommand";
import { StopProcessingJobCommand, } from "./commands/StopProcessingJobCommand";
import { StopTrainingJobCommand, } from "./commands/StopTrainingJobCommand";
import { StopTransformJobCommand, } from "./commands/StopTransformJobCommand";
import { UpdateActionCommand, } from "./commands/UpdateActionCommand";
import { UpdateAppImageConfigCommand, } from "./commands/UpdateAppImageConfigCommand";
import { UpdateArtifactCommand, } from "./commands/UpdateArtifactCommand";
import { UpdateClusterCommand, } from "./commands/UpdateClusterCommand";
import { UpdateClusterSchedulerConfigCommand, } from "./commands/UpdateClusterSchedulerConfigCommand";
import { UpdateClusterSoftwareCommand, } from "./commands/UpdateClusterSoftwareCommand";
import { UpdateCodeRepositoryCommand, } from "./commands/UpdateCodeRepositoryCommand";
import { UpdateComputeQuotaCommand, } from "./commands/UpdateComputeQuotaCommand";
import { UpdateContextCommand, } from "./commands/UpdateContextCommand";
import { UpdateDeviceFleetCommand, } from "./commands/UpdateDeviceFleetCommand";
import { UpdateDevicesCommand, } from "./commands/UpdateDevicesCommand";
import { UpdateDomainCommand, } from "./commands/UpdateDomainCommand";
import { UpdateEndpointCommand, } from "./commands/UpdateEndpointCommand";
import { UpdateEndpointWeightsAndCapacitiesCommand, } from "./commands/UpdateEndpointWeightsAndCapacitiesCommand";
import { UpdateExperimentCommand, } from "./commands/UpdateExperimentCommand";
import { UpdateFeatureGroupCommand, } from "./commands/UpdateFeatureGroupCommand";
import { UpdateFeatureMetadataCommand, } from "./commands/UpdateFeatureMetadataCommand";
import { UpdateHubCommand } from "./commands/UpdateHubCommand";
import { UpdateHubContentCommand, } from "./commands/UpdateHubContentCommand";
import { UpdateHubContentReferenceCommand, } from "./commands/UpdateHubContentReferenceCommand";
import { UpdateImageCommand } from "./commands/UpdateImageCommand";
import { UpdateImageVersionCommand, } from "./commands/UpdateImageVersionCommand";
import { UpdateInferenceComponentCommand, } from "./commands/UpdateInferenceComponentCommand";
import { UpdateInferenceComponentRuntimeConfigCommand, } from "./commands/UpdateInferenceComponentRuntimeConfigCommand";
import { UpdateInferenceExperimentCommand, } from "./commands/UpdateInferenceExperimentCommand";
import { UpdateMlflowAppCommand, } from "./commands/UpdateMlflowAppCommand";
import { UpdateMlflowTrackingServerCommand, } from "./commands/UpdateMlflowTrackingServerCommand";
import { UpdateModelCardCommand, } from "./commands/UpdateModelCardCommand";
import { UpdateModelPackageCommand, } from "./commands/UpdateModelPackageCommand";
import { UpdateMonitoringAlertCommand, } from "./commands/UpdateMonitoringAlertCommand";
import { UpdateMonitoringScheduleCommand, } from "./commands/UpdateMonitoringScheduleCommand";
import { UpdateNotebookInstanceCommand, } from "./commands/UpdateNotebookInstanceCommand";
import { UpdateNotebookInstanceLifecycleConfigCommand, } from "./commands/UpdateNotebookInstanceLifecycleConfigCommand";
import { UpdatePartnerAppCommand, } from "./commands/UpdatePartnerAppCommand";
import { UpdatePipelineCommand, } from "./commands/UpdatePipelineCommand";
import { UpdatePipelineExecutionCommand, } from "./commands/UpdatePipelineExecutionCommand";
import { UpdatePipelineVersionCommand, } from "./commands/UpdatePipelineVersionCommand";
import { UpdateProjectCommand, } from "./commands/UpdateProjectCommand";
import { UpdateSpaceCommand } from "./commands/UpdateSpaceCommand";
import { UpdateTrainingJobCommand, } from "./commands/UpdateTrainingJobCommand";
import { UpdateTrialCommand } from "./commands/UpdateTrialCommand";
import { UpdateTrialComponentCommand, } from "./commands/UpdateTrialComponentCommand";
import { UpdateUserProfileCommand, } from "./commands/UpdateUserProfileCommand";
import { UpdateWorkforceCommand, } from "./commands/UpdateWorkforceCommand";
import { UpdateWorkteamCommand, } from "./commands/UpdateWorkteamCommand";
import { paginateCreateHubContentPresignedUrls } from "./pagination/CreateHubContentPresignedUrlsPaginator";
import { paginateListActions } from "./pagination/ListActionsPaginator";
import { paginateListAlgorithms } from "./pagination/ListAlgorithmsPaginator";
import { paginateListAliases } from "./pagination/ListAliasesPaginator";
import { paginateListAppImageConfigs } from "./pagination/ListAppImageConfigsPaginator";
import { paginateListApps } from "./pagination/ListAppsPaginator";
import { paginateListArtifacts } from "./pagination/ListArtifactsPaginator";
import { paginateListAssociations } from "./pagination/ListAssociationsPaginator";
import { paginateListAutoMLJobs } from "./pagination/ListAutoMLJobsPaginator";
import { paginateListCandidatesForAutoMLJob } from "./pagination/ListCandidatesForAutoMLJobPaginator";
import { paginateListClusterEvents } from "./pagination/ListClusterEventsPaginator";
import { paginateListClusterNodes } from "./pagination/ListClusterNodesPaginator";
import { paginateListClusterSchedulerConfigs } from "./pagination/ListClusterSchedulerConfigsPaginator";
import { paginateListClusters } from "./pagination/ListClustersPaginator";
import { paginateListCodeRepositories } from "./pagination/ListCodeRepositoriesPaginator";
import { paginateListCompilationJobs } from "./pagination/ListCompilationJobsPaginator";
import { paginateListComputeQuotas } from "./pagination/ListComputeQuotasPaginator";
import { paginateListContexts } from "./pagination/ListContextsPaginator";
import { paginateListDataQualityJobDefinitions } from "./pagination/ListDataQualityJobDefinitionsPaginator";
import { paginateListDeviceFleets } from "./pagination/ListDeviceFleetsPaginator";
import { paginateListDevices } from "./pagination/ListDevicesPaginator";
import { paginateListDomains } from "./pagination/ListDomainsPaginator";
import { paginateListEdgeDeploymentPlans } from "./pagination/ListEdgeDeploymentPlansPaginator";
import { paginateListEdgePackagingJobs } from "./pagination/ListEdgePackagingJobsPaginator";
import { paginateListEndpointConfigs } from "./pagination/ListEndpointConfigsPaginator";
import { paginateListEndpoints } from "./pagination/ListEndpointsPaginator";
import { paginateListExperiments } from "./pagination/ListExperimentsPaginator";
import { paginateListFeatureGroups } from "./pagination/ListFeatureGroupsPaginator";
import { paginateListFlowDefinitions } from "./pagination/ListFlowDefinitionsPaginator";
import { paginateListHumanTaskUis } from "./pagination/ListHumanTaskUisPaginator";
import { paginateListHyperParameterTuningJobs } from "./pagination/ListHyperParameterTuningJobsPaginator";
import { paginateListImages } from "./pagination/ListImagesPaginator";
import { paginateListImageVersions } from "./pagination/ListImageVersionsPaginator";
import { paginateListInferenceComponents } from "./pagination/ListInferenceComponentsPaginator";
import { paginateListInferenceExperiments } from "./pagination/ListInferenceExperimentsPaginator";
import { paginateListInferenceRecommendationsJobs } from "./pagination/ListInferenceRecommendationsJobsPaginator";
import { paginateListInferenceRecommendationsJobSteps, } from "./pagination/ListInferenceRecommendationsJobStepsPaginator";
import { paginateListLabelingJobsForWorkteam } from "./pagination/ListLabelingJobsForWorkteamPaginator";
import { paginateListLabelingJobs } from "./pagination/ListLabelingJobsPaginator";
import { paginateListLineageGroups } from "./pagination/ListLineageGroupsPaginator";
import { paginateListMlflowApps } from "./pagination/ListMlflowAppsPaginator";
import { paginateListMlflowTrackingServers } from "./pagination/ListMlflowTrackingServersPaginator";
import { paginateListModelBiasJobDefinitions } from "./pagination/ListModelBiasJobDefinitionsPaginator";
import { paginateListModelCardExportJobs } from "./pagination/ListModelCardExportJobsPaginator";
import { paginateListModelCards } from "./pagination/ListModelCardsPaginator";
import { paginateListModelCardVersions } from "./pagination/ListModelCardVersionsPaginator";
import { paginateListModelExplainabilityJobDefinitions, } from "./pagination/ListModelExplainabilityJobDefinitionsPaginator";
import { paginateListModelMetadata } from "./pagination/ListModelMetadataPaginator";
import { paginateListModelPackageGroups } from "./pagination/ListModelPackageGroupsPaginator";
import { paginateListModelPackages } from "./pagination/ListModelPackagesPaginator";
import { paginateListModelQualityJobDefinitions } from "./pagination/ListModelQualityJobDefinitionsPaginator";
import { paginateListModels } from "./pagination/ListModelsPaginator";
import { paginateListMonitoringAlertHistory } from "./pagination/ListMonitoringAlertHistoryPaginator";
import { paginateListMonitoringAlerts } from "./pagination/ListMonitoringAlertsPaginator";
import { paginateListMonitoringExecutions } from "./pagination/ListMonitoringExecutionsPaginator";
import { paginateListMonitoringSchedules } from "./pagination/ListMonitoringSchedulesPaginator";
import { paginateListNotebookInstanceLifecycleConfigs, } from "./pagination/ListNotebookInstanceLifecycleConfigsPaginator";
import { paginateListNotebookInstances } from "./pagination/ListNotebookInstancesPaginator";
import { paginateListOptimizationJobs } from "./pagination/ListOptimizationJobsPaginator";
import { paginateListPartnerApps } from "./pagination/ListPartnerAppsPaginator";
import { paginateListPipelineExecutions } from "./pagination/ListPipelineExecutionsPaginator";
import { paginateListPipelineExecutionSteps } from "./pagination/ListPipelineExecutionStepsPaginator";
import { paginateListPipelineParametersForExecution } from "./pagination/ListPipelineParametersForExecutionPaginator";
import { paginateListPipelines } from "./pagination/ListPipelinesPaginator";
import { paginateListPipelineVersions } from "./pagination/ListPipelineVersionsPaginator";
import { paginateListProcessingJobs } from "./pagination/ListProcessingJobsPaginator";
import { paginateListProjects } from "./pagination/ListProjectsPaginator";
import { paginateListResourceCatalogs } from "./pagination/ListResourceCatalogsPaginator";
import { paginateListSpaces } from "./pagination/ListSpacesPaginator";
import { paginateListStageDevices } from "./pagination/ListStageDevicesPaginator";
import { paginateListStudioLifecycleConfigs } from "./pagination/ListStudioLifecycleConfigsPaginator";
import { paginateListSubscribedWorkteams } from "./pagination/ListSubscribedWorkteamsPaginator";
import { paginateListTags } from "./pagination/ListTagsPaginator";
import { paginateListTrainingJobsForHyperParameterTuningJob, } from "./pagination/ListTrainingJobsForHyperParameterTuningJobPaginator";
import { paginateListTrainingJobs } from "./pagination/ListTrainingJobsPaginator";
import { paginateListTrainingPlans } from "./pagination/ListTrainingPlansPaginator";
import { paginateListTransformJobs } from "./pagination/ListTransformJobsPaginator";
import { paginateListTrialComponents } from "./pagination/ListTrialComponentsPaginator";
import { paginateListTrials } from "./pagination/ListTrialsPaginator";
import { paginateListUltraServersByReservedCapacity } from "./pagination/ListUltraServersByReservedCapacityPaginator";
import { paginateListUserProfiles } from "./pagination/ListUserProfilesPaginator";
import { paginateListWorkforces } from "./pagination/ListWorkforcesPaginator";
import { paginateListWorkteams } from "./pagination/ListWorkteamsPaginator";
import { paginateQueryLineage } from "./pagination/QueryLineagePaginator";
import { paginateSearch } from "./pagination/SearchPaginator";
import { SageMakerClient } from "./SageMakerClient";
import { waitUntilEndpointDeleted } from "./waiters/waitForEndpointDeleted";
import { waitUntilEndpointInService } from "./waiters/waitForEndpointInService";
import { waitUntilImageCreated } from "./waiters/waitForImageCreated";
import { waitUntilImageDeleted } from "./waiters/waitForImageDeleted";
import { waitUntilImageUpdated } from "./waiters/waitForImageUpdated";
import { waitUntilImageVersionCreated } from "./waiters/waitForImageVersionCreated";
import { waitUntilImageVersionDeleted } from "./waiters/waitForImageVersionDeleted";
import { waitUntilNotebookInstanceDeleted } from "./waiters/waitForNotebookInstanceDeleted";
import { waitUntilNotebookInstanceInService } from "./waiters/waitForNotebookInstanceInService";
import { waitUntilNotebookInstanceStopped } from "./waiters/waitForNotebookInstanceStopped";
import { waitUntilProcessingJobCompletedOrStopped } from "./waiters/waitForProcessingJobCompletedOrStopped";
import { waitUntilTrainingJobCompletedOrStopped } from "./waiters/waitForTrainingJobCompletedOrStopped";
import { waitUntilTransformJobCompletedOrStopped } from "./waiters/waitForTransformJobCompletedOrStopped";
const commands = {
    AddAssociationCommand,
    AddTagsCommand,
    AssociateTrialComponentCommand,
    AttachClusterNodeVolumeCommand,
    BatchAddClusterNodesCommand,
    BatchDeleteClusterNodesCommand,
    BatchDescribeModelPackageCommand,
    BatchRebootClusterNodesCommand,
    BatchReplaceClusterNodesCommand,
    CreateActionCommand,
    CreateAlgorithmCommand,
    CreateAppCommand,
    CreateAppImageConfigCommand,
    CreateArtifactCommand,
    CreateAutoMLJobCommand,
    CreateAutoMLJobV2Command,
    CreateClusterCommand,
    CreateClusterSchedulerConfigCommand,
    CreateCodeRepositoryCommand,
    CreateCompilationJobCommand,
    CreateComputeQuotaCommand,
    CreateContextCommand,
    CreateDataQualityJobDefinitionCommand,
    CreateDeviceFleetCommand,
    CreateDomainCommand,
    CreateEdgeDeploymentPlanCommand,
    CreateEdgeDeploymentStageCommand,
    CreateEdgePackagingJobCommand,
    CreateEndpointCommand,
    CreateEndpointConfigCommand,
    CreateExperimentCommand,
    CreateFeatureGroupCommand,
    CreateFlowDefinitionCommand,
    CreateHubCommand,
    CreateHubContentPresignedUrlsCommand,
    CreateHubContentReferenceCommand,
    CreateHumanTaskUiCommand,
    CreateHyperParameterTuningJobCommand,
    CreateImageCommand,
    CreateImageVersionCommand,
    CreateInferenceComponentCommand,
    CreateInferenceExperimentCommand,
    CreateInferenceRecommendationsJobCommand,
    CreateLabelingJobCommand,
    CreateMlflowAppCommand,
    CreateMlflowTrackingServerCommand,
    CreateModelCommand,
    CreateModelBiasJobDefinitionCommand,
    CreateModelCardCommand,
    CreateModelCardExportJobCommand,
    CreateModelExplainabilityJobDefinitionCommand,
    CreateModelPackageCommand,
    CreateModelPackageGroupCommand,
    CreateModelQualityJobDefinitionCommand,
    CreateMonitoringScheduleCommand,
    CreateNotebookInstanceCommand,
    CreateNotebookInstanceLifecycleConfigCommand,
    CreateOptimizationJobCommand,
    CreatePartnerAppCommand,
    CreatePartnerAppPresignedUrlCommand,
    CreatePipelineCommand,
    CreatePresignedDomainUrlCommand,
    CreatePresignedMlflowAppUrlCommand,
    CreatePresignedMlflowTrackingServerUrlCommand,
    CreatePresignedNotebookInstanceUrlCommand,
    CreateProcessingJobCommand,
    CreateProjectCommand,
    CreateSpaceCommand,
    CreateStudioLifecycleConfigCommand,
    CreateTrainingJobCommand,
    CreateTrainingPlanCommand,
    CreateTransformJobCommand,
    CreateTrialCommand,
    CreateTrialComponentCommand,
    CreateUserProfileCommand,
    CreateWorkforceCommand,
    CreateWorkteamCommand,
    DeleteActionCommand,
    DeleteAlgorithmCommand,
    DeleteAppCommand,
    DeleteAppImageConfigCommand,
    DeleteArtifactCommand,
    DeleteAssociationCommand,
    DeleteClusterCommand,
    DeleteClusterSchedulerConfigCommand,
    DeleteCodeRepositoryCommand,
    DeleteCompilationJobCommand,
    DeleteComputeQuotaCommand,
    DeleteContextCommand,
    DeleteDataQualityJobDefinitionCommand,
    DeleteDeviceFleetCommand,
    DeleteDomainCommand,
    DeleteEdgeDeploymentPlanCommand,
    DeleteEdgeDeploymentStageCommand,
    DeleteEndpointCommand,
    DeleteEndpointConfigCommand,
    DeleteExperimentCommand,
    DeleteFeatureGroupCommand,
    DeleteFlowDefinitionCommand,
    DeleteHubCommand,
    DeleteHubContentCommand,
    DeleteHubContentReferenceCommand,
    DeleteHumanTaskUiCommand,
    DeleteHyperParameterTuningJobCommand,
    DeleteImageCommand,
    DeleteImageVersionCommand,
    DeleteInferenceComponentCommand,
    DeleteInferenceExperimentCommand,
    DeleteMlflowAppCommand,
    DeleteMlflowTrackingServerCommand,
    DeleteModelCommand,
    DeleteModelBiasJobDefinitionCommand,
    DeleteModelCardCommand,
    DeleteModelExplainabilityJobDefinitionCommand,
    DeleteModelPackageCommand,
    DeleteModelPackageGroupCommand,
    DeleteModelPackageGroupPolicyCommand,
    DeleteModelQualityJobDefinitionCommand,
    DeleteMonitoringScheduleCommand,
    DeleteNotebookInstanceCommand,
    DeleteNotebookInstanceLifecycleConfigCommand,
    DeleteOptimizationJobCommand,
    DeletePartnerAppCommand,
    DeletePipelineCommand,
    DeleteProcessingJobCommand,
    DeleteProjectCommand,
    DeleteSpaceCommand,
    DeleteStudioLifecycleConfigCommand,
    DeleteTagsCommand,
    DeleteTrainingJobCommand,
    DeleteTrialCommand,
    DeleteTrialComponentCommand,
    DeleteUserProfileCommand,
    DeleteWorkforceCommand,
    DeleteWorkteamCommand,
    DeregisterDevicesCommand,
    DescribeActionCommand,
    DescribeAlgorithmCommand,
    DescribeAppCommand,
    DescribeAppImageConfigCommand,
    DescribeArtifactCommand,
    DescribeAutoMLJobCommand,
    DescribeAutoMLJobV2Command,
    DescribeClusterCommand,
    DescribeClusterEventCommand,
    DescribeClusterNodeCommand,
    DescribeClusterSchedulerConfigCommand,
    DescribeCodeRepositoryCommand,
    DescribeCompilationJobCommand,
    DescribeComputeQuotaCommand,
    DescribeContextCommand,
    DescribeDataQualityJobDefinitionCommand,
    DescribeDeviceCommand,
    DescribeDeviceFleetCommand,
    DescribeDomainCommand,
    DescribeEdgeDeploymentPlanCommand,
    DescribeEdgePackagingJobCommand,
    DescribeEndpointCommand,
    DescribeEndpointConfigCommand,
    DescribeExperimentCommand,
    DescribeFeatureGroupCommand,
    DescribeFeatureMetadataCommand,
    DescribeFlowDefinitionCommand,
    DescribeHubCommand,
    DescribeHubContentCommand,
    DescribeHumanTaskUiCommand,
    DescribeHyperParameterTuningJobCommand,
    DescribeImageCommand,
    DescribeImageVersionCommand,
    DescribeInferenceComponentCommand,
    DescribeInferenceExperimentCommand,
    DescribeInferenceRecommendationsJobCommand,
    DescribeLabelingJobCommand,
    DescribeLineageGroupCommand,
    DescribeMlflowAppCommand,
    DescribeMlflowTrackingServerCommand,
    DescribeModelCommand,
    DescribeModelBiasJobDefinitionCommand,
    DescribeModelCardCommand,
    DescribeModelCardExportJobCommand,
    DescribeModelExplainabilityJobDefinitionCommand,
    DescribeModelPackageCommand,
    DescribeModelPackageGroupCommand,
    DescribeModelQualityJobDefinitionCommand,
    DescribeMonitoringScheduleCommand,
    DescribeNotebookInstanceCommand,
    DescribeNotebookInstanceLifecycleConfigCommand,
    DescribeOptimizationJobCommand,
    DescribePartnerAppCommand,
    DescribePipelineCommand,
    DescribePipelineDefinitionForExecutionCommand,
    DescribePipelineExecutionCommand,
    DescribeProcessingJobCommand,
    DescribeProjectCommand,
    DescribeReservedCapacityCommand,
    DescribeSpaceCommand,
    DescribeStudioLifecycleConfigCommand,
    DescribeSubscribedWorkteamCommand,
    DescribeTrainingJobCommand,
    DescribeTrainingPlanCommand,
    DescribeTransformJobCommand,
    DescribeTrialCommand,
    DescribeTrialComponentCommand,
    DescribeUserProfileCommand,
    DescribeWorkforceCommand,
    DescribeWorkteamCommand,
    DetachClusterNodeVolumeCommand,
    DisableSagemakerServicecatalogPortfolioCommand,
    DisassociateTrialComponentCommand,
    EnableSagemakerServicecatalogPortfolioCommand,
    GetDeviceFleetReportCommand,
    GetLineageGroupPolicyCommand,
    GetModelPackageGroupPolicyCommand,
    GetSagemakerServicecatalogPortfolioStatusCommand,
    GetScalingConfigurationRecommendationCommand,
    GetSearchSuggestionsCommand,
    ImportHubContentCommand,
    ListActionsCommand,
    ListAlgorithmsCommand,
    ListAliasesCommand,
    ListAppImageConfigsCommand,
    ListAppsCommand,
    ListArtifactsCommand,
    ListAssociationsCommand,
    ListAutoMLJobsCommand,
    ListCandidatesForAutoMLJobCommand,
    ListClusterEventsCommand,
    ListClusterNodesCommand,
    ListClustersCommand,
    ListClusterSchedulerConfigsCommand,
    ListCodeRepositoriesCommand,
    ListCompilationJobsCommand,
    ListComputeQuotasCommand,
    ListContextsCommand,
    ListDataQualityJobDefinitionsCommand,
    ListDeviceFleetsCommand,
    ListDevicesCommand,
    ListDomainsCommand,
    ListEdgeDeploymentPlansCommand,
    ListEdgePackagingJobsCommand,
    ListEndpointConfigsCommand,
    ListEndpointsCommand,
    ListExperimentsCommand,
    ListFeatureGroupsCommand,
    ListFlowDefinitionsCommand,
    ListHubContentsCommand,
    ListHubContentVersionsCommand,
    ListHubsCommand,
    ListHumanTaskUisCommand,
    ListHyperParameterTuningJobsCommand,
    ListImagesCommand,
    ListImageVersionsCommand,
    ListInferenceComponentsCommand,
    ListInferenceExperimentsCommand,
    ListInferenceRecommendationsJobsCommand,
    ListInferenceRecommendationsJobStepsCommand,
    ListLabelingJobsCommand,
    ListLabelingJobsForWorkteamCommand,
    ListLineageGroupsCommand,
    ListMlflowAppsCommand,
    ListMlflowTrackingServersCommand,
    ListModelBiasJobDefinitionsCommand,
    ListModelCardExportJobsCommand,
    ListModelCardsCommand,
    ListModelCardVersionsCommand,
    ListModelExplainabilityJobDefinitionsCommand,
    ListModelMetadataCommand,
    ListModelPackageGroupsCommand,
    ListModelPackagesCommand,
    ListModelQualityJobDefinitionsCommand,
    ListModelsCommand,
    ListMonitoringAlertHistoryCommand,
    ListMonitoringAlertsCommand,
    ListMonitoringExecutionsCommand,
    ListMonitoringSchedulesCommand,
    ListNotebookInstanceLifecycleConfigsCommand,
    ListNotebookInstancesCommand,
    ListOptimizationJobsCommand,
    ListPartnerAppsCommand,
    ListPipelineExecutionsCommand,
    ListPipelineExecutionStepsCommand,
    ListPipelineParametersForExecutionCommand,
    ListPipelinesCommand,
    ListPipelineVersionsCommand,
    ListProcessingJobsCommand,
    ListProjectsCommand,
    ListResourceCatalogsCommand,
    ListSpacesCommand,
    ListStageDevicesCommand,
    ListStudioLifecycleConfigsCommand,
    ListSubscribedWorkteamsCommand,
    ListTagsCommand,
    ListTrainingJobsCommand,
    ListTrainingJobsForHyperParameterTuningJobCommand,
    ListTrainingPlansCommand,
    ListTransformJobsCommand,
    ListTrialComponentsCommand,
    ListTrialsCommand,
    ListUltraServersByReservedCapacityCommand,
    ListUserProfilesCommand,
    ListWorkforcesCommand,
    ListWorkteamsCommand,
    PutModelPackageGroupPolicyCommand,
    QueryLineageCommand,
    RegisterDevicesCommand,
    RenderUiTemplateCommand,
    RetryPipelineExecutionCommand,
    SearchCommand,
    SearchTrainingPlanOfferingsCommand,
    SendPipelineExecutionStepFailureCommand,
    SendPipelineExecutionStepSuccessCommand,
    StartEdgeDeploymentStageCommand,
    StartInferenceExperimentCommand,
    StartMlflowTrackingServerCommand,
    StartMonitoringScheduleCommand,
    StartNotebookInstanceCommand,
    StartPipelineExecutionCommand,
    StartSessionCommand,
    StopAutoMLJobCommand,
    StopCompilationJobCommand,
    StopEdgeDeploymentStageCommand,
    StopEdgePackagingJobCommand,
    StopHyperParameterTuningJobCommand,
    StopInferenceExperimentCommand,
    StopInferenceRecommendationsJobCommand,
    StopLabelingJobCommand,
    StopMlflowTrackingServerCommand,
    StopMonitoringScheduleCommand,
    StopNotebookInstanceCommand,
    StopOptimizationJobCommand,
    StopPipelineExecutionCommand,
    StopProcessingJobCommand,
    StopTrainingJobCommand,
    StopTransformJobCommand,
    UpdateActionCommand,
    UpdateAppImageConfigCommand,
    UpdateArtifactCommand,
    UpdateClusterCommand,
    UpdateClusterSchedulerConfigCommand,
    UpdateClusterSoftwareCommand,
    UpdateCodeRepositoryCommand,
    UpdateComputeQuotaCommand,
    UpdateContextCommand,
    UpdateDeviceFleetCommand,
    UpdateDevicesCommand,
    UpdateDomainCommand,
    UpdateEndpointCommand,
    UpdateEndpointWeightsAndCapacitiesCommand,
    UpdateExperimentCommand,
    UpdateFeatureGroupCommand,
    UpdateFeatureMetadataCommand,
    UpdateHubCommand,
    UpdateHubContentCommand,
    UpdateHubContentReferenceCommand,
    UpdateImageCommand,
    UpdateImageVersionCommand,
    UpdateInferenceComponentCommand,
    UpdateInferenceComponentRuntimeConfigCommand,
    UpdateInferenceExperimentCommand,
    UpdateMlflowAppCommand,
    UpdateMlflowTrackingServerCommand,
    UpdateModelCardCommand,
    UpdateModelPackageCommand,
    UpdateMonitoringAlertCommand,
    UpdateMonitoringScheduleCommand,
    UpdateNotebookInstanceCommand,
    UpdateNotebookInstanceLifecycleConfigCommand,
    UpdatePartnerAppCommand,
    UpdatePipelineCommand,
    UpdatePipelineExecutionCommand,
    UpdatePipelineVersionCommand,
    UpdateProjectCommand,
    UpdateSpaceCommand,
    UpdateTrainingJobCommand,
    UpdateTrialCommand,
    UpdateTrialComponentCommand,
    UpdateUserProfileCommand,
    UpdateWorkforceCommand,
    UpdateWorkteamCommand,
};
const paginators = {
    paginateCreateHubContentPresignedUrls,
    paginateListActions,
    paginateListAlgorithms,
    paginateListAliases,
    paginateListAppImageConfigs,
    paginateListApps,
    paginateListArtifacts,
    paginateListAssociations,
    paginateListAutoMLJobs,
    paginateListCandidatesForAutoMLJob,
    paginateListClusterEvents,
    paginateListClusterNodes,
    paginateListClusters,
    paginateListClusterSchedulerConfigs,
    paginateListCodeRepositories,
    paginateListCompilationJobs,
    paginateListComputeQuotas,
    paginateListContexts,
    paginateListDataQualityJobDefinitions,
    paginateListDeviceFleets,
    paginateListDevices,
    paginateListDomains,
    paginateListEdgeDeploymentPlans,
    paginateListEdgePackagingJobs,
    paginateListEndpointConfigs,
    paginateListEndpoints,
    paginateListExperiments,
    paginateListFeatureGroups,
    paginateListFlowDefinitions,
    paginateListHumanTaskUis,
    paginateListHyperParameterTuningJobs,
    paginateListImages,
    paginateListImageVersions,
    paginateListInferenceComponents,
    paginateListInferenceExperiments,
    paginateListInferenceRecommendationsJobs,
    paginateListInferenceRecommendationsJobSteps,
    paginateListLabelingJobs,
    paginateListLabelingJobsForWorkteam,
    paginateListLineageGroups,
    paginateListMlflowApps,
    paginateListMlflowTrackingServers,
    paginateListModelBiasJobDefinitions,
    paginateListModelCardExportJobs,
    paginateListModelCards,
    paginateListModelCardVersions,
    paginateListModelExplainabilityJobDefinitions,
    paginateListModelMetadata,
    paginateListModelPackageGroups,
    paginateListModelPackages,
    paginateListModelQualityJobDefinitions,
    paginateListModels,
    paginateListMonitoringAlertHistory,
    paginateListMonitoringAlerts,
    paginateListMonitoringExecutions,
    paginateListMonitoringSchedules,
    paginateListNotebookInstanceLifecycleConfigs,
    paginateListNotebookInstances,
    paginateListOptimizationJobs,
    paginateListPartnerApps,
    paginateListPipelineExecutions,
    paginateListPipelineExecutionSteps,
    paginateListPipelineParametersForExecution,
    paginateListPipelines,
    paginateListPipelineVersions,
    paginateListProcessingJobs,
    paginateListProjects,
    paginateListResourceCatalogs,
    paginateListSpaces,
    paginateListStageDevices,
    paginateListStudioLifecycleConfigs,
    paginateListSubscribedWorkteams,
    paginateListTags,
    paginateListTrainingJobs,
    paginateListTrainingJobsForHyperParameterTuningJob,
    paginateListTrainingPlans,
    paginateListTransformJobs,
    paginateListTrialComponents,
    paginateListTrials,
    paginateListUltraServersByReservedCapacity,
    paginateListUserProfiles,
    paginateListWorkforces,
    paginateListWorkteams,
    paginateQueryLineage,
    paginateSearch,
};
const waiters = {
    waitUntilEndpointDeleted,
    waitUntilEndpointInService,
    waitUntilImageCreated,
    waitUntilImageDeleted,
    waitUntilImageUpdated,
    waitUntilImageVersionCreated,
    waitUntilImageVersionDeleted,
    waitUntilNotebookInstanceDeleted,
    waitUntilNotebookInstanceInService,
    waitUntilNotebookInstanceStopped,
    waitUntilProcessingJobCompletedOrStopped,
    waitUntilTrainingJobCompletedOrStopped,
    waitUntilTransformJobCompletedOrStopped,
};
export class SageMaker extends SageMakerClient {
}
createAggregatedClient(commands, SageMaker, { paginators, waiters });
