import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  ListUltraServersByReservedCapacityRequest,
  ListUltraServersByReservedCapacityResponse,
} from "../models/models_4";
import {
  SageMakerClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../SageMakerClient";
export { __MetadataBearer };
export { $Command };
export interface ListUltraServersByReservedCapacityCommandInput
  extends ListUltraServersByReservedCapacityRequest {}
export interface ListUltraServersByReservedCapacityCommandOutput
  extends ListUltraServersByReservedCapacityResponse,
    __MetadataBearer {}
declare const ListUltraServersByReservedCapacityCommand_base: {
  new (
    input: ListUltraServersByReservedCapacityCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    ListUltraServersByReservedCapacityCommandInput,
    ListUltraServersByReservedCapacityCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: ListUltraServersByReservedCapacityCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    ListUltraServersByReservedCapacityCommandInput,
    ListUltraServersByReservedCapacityCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class ListUltraServersByReservedCapacityCommand extends ListUltraServersByReservedCapacityCommand_base {
  protected static __types: {
    api: {
      input: ListUltraServersByReservedCapacityRequest;
      output: ListUltraServersByReservedCapacityResponse;
    };
    sdk: {
      input: ListUltraServersByReservedCapacityCommandInput;
      output: ListUltraServersByReservedCapacityCommandOutput;
    };
  };
}
