import type { Paginator } from "@smithy/types";
import { ListInferenceComponentsCommandInput, ListInferenceComponentsCommandOutput } from "../commands/ListInferenceComponentsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListInferenceComponents: (config: SageMakerPaginationConfiguration, input: ListInferenceComponentsCommandInput, ...rest: any[]) => Paginator<ListInferenceComponentsCommandOutput>;
