import { Paginator } from "@smithy/types";
import {
  QueryLineageCommandInput,
  QueryLineageCommandOutput,
} from "../commands/QueryLineageCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
export declare const paginateQueryLineage: (
  config: SageMakerPaginationConfiguration,
  input: QueryLineageCommandInput,
  ...rest: any[]
) => Paginator<QueryLineageCommandOutput>;
