import { Paginator } from "@smithy/types";
import {
  ListTrialsCommandInput,
  ListTrialsCommandOutput,
} from "../commands/ListTrialsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
export declare const paginateListTrials: (
  config: SageMakerPaginationConfiguration,
  input: ListTrialsCommandInput,
  ...rest: any[]
) => Paginator<ListTrialsCommandOutput>;
