import { WaiterConfiguration, WaiterResult } from "@smithy/util-waiter";
import { DescribeImageCommandInput } from "../commands/DescribeImageCommand";
import { SageMakerClient } from "../SageMakerClient";
/**
 *
 *  @deprecated Use waitUntilImageDeleted instead. waitForImageDeleted does not throw error in non-success cases.
 */
export declare const waitForImageDeleted: (params: WaiterConfiguration<SageMakerClient>, input: DescribeImageCommandInput) => Promise<WaiterResult>;
/**
 *
 *  @param params - Waiter configuration options.
 *  @param input - The input to DescribeImageCommand for polling.
 */
export declare const waitUntilImageDeleted: (params: WaiterConfiguration<SageMakerClient>, input: DescribeImageCommandInput) => Promise<WaiterResult>;
