import { Paginator } from "@smithy/types";
import {
  ListDomainsCommandInput,
  ListDomainsCommandOutput,
} from "../commands/ListDomainsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
export declare const paginateListDomains: (
  config: SageMakerPaginationConfiguration,
  input: ListDomainsCommandInput,
  ...rest: any[]
) => Paginator<ListDomainsCommandOutput>;
