import { Paginator } from "@smithy/types";
import {
  ListPipelineVersionsCommandInput,
  ListPipelineVersionsCommandOutput,
} from "../commands/ListPipelineVersionsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
export declare const paginateListPipelineVersions: (
  config: SageMakerPaginationConfiguration,
  input: ListPipelineVersionsCommandInput,
  ...rest: any[]
) => Paginator<ListPipelineVersionsCommandOutput>;
