import type { Paginator } from "@smithy/types";
import { ListInferenceExperimentsCommandInput, ListInferenceExperimentsCommandOutput } from "../commands/ListInferenceExperimentsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListInferenceExperiments: (config: SageMakerPaginationConfiguration, input: ListInferenceExperimentsCommandInput, ...rest: any[]) => Paginator<ListInferenceExperimentsCommandOutput>;
