import { Paginator } from "@smithy/types";
import {
  ListUltraServersByReservedCapacityCommandInput,
  ListUltraServersByReservedCapacityCommandOutput,
} from "../commands/ListUltraServersByReservedCapacityCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
export declare const paginateListUltraServersByReservedCapacity: (
  config: SageMakerPaginationConfiguration,
  input: ListUltraServersByReservedCapacityCommandInput,
  ...rest: any[]
) => Paginator<ListUltraServersByReservedCapacityCommandOutput>;
