import type { Paginator } from "@smithy/types";
import { ListPipelineVersionsCommandInput, ListPipelineVersionsCommandOutput } from "../commands/ListPipelineVersionsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListPipelineVersions: (config: SageMakerPaginationConfiguration, input: ListPipelineVersionsCommandInput, ...rest: any[]) => Paginator<ListPipelineVersionsCommandOutput>;
