import { createPaginator } from "@smithy/core";
import { ListUltraServersByReservedCapacityCommand, } from "../commands/ListUltraServersByReservedCapacityCommand";
import { SageMakerClient } from "../SageMakerClient";
export const paginateListUltraServersByReservedCapacity = createPaginator(SageMakerClient, ListUltraServersByReservedCapacityCommand, "NextToken", "NextToken", "MaxResults");
