import { Paginator } from "@smithy/types";
import {
  ListTagsCommandInput,
  ListTagsCommandOutput,
} from "../commands/ListTagsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
export declare const paginateListTags: (
  config: SageMakerPaginationConfiguration,
  input: ListTagsCommandInput,
  ...rest: any[]
) => Paginator<ListTagsCommandOutput>;
