import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  BatchAddClusterNodesRequest,
  BatchAddClusterNodesResponse,
} from "../models/models_0";
import {
  SageMakerClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../SageMakerClient";
export { __MetadataBearer };
export { $Command };
export interface BatchAddClusterNodesCommandInput
  extends BatchAddClusterNodesRequest {}
export interface BatchAddClusterNodesCommandOutput
  extends BatchAddClusterNodesResponse,
    __MetadataBearer {}
declare const BatchAddClusterNodesCommand_base: {
  new (
    input: BatchAddClusterNodesCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    BatchAddClusterNodesCommandInput,
    BatchAddClusterNodesCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: BatchAddClusterNodesCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    BatchAddClusterNodesCommandInput,
    BatchAddClusterNodesCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class BatchAddClusterNodesCommand extends BatchAddClusterNodesCommand_base {
  protected static __types: {
    api: {
      input: BatchAddClusterNodesRequest;
      output: BatchAddClusterNodesResponse;
    };
    sdk: {
      input: BatchAddClusterNodesCommandInput;
      output: BatchAddClusterNodesCommandOutput;
    };
  };
}
