import {
  _InstanceType,
  AccountDefaultStatus,
  AlgorithmSortBy,
  AppImageConfigSortKey,
  AppSortKey,
  AssociationEdgeType,
  AutoMLJobStatus,
  AutoMLSortBy,
  AutoMLSortOrder,
  BatchStrategy,
  CandidateSortBy,
  CandidateStatus,
  ClusterEventResourceType,
  ClusterSortBy,
  CodeRepositorySortBy,
  CodeRepositorySortOrder,
  CompilationJobStatus,
  CrossAccountFilterOption,
  DeviceDeploymentStatus,
  DomainStatus,
  EdgePackagingJobStatus,
  EndpointConfigSortKey,
  EndpointSortKey,
  EndpointStatus,
  EventSortBy,
  ExecutionRoleIdentityConfig,
  ExecutionStatus,
  FeatureGroupSortBy,
  FeatureGroupSortOrder,
  FeatureGroupStatus,
  FeatureType,
  FlowDefinitionStatus,
  HubContentSortBy,
  HubContentStatus,
  HubContentSupportStatus,
  HubContentType,
  HubSortBy,
  HubStatus,
  HyperParameterTuningJobSortByOptions,
  HyperParameterTuningJobStatus,
  HyperParameterTuningJobStrategyType,
  ImageSortBy,
  ImageSortOrder,
  ImageStatus,
  ImageVersionSortBy,
  ImageVersionSortOrder,
  ImageVersionStatus,
  InferenceComponentSortKey,
  InferenceComponentStatus,
  InferenceExperimentStatus,
  InferenceExperimentType,
  IPAddressType,
  IsTrackingServerActive,
  LabelingJobStatus,
  ListCompilationJobsSortBy,
  ListDeviceFleetsSortBy,
  ListEdgeDeploymentPlansSortBy,
  ListEdgePackagingJobsSortBy,
  ListInferenceRecommendationsJobsSortBy,
  ListLabelingJobsForWorkteamSortByOptions,
  ListOptimizationJobsSortBy,
  MlflowAppStatus,
  ModelApprovalStatus,
  ModelCardExportJobSortBy,
  ModelCardExportJobSortOrder,
  ModelCardExportJobStatus,
  ModelCardSortBy,
  ModelCardSortOrder,
  ModelCardStatus,
  ModelCardVersionSortBy,
  ModelMetadataFilterType,
  ModelPackageGroupSortBy,
  ModelPackageGroupStatus,
  ModelPackageRegistrationType,
  ModelPackageSortBy,
  ModelPackageStatus,
  ModelPackageType,
  ModelSortKey,
  MonitoringAlertHistorySortKey,
  MonitoringAlertStatus,
  MonitoringExecutionSortKey,
  MonitoringJobDefinitionSortKey,
  MonitoringScheduleSortKey,
  MonitoringType,
  NotebookInstanceLifecycleConfigSortKey,
  NotebookInstanceLifecycleConfigSortOrder,
  NotebookInstanceSortKey,
  NotebookInstanceSortOrder,
  NotebookInstanceStatus,
  OfflineStoreStatusValue,
  Operator,
  OptimizationJobDeploymentInstanceType,
  OptimizationJobStatus,
  OrderKey,
  PartnerAppStatus,
  PartnerAppType,
  PipelineExecutionStatus,
  ProcessingJobStatus,
  ProfilingStatus,
  ProjectStatus,
  RecommendationJobStatus,
  RecommendationJobType,
  RecommendationStepType,
  ReservedCapacityInstanceType,
  ReservedCapacityStatus,
  ReservedCapacityType,
  ResourceType,
  RuleEvaluationStatus,
  SageMakerResourceName,
  SagemakerServicecatalogStatus,
  SchedulerResourceStatus,
  ScheduleStatus,
  SecondaryStatus,
  SortActionsBy,
  SortArtifactsBy,
  SortAssociationsBy,
  SortBy,
  SortClusterSchedulerConfigBy,
  SortContextsBy,
  SortExperimentsBy,
  SortInferenceExperimentsBy,
  SortLineageGroupsBy,
  SortMlflowAppBy,
  SortOrder,
  SortPipelineExecutionsBy,
  SortPipelinesBy,
  SortQuotaBy,
  SortTrackingServerBy,
  SpaceStatus,
  StepStatus,
  StudioLifecycleConfigAppType,
  TrackingServerStatus,
  TrainingJobStatus,
  TrainingPlanStatus,
  TransformJobStatus,
  UserProfileStatus,
  VolumeAttachmentStatus,
  WarmPoolResourceStatus,
  WorkforceIpAddressType,
  WorkforceStatus,
} from "./enums";
import {
  AlgorithmSpecification,
  AmazonQSettings,
  AppSpecification,
  AutoMLJobStepMetadata,
  BatchDataCaptureConfig,
  BedrockCustomModelDeploymentMetadata,
  BedrockCustomModelMetadata,
  BedrockModelImportMetadata,
  BedrockProvisionedModelThroughputMetadata,
  CacheHitResult,
  CallbackStepMetadata,
  CfnTemplateProviderDetail,
  CheckpointConfig,
  ClarifyCheckStepMetadata,
  CognitoConfig,
  ConditionStepMetadata,
  MetadataProperties,
  OutputDataConfig,
  ResourceConfig,
  ResourceSpec,
  StoppingCondition,
  TransformInput,
  TransformOutput,
  TransformResources,
  UserContext,
  VpcConfig,
  ActionSummary,
  AgentVersion,
  AlgorithmSummary,
  AppDetails,
  AppImageConfigDetails,
  ArtifactSummary,
  AssociationInfo,
  AssociationSummary,
  AutoMLCandidate,
  AutoMLJobSummary,
  Channel,
  ClusterEventSummary,
  ClusterNodeSummary,
  ClusterSchedulerConfigSummary,
  ClusterSummary,
  CodeRepositorySummary,
  CompilationJobSummary,
  ComputeQuotaSummary,
  ContextSummary,
  OutputParameter,
  Tag,
} from "./models_0";
import {
  DockerSettings,
  EdgeOutputConfig,
  ExperimentConfig,
  HyperParameterTuningJobConfig,
  HyperParameterTuningJobWarmStartConfig,
  InferenceExperimentSchedule,
  LabelingJobInputConfig,
  ModelLifeCycle,
  MonitoringScheduleConfig,
  NetworkConfig,
  OfflineStoreConfig,
  OnlineStoreConfig,
  OwnershipSettings,
  ParallelismConfiguration,
  ProcessingOutputConfig,
  ProcessingResources,
  ProcessingStoppingCondition,
  ResourceLimits,
  RetryStrategy,
  ServiceCatalogProvisioningDetails,
  TrustedIdentityPropagationSettings,
  UnifiedStudioSettings,
  UserSettings,
  FeatureDefinition,
  HyperParameterTrainingJobDefinition,
  ProcessingInput,
} from "./models_1";
import {
  DataCaptureConfigSummary,
  DataProcessing,
  DebugHookConfig,
  EndpointOutputConfiguration,
  ExperimentSource,
  HyperParameterTrainingJobSummary,
  HyperParameterTuningJobCompletionDetails,
  HyperParameterTuningJobConsumedResources,
  InferenceMetrics,
  InfraCheckConfig,
  LabelCounters,
  LabelingJobOutput,
  LastUpdateStatus,
  MlflowConfig,
  MLflowConfiguration,
  ModelArtifacts,
  ModelClientConfig,
  ModelConfiguration,
  ModelPackageConfig,
  NotificationConfiguration,
  ObjectiveStatusCounters,
  OfflineStoreStatus,
  PipelineExperimentConfig,
  ProfilerConfig,
  RecommendationMetrics,
  RemoteDebugConfig,
  ServerlessJobConfig,
  SourceIpConfig,
  SpaceSettings,
  SpaceSharingSettings,
  TensorBoardOutputConfig,
  TrainingJobStatusCounters,
  TrialComponentStatus,
  WorkerAccessConfiguration,
  CustomizedMetricSpecification,
  DebugRuleConfiguration,
  DebugRuleEvaluationStatus,
  FeatureParameter,
  MemberDefinition,
  MonitoringExecutionSummary,
  ProductionVariantSummary,
  ProfilerRuleConfiguration,
  SelectedStep,
  TrialComponentArtifact,
  TrialComponentParameterValue,
} from "./models_2";
export interface SelectiveExecutionConfig {
  SourcePipelineExecutionArn?: string | undefined;
  SelectedSteps: SelectedStep[] | undefined;
}
export interface DescribePipelineExecutionResponse {
  PipelineArn?: string | undefined;
  PipelineExecutionArn?: string | undefined;
  PipelineExecutionDisplayName?: string | undefined;
  PipelineExecutionStatus?: PipelineExecutionStatus | undefined;
  PipelineExecutionDescription?: string | undefined;
  PipelineExperimentConfig?: PipelineExperimentConfig | undefined;
  FailureReason?: string | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  CreatedBy?: UserContext | undefined;
  LastModifiedBy?: UserContext | undefined;
  ParallelismConfiguration?: ParallelismConfiguration | undefined;
  SelectiveExecutionConfig?: SelectiveExecutionConfig | undefined;
  PipelineVersionId?: number | undefined;
  MLflowConfig?: MLflowConfiguration | undefined;
}
export interface DescribeProcessingJobRequest {
  ProcessingJobName: string | undefined;
}
export interface DescribeProcessingJobResponse {
  ProcessingInputs?: ProcessingInput[] | undefined;
  ProcessingOutputConfig?: ProcessingOutputConfig | undefined;
  ProcessingJobName: string | undefined;
  ProcessingResources: ProcessingResources | undefined;
  StoppingCondition?: ProcessingStoppingCondition | undefined;
  AppSpecification: AppSpecification | undefined;
  Environment?: Record<string, string> | undefined;
  NetworkConfig?: NetworkConfig | undefined;
  RoleArn?: string | undefined;
  ExperimentConfig?: ExperimentConfig | undefined;
  ProcessingJobArn: string | undefined;
  ProcessingJobStatus: ProcessingJobStatus | undefined;
  ExitMessage?: string | undefined;
  FailureReason?: string | undefined;
  ProcessingEndTime?: Date | undefined;
  ProcessingStartTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  CreationTime: Date | undefined;
  MonitoringScheduleArn?: string | undefined;
  AutoMLJobArn?: string | undefined;
  TrainingJobArn?: string | undefined;
}
export interface DescribeProjectInput {
  ProjectName: string | undefined;
}
export interface ServiceCatalogProvisionedProductDetails {
  ProvisionedProductId?: string | undefined;
  ProvisionedProductStatusMessage?: string | undefined;
}
export interface TemplateProviderDetail {
  CfnTemplateProviderDetail?: CfnTemplateProviderDetail | undefined;
}
export interface DescribeProjectOutput {
  ProjectArn: string | undefined;
  ProjectName: string | undefined;
  ProjectId: string | undefined;
  ProjectDescription?: string | undefined;
  ServiceCatalogProvisioningDetails?:
    | ServiceCatalogProvisioningDetails
    | undefined;
  ServiceCatalogProvisionedProductDetails?:
    | ServiceCatalogProvisionedProductDetails
    | undefined;
  ProjectStatus: ProjectStatus | undefined;
  TemplateProviderDetails?: TemplateProviderDetail[] | undefined;
  CreatedBy?: UserContext | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
}
export interface DescribeReservedCapacityRequest {
  ReservedCapacityArn: string | undefined;
}
export interface UltraServerSummary {
  UltraServerType: string | undefined;
  InstanceType: ReservedCapacityInstanceType | undefined;
  UltraServerCount?: number | undefined;
  AvailableSpareInstanceCount?: number | undefined;
  UnhealthyInstanceCount?: number | undefined;
}
export interface DescribeReservedCapacityResponse {
  ReservedCapacityArn: string | undefined;
  ReservedCapacityType?: ReservedCapacityType | undefined;
  Status?: ReservedCapacityStatus | undefined;
  AvailabilityZone?: string | undefined;
  DurationHours?: number | undefined;
  DurationMinutes?: number | undefined;
  StartTime?: Date | undefined;
  EndTime?: Date | undefined;
  InstanceType: ReservedCapacityInstanceType | undefined;
  TotalInstanceCount: number | undefined;
  AvailableInstanceCount?: number | undefined;
  InUseInstanceCount?: number | undefined;
  UltraServerSummary?: UltraServerSummary | undefined;
}
export interface DescribeSpaceRequest {
  DomainId: string | undefined;
  SpaceName: string | undefined;
}
export interface DescribeSpaceResponse {
  DomainId?: string | undefined;
  SpaceArn?: string | undefined;
  SpaceName?: string | undefined;
  HomeEfsFileSystemUid?: string | undefined;
  Status?: SpaceStatus | undefined;
  LastModifiedTime?: Date | undefined;
  CreationTime?: Date | undefined;
  FailureReason?: string | undefined;
  SpaceSettings?: SpaceSettings | undefined;
  OwnershipSettings?: OwnershipSettings | undefined;
  SpaceSharingSettings?: SpaceSharingSettings | undefined;
  SpaceDisplayName?: string | undefined;
  Url?: string | undefined;
}
export interface DescribeStudioLifecycleConfigRequest {
  StudioLifecycleConfigName: string | undefined;
}
export interface DescribeStudioLifecycleConfigResponse {
  StudioLifecycleConfigArn?: string | undefined;
  StudioLifecycleConfigName?: string | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  StudioLifecycleConfigContent?: string | undefined;
  StudioLifecycleConfigAppType?: StudioLifecycleConfigAppType | undefined;
}
export interface DescribeSubscribedWorkteamRequest {
  WorkteamArn: string | undefined;
}
export interface SubscribedWorkteam {
  WorkteamArn: string | undefined;
  MarketplaceTitle?: string | undefined;
  SellerName?: string | undefined;
  MarketplaceDescription?: string | undefined;
  ListingId?: string | undefined;
}
export interface DescribeSubscribedWorkteamResponse {
  SubscribedWorkteam: SubscribedWorkteam | undefined;
}
export interface DescribeTrainingJobRequest {
  TrainingJobName: string | undefined;
}
export interface MetricData {
  MetricName?: string | undefined;
  Value?: number | undefined;
  Timestamp?: Date | undefined;
}
export interface MlflowDetails {
  MlflowExperimentId?: string | undefined;
  MlflowRunId?: string | undefined;
}
export interface ProfilerRuleEvaluationStatus {
  RuleConfigurationName?: string | undefined;
  RuleEvaluationJobArn?: string | undefined;
  RuleEvaluationStatus?: RuleEvaluationStatus | undefined;
  StatusDetails?: string | undefined;
  LastModifiedTime?: Date | undefined;
}
export interface TrainingProgressInfo {
  TotalStepCountPerEpoch?: number | undefined;
  CurrentStep?: number | undefined;
  CurrentEpoch?: number | undefined;
  MaxEpoch?: number | undefined;
}
export interface SecondaryStatusTransition {
  Status: SecondaryStatus | undefined;
  StartTime: Date | undefined;
  EndTime?: Date | undefined;
  StatusMessage?: string | undefined;
}
export interface WarmPoolStatus {
  Status: WarmPoolResourceStatus | undefined;
  ResourceRetainedBillableTimeInSeconds?: number | undefined;
  ReusedByJob?: string | undefined;
}
export interface DescribeTrainingJobResponse {
  TrainingJobName: string | undefined;
  TrainingJobArn: string | undefined;
  TuningJobArn?: string | undefined;
  LabelingJobArn?: string | undefined;
  AutoMLJobArn?: string | undefined;
  ModelArtifacts: ModelArtifacts | undefined;
  TrainingJobStatus: TrainingJobStatus | undefined;
  SecondaryStatus: SecondaryStatus | undefined;
  FailureReason?: string | undefined;
  HyperParameters?: Record<string, string> | undefined;
  AlgorithmSpecification?: AlgorithmSpecification | undefined;
  RoleArn?: string | undefined;
  InputDataConfig?: Channel[] | undefined;
  OutputDataConfig?: OutputDataConfig | undefined;
  ResourceConfig?: ResourceConfig | undefined;
  WarmPoolStatus?: WarmPoolStatus | undefined;
  VpcConfig?: VpcConfig | undefined;
  StoppingCondition: StoppingCondition | undefined;
  CreationTime: Date | undefined;
  TrainingStartTime?: Date | undefined;
  TrainingEndTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  SecondaryStatusTransitions?: SecondaryStatusTransition[] | undefined;
  FinalMetricDataList?: MetricData[] | undefined;
  EnableNetworkIsolation?: boolean | undefined;
  EnableInterContainerTrafficEncryption?: boolean | undefined;
  EnableManagedSpotTraining?: boolean | undefined;
  CheckpointConfig?: CheckpointConfig | undefined;
  TrainingTimeInSeconds?: number | undefined;
  BillableTimeInSeconds?: number | undefined;
  BillableTokenCount?: number | undefined;
  DebugHookConfig?: DebugHookConfig | undefined;
  ExperimentConfig?: ExperimentConfig | undefined;
  DebugRuleConfigurations?: DebugRuleConfiguration[] | undefined;
  TensorBoardOutputConfig?: TensorBoardOutputConfig | undefined;
  DebugRuleEvaluationStatuses?: DebugRuleEvaluationStatus[] | undefined;
  ProfilerConfig?: ProfilerConfig | undefined;
  ProfilerRuleConfigurations?: ProfilerRuleConfiguration[] | undefined;
  ProfilerRuleEvaluationStatuses?: ProfilerRuleEvaluationStatus[] | undefined;
  ProfilingStatus?: ProfilingStatus | undefined;
  Environment?: Record<string, string> | undefined;
  RetryStrategy?: RetryStrategy | undefined;
  RemoteDebugConfig?: RemoteDebugConfig | undefined;
  InfraCheckConfig?: InfraCheckConfig | undefined;
  ServerlessJobConfig?: ServerlessJobConfig | undefined;
  MlflowConfig?: MlflowConfig | undefined;
  ModelPackageConfig?: ModelPackageConfig | undefined;
  MlflowDetails?: MlflowDetails | undefined;
  ProgressInfo?: TrainingProgressInfo | undefined;
  OutputModelPackageArn?: string | undefined;
}
export interface DescribeTrainingPlanRequest {
  TrainingPlanName: string | undefined;
}
export interface ReservedCapacitySummary {
  ReservedCapacityArn: string | undefined;
  ReservedCapacityType?: ReservedCapacityType | undefined;
  UltraServerType?: string | undefined;
  UltraServerCount?: number | undefined;
  InstanceType: ReservedCapacityInstanceType | undefined;
  TotalInstanceCount: number | undefined;
  Status: ReservedCapacityStatus | undefined;
  AvailabilityZone?: string | undefined;
  DurationHours?: number | undefined;
  DurationMinutes?: number | undefined;
  StartTime?: Date | undefined;
  EndTime?: Date | undefined;
}
export interface DescribeTrainingPlanResponse {
  TrainingPlanArn: string | undefined;
  TrainingPlanName: string | undefined;
  Status: TrainingPlanStatus | undefined;
  StatusMessage?: string | undefined;
  DurationHours?: number | undefined;
  DurationMinutes?: number | undefined;
  StartTime?: Date | undefined;
  EndTime?: Date | undefined;
  UpfrontFee?: string | undefined;
  CurrencyCode?: string | undefined;
  TotalInstanceCount?: number | undefined;
  AvailableInstanceCount?: number | undefined;
  InUseInstanceCount?: number | undefined;
  UnhealthyInstanceCount?: number | undefined;
  AvailableSpareInstanceCount?: number | undefined;
  TotalUltraServerCount?: number | undefined;
  TargetResources?: SageMakerResourceName[] | undefined;
  ReservedCapacitySummaries?: ReservedCapacitySummary[] | undefined;
}
export interface DescribeTransformJobRequest {
  TransformJobName: string | undefined;
}
export interface DescribeTransformJobResponse {
  TransformJobName: string | undefined;
  TransformJobArn: string | undefined;
  TransformJobStatus: TransformJobStatus | undefined;
  FailureReason?: string | undefined;
  ModelName: string | undefined;
  MaxConcurrentTransforms?: number | undefined;
  ModelClientConfig?: ModelClientConfig | undefined;
  MaxPayloadInMB?: number | undefined;
  BatchStrategy?: BatchStrategy | undefined;
  Environment?: Record<string, string> | undefined;
  TransformInput: TransformInput | undefined;
  TransformOutput?: TransformOutput | undefined;
  DataCaptureConfig?: BatchDataCaptureConfig | undefined;
  TransformResources: TransformResources | undefined;
  CreationTime: Date | undefined;
  TransformStartTime?: Date | undefined;
  TransformEndTime?: Date | undefined;
  LabelingJobArn?: string | undefined;
  AutoMLJobArn?: string | undefined;
  DataProcessing?: DataProcessing | undefined;
  ExperimentConfig?: ExperimentConfig | undefined;
}
export interface DescribeTrialRequest {
  TrialName: string | undefined;
}
export interface TrialSource {
  SourceArn: string | undefined;
  SourceType?: string | undefined;
}
export interface DescribeTrialResponse {
  TrialName?: string | undefined;
  TrialArn?: string | undefined;
  DisplayName?: string | undefined;
  ExperimentName?: string | undefined;
  Source?: TrialSource | undefined;
  CreationTime?: Date | undefined;
  CreatedBy?: UserContext | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
  MetadataProperties?: MetadataProperties | undefined;
}
export interface DescribeTrialComponentRequest {
  TrialComponentName: string | undefined;
}
export interface TrialComponentMetricSummary {
  MetricName?: string | undefined;
  SourceArn?: string | undefined;
  TimeStamp?: Date | undefined;
  Max?: number | undefined;
  Min?: number | undefined;
  Last?: number | undefined;
  Count?: number | undefined;
  Avg?: number | undefined;
  StdDev?: number | undefined;
}
export interface TrialComponentSource {
  SourceArn: string | undefined;
  SourceType?: string | undefined;
}
export interface DescribeTrialComponentResponse {
  TrialComponentName?: string | undefined;
  TrialComponentArn?: string | undefined;
  DisplayName?: string | undefined;
  Source?: TrialComponentSource | undefined;
  Status?: TrialComponentStatus | undefined;
  StartTime?: Date | undefined;
  EndTime?: Date | undefined;
  CreationTime?: Date | undefined;
  CreatedBy?: UserContext | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
  Parameters?: Record<string, TrialComponentParameterValue> | undefined;
  InputArtifacts?: Record<string, TrialComponentArtifact> | undefined;
  OutputArtifacts?: Record<string, TrialComponentArtifact> | undefined;
  MetadataProperties?: MetadataProperties | undefined;
  Metrics?: TrialComponentMetricSummary[] | undefined;
  LineageGroupArn?: string | undefined;
  Sources?: TrialComponentSource[] | undefined;
}
export interface DescribeUserProfileRequest {
  DomainId: string | undefined;
  UserProfileName: string | undefined;
}
export interface DescribeUserProfileResponse {
  DomainId?: string | undefined;
  UserProfileArn?: string | undefined;
  UserProfileName?: string | undefined;
  HomeEfsFileSystemUid?: string | undefined;
  Status?: UserProfileStatus | undefined;
  LastModifiedTime?: Date | undefined;
  CreationTime?: Date | undefined;
  FailureReason?: string | undefined;
  SingleSignOnUserIdentifier?: string | undefined;
  SingleSignOnUserValue?: string | undefined;
  UserSettings?: UserSettings | undefined;
}
export interface DescribeWorkforceRequest {
  WorkforceName: string | undefined;
}
export interface OidcConfigForResponse {
  ClientId?: string | undefined;
  Issuer?: string | undefined;
  AuthorizationEndpoint?: string | undefined;
  TokenEndpoint?: string | undefined;
  UserInfoEndpoint?: string | undefined;
  LogoutEndpoint?: string | undefined;
  JwksUri?: string | undefined;
  Scope?: string | undefined;
  AuthenticationRequestExtraParams?: Record<string, string> | undefined;
}
export interface WorkforceVpcConfigResponse {
  VpcId: string | undefined;
  SecurityGroupIds: string[] | undefined;
  Subnets: string[] | undefined;
  VpcEndpointId?: string | undefined;
}
export interface Workforce {
  WorkforceName: string | undefined;
  WorkforceArn: string | undefined;
  LastUpdatedDate?: Date | undefined;
  SourceIpConfig?: SourceIpConfig | undefined;
  SubDomain?: string | undefined;
  CognitoConfig?: CognitoConfig | undefined;
  OidcConfig?: OidcConfigForResponse | undefined;
  CreateDate?: Date | undefined;
  WorkforceVpcConfig?: WorkforceVpcConfigResponse | undefined;
  Status?: WorkforceStatus | undefined;
  FailureReason?: string | undefined;
  IpAddressType?: WorkforceIpAddressType | undefined;
}
export interface DescribeWorkforceResponse {
  Workforce: Workforce | undefined;
}
export interface DescribeWorkteamRequest {
  WorkteamName: string | undefined;
}
export interface Workteam {
  WorkteamName: string | undefined;
  MemberDefinitions: MemberDefinition[] | undefined;
  WorkteamArn: string | undefined;
  WorkforceArn?: string | undefined;
  ProductListingIds?: string[] | undefined;
  Description: string | undefined;
  SubDomain?: string | undefined;
  CreateDate?: Date | undefined;
  LastUpdatedDate?: Date | undefined;
  NotificationConfiguration?: NotificationConfiguration | undefined;
  WorkerAccessConfiguration?: WorkerAccessConfiguration | undefined;
}
export interface DescribeWorkteamResponse {
  Workteam: Workteam | undefined;
}
export interface ProductionVariantServerlessUpdateConfig {
  MaxConcurrency?: number | undefined;
  ProvisionedConcurrency?: number | undefined;
}
export interface DesiredWeightAndCapacity {
  VariantName: string | undefined;
  DesiredWeight?: number | undefined;
  DesiredInstanceCount?: number | undefined;
  ServerlessUpdateConfig?: ProductionVariantServerlessUpdateConfig | undefined;
}
export interface DetachClusterNodeVolumeRequest {
  ClusterArn: string | undefined;
  NodeId: string | undefined;
  VolumeId: string | undefined;
}
export interface DetachClusterNodeVolumeResponse {
  ClusterArn: string | undefined;
  NodeId: string | undefined;
  VolumeId: string | undefined;
  AttachTime: Date | undefined;
  Status: VolumeAttachmentStatus | undefined;
  DeviceName: string | undefined;
}
export interface Device {
  DeviceName: string | undefined;
  Description?: string | undefined;
  IotThingName?: string | undefined;
}
export interface DeviceDeploymentSummary {
  EdgeDeploymentPlanArn: string | undefined;
  EdgeDeploymentPlanName: string | undefined;
  StageName: string | undefined;
  DeployedStageName?: string | undefined;
  DeviceFleetName?: string | undefined;
  DeviceName: string | undefined;
  DeviceArn: string | undefined;
  DeviceDeploymentStatus?: DeviceDeploymentStatus | undefined;
  DeviceDeploymentStatusMessage?: string | undefined;
  Description?: string | undefined;
  DeploymentStartTime?: Date | undefined;
}
export interface DeviceFleetSummary {
  DeviceFleetArn: string | undefined;
  DeviceFleetName: string | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
}
export interface DeviceStats {
  ConnectedDeviceCount: number | undefined;
  RegisteredDeviceCount: number | undefined;
}
export interface EdgeModelSummary {
  ModelName: string | undefined;
  ModelVersion: string | undefined;
}
export interface DeviceSummary {
  DeviceName: string | undefined;
  DeviceArn: string | undefined;
  Description?: string | undefined;
  DeviceFleetName?: string | undefined;
  IotThingName?: string | undefined;
  RegistrationTime?: Date | undefined;
  LatestHeartbeat?: Date | undefined;
  Models?: EdgeModelSummary[] | undefined;
  AgentVersion?: string | undefined;
}
export interface DisableSagemakerServicecatalogPortfolioInput {}
export interface DisableSagemakerServicecatalogPortfolioOutput {}
export interface DisassociateTrialComponentRequest {
  TrialComponentName: string | undefined;
  TrialName: string | undefined;
}
export interface DisassociateTrialComponentResponse {
  TrialComponentArn?: string | undefined;
  TrialArn?: string | undefined;
}
export interface DomainDetails {
  DomainArn?: string | undefined;
  DomainId?: string | undefined;
  DomainName?: string | undefined;
  Status?: DomainStatus | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  Url?: string | undefined;
}
export interface RStudioServerProDomainSettingsForUpdate {
  DomainExecutionRoleArn: string | undefined;
  DefaultResourceSpec?: ResourceSpec | undefined;
  RStudioConnectUrl?: string | undefined;
  RStudioPackageManagerUrl?: string | undefined;
}
export interface DomainSettingsForUpdate {
  RStudioServerProDomainSettingsForUpdate?:
    | RStudioServerProDomainSettingsForUpdate
    | undefined;
  ExecutionRoleIdentityConfig?: ExecutionRoleIdentityConfig | undefined;
  SecurityGroupIds?: string[] | undefined;
  TrustedIdentityPropagationSettings?:
    | TrustedIdentityPropagationSettings
    | undefined;
  DockerSettings?: DockerSettings | undefined;
  AmazonQSettings?: AmazonQSettings | undefined;
  UnifiedStudioSettings?: UnifiedStudioSettings | undefined;
  IpAddressType?: IPAddressType | undefined;
}
export interface PredefinedMetricSpecification {
  PredefinedMetricType?: string | undefined;
}
export type MetricSpecification =
  | MetricSpecification.CustomizedMember
  | MetricSpecification.PredefinedMember
  | MetricSpecification.$UnknownMember;
export declare namespace MetricSpecification {
  interface PredefinedMember {
    Predefined: PredefinedMetricSpecification;
    Customized?: never;
    $unknown?: never;
  }
  interface CustomizedMember {
    Predefined?: never;
    Customized: CustomizedMetricSpecification;
    $unknown?: never;
  }
  interface $UnknownMember {
    Predefined?: never;
    Customized?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    Predefined: (value: PredefinedMetricSpecification) => T;
    Customized: (value: CustomizedMetricSpecification) => T;
    _: (name: string, value: any) => T;
  }
}
export interface TargetTrackingScalingPolicyConfiguration {
  MetricSpecification?: MetricSpecification | undefined;
  TargetValue?: number | undefined;
}
export type ScalingPolicy =
  | ScalingPolicy.TargetTrackingMember
  | ScalingPolicy.$UnknownMember;
export declare namespace ScalingPolicy {
  interface TargetTrackingMember {
    TargetTracking: TargetTrackingScalingPolicyConfiguration;
    $unknown?: never;
  }
  interface $UnknownMember {
    TargetTracking?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    TargetTracking: (value: TargetTrackingScalingPolicyConfiguration) => T;
    _: (name: string, value: any) => T;
  }
}
export interface DynamicScalingConfiguration {
  MinCapacity?: number | undefined;
  MaxCapacity?: number | undefined;
  ScaleInCooldown?: number | undefined;
  ScaleOutCooldown?: number | undefined;
  ScalingPolicies?: ScalingPolicy[] | undefined;
}
export interface Edge {
  SourceArn?: string | undefined;
  DestinationArn?: string | undefined;
  AssociationType?: AssociationEdgeType | undefined;
}
export interface EdgeDeploymentPlanSummary {
  EdgeDeploymentPlanArn: string | undefined;
  EdgeDeploymentPlanName: string | undefined;
  DeviceFleetName: string | undefined;
  EdgeDeploymentSuccess: number | undefined;
  EdgeDeploymentPending: number | undefined;
  EdgeDeploymentFailed: number | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
}
export interface EdgeModelStat {
  ModelName: string | undefined;
  ModelVersion: string | undefined;
  OfflineDeviceCount: number | undefined;
  ConnectedDeviceCount: number | undefined;
  ActiveDeviceCount: number | undefined;
  SamplingDeviceCount: number | undefined;
}
export interface EdgePackagingJobSummary {
  EdgePackagingJobArn: string | undefined;
  EdgePackagingJobName: string | undefined;
  EdgePackagingJobStatus: EdgePackagingJobStatus | undefined;
  CompilationJobName?: string | undefined;
  ModelName?: string | undefined;
  ModelVersion?: string | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
}
export interface EMRStepMetadata {
  ClusterId?: string | undefined;
  StepId?: string | undefined;
  StepName?: string | undefined;
  LogFilePath?: string | undefined;
}
export interface EnableSagemakerServicecatalogPortfolioInput {}
export interface EnableSagemakerServicecatalogPortfolioOutput {}
export interface MonitoringSchedule {
  MonitoringScheduleArn?: string | undefined;
  MonitoringScheduleName?: string | undefined;
  MonitoringScheduleStatus?: ScheduleStatus | undefined;
  MonitoringType?: MonitoringType | undefined;
  FailureReason?: string | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  MonitoringScheduleConfig?: MonitoringScheduleConfig | undefined;
  EndpointName?: string | undefined;
  LastMonitoringExecutionSummary?: MonitoringExecutionSummary | undefined;
  Tags?: Tag[] | undefined;
}
export interface Endpoint {
  EndpointName: string | undefined;
  EndpointArn: string | undefined;
  EndpointConfigName: string | undefined;
  ProductionVariants?: ProductionVariantSummary[] | undefined;
  DataCaptureConfig?: DataCaptureConfigSummary | undefined;
  EndpointStatus: EndpointStatus | undefined;
  FailureReason?: string | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  MonitoringSchedules?: MonitoringSchedule[] | undefined;
  Tags?: Tag[] | undefined;
  ShadowProductionVariants?: ProductionVariantSummary[] | undefined;
}
export interface EndpointConfigStepMetadata {
  Arn?: string | undefined;
}
export interface EndpointConfigSummary {
  EndpointConfigName: string | undefined;
  EndpointConfigArn: string | undefined;
  CreationTime: Date | undefined;
}
export interface EndpointStepMetadata {
  Arn?: string | undefined;
}
export interface EndpointSummary {
  EndpointName: string | undefined;
  EndpointArn: string | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  EndpointStatus: EndpointStatus | undefined;
}
export interface Experiment {
  ExperimentName?: string | undefined;
  ExperimentArn?: string | undefined;
  DisplayName?: string | undefined;
  Source?: ExperimentSource | undefined;
  Description?: string | undefined;
  CreationTime?: Date | undefined;
  CreatedBy?: UserContext | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
  Tags?: Tag[] | undefined;
}
export interface ExperimentSummary {
  ExperimentArn?: string | undefined;
  ExperimentName?: string | undefined;
  DisplayName?: string | undefined;
  ExperimentSource?: ExperimentSource | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
}
export interface FailStepMetadata {
  ErrorMessage?: string | undefined;
}
export interface FeatureGroup {
  FeatureGroupArn?: string | undefined;
  FeatureGroupName?: string | undefined;
  RecordIdentifierFeatureName?: string | undefined;
  EventTimeFeatureName?: string | undefined;
  FeatureDefinitions?: FeatureDefinition[] | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  OnlineStoreConfig?: OnlineStoreConfig | undefined;
  OfflineStoreConfig?: OfflineStoreConfig | undefined;
  RoleArn?: string | undefined;
  FeatureGroupStatus?: FeatureGroupStatus | undefined;
  OfflineStoreStatus?: OfflineStoreStatus | undefined;
  LastUpdateStatus?: LastUpdateStatus | undefined;
  FailureReason?: string | undefined;
  Description?: string | undefined;
  Tags?: Tag[] | undefined;
}
export interface FeatureGroupSummary {
  FeatureGroupName: string | undefined;
  FeatureGroupArn: string | undefined;
  CreationTime: Date | undefined;
  FeatureGroupStatus?: FeatureGroupStatus | undefined;
  OfflineStoreStatus?: OfflineStoreStatus | undefined;
}
export interface FeatureMetadata {
  FeatureGroupArn?: string | undefined;
  FeatureGroupName?: string | undefined;
  FeatureName?: string | undefined;
  FeatureType?: FeatureType | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  Description?: string | undefined;
  Parameters?: FeatureParameter[] | undefined;
}
export interface Filter {
  Name: string | undefined;
  Operator?: Operator | undefined;
  Value?: string | undefined;
}
export interface FlowDefinitionSummary {
  FlowDefinitionName: string | undefined;
  FlowDefinitionArn: string | undefined;
  FlowDefinitionStatus: FlowDefinitionStatus | undefined;
  CreationTime: Date | undefined;
  FailureReason?: string | undefined;
}
export interface GetDeviceFleetReportRequest {
  DeviceFleetName: string | undefined;
}
export interface GetDeviceFleetReportResponse {
  DeviceFleetArn: string | undefined;
  DeviceFleetName: string | undefined;
  OutputConfig?: EdgeOutputConfig | undefined;
  Description?: string | undefined;
  ReportGenerated?: Date | undefined;
  DeviceStats?: DeviceStats | undefined;
  AgentVersions?: AgentVersion[] | undefined;
  ModelStats?: EdgeModelStat[] | undefined;
}
export interface GetLineageGroupPolicyRequest {
  LineageGroupName: string | undefined;
}
export interface GetLineageGroupPolicyResponse {
  LineageGroupArn?: string | undefined;
  ResourcePolicy?: string | undefined;
}
export interface GetModelPackageGroupPolicyInput {
  ModelPackageGroupName: string | undefined;
}
export interface GetModelPackageGroupPolicyOutput {
  ResourcePolicy: string | undefined;
}
export interface GetSagemakerServicecatalogPortfolioStatusInput {}
export interface GetSagemakerServicecatalogPortfolioStatusOutput {
  Status?: SagemakerServicecatalogStatus | undefined;
}
export interface ScalingPolicyObjective {
  MinInvocationsPerMinute?: number | undefined;
  MaxInvocationsPerMinute?: number | undefined;
}
export interface GetScalingConfigurationRecommendationRequest {
  InferenceRecommendationsJobName: string | undefined;
  RecommendationId?: string | undefined;
  EndpointName?: string | undefined;
  TargetCpuUtilizationPerCore?: number | undefined;
  ScalingPolicyObjective?: ScalingPolicyObjective | undefined;
}
export interface ScalingPolicyMetric {
  InvocationsPerInstance?: number | undefined;
  ModelLatency?: number | undefined;
}
export interface GetScalingConfigurationRecommendationResponse {
  InferenceRecommendationsJobName?: string | undefined;
  RecommendationId?: string | undefined;
  EndpointName?: string | undefined;
  TargetCpuUtilizationPerCore?: number | undefined;
  ScalingPolicyObjective?: ScalingPolicyObjective | undefined;
  Metric?: ScalingPolicyMetric | undefined;
  DynamicScalingConfiguration?: DynamicScalingConfiguration | undefined;
}
export interface PropertyNameQuery {
  PropertyNameHint: string | undefined;
}
export interface SuggestionQuery {
  PropertyNameQuery?: PropertyNameQuery | undefined;
}
export interface GetSearchSuggestionsRequest {
  Resource: ResourceType | undefined;
  SuggestionQuery?: SuggestionQuery | undefined;
}
export interface PropertyNameSuggestion {
  PropertyName?: string | undefined;
}
export interface GetSearchSuggestionsResponse {
  PropertyNameSuggestions?: PropertyNameSuggestion[] | undefined;
}
export interface GitConfigForUpdate {
  SecretArn?: string | undefined;
}
export interface HubContentInfo {
  HubContentName: string | undefined;
  HubContentArn: string | undefined;
  SageMakerPublicHubContentArn?: string | undefined;
  HubContentVersion: string | undefined;
  HubContentType: HubContentType | undefined;
  DocumentSchemaVersion: string | undefined;
  HubContentDisplayName?: string | undefined;
  HubContentDescription?: string | undefined;
  SupportStatus?: HubContentSupportStatus | undefined;
  HubContentSearchKeywords?: string[] | undefined;
  HubContentStatus: HubContentStatus | undefined;
  CreationTime: Date | undefined;
  OriginalCreationTime?: Date | undefined;
}
export interface HubInfo {
  HubName: string | undefined;
  HubArn: string | undefined;
  HubDisplayName?: string | undefined;
  HubDescription?: string | undefined;
  HubSearchKeywords?: string[] | undefined;
  HubStatus: HubStatus | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
}
export interface HumanTaskUiSummary {
  HumanTaskUiName: string | undefined;
  HumanTaskUiArn: string | undefined;
  CreationTime: Date | undefined;
}
export interface HyperParameterTuningJobSearchEntity {
  HyperParameterTuningJobName?: string | undefined;
  HyperParameterTuningJobArn?: string | undefined;
  HyperParameterTuningJobConfig?: HyperParameterTuningJobConfig | undefined;
  TrainingJobDefinition?: HyperParameterTrainingJobDefinition | undefined;
  TrainingJobDefinitions?: HyperParameterTrainingJobDefinition[] | undefined;
  HyperParameterTuningJobStatus?: HyperParameterTuningJobStatus | undefined;
  CreationTime?: Date | undefined;
  HyperParameterTuningEndTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  TrainingJobStatusCounters?: TrainingJobStatusCounters | undefined;
  ObjectiveStatusCounters?: ObjectiveStatusCounters | undefined;
  BestTrainingJob?: HyperParameterTrainingJobSummary | undefined;
  OverallBestTrainingJob?: HyperParameterTrainingJobSummary | undefined;
  WarmStartConfig?: HyperParameterTuningJobWarmStartConfig | undefined;
  FailureReason?: string | undefined;
  TuningJobCompletionDetails?:
    | HyperParameterTuningJobCompletionDetails
    | undefined;
  ConsumedResources?: HyperParameterTuningJobConsumedResources | undefined;
  Tags?: Tag[] | undefined;
}
export interface HyperParameterTuningJobSummary {
  HyperParameterTuningJobName: string | undefined;
  HyperParameterTuningJobArn: string | undefined;
  HyperParameterTuningJobStatus: HyperParameterTuningJobStatus | undefined;
  Strategy: HyperParameterTuningJobStrategyType | undefined;
  CreationTime: Date | undefined;
  HyperParameterTuningEndTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  TrainingJobStatusCounters: TrainingJobStatusCounters | undefined;
  ObjectiveStatusCounters: ObjectiveStatusCounters | undefined;
  ResourceLimits?: ResourceLimits | undefined;
}
export interface Image {
  CreationTime: Date | undefined;
  Description?: string | undefined;
  DisplayName?: string | undefined;
  FailureReason?: string | undefined;
  ImageArn: string | undefined;
  ImageName: string | undefined;
  ImageStatus: ImageStatus | undefined;
  LastModifiedTime: Date | undefined;
}
export interface ImageVersion {
  CreationTime: Date | undefined;
  FailureReason?: string | undefined;
  ImageArn: string | undefined;
  ImageVersionArn: string | undefined;
  ImageVersionStatus: ImageVersionStatus | undefined;
  LastModifiedTime: Date | undefined;
  Version: number | undefined;
}
export interface ImportHubContentRequest {
  HubContentName: string | undefined;
  HubContentVersion?: string | undefined;
  HubContentType: HubContentType | undefined;
  DocumentSchemaVersion: string | undefined;
  HubName: string | undefined;
  HubContentDisplayName?: string | undefined;
  HubContentDescription?: string | undefined;
  HubContentMarkdown?: string | undefined;
  HubContentDocument: string | undefined;
  SupportStatus?: HubContentSupportStatus | undefined;
  HubContentSearchKeywords?: string[] | undefined;
  Tags?: Tag[] | undefined;
}
export interface ImportHubContentResponse {
  HubArn: string | undefined;
  HubContentArn: string | undefined;
}
export interface InferenceComponentMetadata {
  Arn?: string | undefined;
}
export interface InferenceComponentSummary {
  CreationTime: Date | undefined;
  InferenceComponentArn: string | undefined;
  InferenceComponentName: string | undefined;
  EndpointArn: string | undefined;
  EndpointName: string | undefined;
  VariantName: string | undefined;
  InferenceComponentStatus?: InferenceComponentStatus | undefined;
  LastModifiedTime: Date | undefined;
}
export interface InferenceExperimentSummary {
  Name: string | undefined;
  Type: InferenceExperimentType | undefined;
  Schedule?: InferenceExperimentSchedule | undefined;
  Status: InferenceExperimentStatus | undefined;
  StatusReason?: string | undefined;
  Description?: string | undefined;
  CreationTime: Date | undefined;
  CompletionTime?: Date | undefined;
  LastModifiedTime: Date | undefined;
  RoleArn?: string | undefined;
}
export interface InferenceRecommendationsJob {
  JobName: string | undefined;
  JobDescription: string | undefined;
  JobType: RecommendationJobType | undefined;
  JobArn: string | undefined;
  Status: RecommendationJobStatus | undefined;
  CreationTime: Date | undefined;
  CompletionTime?: Date | undefined;
  RoleArn: string | undefined;
  LastModifiedTime: Date | undefined;
  FailureReason?: string | undefined;
  ModelName?: string | undefined;
  SamplePayloadUrl?: string | undefined;
  ModelPackageVersionArn?: string | undefined;
}
export interface RecommendationJobInferenceBenchmark {
  Metrics?: RecommendationMetrics | undefined;
  EndpointMetrics?: InferenceMetrics | undefined;
  EndpointConfiguration?: EndpointOutputConfiguration | undefined;
  ModelConfiguration: ModelConfiguration | undefined;
  FailureReason?: string | undefined;
  InvocationEndTime?: Date | undefined;
  InvocationStartTime?: Date | undefined;
}
export interface InferenceRecommendationsJobStep {
  StepType: RecommendationStepType | undefined;
  JobName: string | undefined;
  Status: RecommendationJobStatus | undefined;
  InferenceBenchmark?: RecommendationJobInferenceBenchmark | undefined;
}
export interface LabelCountersForWorkteam {
  HumanLabeled?: number | undefined;
  PendingHuman?: number | undefined;
  Total?: number | undefined;
}
export interface LabelingJobForWorkteamSummary {
  LabelingJobName?: string | undefined;
  JobReferenceCode: string | undefined;
  WorkRequesterAccountId: string | undefined;
  CreationTime: Date | undefined;
  LabelCounters?: LabelCountersForWorkteam | undefined;
  NumberOfHumanWorkersPerDataObject?: number | undefined;
}
export interface LabelingJobSummary {
  LabelingJobName: string | undefined;
  LabelingJobArn: string | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  LabelingJobStatus: LabelingJobStatus | undefined;
  LabelCounters: LabelCounters | undefined;
  WorkteamArn: string | undefined;
  PreHumanTaskLambdaArn?: string | undefined;
  AnnotationConsolidationLambdaArn?: string | undefined;
  FailureReason?: string | undefined;
  LabelingJobOutput?: LabelingJobOutput | undefined;
  InputConfig?: LabelingJobInputConfig | undefined;
}
export interface LambdaStepMetadata {
  Arn?: string | undefined;
  OutputParameters?: OutputParameter[] | undefined;
}
export interface LineageGroupSummary {
  LineageGroupArn?: string | undefined;
  LineageGroupName?: string | undefined;
  DisplayName?: string | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
}
export interface LineageMetadata {
  ActionArns?: Record<string, string> | undefined;
  ArtifactArns?: Record<string, string> | undefined;
  ContextArns?: Record<string, string> | undefined;
  Associations?: AssociationInfo[] | undefined;
}
export interface ListActionsRequest {
  SourceUri?: string | undefined;
  ActionType?: string | undefined;
  CreatedAfter?: Date | undefined;
  CreatedBefore?: Date | undefined;
  SortBy?: SortActionsBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListActionsResponse {
  ActionSummaries?: ActionSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListAlgorithmsInput {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  NextToken?: string | undefined;
  SortBy?: AlgorithmSortBy | undefined;
  SortOrder?: SortOrder | undefined;
}
export interface ListAlgorithmsOutput {
  AlgorithmSummaryList: AlgorithmSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListAliasesRequest {
  ImageName: string | undefined;
  Alias?: string | undefined;
  Version?: number | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListAliasesResponse {
  SageMakerImageVersionAliases?: string[] | undefined;
  NextToken?: string | undefined;
}
export interface ListAppImageConfigsRequest {
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
  NameContains?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
  ModifiedTimeBefore?: Date | undefined;
  ModifiedTimeAfter?: Date | undefined;
  SortBy?: AppImageConfigSortKey | undefined;
  SortOrder?: SortOrder | undefined;
}
export interface ListAppImageConfigsResponse {
  NextToken?: string | undefined;
  AppImageConfigs?: AppImageConfigDetails[] | undefined;
}
export interface ListAppsRequest {
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  SortOrder?: SortOrder | undefined;
  SortBy?: AppSortKey | undefined;
  DomainIdEquals?: string | undefined;
  UserProfileNameEquals?: string | undefined;
  SpaceNameEquals?: string | undefined;
}
export interface ListAppsResponse {
  Apps?: AppDetails[] | undefined;
  NextToken?: string | undefined;
}
export interface ListArtifactsRequest {
  SourceUri?: string | undefined;
  ArtifactType?: string | undefined;
  CreatedAfter?: Date | undefined;
  CreatedBefore?: Date | undefined;
  SortBy?: SortArtifactsBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListArtifactsResponse {
  ArtifactSummaries?: ArtifactSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListAssociationsRequest {
  SourceArn?: string | undefined;
  DestinationArn?: string | undefined;
  SourceType?: string | undefined;
  DestinationType?: string | undefined;
  AssociationType?: AssociationEdgeType | undefined;
  CreatedAfter?: Date | undefined;
  CreatedBefore?: Date | undefined;
  SortBy?: SortAssociationsBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListAssociationsResponse {
  AssociationSummaries?: AssociationSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListAutoMLJobsRequest {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  NameContains?: string | undefined;
  StatusEquals?: AutoMLJobStatus | undefined;
  SortOrder?: AutoMLSortOrder | undefined;
  SortBy?: AutoMLSortBy | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListAutoMLJobsResponse {
  AutoMLJobSummaries: AutoMLJobSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListCandidatesForAutoMLJobRequest {
  AutoMLJobName: string | undefined;
  StatusEquals?: CandidateStatus | undefined;
  CandidateNameEquals?: string | undefined;
  SortOrder?: AutoMLSortOrder | undefined;
  SortBy?: CandidateSortBy | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListCandidatesForAutoMLJobResponse {
  Candidates: AutoMLCandidate[] | undefined;
  NextToken?: string | undefined;
}
export interface ListClusterEventsRequest {
  ClusterName: string | undefined;
  InstanceGroupName?: string | undefined;
  NodeId?: string | undefined;
  EventTimeAfter?: Date | undefined;
  EventTimeBefore?: Date | undefined;
  SortBy?: EventSortBy | undefined;
  SortOrder?: SortOrder | undefined;
  ResourceType?: ClusterEventResourceType | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListClusterEventsResponse {
  NextToken?: string | undefined;
  Events?: ClusterEventSummary[] | undefined;
}
export interface ListClusterNodesRequest {
  ClusterName: string | undefined;
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  InstanceGroupNameContains?: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
  SortBy?: ClusterSortBy | undefined;
  SortOrder?: SortOrder | undefined;
  IncludeNodeLogicalIds?: boolean | undefined;
}
export interface ListClusterNodesResponse {
  NextToken?: string | undefined;
  ClusterNodeSummaries: ClusterNodeSummary[] | undefined;
}
export interface ListClustersRequest {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  NextToken?: string | undefined;
  SortBy?: ClusterSortBy | undefined;
  SortOrder?: SortOrder | undefined;
  TrainingPlanArn?: string | undefined;
}
export interface ListClustersResponse {
  NextToken?: string | undefined;
  ClusterSummaries: ClusterSummary[] | undefined;
}
export interface ListClusterSchedulerConfigsRequest {
  CreatedAfter?: Date | undefined;
  CreatedBefore?: Date | undefined;
  NameContains?: string | undefined;
  ClusterArn?: string | undefined;
  Status?: SchedulerResourceStatus | undefined;
  SortBy?: SortClusterSchedulerConfigBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListClusterSchedulerConfigsResponse {
  ClusterSchedulerConfigSummaries?: ClusterSchedulerConfigSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListCodeRepositoriesInput {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  NextToken?: string | undefined;
  SortBy?: CodeRepositorySortBy | undefined;
  SortOrder?: CodeRepositorySortOrder | undefined;
}
export interface ListCodeRepositoriesOutput {
  CodeRepositorySummaryList: CodeRepositorySummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListCompilationJobsRequest {
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  NameContains?: string | undefined;
  StatusEquals?: CompilationJobStatus | undefined;
  SortBy?: ListCompilationJobsSortBy | undefined;
  SortOrder?: SortOrder | undefined;
}
export interface ListCompilationJobsResponse {
  CompilationJobSummaries: CompilationJobSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListComputeQuotasRequest {
  CreatedAfter?: Date | undefined;
  CreatedBefore?: Date | undefined;
  NameContains?: string | undefined;
  Status?: SchedulerResourceStatus | undefined;
  ClusterArn?: string | undefined;
  SortBy?: SortQuotaBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListComputeQuotasResponse {
  ComputeQuotaSummaries?: ComputeQuotaSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListContextsRequest {
  SourceUri?: string | undefined;
  ContextType?: string | undefined;
  CreatedAfter?: Date | undefined;
  CreatedBefore?: Date | undefined;
  SortBy?: SortContextsBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListContextsResponse {
  ContextSummaries?: ContextSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListDataQualityJobDefinitionsRequest {
  EndpointName?: string | undefined;
  SortBy?: MonitoringJobDefinitionSortKey | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
}
export interface MonitoringJobDefinitionSummary {
  MonitoringJobDefinitionName: string | undefined;
  MonitoringJobDefinitionArn: string | undefined;
  CreationTime: Date | undefined;
  EndpointName: string | undefined;
}
export interface ListDataQualityJobDefinitionsResponse {
  JobDefinitionSummaries: MonitoringJobDefinitionSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListDeviceFleetsRequest {
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  NameContains?: string | undefined;
  SortBy?: ListDeviceFleetsSortBy | undefined;
  SortOrder?: SortOrder | undefined;
}
export interface ListDeviceFleetsResponse {
  DeviceFleetSummaries: DeviceFleetSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListDevicesRequest {
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  LatestHeartbeatAfter?: Date | undefined;
  ModelName?: string | undefined;
  DeviceFleetName?: string | undefined;
}
export interface ListDevicesResponse {
  DeviceSummaries: DeviceSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListDomainsRequest {
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListDomainsResponse {
  Domains?: DomainDetails[] | undefined;
  NextToken?: string | undefined;
}
export interface ListEdgeDeploymentPlansRequest {
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  NameContains?: string | undefined;
  DeviceFleetNameContains?: string | undefined;
  SortBy?: ListEdgeDeploymentPlansSortBy | undefined;
  SortOrder?: SortOrder | undefined;
}
export interface ListEdgeDeploymentPlansResponse {
  EdgeDeploymentPlanSummaries: EdgeDeploymentPlanSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListEdgePackagingJobsRequest {
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  NameContains?: string | undefined;
  ModelNameContains?: string | undefined;
  StatusEquals?: EdgePackagingJobStatus | undefined;
  SortBy?: ListEdgePackagingJobsSortBy | undefined;
  SortOrder?: SortOrder | undefined;
}
export interface ListEdgePackagingJobsResponse {
  EdgePackagingJobSummaries: EdgePackagingJobSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListEndpointConfigsInput {
  SortBy?: EndpointConfigSortKey | undefined;
  SortOrder?: OrderKey | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
}
export interface ListEndpointConfigsOutput {
  EndpointConfigs: EndpointConfigSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListEndpointsInput {
  SortBy?: EndpointSortKey | undefined;
  SortOrder?: OrderKey | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  StatusEquals?: EndpointStatus | undefined;
}
export interface ListEndpointsOutput {
  Endpoints: EndpointSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListExperimentsRequest {
  CreatedAfter?: Date | undefined;
  CreatedBefore?: Date | undefined;
  SortBy?: SortExperimentsBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListExperimentsResponse {
  ExperimentSummaries?: ExperimentSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListFeatureGroupsRequest {
  NameContains?: string | undefined;
  FeatureGroupStatusEquals?: FeatureGroupStatus | undefined;
  OfflineStoreStatusEquals?: OfflineStoreStatusValue | undefined;
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  SortOrder?: FeatureGroupSortOrder | undefined;
  SortBy?: FeatureGroupSortBy | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListFeatureGroupsResponse {
  FeatureGroupSummaries: FeatureGroupSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListFlowDefinitionsRequest {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListFlowDefinitionsResponse {
  FlowDefinitionSummaries: FlowDefinitionSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListHubContentsRequest {
  HubName: string | undefined;
  HubContentType: HubContentType | undefined;
  NameContains?: string | undefined;
  MaxSchemaVersion?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
  SortBy?: HubContentSortBy | undefined;
  SortOrder?: SortOrder | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListHubContentsResponse {
  HubContentSummaries: HubContentInfo[] | undefined;
  NextToken?: string | undefined;
}
export interface ListHubContentVersionsRequest {
  HubName: string | undefined;
  HubContentType: HubContentType | undefined;
  HubContentName: string | undefined;
  MinVersion?: string | undefined;
  MaxSchemaVersion?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
  SortBy?: HubContentSortBy | undefined;
  SortOrder?: SortOrder | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListHubContentVersionsResponse {
  HubContentSummaries: HubContentInfo[] | undefined;
  NextToken?: string | undefined;
}
export interface ListHubsRequest {
  NameContains?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  SortBy?: HubSortBy | undefined;
  SortOrder?: SortOrder | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListHubsResponse {
  HubSummaries: HubInfo[] | undefined;
  NextToken?: string | undefined;
}
export interface ListHumanTaskUisRequest {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListHumanTaskUisResponse {
  HumanTaskUiSummaries: HumanTaskUiSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListHyperParameterTuningJobsRequest {
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  SortBy?: HyperParameterTuningJobSortByOptions | undefined;
  SortOrder?: SortOrder | undefined;
  NameContains?: string | undefined;
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  StatusEquals?: HyperParameterTuningJobStatus | undefined;
}
export interface ListHyperParameterTuningJobsResponse {
  HyperParameterTuningJobSummaries:
    | HyperParameterTuningJobSummary[]
    | undefined;
  NextToken?: string | undefined;
}
export interface ListImagesRequest {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  NextToken?: string | undefined;
  SortBy?: ImageSortBy | undefined;
  SortOrder?: ImageSortOrder | undefined;
}
export interface ListImagesResponse {
  Images?: Image[] | undefined;
  NextToken?: string | undefined;
}
export interface ListImageVersionsRequest {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  ImageName: string | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
  SortBy?: ImageVersionSortBy | undefined;
  SortOrder?: ImageVersionSortOrder | undefined;
}
export interface ListImageVersionsResponse {
  ImageVersions?: ImageVersion[] | undefined;
  NextToken?: string | undefined;
}
export interface ListInferenceComponentsInput {
  SortBy?: InferenceComponentSortKey | undefined;
  SortOrder?: OrderKey | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  StatusEquals?: InferenceComponentStatus | undefined;
  EndpointNameEquals?: string | undefined;
  VariantNameEquals?: string | undefined;
}
export interface ListInferenceComponentsOutput {
  InferenceComponents: InferenceComponentSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListInferenceExperimentsRequest {
  NameContains?: string | undefined;
  Type?: InferenceExperimentType | undefined;
  StatusEquals?: InferenceExperimentStatus | undefined;
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  SortBy?: SortInferenceExperimentsBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListInferenceExperimentsResponse {
  InferenceExperiments?: InferenceExperimentSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListInferenceRecommendationsJobsRequest {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  NameContains?: string | undefined;
  StatusEquals?: RecommendationJobStatus | undefined;
  SortBy?: ListInferenceRecommendationsJobsSortBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  ModelNameEquals?: string | undefined;
  ModelPackageVersionArnEquals?: string | undefined;
}
export interface ListInferenceRecommendationsJobsResponse {
  InferenceRecommendationsJobs: InferenceRecommendationsJob[] | undefined;
  NextToken?: string | undefined;
}
export interface ListInferenceRecommendationsJobStepsRequest {
  JobName: string | undefined;
  Status?: RecommendationJobStatus | undefined;
  StepType?: RecommendationStepType | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface ListInferenceRecommendationsJobStepsResponse {
  Steps?: InferenceRecommendationsJobStep[] | undefined;
  NextToken?: string | undefined;
}
export interface ListLabelingJobsRequest {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
  NameContains?: string | undefined;
  SortBy?: SortBy | undefined;
  SortOrder?: SortOrder | undefined;
  StatusEquals?: LabelingJobStatus | undefined;
}
export interface ListLabelingJobsResponse {
  LabelingJobSummaryList?: LabelingJobSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListLabelingJobsForWorkteamRequest {
  WorkteamArn: string | undefined;
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  JobReferenceCodeContains?: string | undefined;
  SortBy?: ListLabelingJobsForWorkteamSortByOptions | undefined;
  SortOrder?: SortOrder | undefined;
}
export interface ListLabelingJobsForWorkteamResponse {
  LabelingJobSummaryList: LabelingJobForWorkteamSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListLineageGroupsRequest {
  CreatedAfter?: Date | undefined;
  CreatedBefore?: Date | undefined;
  SortBy?: SortLineageGroupsBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ListLineageGroupsResponse {
  LineageGroupSummaries?: LineageGroupSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListMlflowAppsRequest {
  CreatedAfter?: Date | undefined;
  CreatedBefore?: Date | undefined;
  Status?: MlflowAppStatus | undefined;
  MlflowVersion?: string | undefined;
  DefaultForDomainId?: string | undefined;
  AccountDefaultStatus?: AccountDefaultStatus | undefined;
  SortBy?: SortMlflowAppBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface MlflowAppSummary {
  Arn?: string | undefined;
  Name?: string | undefined;
  Status?: MlflowAppStatus | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  MlflowVersion?: string | undefined;
}
export interface ListMlflowAppsResponse {
  Summaries?: MlflowAppSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListMlflowTrackingServersRequest {
  CreatedAfter?: Date | undefined;
  CreatedBefore?: Date | undefined;
  TrackingServerStatus?: TrackingServerStatus | undefined;
  MlflowVersion?: string | undefined;
  SortBy?: SortTrackingServerBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface TrackingServerSummary {
  TrackingServerArn?: string | undefined;
  TrackingServerName?: string | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  TrackingServerStatus?: TrackingServerStatus | undefined;
  IsActive?: IsTrackingServerActive | undefined;
  MlflowVersion?: string | undefined;
}
export interface ListMlflowTrackingServersResponse {
  TrackingServerSummaries?: TrackingServerSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListModelBiasJobDefinitionsRequest {
  EndpointName?: string | undefined;
  SortBy?: MonitoringJobDefinitionSortKey | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
}
export interface ListModelBiasJobDefinitionsResponse {
  JobDefinitionSummaries: MonitoringJobDefinitionSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListModelCardExportJobsRequest {
  ModelCardName: string | undefined;
  ModelCardVersion?: number | undefined;
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  ModelCardExportJobNameContains?: string | undefined;
  StatusEquals?: ModelCardExportJobStatus | undefined;
  SortBy?: ModelCardExportJobSortBy | undefined;
  SortOrder?: ModelCardExportJobSortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ModelCardExportJobSummary {
  ModelCardExportJobName: string | undefined;
  ModelCardExportJobArn: string | undefined;
  Status: ModelCardExportJobStatus | undefined;
  ModelCardName: string | undefined;
  ModelCardVersion: number | undefined;
  CreatedAt: Date | undefined;
  LastModifiedAt: Date | undefined;
}
export interface ListModelCardExportJobsResponse {
  ModelCardExportJobSummaries: ModelCardExportJobSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListModelCardsRequest {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  ModelCardStatus?: ModelCardStatus | undefined;
  NextToken?: string | undefined;
  SortBy?: ModelCardSortBy | undefined;
  SortOrder?: ModelCardSortOrder | undefined;
}
export interface ModelCardSummary {
  ModelCardName: string | undefined;
  ModelCardArn: string | undefined;
  ModelCardStatus: ModelCardStatus | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime?: Date | undefined;
}
export interface ListModelCardsResponse {
  ModelCardSummaries: ModelCardSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListModelCardVersionsRequest {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  MaxResults?: number | undefined;
  ModelCardName: string | undefined;
  ModelCardStatus?: ModelCardStatus | undefined;
  NextToken?: string | undefined;
  SortBy?: ModelCardVersionSortBy | undefined;
  SortOrder?: ModelCardSortOrder | undefined;
}
export interface ModelCardVersionSummary {
  ModelCardName: string | undefined;
  ModelCardArn: string | undefined;
  ModelCardStatus: ModelCardStatus | undefined;
  ModelCardVersion: number | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime?: Date | undefined;
}
export interface ListModelCardVersionsResponse {
  ModelCardVersionSummaryList: ModelCardVersionSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListModelExplainabilityJobDefinitionsRequest {
  EndpointName?: string | undefined;
  SortBy?: MonitoringJobDefinitionSortKey | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
}
export interface ListModelExplainabilityJobDefinitionsResponse {
  JobDefinitionSummaries: MonitoringJobDefinitionSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ModelMetadataFilter {
  Name: ModelMetadataFilterType | undefined;
  Value: string | undefined;
}
export interface ModelMetadataSearchExpression {
  Filters?: ModelMetadataFilter[] | undefined;
}
export interface ListModelMetadataRequest {
  SearchExpression?: ModelMetadataSearchExpression | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ModelMetadataSummary {
  Domain: string | undefined;
  Framework: string | undefined;
  Task: string | undefined;
  Model: string | undefined;
  FrameworkVersion: string | undefined;
}
export interface ListModelMetadataResponse {
  ModelMetadataSummaries: ModelMetadataSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListModelPackageGroupsInput {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  NextToken?: string | undefined;
  SortBy?: ModelPackageGroupSortBy | undefined;
  SortOrder?: SortOrder | undefined;
  CrossAccountFilterOption?: CrossAccountFilterOption | undefined;
}
export interface ModelPackageGroupSummary {
  ModelPackageGroupName: string | undefined;
  ModelPackageGroupArn: string | undefined;
  ModelPackageGroupDescription?: string | undefined;
  CreationTime: Date | undefined;
  ModelPackageGroupStatus: ModelPackageGroupStatus | undefined;
}
export interface ListModelPackageGroupsOutput {
  ModelPackageGroupSummaryList: ModelPackageGroupSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListModelPackagesInput {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  ModelApprovalStatus?: ModelApprovalStatus | undefined;
  ModelPackageGroupName?: string | undefined;
  ModelPackageType?: ModelPackageType | undefined;
  NextToken?: string | undefined;
  SortBy?: ModelPackageSortBy | undefined;
  SortOrder?: SortOrder | undefined;
}
export interface ModelPackageSummary {
  ModelPackageName?: string | undefined;
  ModelPackageGroupName?: string | undefined;
  ModelPackageVersion?: number | undefined;
  ModelPackageArn: string | undefined;
  ModelPackageDescription?: string | undefined;
  CreationTime: Date | undefined;
  ModelPackageStatus: ModelPackageStatus | undefined;
  ModelApprovalStatus?: ModelApprovalStatus | undefined;
  ModelLifeCycle?: ModelLifeCycle | undefined;
  ModelPackageRegistrationType?: ModelPackageRegistrationType | undefined;
}
export interface ListModelPackagesOutput {
  ModelPackageSummaryList: ModelPackageSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListModelQualityJobDefinitionsRequest {
  EndpointName?: string | undefined;
  SortBy?: MonitoringJobDefinitionSortKey | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
}
export interface ListModelQualityJobDefinitionsResponse {
  JobDefinitionSummaries: MonitoringJobDefinitionSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListModelsInput {
  SortBy?: ModelSortKey | undefined;
  SortOrder?: OrderKey | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
}
export interface ModelSummary {
  ModelName: string | undefined;
  ModelArn: string | undefined;
  CreationTime: Date | undefined;
}
export interface ListModelsOutput {
  Models: ModelSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListMonitoringAlertHistoryRequest {
  MonitoringScheduleName?: string | undefined;
  MonitoringAlertName?: string | undefined;
  SortBy?: MonitoringAlertHistorySortKey | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
  StatusEquals?: MonitoringAlertStatus | undefined;
}
export interface MonitoringAlertHistorySummary {
  MonitoringScheduleName: string | undefined;
  MonitoringAlertName: string | undefined;
  CreationTime: Date | undefined;
  AlertStatus: MonitoringAlertStatus | undefined;
}
export interface ListMonitoringAlertHistoryResponse {
  MonitoringAlertHistory?: MonitoringAlertHistorySummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListMonitoringAlertsRequest {
  MonitoringScheduleName: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface ModelDashboardIndicatorAction {
  Enabled?: boolean | undefined;
}
export interface MonitoringAlertActions {
  ModelDashboardIndicator?: ModelDashboardIndicatorAction | undefined;
}
export interface MonitoringAlertSummary {
  MonitoringAlertName: string | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  AlertStatus: MonitoringAlertStatus | undefined;
  DatapointsToAlert: number | undefined;
  EvaluationPeriod: number | undefined;
  Actions: MonitoringAlertActions | undefined;
}
export interface ListMonitoringAlertsResponse {
  MonitoringAlertSummaries?: MonitoringAlertSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListMonitoringExecutionsRequest {
  MonitoringScheduleName?: string | undefined;
  EndpointName?: string | undefined;
  SortBy?: MonitoringExecutionSortKey | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  ScheduledTimeBefore?: Date | undefined;
  ScheduledTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  StatusEquals?: ExecutionStatus | undefined;
  MonitoringJobDefinitionName?: string | undefined;
  MonitoringTypeEquals?: MonitoringType | undefined;
}
export interface ListMonitoringExecutionsResponse {
  MonitoringExecutionSummaries: MonitoringExecutionSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListMonitoringSchedulesRequest {
  EndpointName?: string | undefined;
  SortBy?: MonitoringScheduleSortKey | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  NameContains?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  StatusEquals?: ScheduleStatus | undefined;
  MonitoringJobDefinitionName?: string | undefined;
  MonitoringTypeEquals?: MonitoringType | undefined;
}
export interface MonitoringScheduleSummary {
  MonitoringScheduleName: string | undefined;
  MonitoringScheduleArn: string | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  MonitoringScheduleStatus: ScheduleStatus | undefined;
  EndpointName?: string | undefined;
  MonitoringJobDefinitionName?: string | undefined;
  MonitoringType?: MonitoringType | undefined;
}
export interface ListMonitoringSchedulesResponse {
  MonitoringScheduleSummaries: MonitoringScheduleSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListNotebookInstanceLifecycleConfigsInput {
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  SortBy?: NotebookInstanceLifecycleConfigSortKey | undefined;
  SortOrder?: NotebookInstanceLifecycleConfigSortOrder | undefined;
  NameContains?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
}
export interface NotebookInstanceLifecycleConfigSummary {
  NotebookInstanceLifecycleConfigName: string | undefined;
  NotebookInstanceLifecycleConfigArn: string | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
}
export interface ListNotebookInstanceLifecycleConfigsOutput {
  NextToken?: string | undefined;
  NotebookInstanceLifecycleConfigs?:
    | NotebookInstanceLifecycleConfigSummary[]
    | undefined;
}
export interface ListNotebookInstancesInput {
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  SortBy?: NotebookInstanceSortKey | undefined;
  SortOrder?: NotebookInstanceSortOrder | undefined;
  NameContains?: string | undefined;
  CreationTimeBefore?: Date | undefined;
  CreationTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  StatusEquals?: NotebookInstanceStatus | undefined;
  NotebookInstanceLifecycleConfigNameContains?: string | undefined;
  DefaultCodeRepositoryContains?: string | undefined;
  AdditionalCodeRepositoryEquals?: string | undefined;
}
export interface NotebookInstanceSummary {
  NotebookInstanceName: string | undefined;
  NotebookInstanceArn: string | undefined;
  NotebookInstanceStatus?: NotebookInstanceStatus | undefined;
  Url?: string | undefined;
  InstanceType?: _InstanceType | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  NotebookInstanceLifecycleConfigName?: string | undefined;
  DefaultCodeRepository?: string | undefined;
  AdditionalCodeRepositories?: string[] | undefined;
}
export interface ListNotebookInstancesOutput {
  NextToken?: string | undefined;
  NotebookInstances?: NotebookInstanceSummary[] | undefined;
}
export interface ListOptimizationJobsRequest {
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  OptimizationContains?: string | undefined;
  NameContains?: string | undefined;
  StatusEquals?: OptimizationJobStatus | undefined;
  SortBy?: ListOptimizationJobsSortBy | undefined;
  SortOrder?: SortOrder | undefined;
}
export interface OptimizationJobSummary {
  OptimizationJobName: string | undefined;
  OptimizationJobArn: string | undefined;
  CreationTime: Date | undefined;
  OptimizationJobStatus: OptimizationJobStatus | undefined;
  OptimizationStartTime?: Date | undefined;
  OptimizationEndTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  DeploymentInstanceType: OptimizationJobDeploymentInstanceType | undefined;
  MaxInstanceCount?: number | undefined;
  OptimizationTypes: string[] | undefined;
}
export interface ListOptimizationJobsResponse {
  OptimizationJobSummaries: OptimizationJobSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListPartnerAppsRequest {
  MaxResults?: number | undefined;
  NextToken?: string | undefined;
}
export interface PartnerAppSummary {
  Arn?: string | undefined;
  Name?: string | undefined;
  Type?: PartnerAppType | undefined;
  Status?: PartnerAppStatus | undefined;
  CreationTime?: Date | undefined;
}
export interface ListPartnerAppsResponse {
  Summaries?: PartnerAppSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListPipelineExecutionsRequest {
  PipelineName: string | undefined;
  CreatedAfter?: Date | undefined;
  CreatedBefore?: Date | undefined;
  SortBy?: SortPipelineExecutionsBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface PipelineExecutionSummary {
  PipelineExecutionArn?: string | undefined;
  StartTime?: Date | undefined;
  PipelineExecutionStatus?: PipelineExecutionStatus | undefined;
  PipelineExecutionDescription?: string | undefined;
  PipelineExecutionDisplayName?: string | undefined;
  PipelineExecutionFailureReason?: string | undefined;
}
export interface ListPipelineExecutionsResponse {
  PipelineExecutionSummaries?: PipelineExecutionSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListPipelineExecutionStepsRequest {
  PipelineExecutionArn?: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
  SortOrder?: SortOrder | undefined;
}
export interface ModelStepMetadata {
  Arn?: string | undefined;
}
export interface ProcessingJobStepMetadata {
  Arn?: string | undefined;
}
export interface QualityCheckStepMetadata {
  CheckType?: string | undefined;
  BaselineUsedForDriftCheckStatistics?: string | undefined;
  BaselineUsedForDriftCheckConstraints?: string | undefined;
  CalculatedBaselineStatistics?: string | undefined;
  CalculatedBaselineConstraints?: string | undefined;
  ModelPackageGroupName?: string | undefined;
  ViolationReport?: string | undefined;
  CheckJobArn?: string | undefined;
  SkipCheck?: boolean | undefined;
  RegisterNewBaseline?: boolean | undefined;
}
export interface RegisterModelStepMetadata {
  Arn?: string | undefined;
}
export interface TrainingJobStepMetadata {
  Arn?: string | undefined;
}
export interface TransformJobStepMetadata {
  Arn?: string | undefined;
}
export interface TuningJobStepMetaData {
  Arn?: string | undefined;
}
export interface PipelineExecutionStepMetadata {
  TrainingJob?: TrainingJobStepMetadata | undefined;
  ProcessingJob?: ProcessingJobStepMetadata | undefined;
  TransformJob?: TransformJobStepMetadata | undefined;
  TuningJob?: TuningJobStepMetaData | undefined;
  Model?: ModelStepMetadata | undefined;
  RegisterModel?: RegisterModelStepMetadata | undefined;
  Condition?: ConditionStepMetadata | undefined;
  Callback?: CallbackStepMetadata | undefined;
  Lambda?: LambdaStepMetadata | undefined;
  EMR?: EMRStepMetadata | undefined;
  QualityCheck?: QualityCheckStepMetadata | undefined;
  ClarifyCheck?: ClarifyCheckStepMetadata | undefined;
  Fail?: FailStepMetadata | undefined;
  AutoMLJob?: AutoMLJobStepMetadata | undefined;
  Endpoint?: EndpointStepMetadata | undefined;
  EndpointConfig?: EndpointConfigStepMetadata | undefined;
  BedrockCustomModel?: BedrockCustomModelMetadata | undefined;
  BedrockCustomModelDeployment?:
    | BedrockCustomModelDeploymentMetadata
    | undefined;
  BedrockProvisionedModelThroughput?:
    | BedrockProvisionedModelThroughputMetadata
    | undefined;
  BedrockModelImport?: BedrockModelImportMetadata | undefined;
  InferenceComponent?: InferenceComponentMetadata | undefined;
  Lineage?: LineageMetadata | undefined;
}
export interface SelectiveExecutionResult {
  SourcePipelineExecutionArn?: string | undefined;
}
export interface PipelineExecutionStep {
  StepName?: string | undefined;
  StepDisplayName?: string | undefined;
  StepDescription?: string | undefined;
  StartTime?: Date | undefined;
  EndTime?: Date | undefined;
  StepStatus?: StepStatus | undefined;
  CacheHitResult?: CacheHitResult | undefined;
  FailureReason?: string | undefined;
  Metadata?: PipelineExecutionStepMetadata | undefined;
  AttemptCount?: number | undefined;
  SelectiveExecutionResult?: SelectiveExecutionResult | undefined;
}
export interface ListPipelineExecutionStepsResponse {
  PipelineExecutionSteps?: PipelineExecutionStep[] | undefined;
  NextToken?: string | undefined;
}
export interface ListPipelineParametersForExecutionRequest {
  PipelineExecutionArn: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface Parameter {
  Name: string | undefined;
  Value: string | undefined;
}
export interface ListPipelineParametersForExecutionResponse {
  PipelineParameters?: Parameter[] | undefined;
  NextToken?: string | undefined;
}
export interface ListPipelinesRequest {
  PipelineNamePrefix?: string | undefined;
  CreatedAfter?: Date | undefined;
  CreatedBefore?: Date | undefined;
  SortBy?: SortPipelinesBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface PipelineSummary {
  PipelineArn?: string | undefined;
  PipelineName?: string | undefined;
  PipelineDisplayName?: string | undefined;
  PipelineDescription?: string | undefined;
  RoleArn?: string | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  LastExecutionTime?: Date | undefined;
}
export interface ListPipelinesResponse {
  PipelineSummaries?: PipelineSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListPipelineVersionsRequest {
  PipelineName: string | undefined;
  CreatedAfter?: Date | undefined;
  CreatedBefore?: Date | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface PipelineVersionSummary {
  PipelineArn?: string | undefined;
  PipelineVersionId?: number | undefined;
  CreationTime?: Date | undefined;
  PipelineVersionDescription?: string | undefined;
  PipelineVersionDisplayName?: string | undefined;
  LastExecutionPipelineExecutionArn?: string | undefined;
}
export interface ListPipelineVersionsResponse {
  PipelineVersionSummaries?: PipelineVersionSummary[] | undefined;
  NextToken?: string | undefined;
}
export interface ListProcessingJobsRequest {
  CreationTimeAfter?: Date | undefined;
  CreationTimeBefore?: Date | undefined;
  LastModifiedTimeAfter?: Date | undefined;
  LastModifiedTimeBefore?: Date | undefined;
  NameContains?: string | undefined;
  StatusEquals?: ProcessingJobStatus | undefined;
  SortBy?: SortBy | undefined;
  SortOrder?: SortOrder | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
