import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import {
  AttachClusterNodeVolumeRequest,
  AttachClusterNodeVolumeResponse,
} from "../models/models_0";
import {
  SageMakerClientResolvedConfig,
  ServiceInputTypes,
  ServiceOutputTypes,
} from "../SageMakerClient";
export { __MetadataBearer };
export { $Command };
export interface AttachClusterNodeVolumeCommandInput
  extends AttachClusterNodeVolumeRequest {}
export interface AttachClusterNodeVolumeCommandOutput
  extends AttachClusterNodeVolumeResponse,
    __MetadataBearer {}
declare const AttachClusterNodeVolumeCommand_base: {
  new (
    input: AttachClusterNodeVolumeCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    AttachClusterNodeVolumeCommandInput,
    AttachClusterNodeVolumeCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  new (
    input: AttachClusterNodeVolumeCommandInput
  ): import("@smithy/smithy-client").CommandImpl<
    AttachClusterNodeVolumeCommandInput,
    AttachClusterNodeVolumeCommandOutput,
    SageMakerClientResolvedConfig,
    ServiceInputTypes,
    ServiceOutputTypes
  >;
  getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
export declare class AttachClusterNodeVolumeCommand extends AttachClusterNodeVolumeCommand_base {
  protected static __types: {
    api: {
      input: AttachClusterNodeVolumeRequest;
      output: AttachClusterNodeVolumeResponse;
    };
    sdk: {
      input: AttachClusterNodeVolumeCommandInput;
      output: AttachClusterNodeVolumeCommandOutput;
    };
  };
}
