import { createPaginator } from "@smithy/core";
import { ListLabelingJobsForWorkteamCommand, } from "../commands/ListLabelingJobsForWorkteamCommand";
import { SageMakerClient } from "../SageMakerClient";
export const paginateListLabelingJobsForWorkteam = createPaginator(SageMakerClient, ListLabelingJobsForWorkteamCommand, "NextToken", "NextToken", "MaxResults");
