import type { Paginator } from "@smithy/types";
import { ListTagsCommandInput, ListTagsCommandOutput } from "../commands/ListTagsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListTags: (config: SageMakerPaginationConfiguration, input: ListTagsCommandInput, ...rest: any[]) => Paginator<ListTagsCommandOutput>;
