import type { Paginator } from "@smithy/types";
import { ListTrainingJobsForHyperParameterTuningJobCommandInput, ListTrainingJobsForHyperParameterTuningJobCommandOutput } from "../commands/ListTrainingJobsForHyperParameterTuningJobCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListTrainingJobsForHyperParameterTuningJob: (config: SageMakerPaginationConfiguration, input: ListTrainingJobsForHyperParameterTuningJobCommandInput, ...rest: any[]) => Paginator<ListTrainingJobsForHyperParameterTuningJobCommandOutput>;
