import { createPaginator } from "@smithy/core";
import { ListModelBiasJobDefinitionsCommand, } from "../commands/ListModelBiasJobDefinitionsCommand";
import { SageMakerClient } from "../SageMakerClient";
export const paginateListModelBiasJobDefinitions = createPaginator(SageMakerClient, ListModelBiasJobDefinitionsCommand, "NextToken", "NextToken", "MaxResults");
