import type { Paginator } from "@smithy/types";
import { CreateHubContentPresignedUrlsCommandInput, CreateHubContentPresignedUrlsCommandOutput } from "../commands/CreateHubContentPresignedUrlsCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateCreateHubContentPresignedUrls: (config: SageMakerPaginationConfiguration, input: CreateHubContentPresignedUrlsCommandInput, ...rest: any[]) => Paginator<CreateHubContentPresignedUrlsCommandOutput>;
