import {
  _InstanceType,
  AccountDefaultStatus,
  ActionStatus,
  ActivationState,
  AlgorithmStatus,
  AppNetworkAccessType,
  AppSecurityGroupManagement,
  AppStatus,
  AppType,
  AuthMode,
  AutoMLJobSecondaryStatus,
  AutoMLJobStatus,
  AutoMLProblemTypeConfigName,
  BatchStrategy,
  CapacityReservationPreference,
  CaptureStatus,
  ClusterNodeProvisioningMode,
  ClusterNodeRecovery,
  ClusterStatus,
  CompilationJobStatus,
  CustomizationTechnique,
  DetailedModelPackageStatus,
  DirectInternetAccess,
  DomainStatus,
  EdgePackagingJobStatus,
  EdgePresetDeploymentStatus,
  EdgePresetDeploymentType,
  EnabledOrDisabled,
  EndpointStatus,
  EvaluationType,
  ExecutionStatus,
  FeatureGroupStatus,
  FeatureStatus,
  FeatureType,
  FlowDefinitionStatus,
  HubContentStatus,
  HubContentSupportStatus,
  HubContentType,
  HubStatus,
  HumanTaskUiStatus,
  HyperParameterTuningJobObjectiveType,
  HyperParameterTuningJobStatus,
  ImageStatus,
  ImageVersionStatus,
  InferenceComponentCapacitySizeType,
  InferenceComponentStatus,
  InferenceExperimentStatus,
  InferenceExperimentType,
  IPAddressType,
  IsTrackingServerActive,
  JobType,
  JoinSource,
  LabelingJobStatus,
  LastUpdateStatusValue,
  MaintenanceStatus,
  MlflowAppStatus,
  ModelApprovalStatus,
  ModelCardExportJobStatus,
  ModelCardProcessingStatus,
  ModelCardStatus,
  ModelPackageGroupStatus,
  ModelPackageRegistrationType,
  ModelPackageStatus,
  ModelRegistrationMode,
  ModelVariantStatus,
  MonitoringType,
  NotebookInstanceAcceleratorType,
  NotebookInstanceStatus,
  ObjectiveStatus,
  OfflineStoreStatusValue,
  OptimizationJobDeploymentInstanceType,
  OptimizationJobStatus,
  PartnerAppAuthType,
  PartnerAppStatus,
  PartnerAppType,
  Peft,
  PipelineStatus,
  ProblemType,
  ProcessingInstanceType,
  Processor,
  ProductionVariantAcceleratorType,
  ProductionVariantInstanceType,
  RecommendationJobStatus,
  RecommendationJobType,
  RecommendationStatus,
  RetentionType,
  RootAccess,
  RuleEvaluationStatus,
  SchedulerConfigComponent,
  SchedulerResourceStatus,
  ScheduleStatus,
  ServerlessJobType,
  SharingType,
  SkipModelValidation,
  StageStatus,
  Statistic,
  StudioLifecycleConfigAppType,
  TagPropagation,
  ThroughputMode,
  TrackingServerMaintenanceStatus,
  TrackingServerSize,
  TrackingServerStatus,
  TrainingJobStatus,
  TrialComponentPrimaryStatus,
  VariantStatus,
  VendorGuidance,
  WorkforceIpAddressType,
} from "./enums";
import {
  ActionSource,
  AlgorithmSpecification,
  AlgorithmStatusDetails,
  AlgorithmValidationSpecification,
  ArtifactSource,
  AsyncInferenceConfig,
  AutoMLCandidate,
  AutoMLComputeConfig,
  AutoMLDataSplitConfig,
  AutoMLJobArtifacts,
  AutoMLJobCompletionCriteria,
  AutoMLJobConfig,
  AutoMLJobObjective,
  AutoMLOutputDataConfig,
  AutoMLProblemTypeConfig,
  AutoMLResolvedAttributes,
  AutoMLSecurityConfig,
  AutoRollbackConfig,
  Autotune,
  AvailableUpgrade,
  BatchDataCaptureConfig,
  CheckpointConfig,
  ClusterAutoScalingConfigOutput,
  ClusterEventDetail,
  ClusterNodeDetails,
  ClusterOrchestrator,
  ClusterTieredStorageConfig,
  CodeEditorAppImageConfig,
  CognitoConfig,
  CognitoMemberDefinition,
  ComputeQuotaConfig,
  ComputeQuotaTarget,
  ContextSource,
  GitConfig,
  InferenceSpecification,
  InputConfig,
  JupyterLabAppImageConfig,
  KernelGatewayImageConfig,
  MetadataProperties,
  ModelDeployConfig,
  OutputDataConfig,
  ResourceConfig,
  ResourceSpec,
  SchedulerConfig,
  StoppingCondition,
  TrainingSpecification,
  TransformInput,
  TransformOutput,
  TransformResources,
  UserContext,
  VpcConfig,
  AdditionalInferenceSpecificationDefinition,
  AutoMLChannel,
  AutoMLJobChannel,
  AutoMLPartialFailureReason,
  Channel,
  ClusterInstanceGroupDetails,
  ClusterRestrictedInstanceGroupDetails,
  CollectionConfiguration,
  ContainerDefinition,
  Tag,
} from "./models_0";
import {
  DataCaptureConfig,
  DataQualityAppSpecification,
  DataQualityBaselineConfig,
  DataQualityJobInput,
  DefaultSpaceSettings,
  DeploymentConfig,
  DeviceSelectionConfig,
  DomainSettings,
  DriftCheckBaselines,
  EbsStorageSettings,
  EdgeDeploymentConfig,
  EdgeOutputConfig,
  EndpointInfo,
  ExperimentConfig,
  ExplainerConfig,
  FlowDefinitionOutputConfig,
  HubS3StorageConfig,
  HumanLoopActivationConfig,
  HumanLoopConfig,
  HumanLoopRequestSource,
  HumanTaskConfig,
  HyperParameterTuningJobConfig,
  HyperParameterTuningJobWarmStartConfig,
  InferenceComponentComputeResourceRequirements,
  InferenceComponentStartupParameters,
  InferenceExecutionConfig,
  InferenceExperimentDataStorageConfig,
  InferenceExperimentSchedule,
  InstanceMetadataServiceConfiguration,
  JupyterServerAppSettings,
  KernelGatewayAppSettings,
  LabelingJobAlgorithmsConfig,
  LabelingJobInputConfig,
  LabelingJobOutputConfig,
  LabelingJobStoppingConditions,
  MetricsConfig,
  ModelBiasAppSpecification,
  ModelBiasBaselineConfig,
  ModelBiasJobInput,
  ModelCardExportOutputConfig,
  ModelCardSecurityConfig,
  ModelExplainabilityAppSpecification,
  ModelExplainabilityBaselineConfig,
  ModelExplainabilityJobInput,
  ModelInfrastructureConfig,
  ModelLifeCycle,
  ModelMetrics,
  ModelPackageModelCard,
  ModelPackageSecurityConfig,
  ModelPackageValidationSpecification,
  ModelQualityAppSpecification,
  ModelQualityBaselineConfig,
  ModelQualityJobInput,
  MonitoringNetworkConfig,
  MonitoringOutputConfig,
  MonitoringResources,
  MonitoringScheduleConfig,
  MonitoringStoppingCondition,
  NeoVpcConfig,
  OfflineStoreConfig,
  OnlineStoreConfig,
  OptimizationJobModelSource,
  OptimizationJobOutputConfig,
  OptimizationVpcConfig,
  OutputConfig,
  OwnershipSettings,
  ParallelismConfiguration,
  PartnerAppConfig,
  PartnerAppMaintenanceConfig,
  ProductionVariantManagedInstanceScaling,
  ProductionVariantRoutingConfig,
  ProductionVariantServerlessConfig,
  RecommendationJobInputConfig,
  RecommendationJobStoppingConditions,
  RetryStrategy,
  ShadowModeConfig,
  SourceAlgorithmSpecification,
  SpaceCodeEditorAppSettings,
  SpaceJupyterLabAppSettings,
  UserSettings,
  CustomFileSystem,
  EdgeDeploymentModelConfig,
  FeatureDefinition,
  HyperParameterTrainingJobDefinition,
  NotebookInstanceLifecycleHook,
  OptimizationConfig,
  ProductionVariant,
} from "./models_1";
export interface SpaceStorageSettings {
  EbsStorageSettings?: EbsStorageSettings | undefined;
}
export interface SpaceSettings {
  JupyterServerAppSettings?: JupyterServerAppSettings | undefined;
  KernelGatewayAppSettings?: KernelGatewayAppSettings | undefined;
  CodeEditorAppSettings?: SpaceCodeEditorAppSettings | undefined;
  JupyterLabAppSettings?: SpaceJupyterLabAppSettings | undefined;
  AppType?: AppType | undefined;
  SpaceStorageSettings?: SpaceStorageSettings | undefined;
  SpaceManagedResources?: FeatureStatus | undefined;
  CustomFileSystems?: CustomFileSystem[] | undefined;
  RemoteAccess?: FeatureStatus | undefined;
}
export interface SpaceSharingSettings {
  SharingType: SharingType | undefined;
}
export interface CreateSpaceRequest {
  DomainId: string | undefined;
  SpaceName: string | undefined;
  Tags?: Tag[] | undefined;
  SpaceSettings?: SpaceSettings | undefined;
  OwnershipSettings?: OwnershipSettings | undefined;
  SpaceSharingSettings?: SpaceSharingSettings | undefined;
  SpaceDisplayName?: string | undefined;
}
export interface CreateSpaceResponse {
  SpaceArn?: string | undefined;
}
export interface CreateStudioLifecycleConfigRequest {
  StudioLifecycleConfigName: string | undefined;
  StudioLifecycleConfigContent: string | undefined;
  StudioLifecycleConfigAppType: StudioLifecycleConfigAppType | undefined;
  Tags?: Tag[] | undefined;
}
export interface CreateStudioLifecycleConfigResponse {
  StudioLifecycleConfigArn?: string | undefined;
}
export interface DebugHookConfig {
  LocalPath?: string | undefined;
  S3OutputPath: string | undefined;
  HookParameters?: Record<string, string> | undefined;
  CollectionConfigurations?: CollectionConfiguration[] | undefined;
}
export interface DebugRuleConfiguration {
  RuleConfigurationName: string | undefined;
  LocalPath?: string | undefined;
  S3OutputPath?: string | undefined;
  RuleEvaluatorImage: string | undefined;
  InstanceType?: ProcessingInstanceType | undefined;
  VolumeSizeInGB?: number | undefined;
  RuleParameters?: Record<string, string> | undefined;
}
export interface InfraCheckConfig {
  EnableInfraCheck?: boolean | undefined;
}
export interface MlflowConfig {
  MlflowResourceArn: string | undefined;
  MlflowExperimentName?: string | undefined;
  MlflowRunName?: string | undefined;
}
export interface ModelPackageConfig {
  ModelPackageGroupArn: string | undefined;
  SourceModelPackageArn?: string | undefined;
}
export interface ProfilerConfig {
  S3OutputPath?: string | undefined;
  ProfilingIntervalInMilliseconds?: number | undefined;
  ProfilingParameters?: Record<string, string> | undefined;
  DisableProfiler?: boolean | undefined;
}
export interface ProfilerRuleConfiguration {
  RuleConfigurationName: string | undefined;
  LocalPath?: string | undefined;
  S3OutputPath?: string | undefined;
  RuleEvaluatorImage: string | undefined;
  InstanceType?: ProcessingInstanceType | undefined;
  VolumeSizeInGB?: number | undefined;
  RuleParameters?: Record<string, string> | undefined;
}
export interface RemoteDebugConfig {
  EnableRemoteDebug?: boolean | undefined;
}
export interface ServerlessJobConfig {
  BaseModelArn: string | undefined;
  AcceptEula?: boolean | undefined;
  JobType: ServerlessJobType | undefined;
  CustomizationTechnique?: CustomizationTechnique | undefined;
  Peft?: Peft | undefined;
  EvaluationType?: EvaluationType | undefined;
  EvaluatorArn?: string | undefined;
}
export interface SessionChainingConfig {
  EnableSessionTagChaining?: boolean | undefined;
}
export interface TensorBoardOutputConfig {
  LocalPath?: string | undefined;
  S3OutputPath: string | undefined;
}
export interface CreateTrainingJobRequest {
  TrainingJobName: string | undefined;
  HyperParameters?: Record<string, string> | undefined;
  AlgorithmSpecification?: AlgorithmSpecification | undefined;
  RoleArn: string | undefined;
  InputDataConfig?: Channel[] | undefined;
  OutputDataConfig: OutputDataConfig | undefined;
  ResourceConfig?: ResourceConfig | undefined;
  VpcConfig?: VpcConfig | undefined;
  StoppingCondition?: StoppingCondition | undefined;
  Tags?: Tag[] | undefined;
  EnableNetworkIsolation?: boolean | undefined;
  EnableInterContainerTrafficEncryption?: boolean | undefined;
  EnableManagedSpotTraining?: boolean | undefined;
  CheckpointConfig?: CheckpointConfig | undefined;
  DebugHookConfig?: DebugHookConfig | undefined;
  DebugRuleConfigurations?: DebugRuleConfiguration[] | undefined;
  TensorBoardOutputConfig?: TensorBoardOutputConfig | undefined;
  ExperimentConfig?: ExperimentConfig | undefined;
  ProfilerConfig?: ProfilerConfig | undefined;
  ProfilerRuleConfigurations?: ProfilerRuleConfiguration[] | undefined;
  Environment?: Record<string, string> | undefined;
  RetryStrategy?: RetryStrategy | undefined;
  RemoteDebugConfig?: RemoteDebugConfig | undefined;
  InfraCheckConfig?: InfraCheckConfig | undefined;
  SessionChainingConfig?: SessionChainingConfig | undefined;
  ServerlessJobConfig?: ServerlessJobConfig | undefined;
  MlflowConfig?: MlflowConfig | undefined;
  ModelPackageConfig?: ModelPackageConfig | undefined;
}
export interface CreateTrainingJobResponse {
  TrainingJobArn: string | undefined;
}
export interface CreateTrainingPlanRequest {
  TrainingPlanName: string | undefined;
  TrainingPlanOfferingId: string | undefined;
  SpareInstanceCountPerUltraServer?: number | undefined;
  Tags?: Tag[] | undefined;
}
export interface CreateTrainingPlanResponse {
  TrainingPlanArn: string | undefined;
}
export interface DataProcessing {
  InputFilter?: string | undefined;
  OutputFilter?: string | undefined;
  JoinSource?: JoinSource | undefined;
}
export interface ModelClientConfig {
  InvocationsTimeoutInSeconds?: number | undefined;
  InvocationsMaxRetries?: number | undefined;
}
export interface CreateTransformJobRequest {
  TransformJobName: string | undefined;
  ModelName: string | undefined;
  MaxConcurrentTransforms?: number | undefined;
  ModelClientConfig?: ModelClientConfig | undefined;
  MaxPayloadInMB?: number | undefined;
  BatchStrategy?: BatchStrategy | undefined;
  Environment?: Record<string, string> | undefined;
  TransformInput: TransformInput | undefined;
  TransformOutput: TransformOutput | undefined;
  DataCaptureConfig?: BatchDataCaptureConfig | undefined;
  TransformResources: TransformResources | undefined;
  DataProcessing?: DataProcessing | undefined;
  Tags?: Tag[] | undefined;
  ExperimentConfig?: ExperimentConfig | undefined;
}
export interface CreateTransformJobResponse {
  TransformJobArn: string | undefined;
}
export interface CreateTrialRequest {
  TrialName: string | undefined;
  DisplayName?: string | undefined;
  ExperimentName: string | undefined;
  MetadataProperties?: MetadataProperties | undefined;
  Tags?: Tag[] | undefined;
}
export interface CreateTrialResponse {
  TrialArn?: string | undefined;
}
export interface TrialComponentArtifact {
  MediaType?: string | undefined;
  Value: string | undefined;
}
export type TrialComponentParameterValue =
  | TrialComponentParameterValue.NumberValueMember
  | TrialComponentParameterValue.StringValueMember
  | TrialComponentParameterValue.$UnknownMember;
export declare namespace TrialComponentParameterValue {
  interface StringValueMember {
    StringValue: string;
    NumberValue?: never;
    $unknown?: never;
  }
  interface NumberValueMember {
    StringValue?: never;
    NumberValue: number;
    $unknown?: never;
  }
  interface $UnknownMember {
    StringValue?: never;
    NumberValue?: never;
    $unknown: [string, any];
  }
  interface Visitor<T> {
    StringValue: (value: string) => T;
    NumberValue: (value: number) => T;
    _: (name: string, value: any) => T;
  }
}
export interface TrialComponentStatus {
  PrimaryStatus?: TrialComponentPrimaryStatus | undefined;
  Message?: string | undefined;
}
export interface CreateTrialComponentRequest {
  TrialComponentName: string | undefined;
  DisplayName?: string | undefined;
  Status?: TrialComponentStatus | undefined;
  StartTime?: Date | undefined;
  EndTime?: Date | undefined;
  Parameters?: Record<string, TrialComponentParameterValue> | undefined;
  InputArtifacts?: Record<string, TrialComponentArtifact> | undefined;
  OutputArtifacts?: Record<string, TrialComponentArtifact> | undefined;
  MetadataProperties?: MetadataProperties | undefined;
  Tags?: Tag[] | undefined;
}
export interface CreateTrialComponentResponse {
  TrialComponentArn?: string | undefined;
}
export interface CreateUserProfileRequest {
  DomainId: string | undefined;
  UserProfileName: string | undefined;
  SingleSignOnUserIdentifier?: string | undefined;
  SingleSignOnUserValue?: string | undefined;
  Tags?: Tag[] | undefined;
  UserSettings?: UserSettings | undefined;
}
export interface CreateUserProfileResponse {
  UserProfileArn?: string | undefined;
}
export interface OidcConfig {
  ClientId: string | undefined;
  ClientSecret: string | undefined;
  Issuer: string | undefined;
  AuthorizationEndpoint: string | undefined;
  TokenEndpoint: string | undefined;
  UserInfoEndpoint: string | undefined;
  LogoutEndpoint: string | undefined;
  JwksUri: string | undefined;
  Scope?: string | undefined;
  AuthenticationRequestExtraParams?: Record<string, string> | undefined;
}
export interface SourceIpConfig {
  Cidrs: string[] | undefined;
}
export interface WorkforceVpcConfigRequest {
  VpcId?: string | undefined;
  SecurityGroupIds?: string[] | undefined;
  Subnets?: string[] | undefined;
}
export interface CreateWorkforceRequest {
  CognitoConfig?: CognitoConfig | undefined;
  OidcConfig?: OidcConfig | undefined;
  SourceIpConfig?: SourceIpConfig | undefined;
  WorkforceName: string | undefined;
  Tags?: Tag[] | undefined;
  WorkforceVpcConfig?: WorkforceVpcConfigRequest | undefined;
  IpAddressType?: WorkforceIpAddressType | undefined;
}
export interface CreateWorkforceResponse {
  WorkforceArn: string | undefined;
}
export interface OidcMemberDefinition {
  Groups?: string[] | undefined;
}
export interface MemberDefinition {
  CognitoMemberDefinition?: CognitoMemberDefinition | undefined;
  OidcMemberDefinition?: OidcMemberDefinition | undefined;
}
export interface NotificationConfiguration {
  NotificationTopicArn?: string | undefined;
}
export interface IamPolicyConstraints {
  SourceIp?: EnabledOrDisabled | undefined;
  VpcSourceIp?: EnabledOrDisabled | undefined;
}
export interface S3Presign {
  IamPolicyConstraints?: IamPolicyConstraints | undefined;
}
export interface WorkerAccessConfiguration {
  S3Presign?: S3Presign | undefined;
}
export interface CreateWorkteamRequest {
  WorkteamName: string | undefined;
  WorkforceName?: string | undefined;
  MemberDefinitions: MemberDefinition[] | undefined;
  Description: string | undefined;
  NotificationConfiguration?: NotificationConfiguration | undefined;
  WorkerAccessConfiguration?: WorkerAccessConfiguration | undefined;
  Tags?: Tag[] | undefined;
}
export interface CreateWorkteamResponse {
  WorkteamArn?: string | undefined;
}
export interface CustomizedMetricSpecification {
  MetricName?: string | undefined;
  Namespace?: string | undefined;
  Statistic?: Statistic | undefined;
}
export interface DataCaptureConfigSummary {
  EnableCapture: boolean | undefined;
  CaptureStatus: CaptureStatus | undefined;
  CurrentSamplingPercentage: number | undefined;
  DestinationS3Uri: string | undefined;
  KmsKeyId: string | undefined;
}
export interface DebugRuleEvaluationStatus {
  RuleConfigurationName?: string | undefined;
  RuleEvaluationJobArn?: string | undefined;
  RuleEvaluationStatus?: RuleEvaluationStatus | undefined;
  StatusDetails?: string | undefined;
  LastModifiedTime?: Date | undefined;
}
export interface DeleteActionRequest {
  ActionName: string | undefined;
}
export interface DeleteActionResponse {
  ActionArn?: string | undefined;
}
export interface DeleteAlgorithmInput {
  AlgorithmName: string | undefined;
}
export interface DeleteAppRequest {
  DomainId: string | undefined;
  UserProfileName?: string | undefined;
  SpaceName?: string | undefined;
  AppType: AppType | undefined;
  AppName: string | undefined;
}
export interface DeleteAppImageConfigRequest {
  AppImageConfigName: string | undefined;
}
export interface DeleteArtifactRequest {
  ArtifactArn?: string | undefined;
  Source?: ArtifactSource | undefined;
}
export interface DeleteArtifactResponse {
  ArtifactArn?: string | undefined;
}
export interface DeleteAssociationRequest {
  SourceArn: string | undefined;
  DestinationArn: string | undefined;
}
export interface DeleteAssociationResponse {
  SourceArn?: string | undefined;
  DestinationArn?: string | undefined;
}
export interface DeleteClusterRequest {
  ClusterName: string | undefined;
}
export interface DeleteClusterResponse {
  ClusterArn: string | undefined;
}
export interface DeleteClusterSchedulerConfigRequest {
  ClusterSchedulerConfigId: string | undefined;
}
export interface DeleteCodeRepositoryInput {
  CodeRepositoryName: string | undefined;
}
export interface DeleteCompilationJobRequest {
  CompilationJobName: string | undefined;
}
export interface DeleteComputeQuotaRequest {
  ComputeQuotaId: string | undefined;
}
export interface DeleteContextRequest {
  ContextName: string | undefined;
}
export interface DeleteContextResponse {
  ContextArn?: string | undefined;
}
export interface DeleteDataQualityJobDefinitionRequest {
  JobDefinitionName: string | undefined;
}
export interface DeleteDeviceFleetRequest {
  DeviceFleetName: string | undefined;
}
export interface RetentionPolicy {
  HomeEfsFileSystem?: RetentionType | undefined;
}
export interface DeleteDomainRequest {
  DomainId: string | undefined;
  RetentionPolicy?: RetentionPolicy | undefined;
}
export interface DeleteEdgeDeploymentPlanRequest {
  EdgeDeploymentPlanName: string | undefined;
}
export interface DeleteEdgeDeploymentStageRequest {
  EdgeDeploymentPlanName: string | undefined;
  StageName: string | undefined;
}
export interface DeleteEndpointInput {
  EndpointName: string | undefined;
}
export interface DeleteEndpointConfigInput {
  EndpointConfigName: string | undefined;
}
export interface DeleteExperimentRequest {
  ExperimentName: string | undefined;
}
export interface DeleteExperimentResponse {
  ExperimentArn?: string | undefined;
}
export interface DeleteFeatureGroupRequest {
  FeatureGroupName: string | undefined;
}
export interface DeleteFlowDefinitionRequest {
  FlowDefinitionName: string | undefined;
}
export interface DeleteFlowDefinitionResponse {}
export interface DeleteHubRequest {
  HubName: string | undefined;
}
export interface DeleteHubContentRequest {
  HubName: string | undefined;
  HubContentType: HubContentType | undefined;
  HubContentName: string | undefined;
  HubContentVersion: string | undefined;
}
export interface DeleteHubContentReferenceRequest {
  HubName: string | undefined;
  HubContentType: HubContentType | undefined;
  HubContentName: string | undefined;
}
export interface DeleteHumanTaskUiRequest {
  HumanTaskUiName: string | undefined;
}
export interface DeleteHumanTaskUiResponse {}
export interface DeleteHyperParameterTuningJobRequest {
  HyperParameterTuningJobName: string | undefined;
}
export interface DeleteImageRequest {
  ImageName: string | undefined;
}
export interface DeleteImageResponse {}
export interface DeleteImageVersionRequest {
  ImageName: string | undefined;
  Version?: number | undefined;
  Alias?: string | undefined;
}
export interface DeleteImageVersionResponse {}
export interface DeleteInferenceComponentInput {
  InferenceComponentName: string | undefined;
}
export interface DeleteInferenceExperimentRequest {
  Name: string | undefined;
}
export interface DeleteInferenceExperimentResponse {
  InferenceExperimentArn: string | undefined;
}
export interface DeleteMlflowAppRequest {
  Arn: string | undefined;
}
export interface DeleteMlflowAppResponse {
  Arn?: string | undefined;
}
export interface DeleteMlflowTrackingServerRequest {
  TrackingServerName: string | undefined;
}
export interface DeleteMlflowTrackingServerResponse {
  TrackingServerArn?: string | undefined;
}
export interface DeleteModelInput {
  ModelName: string | undefined;
}
export interface DeleteModelBiasJobDefinitionRequest {
  JobDefinitionName: string | undefined;
}
export interface DeleteModelCardRequest {
  ModelCardName: string | undefined;
}
export interface DeleteModelExplainabilityJobDefinitionRequest {
  JobDefinitionName: string | undefined;
}
export interface DeleteModelPackageInput {
  ModelPackageName: string | undefined;
}
export interface DeleteModelPackageGroupInput {
  ModelPackageGroupName: string | undefined;
}
export interface DeleteModelPackageGroupPolicyInput {
  ModelPackageGroupName: string | undefined;
}
export interface DeleteModelQualityJobDefinitionRequest {
  JobDefinitionName: string | undefined;
}
export interface DeleteMonitoringScheduleRequest {
  MonitoringScheduleName: string | undefined;
}
export interface DeleteNotebookInstanceInput {
  NotebookInstanceName: string | undefined;
}
export interface DeleteNotebookInstanceLifecycleConfigInput {
  NotebookInstanceLifecycleConfigName: string | undefined;
}
export interface DeleteOptimizationJobRequest {
  OptimizationJobName: string | undefined;
}
export interface DeletePartnerAppRequest {
  Arn: string | undefined;
  ClientToken?: string | undefined;
}
export interface DeletePartnerAppResponse {
  Arn?: string | undefined;
}
export interface DeletePipelineRequest {
  PipelineName: string | undefined;
  ClientRequestToken?: string | undefined;
}
export interface DeletePipelineResponse {
  PipelineArn?: string | undefined;
}
export interface DeleteProcessingJobRequest {
  ProcessingJobName: string | undefined;
}
export interface DeleteProjectInput {
  ProjectName: string | undefined;
}
export interface DeleteSpaceRequest {
  DomainId: string | undefined;
  SpaceName: string | undefined;
}
export interface DeleteStudioLifecycleConfigRequest {
  StudioLifecycleConfigName: string | undefined;
}
export interface DeleteTagsInput {
  ResourceArn: string | undefined;
  TagKeys: string[] | undefined;
}
export interface DeleteTagsOutput {}
export interface DeleteTrainingJobRequest {
  TrainingJobName: string | undefined;
}
export interface DeleteTrialRequest {
  TrialName: string | undefined;
}
export interface DeleteTrialResponse {
  TrialArn?: string | undefined;
}
export interface DeleteTrialComponentRequest {
  TrialComponentName: string | undefined;
}
export interface DeleteTrialComponentResponse {
  TrialComponentArn?: string | undefined;
}
export interface DeleteUserProfileRequest {
  DomainId: string | undefined;
  UserProfileName: string | undefined;
}
export interface DeleteWorkforceRequest {
  WorkforceName: string | undefined;
}
export interface DeleteWorkforceResponse {}
export interface DeleteWorkteamRequest {
  WorkteamName: string | undefined;
}
export interface DeleteWorkteamResponse {
  Success: boolean | undefined;
}
export interface DeployedImage {
  SpecifiedImage?: string | undefined;
  ResolvedImage?: string | undefined;
  ResolutionTime?: Date | undefined;
}
export interface RealTimeInferenceRecommendation {
  RecommendationId: string | undefined;
  InstanceType: ProductionVariantInstanceType | undefined;
  Environment?: Record<string, string> | undefined;
}
export interface DeploymentRecommendation {
  RecommendationStatus: RecommendationStatus | undefined;
  RealTimeInferenceRecommendations?:
    | RealTimeInferenceRecommendation[]
    | undefined;
}
export interface EdgeDeploymentStatus {
  StageStatus: StageStatus | undefined;
  EdgeDeploymentSuccessInStage: number | undefined;
  EdgeDeploymentPendingInStage: number | undefined;
  EdgeDeploymentFailedInStage: number | undefined;
  EdgeDeploymentStatusMessage?: string | undefined;
  EdgeDeploymentStageStartTime?: Date | undefined;
}
export interface DeploymentStageStatusSummary {
  StageName: string | undefined;
  DeviceSelectionConfig: DeviceSelectionConfig | undefined;
  DeploymentConfig: EdgeDeploymentConfig | undefined;
  DeploymentStatus: EdgeDeploymentStatus | undefined;
}
export interface DeregisterDevicesRequest {
  DeviceFleetName: string | undefined;
  DeviceNames: string[] | undefined;
}
export interface DerivedInformation {
  DerivedDataInputConfig?: string | undefined;
}
export interface DescribeActionRequest {
  ActionName: string | undefined;
}
export interface DescribeActionResponse {
  ActionName?: string | undefined;
  ActionArn?: string | undefined;
  Source?: ActionSource | undefined;
  ActionType?: string | undefined;
  Description?: string | undefined;
  Status?: ActionStatus | undefined;
  Properties?: Record<string, string> | undefined;
  CreationTime?: Date | undefined;
  CreatedBy?: UserContext | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
  MetadataProperties?: MetadataProperties | undefined;
  LineageGroupArn?: string | undefined;
}
export interface DescribeAlgorithmInput {
  AlgorithmName: string | undefined;
}
export interface DescribeAlgorithmOutput {
  AlgorithmName: string | undefined;
  AlgorithmArn: string | undefined;
  AlgorithmDescription?: string | undefined;
  CreationTime: Date | undefined;
  TrainingSpecification: TrainingSpecification | undefined;
  InferenceSpecification?: InferenceSpecification | undefined;
  ValidationSpecification?: AlgorithmValidationSpecification | undefined;
  AlgorithmStatus: AlgorithmStatus | undefined;
  AlgorithmStatusDetails: AlgorithmStatusDetails | undefined;
  ProductId?: string | undefined;
  CertifyForMarketplace?: boolean | undefined;
}
export interface DescribeAppRequest {
  DomainId: string | undefined;
  UserProfileName?: string | undefined;
  SpaceName?: string | undefined;
  AppType: AppType | undefined;
  AppName: string | undefined;
}
export interface DescribeAppResponse {
  AppArn?: string | undefined;
  AppType?: AppType | undefined;
  AppName?: string | undefined;
  DomainId?: string | undefined;
  UserProfileName?: string | undefined;
  SpaceName?: string | undefined;
  Status?: AppStatus | undefined;
  EffectiveTrustedIdentityPropagationStatus?: FeatureStatus | undefined;
  RecoveryMode?: boolean | undefined;
  LastHealthCheckTimestamp?: Date | undefined;
  LastUserActivityTimestamp?: Date | undefined;
  CreationTime?: Date | undefined;
  FailureReason?: string | undefined;
  ResourceSpec?: ResourceSpec | undefined;
  BuiltInLifecycleConfigArn?: string | undefined;
}
export interface DescribeAppImageConfigRequest {
  AppImageConfigName: string | undefined;
}
export interface DescribeAppImageConfigResponse {
  AppImageConfigArn?: string | undefined;
  AppImageConfigName?: string | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  KernelGatewayImageConfig?: KernelGatewayImageConfig | undefined;
  JupyterLabAppImageConfig?: JupyterLabAppImageConfig | undefined;
  CodeEditorAppImageConfig?: CodeEditorAppImageConfig | undefined;
}
export interface DescribeArtifactRequest {
  ArtifactArn: string | undefined;
}
export interface DescribeArtifactResponse {
  ArtifactName?: string | undefined;
  ArtifactArn?: string | undefined;
  Source?: ArtifactSource | undefined;
  ArtifactType?: string | undefined;
  Properties?: Record<string, string> | undefined;
  CreationTime?: Date | undefined;
  CreatedBy?: UserContext | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
  MetadataProperties?: MetadataProperties | undefined;
  LineageGroupArn?: string | undefined;
}
export interface DescribeAutoMLJobRequest {
  AutoMLJobName: string | undefined;
}
export interface ModelDeployResult {
  EndpointName?: string | undefined;
}
export interface ResolvedAttributes {
  AutoMLJobObjective?: AutoMLJobObjective | undefined;
  ProblemType?: ProblemType | undefined;
  CompletionCriteria?: AutoMLJobCompletionCriteria | undefined;
}
export interface DescribeAutoMLJobResponse {
  AutoMLJobName: string | undefined;
  AutoMLJobArn: string | undefined;
  InputDataConfig: AutoMLChannel[] | undefined;
  OutputDataConfig: AutoMLOutputDataConfig | undefined;
  RoleArn: string | undefined;
  AutoMLJobObjective?: AutoMLJobObjective | undefined;
  ProblemType?: ProblemType | undefined;
  AutoMLJobConfig?: AutoMLJobConfig | undefined;
  CreationTime: Date | undefined;
  EndTime?: Date | undefined;
  LastModifiedTime: Date | undefined;
  FailureReason?: string | undefined;
  PartialFailureReasons?: AutoMLPartialFailureReason[] | undefined;
  BestCandidate?: AutoMLCandidate | undefined;
  AutoMLJobStatus: AutoMLJobStatus | undefined;
  AutoMLJobSecondaryStatus: AutoMLJobSecondaryStatus | undefined;
  GenerateCandidateDefinitionsOnly?: boolean | undefined;
  AutoMLJobArtifacts?: AutoMLJobArtifacts | undefined;
  ResolvedAttributes?: ResolvedAttributes | undefined;
  ModelDeployConfig?: ModelDeployConfig | undefined;
  ModelDeployResult?: ModelDeployResult | undefined;
}
export interface DescribeAutoMLJobV2Request {
  AutoMLJobName: string | undefined;
}
export interface DescribeAutoMLJobV2Response {
  AutoMLJobName: string | undefined;
  AutoMLJobArn: string | undefined;
  AutoMLJobInputDataConfig: AutoMLJobChannel[] | undefined;
  OutputDataConfig: AutoMLOutputDataConfig | undefined;
  RoleArn: string | undefined;
  AutoMLJobObjective?: AutoMLJobObjective | undefined;
  AutoMLProblemTypeConfig?: AutoMLProblemTypeConfig | undefined;
  AutoMLProblemTypeConfigName?: AutoMLProblemTypeConfigName | undefined;
  CreationTime: Date | undefined;
  EndTime?: Date | undefined;
  LastModifiedTime: Date | undefined;
  FailureReason?: string | undefined;
  PartialFailureReasons?: AutoMLPartialFailureReason[] | undefined;
  BestCandidate?: AutoMLCandidate | undefined;
  AutoMLJobStatus: AutoMLJobStatus | undefined;
  AutoMLJobSecondaryStatus: AutoMLJobSecondaryStatus | undefined;
  AutoMLJobArtifacts?: AutoMLJobArtifacts | undefined;
  ResolvedAttributes?: AutoMLResolvedAttributes | undefined;
  ModelDeployConfig?: ModelDeployConfig | undefined;
  ModelDeployResult?: ModelDeployResult | undefined;
  DataSplitConfig?: AutoMLDataSplitConfig | undefined;
  SecurityConfig?: AutoMLSecurityConfig | undefined;
  AutoMLComputeConfig?: AutoMLComputeConfig | undefined;
}
export interface DescribeClusterRequest {
  ClusterName: string | undefined;
}
export interface DescribeClusterResponse {
  ClusterArn: string | undefined;
  ClusterName?: string | undefined;
  ClusterStatus: ClusterStatus | undefined;
  CreationTime?: Date | undefined;
  FailureMessage?: string | undefined;
  InstanceGroups: ClusterInstanceGroupDetails[] | undefined;
  RestrictedInstanceGroups?:
    | ClusterRestrictedInstanceGroupDetails[]
    | undefined;
  VpcConfig?: VpcConfig | undefined;
  Orchestrator?: ClusterOrchestrator | undefined;
  TieredStorageConfig?: ClusterTieredStorageConfig | undefined;
  NodeRecovery?: ClusterNodeRecovery | undefined;
  NodeProvisioningMode?: ClusterNodeProvisioningMode | undefined;
  ClusterRole?: string | undefined;
  AutoScaling?: ClusterAutoScalingConfigOutput | undefined;
}
export interface DescribeClusterEventRequest {
  EventId: string | undefined;
  ClusterName: string | undefined;
}
export interface DescribeClusterEventResponse {
  EventDetails?: ClusterEventDetail | undefined;
}
export interface DescribeClusterNodeRequest {
  ClusterName: string | undefined;
  NodeId?: string | undefined;
  NodeLogicalId?: string | undefined;
}
export interface DescribeClusterNodeResponse {
  NodeDetails: ClusterNodeDetails | undefined;
}
export interface DescribeClusterSchedulerConfigRequest {
  ClusterSchedulerConfigId: string | undefined;
  ClusterSchedulerConfigVersion?: number | undefined;
}
export interface DescribeClusterSchedulerConfigResponse {
  ClusterSchedulerConfigArn: string | undefined;
  ClusterSchedulerConfigId: string | undefined;
  Name: string | undefined;
  ClusterSchedulerConfigVersion: number | undefined;
  Status: SchedulerResourceStatus | undefined;
  FailureReason?: string | undefined;
  StatusDetails?:
    | Partial<Record<SchedulerConfigComponent, SchedulerResourceStatus>>
    | undefined;
  ClusterArn?: string | undefined;
  SchedulerConfig?: SchedulerConfig | undefined;
  Description?: string | undefined;
  CreationTime: Date | undefined;
  CreatedBy?: UserContext | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
}
export interface DescribeCodeRepositoryInput {
  CodeRepositoryName: string | undefined;
}
export interface DescribeCodeRepositoryOutput {
  CodeRepositoryName: string | undefined;
  CodeRepositoryArn: string | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  GitConfig?: GitConfig | undefined;
}
export interface DescribeCompilationJobRequest {
  CompilationJobName: string | undefined;
}
export interface ModelArtifacts {
  S3ModelArtifacts: string | undefined;
}
export interface ModelDigests {
  ArtifactDigest?: string | undefined;
}
export interface DescribeCompilationJobResponse {
  CompilationJobName: string | undefined;
  CompilationJobArn: string | undefined;
  CompilationJobStatus: CompilationJobStatus | undefined;
  CompilationStartTime?: Date | undefined;
  CompilationEndTime?: Date | undefined;
  StoppingCondition: StoppingCondition | undefined;
  InferenceImage?: string | undefined;
  ModelPackageVersionArn?: string | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  FailureReason: string | undefined;
  ModelArtifacts: ModelArtifacts | undefined;
  ModelDigests?: ModelDigests | undefined;
  RoleArn: string | undefined;
  InputConfig: InputConfig | undefined;
  OutputConfig: OutputConfig | undefined;
  VpcConfig?: NeoVpcConfig | undefined;
  DerivedInformation?: DerivedInformation | undefined;
}
export interface DescribeComputeQuotaRequest {
  ComputeQuotaId: string | undefined;
  ComputeQuotaVersion?: number | undefined;
}
export interface DescribeComputeQuotaResponse {
  ComputeQuotaArn: string | undefined;
  ComputeQuotaId: string | undefined;
  Name: string | undefined;
  Description?: string | undefined;
  ComputeQuotaVersion: number | undefined;
  Status: SchedulerResourceStatus | undefined;
  FailureReason?: string | undefined;
  ClusterArn?: string | undefined;
  ComputeQuotaConfig?: ComputeQuotaConfig | undefined;
  ComputeQuotaTarget: ComputeQuotaTarget | undefined;
  ActivationState?: ActivationState | undefined;
  CreationTime: Date | undefined;
  CreatedBy?: UserContext | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
}
export interface DescribeContextRequest {
  ContextName: string | undefined;
}
export interface DescribeContextResponse {
  ContextName?: string | undefined;
  ContextArn?: string | undefined;
  Source?: ContextSource | undefined;
  ContextType?: string | undefined;
  Description?: string | undefined;
  Properties?: Record<string, string> | undefined;
  CreationTime?: Date | undefined;
  CreatedBy?: UserContext | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
  LineageGroupArn?: string | undefined;
}
export interface DescribeDataQualityJobDefinitionRequest {
  JobDefinitionName: string | undefined;
}
export interface DescribeDataQualityJobDefinitionResponse {
  JobDefinitionArn: string | undefined;
  JobDefinitionName: string | undefined;
  CreationTime: Date | undefined;
  DataQualityBaselineConfig?: DataQualityBaselineConfig | undefined;
  DataQualityAppSpecification: DataQualityAppSpecification | undefined;
  DataQualityJobInput: DataQualityJobInput | undefined;
  DataQualityJobOutputConfig: MonitoringOutputConfig | undefined;
  JobResources: MonitoringResources | undefined;
  NetworkConfig?: MonitoringNetworkConfig | undefined;
  RoleArn: string | undefined;
  StoppingCondition?: MonitoringStoppingCondition | undefined;
}
export interface DescribeDeviceRequest {
  NextToken?: string | undefined;
  DeviceName: string | undefined;
  DeviceFleetName: string | undefined;
}
export interface EdgeModel {
  ModelName: string | undefined;
  ModelVersion: string | undefined;
  LatestSampleTime?: Date | undefined;
  LatestInference?: Date | undefined;
}
export interface DescribeDeviceResponse {
  DeviceArn?: string | undefined;
  DeviceName: string | undefined;
  Description?: string | undefined;
  DeviceFleetName: string | undefined;
  IotThingName?: string | undefined;
  RegistrationTime: Date | undefined;
  LatestHeartbeat?: Date | undefined;
  Models?: EdgeModel[] | undefined;
  MaxModels?: number | undefined;
  NextToken?: string | undefined;
  AgentVersion?: string | undefined;
}
export interface DescribeDeviceFleetRequest {
  DeviceFleetName: string | undefined;
}
export interface DescribeDeviceFleetResponse {
  DeviceFleetName: string | undefined;
  DeviceFleetArn: string | undefined;
  OutputConfig: EdgeOutputConfig | undefined;
  Description?: string | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  RoleArn?: string | undefined;
  IotRoleAlias?: string | undefined;
}
export interface DescribeDomainRequest {
  DomainId: string | undefined;
}
export interface DescribeDomainResponse {
  DomainArn?: string | undefined;
  DomainId?: string | undefined;
  DomainName?: string | undefined;
  HomeEfsFileSystemId?: string | undefined;
  SingleSignOnManagedApplicationInstanceId?: string | undefined;
  SingleSignOnApplicationArn?: string | undefined;
  Status?: DomainStatus | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  FailureReason?: string | undefined;
  SecurityGroupIdForDomainBoundary?: string | undefined;
  AuthMode?: AuthMode | undefined;
  DefaultUserSettings?: UserSettings | undefined;
  DomainSettings?: DomainSettings | undefined;
  AppNetworkAccessType?: AppNetworkAccessType | undefined;
  HomeEfsFileSystemKmsKeyId?: string | undefined;
  SubnetIds?: string[] | undefined;
  Url?: string | undefined;
  VpcId?: string | undefined;
  KmsKeyId?: string | undefined;
  AppSecurityGroupManagement?: AppSecurityGroupManagement | undefined;
  TagPropagation?: TagPropagation | undefined;
  DefaultSpaceSettings?: DefaultSpaceSettings | undefined;
}
export interface DescribeEdgeDeploymentPlanRequest {
  EdgeDeploymentPlanName: string | undefined;
  NextToken?: string | undefined;
  MaxResults?: number | undefined;
}
export interface DescribeEdgeDeploymentPlanResponse {
  EdgeDeploymentPlanArn: string | undefined;
  EdgeDeploymentPlanName: string | undefined;
  ModelConfigs: EdgeDeploymentModelConfig[] | undefined;
  DeviceFleetName: string | undefined;
  EdgeDeploymentSuccess?: number | undefined;
  EdgeDeploymentPending?: number | undefined;
  EdgeDeploymentFailed?: number | undefined;
  Stages: DeploymentStageStatusSummary[] | undefined;
  NextToken?: string | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
}
export interface DescribeEdgePackagingJobRequest {
  EdgePackagingJobName: string | undefined;
}
export interface EdgePresetDeploymentOutput {
  Type: EdgePresetDeploymentType | undefined;
  Artifact?: string | undefined;
  Status?: EdgePresetDeploymentStatus | undefined;
  StatusMessage?: string | undefined;
}
export interface DescribeEdgePackagingJobResponse {
  EdgePackagingJobArn: string | undefined;
  EdgePackagingJobName: string | undefined;
  CompilationJobName?: string | undefined;
  ModelName?: string | undefined;
  ModelVersion?: string | undefined;
  RoleArn?: string | undefined;
  OutputConfig?: EdgeOutputConfig | undefined;
  ResourceKey?: string | undefined;
  EdgePackagingJobStatus: EdgePackagingJobStatus | undefined;
  EdgePackagingJobStatusMessage?: string | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  ModelArtifact?: string | undefined;
  ModelSignature?: string | undefined;
  PresetDeploymentOutput?: EdgePresetDeploymentOutput | undefined;
}
export interface DescribeEndpointInput {
  EndpointName: string | undefined;
}
export interface ProductionVariantStatus {
  Status: VariantStatus | undefined;
  StatusMessage?: string | undefined;
  StartTime?: Date | undefined;
}
export interface PendingProductionVariantSummary {
  VariantName: string | undefined;
  DeployedImages?: DeployedImage[] | undefined;
  CurrentWeight?: number | undefined;
  DesiredWeight?: number | undefined;
  CurrentInstanceCount?: number | undefined;
  DesiredInstanceCount?: number | undefined;
  InstanceType?: ProductionVariantInstanceType | undefined;
  AcceleratorType?: ProductionVariantAcceleratorType | undefined;
  VariantStatus?: ProductionVariantStatus[] | undefined;
  CurrentServerlessConfig?: ProductionVariantServerlessConfig | undefined;
  DesiredServerlessConfig?: ProductionVariantServerlessConfig | undefined;
  ManagedInstanceScaling?: ProductionVariantManagedInstanceScaling | undefined;
  RoutingConfig?: ProductionVariantRoutingConfig | undefined;
}
export interface PendingDeploymentSummary {
  EndpointConfigName: string | undefined;
  ProductionVariants?: PendingProductionVariantSummary[] | undefined;
  StartTime?: Date | undefined;
  ShadowProductionVariants?: PendingProductionVariantSummary[] | undefined;
}
export interface Ec2CapacityReservation {
  Ec2CapacityReservationId?: string | undefined;
  TotalInstanceCount?: number | undefined;
  AvailableInstanceCount?: number | undefined;
  UsedByCurrentEndpoint?: number | undefined;
}
export interface ProductionVariantCapacityReservationSummary {
  MlReservationArn?: string | undefined;
  CapacityReservationPreference?: CapacityReservationPreference | undefined;
  TotalInstanceCount?: number | undefined;
  AvailableInstanceCount?: number | undefined;
  UsedByCurrentEndpoint?: number | undefined;
  Ec2CapacityReservations?: Ec2CapacityReservation[] | undefined;
}
export interface ProductionVariantSummary {
  VariantName: string | undefined;
  DeployedImages?: DeployedImage[] | undefined;
  CurrentWeight?: number | undefined;
  DesiredWeight?: number | undefined;
  CurrentInstanceCount?: number | undefined;
  DesiredInstanceCount?: number | undefined;
  VariantStatus?: ProductionVariantStatus[] | undefined;
  CurrentServerlessConfig?: ProductionVariantServerlessConfig | undefined;
  DesiredServerlessConfig?: ProductionVariantServerlessConfig | undefined;
  ManagedInstanceScaling?: ProductionVariantManagedInstanceScaling | undefined;
  RoutingConfig?: ProductionVariantRoutingConfig | undefined;
  CapacityReservationConfig?:
    | ProductionVariantCapacityReservationSummary
    | undefined;
}
export interface DescribeEndpointOutput {
  EndpointName: string | undefined;
  EndpointArn: string | undefined;
  EndpointConfigName?: string | undefined;
  ProductionVariants?: ProductionVariantSummary[] | undefined;
  DataCaptureConfig?: DataCaptureConfigSummary | undefined;
  EndpointStatus: EndpointStatus | undefined;
  FailureReason?: string | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  LastDeploymentConfig?: DeploymentConfig | undefined;
  AsyncInferenceConfig?: AsyncInferenceConfig | undefined;
  PendingDeploymentSummary?: PendingDeploymentSummary | undefined;
  ExplainerConfig?: ExplainerConfig | undefined;
  ShadowProductionVariants?: ProductionVariantSummary[] | undefined;
  MetricsConfig?: MetricsConfig | undefined;
}
export interface DescribeEndpointConfigInput {
  EndpointConfigName: string | undefined;
}
export interface DescribeEndpointConfigOutput {
  EndpointConfigName: string | undefined;
  EndpointConfigArn: string | undefined;
  ProductionVariants: ProductionVariant[] | undefined;
  DataCaptureConfig?: DataCaptureConfig | undefined;
  KmsKeyId?: string | undefined;
  CreationTime: Date | undefined;
  AsyncInferenceConfig?: AsyncInferenceConfig | undefined;
  ExplainerConfig?: ExplainerConfig | undefined;
  ShadowProductionVariants?: ProductionVariant[] | undefined;
  ExecutionRoleArn?: string | undefined;
  VpcConfig?: VpcConfig | undefined;
  EnableNetworkIsolation?: boolean | undefined;
  MetricsConfig?: MetricsConfig | undefined;
}
export interface DescribeExperimentRequest {
  ExperimentName: string | undefined;
}
export interface ExperimentSource {
  SourceArn: string | undefined;
  SourceType?: string | undefined;
}
export interface DescribeExperimentResponse {
  ExperimentName?: string | undefined;
  ExperimentArn?: string | undefined;
  DisplayName?: string | undefined;
  Source?: ExperimentSource | undefined;
  Description?: string | undefined;
  CreationTime?: Date | undefined;
  CreatedBy?: UserContext | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
}
export interface DescribeFeatureGroupRequest {
  FeatureGroupName: string | undefined;
  NextToken?: string | undefined;
}
export interface LastUpdateStatus {
  Status: LastUpdateStatusValue | undefined;
  FailureReason?: string | undefined;
}
export interface OfflineStoreStatus {
  Status: OfflineStoreStatusValue | undefined;
  BlockedReason?: string | undefined;
}
export interface ThroughputConfigDescription {
  ThroughputMode: ThroughputMode | undefined;
  ProvisionedReadCapacityUnits?: number | undefined;
  ProvisionedWriteCapacityUnits?: number | undefined;
}
export interface DescribeFeatureGroupResponse {
  FeatureGroupArn: string | undefined;
  FeatureGroupName: string | undefined;
  RecordIdentifierFeatureName: string | undefined;
  EventTimeFeatureName: string | undefined;
  FeatureDefinitions: FeatureDefinition[] | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime?: Date | undefined;
  OnlineStoreConfig?: OnlineStoreConfig | undefined;
  OfflineStoreConfig?: OfflineStoreConfig | undefined;
  ThroughputConfig?: ThroughputConfigDescription | undefined;
  RoleArn?: string | undefined;
  FeatureGroupStatus?: FeatureGroupStatus | undefined;
  OfflineStoreStatus?: OfflineStoreStatus | undefined;
  LastUpdateStatus?: LastUpdateStatus | undefined;
  FailureReason?: string | undefined;
  Description?: string | undefined;
  NextToken: string | undefined;
  OnlineStoreTotalSizeBytes?: number | undefined;
}
export interface DescribeFeatureMetadataRequest {
  FeatureGroupName: string | undefined;
  FeatureName: string | undefined;
}
export interface FeatureParameter {
  Key?: string | undefined;
  Value?: string | undefined;
}
export interface DescribeFeatureMetadataResponse {
  FeatureGroupArn: string | undefined;
  FeatureGroupName: string | undefined;
  FeatureName: string | undefined;
  FeatureType: FeatureType | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  Description?: string | undefined;
  Parameters?: FeatureParameter[] | undefined;
}
export interface DescribeFlowDefinitionRequest {
  FlowDefinitionName: string | undefined;
}
export interface DescribeFlowDefinitionResponse {
  FlowDefinitionArn: string | undefined;
  FlowDefinitionName: string | undefined;
  FlowDefinitionStatus: FlowDefinitionStatus | undefined;
  CreationTime: Date | undefined;
  HumanLoopRequestSource?: HumanLoopRequestSource | undefined;
  HumanLoopActivationConfig?: HumanLoopActivationConfig | undefined;
  HumanLoopConfig?: HumanLoopConfig | undefined;
  OutputConfig: FlowDefinitionOutputConfig | undefined;
  RoleArn: string | undefined;
  FailureReason?: string | undefined;
}
export interface DescribeHubRequest {
  HubName: string | undefined;
}
export interface DescribeHubResponse {
  HubName: string | undefined;
  HubArn: string | undefined;
  HubDisplayName?: string | undefined;
  HubDescription?: string | undefined;
  HubSearchKeywords?: string[] | undefined;
  S3StorageConfig?: HubS3StorageConfig | undefined;
  HubStatus: HubStatus | undefined;
  FailureReason?: string | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
}
export interface DescribeHubContentRequest {
  HubName: string | undefined;
  HubContentType: HubContentType | undefined;
  HubContentName: string | undefined;
  HubContentVersion?: string | undefined;
}
export interface HubContentDependency {
  DependencyOriginPath?: string | undefined;
  DependencyCopyPath?: string | undefined;
}
export interface DescribeHubContentResponse {
  HubContentName: string | undefined;
  HubContentArn: string | undefined;
  HubContentVersion: string | undefined;
  HubContentType: HubContentType | undefined;
  DocumentSchemaVersion: string | undefined;
  HubName: string | undefined;
  HubArn: string | undefined;
  HubContentDisplayName?: string | undefined;
  HubContentDescription?: string | undefined;
  HubContentMarkdown?: string | undefined;
  HubContentDocument: string | undefined;
  SageMakerPublicHubContentArn?: string | undefined;
  ReferenceMinVersion?: string | undefined;
  SupportStatus?: HubContentSupportStatus | undefined;
  HubContentSearchKeywords?: string[] | undefined;
  HubContentDependencies?: HubContentDependency[] | undefined;
  HubContentStatus: HubContentStatus | undefined;
  FailureReason?: string | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime?: Date | undefined;
}
export interface DescribeHumanTaskUiRequest {
  HumanTaskUiName: string | undefined;
}
export interface UiTemplateInfo {
  Url?: string | undefined;
  ContentSha256?: string | undefined;
}
export interface DescribeHumanTaskUiResponse {
  HumanTaskUiArn: string | undefined;
  HumanTaskUiName: string | undefined;
  HumanTaskUiStatus?: HumanTaskUiStatus | undefined;
  CreationTime: Date | undefined;
  UiTemplate: UiTemplateInfo | undefined;
}
export interface DescribeHyperParameterTuningJobRequest {
  HyperParameterTuningJobName: string | undefined;
}
export interface FinalHyperParameterTuningJobObjectiveMetric {
  Type?: HyperParameterTuningJobObjectiveType | undefined;
  MetricName: string | undefined;
  Value: number | undefined;
}
export interface HyperParameterTrainingJobSummary {
  TrainingJobDefinitionName?: string | undefined;
  TrainingJobName: string | undefined;
  TrainingJobArn: string | undefined;
  TuningJobName?: string | undefined;
  CreationTime: Date | undefined;
  TrainingStartTime?: Date | undefined;
  TrainingEndTime?: Date | undefined;
  TrainingJobStatus: TrainingJobStatus | undefined;
  TunedHyperParameters: Record<string, string> | undefined;
  FailureReason?: string | undefined;
  FinalHyperParameterTuningJobObjectiveMetric?:
    | FinalHyperParameterTuningJobObjectiveMetric
    | undefined;
  ObjectiveStatus?: ObjectiveStatus | undefined;
}
export interface HyperParameterTuningJobConsumedResources {
  RuntimeInSeconds?: number | undefined;
}
export interface ObjectiveStatusCounters {
  Succeeded?: number | undefined;
  Pending?: number | undefined;
  Failed?: number | undefined;
}
export interface TrainingJobStatusCounters {
  Completed?: number | undefined;
  InProgress?: number | undefined;
  RetryableError?: number | undefined;
  NonRetryableError?: number | undefined;
  Stopped?: number | undefined;
}
export interface HyperParameterTuningJobCompletionDetails {
  NumberOfTrainingJobsObjectiveNotImproving?: number | undefined;
  ConvergenceDetectedTime?: Date | undefined;
}
export interface DescribeHyperParameterTuningJobResponse {
  HyperParameterTuningJobName: string | undefined;
  HyperParameterTuningJobArn: string | undefined;
  HyperParameterTuningJobConfig: HyperParameterTuningJobConfig | undefined;
  TrainingJobDefinition?: HyperParameterTrainingJobDefinition | undefined;
  TrainingJobDefinitions?: HyperParameterTrainingJobDefinition[] | undefined;
  HyperParameterTuningJobStatus: HyperParameterTuningJobStatus | undefined;
  CreationTime: Date | undefined;
  HyperParameterTuningEndTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  TrainingJobStatusCounters: TrainingJobStatusCounters | undefined;
  ObjectiveStatusCounters: ObjectiveStatusCounters | undefined;
  BestTrainingJob?: HyperParameterTrainingJobSummary | undefined;
  OverallBestTrainingJob?: HyperParameterTrainingJobSummary | undefined;
  WarmStartConfig?: HyperParameterTuningJobWarmStartConfig | undefined;
  Autotune?: Autotune | undefined;
  FailureReason?: string | undefined;
  TuningJobCompletionDetails?:
    | HyperParameterTuningJobCompletionDetails
    | undefined;
  ConsumedResources?: HyperParameterTuningJobConsumedResources | undefined;
}
export interface DescribeImageRequest {
  ImageName: string | undefined;
}
export interface DescribeImageResponse {
  CreationTime?: Date | undefined;
  Description?: string | undefined;
  DisplayName?: string | undefined;
  FailureReason?: string | undefined;
  ImageArn?: string | undefined;
  ImageName?: string | undefined;
  ImageStatus?: ImageStatus | undefined;
  LastModifiedTime?: Date | undefined;
  RoleArn?: string | undefined;
}
export interface DescribeImageVersionRequest {
  ImageName: string | undefined;
  Version?: number | undefined;
  Alias?: string | undefined;
}
export interface DescribeImageVersionResponse {
  BaseImage?: string | undefined;
  ContainerImage?: string | undefined;
  CreationTime?: Date | undefined;
  FailureReason?: string | undefined;
  ImageArn?: string | undefined;
  ImageVersionArn?: string | undefined;
  ImageVersionStatus?: ImageVersionStatus | undefined;
  LastModifiedTime?: Date | undefined;
  Version?: number | undefined;
  VendorGuidance?: VendorGuidance | undefined;
  JobType?: JobType | undefined;
  MLFramework?: string | undefined;
  ProgrammingLang?: string | undefined;
  Processor?: Processor | undefined;
  Horovod?: boolean | undefined;
  ReleaseNotes?: string | undefined;
}
export interface DescribeInferenceComponentInput {
  InferenceComponentName: string | undefined;
}
export interface InferenceComponentCapacitySize {
  Type: InferenceComponentCapacitySizeType | undefined;
  Value: number | undefined;
}
export interface InferenceComponentRollingUpdatePolicy {
  MaximumBatchSize: InferenceComponentCapacitySize | undefined;
  WaitIntervalInSeconds: number | undefined;
  MaximumExecutionTimeoutInSeconds?: number | undefined;
  RollbackMaximumBatchSize?: InferenceComponentCapacitySize | undefined;
}
export interface InferenceComponentDeploymentConfig {
  RollingUpdatePolicy: InferenceComponentRollingUpdatePolicy | undefined;
  AutoRollbackConfiguration?: AutoRollbackConfig | undefined;
}
export interface InferenceComponentRuntimeConfigSummary {
  DesiredCopyCount?: number | undefined;
  CurrentCopyCount?: number | undefined;
}
export interface InferenceComponentContainerSpecificationSummary {
  DeployedImage?: DeployedImage | undefined;
  ArtifactUrl?: string | undefined;
  Environment?: Record<string, string> | undefined;
}
export interface InferenceComponentDataCacheConfigSummary {
  EnableCaching: boolean | undefined;
}
export interface InferenceComponentSpecificationSummary {
  ModelName?: string | undefined;
  Container?: InferenceComponentContainerSpecificationSummary | undefined;
  StartupParameters?: InferenceComponentStartupParameters | undefined;
  ComputeResourceRequirements?:
    | InferenceComponentComputeResourceRequirements
    | undefined;
  BaseInferenceComponentName?: string | undefined;
  DataCacheConfig?: InferenceComponentDataCacheConfigSummary | undefined;
}
export interface DescribeInferenceComponentOutput {
  InferenceComponentName: string | undefined;
  InferenceComponentArn: string | undefined;
  EndpointName: string | undefined;
  EndpointArn: string | undefined;
  VariantName?: string | undefined;
  FailureReason?: string | undefined;
  Specification?: InferenceComponentSpecificationSummary | undefined;
  RuntimeConfig?: InferenceComponentRuntimeConfigSummary | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  InferenceComponentStatus?: InferenceComponentStatus | undefined;
  LastDeploymentConfig?: InferenceComponentDeploymentConfig | undefined;
}
export interface DescribeInferenceExperimentRequest {
  Name: string | undefined;
}
export interface EndpointMetadata {
  EndpointName: string | undefined;
  EndpointConfigName?: string | undefined;
  EndpointStatus?: EndpointStatus | undefined;
  FailureReason?: string | undefined;
}
export interface ModelVariantConfigSummary {
  ModelName: string | undefined;
  VariantName: string | undefined;
  InfrastructureConfig: ModelInfrastructureConfig | undefined;
  Status: ModelVariantStatus | undefined;
}
export interface DescribeInferenceExperimentResponse {
  Arn: string | undefined;
  Name: string | undefined;
  Type: InferenceExperimentType | undefined;
  Schedule?: InferenceExperimentSchedule | undefined;
  Status: InferenceExperimentStatus | undefined;
  StatusReason?: string | undefined;
  Description?: string | undefined;
  CreationTime?: Date | undefined;
  CompletionTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  RoleArn?: string | undefined;
  EndpointMetadata: EndpointMetadata | undefined;
  ModelVariants: ModelVariantConfigSummary[] | undefined;
  DataStorageConfig?: InferenceExperimentDataStorageConfig | undefined;
  ShadowModeConfig?: ShadowModeConfig | undefined;
  KmsKey?: string | undefined;
}
export interface DescribeInferenceRecommendationsJobRequest {
  JobName: string | undefined;
}
export interface InferenceMetrics {
  MaxInvocations: number | undefined;
  ModelLatency: number | undefined;
}
export interface EndpointPerformance {
  Metrics: InferenceMetrics | undefined;
  EndpointInfo: EndpointInfo | undefined;
}
export interface EndpointOutputConfiguration {
  EndpointName: string | undefined;
  VariantName: string | undefined;
  InstanceType?: ProductionVariantInstanceType | undefined;
  InitialInstanceCount?: number | undefined;
  ServerlessConfig?: ProductionVariantServerlessConfig | undefined;
}
export interface RecommendationMetrics {
  CostPerHour?: number | undefined;
  CostPerInference?: number | undefined;
  MaxInvocations?: number | undefined;
  ModelLatency?: number | undefined;
  CpuUtilization?: number | undefined;
  MemoryUtilization?: number | undefined;
  ModelSetupTime?: number | undefined;
}
export interface EnvironmentParameter {
  Key: string | undefined;
  ValueType: string | undefined;
  Value: string | undefined;
}
export interface ModelConfiguration {
  InferenceSpecificationName?: string | undefined;
  EnvironmentParameters?: EnvironmentParameter[] | undefined;
  CompilationJobName?: string | undefined;
}
export interface InferenceRecommendation {
  RecommendationId?: string | undefined;
  Metrics?: RecommendationMetrics | undefined;
  EndpointConfiguration: EndpointOutputConfiguration | undefined;
  ModelConfiguration: ModelConfiguration | undefined;
  InvocationEndTime?: Date | undefined;
  InvocationStartTime?: Date | undefined;
}
export interface DescribeInferenceRecommendationsJobResponse {
  JobName: string | undefined;
  JobDescription?: string | undefined;
  JobType: RecommendationJobType | undefined;
  JobArn: string | undefined;
  RoleArn: string | undefined;
  Status: RecommendationJobStatus | undefined;
  CreationTime: Date | undefined;
  CompletionTime?: Date | undefined;
  LastModifiedTime: Date | undefined;
  FailureReason?: string | undefined;
  InputConfig: RecommendationJobInputConfig | undefined;
  StoppingConditions?: RecommendationJobStoppingConditions | undefined;
  InferenceRecommendations?: InferenceRecommendation[] | undefined;
  EndpointPerformances?: EndpointPerformance[] | undefined;
}
export interface DescribeLabelingJobRequest {
  LabelingJobName: string | undefined;
}
export interface LabelCounters {
  TotalLabeled?: number | undefined;
  HumanLabeled?: number | undefined;
  MachineLabeled?: number | undefined;
  FailedNonRetryableError?: number | undefined;
  Unlabeled?: number | undefined;
}
export interface LabelingJobOutput {
  OutputDatasetS3Uri: string | undefined;
  FinalActiveLearningModelArn?: string | undefined;
}
export interface DescribeLabelingJobResponse {
  LabelingJobStatus: LabelingJobStatus | undefined;
  LabelCounters: LabelCounters | undefined;
  FailureReason?: string | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  JobReferenceCode: string | undefined;
  LabelingJobName: string | undefined;
  LabelingJobArn: string | undefined;
  LabelAttributeName?: string | undefined;
  InputConfig: LabelingJobInputConfig | undefined;
  OutputConfig: LabelingJobOutputConfig | undefined;
  RoleArn: string | undefined;
  LabelCategoryConfigS3Uri?: string | undefined;
  StoppingConditions?: LabelingJobStoppingConditions | undefined;
  LabelingJobAlgorithmsConfig?: LabelingJobAlgorithmsConfig | undefined;
  HumanTaskConfig: HumanTaskConfig | undefined;
  Tags?: Tag[] | undefined;
  LabelingJobOutput?: LabelingJobOutput | undefined;
}
export interface DescribeLineageGroupRequest {
  LineageGroupName: string | undefined;
}
export interface DescribeLineageGroupResponse {
  LineageGroupName?: string | undefined;
  LineageGroupArn?: string | undefined;
  DisplayName?: string | undefined;
  Description?: string | undefined;
  CreationTime?: Date | undefined;
  CreatedBy?: UserContext | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
}
export interface DescribeMlflowAppRequest {
  Arn: string | undefined;
}
export interface DescribeMlflowAppResponse {
  Arn?: string | undefined;
  Name?: string | undefined;
  ArtifactStoreUri?: string | undefined;
  MlflowVersion?: string | undefined;
  RoleArn?: string | undefined;
  Status?: MlflowAppStatus | undefined;
  ModelRegistrationMode?: ModelRegistrationMode | undefined;
  AccountDefaultStatus?: AccountDefaultStatus | undefined;
  DefaultDomainIdList?: string[] | undefined;
  CreationTime?: Date | undefined;
  CreatedBy?: UserContext | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
  WeeklyMaintenanceWindowStart?: string | undefined;
  MaintenanceStatus?: MaintenanceStatus | undefined;
}
export interface DescribeMlflowTrackingServerRequest {
  TrackingServerName: string | undefined;
}
export interface DescribeMlflowTrackingServerResponse {
  TrackingServerArn?: string | undefined;
  TrackingServerName?: string | undefined;
  ArtifactStoreUri?: string | undefined;
  TrackingServerSize?: TrackingServerSize | undefined;
  MlflowVersion?: string | undefined;
  RoleArn?: string | undefined;
  TrackingServerStatus?: TrackingServerStatus | undefined;
  TrackingServerMaintenanceStatus?: TrackingServerMaintenanceStatus | undefined;
  IsActive?: IsTrackingServerActive | undefined;
  TrackingServerUrl?: string | undefined;
  WeeklyMaintenanceWindowStart?: string | undefined;
  AutomaticModelRegistration?: boolean | undefined;
  CreationTime?: Date | undefined;
  CreatedBy?: UserContext | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
}
export interface DescribeModelInput {
  ModelName: string | undefined;
}
export interface DescribeModelOutput {
  ModelName: string | undefined;
  PrimaryContainer?: ContainerDefinition | undefined;
  Containers?: ContainerDefinition[] | undefined;
  InferenceExecutionConfig?: InferenceExecutionConfig | undefined;
  ExecutionRoleArn?: string | undefined;
  VpcConfig?: VpcConfig | undefined;
  CreationTime: Date | undefined;
  ModelArn: string | undefined;
  EnableNetworkIsolation?: boolean | undefined;
  DeploymentRecommendation?: DeploymentRecommendation | undefined;
}
export interface DescribeModelBiasJobDefinitionRequest {
  JobDefinitionName: string | undefined;
}
export interface DescribeModelBiasJobDefinitionResponse {
  JobDefinitionArn: string | undefined;
  JobDefinitionName: string | undefined;
  CreationTime: Date | undefined;
  ModelBiasBaselineConfig?: ModelBiasBaselineConfig | undefined;
  ModelBiasAppSpecification: ModelBiasAppSpecification | undefined;
  ModelBiasJobInput: ModelBiasJobInput | undefined;
  ModelBiasJobOutputConfig: MonitoringOutputConfig | undefined;
  JobResources: MonitoringResources | undefined;
  NetworkConfig?: MonitoringNetworkConfig | undefined;
  RoleArn: string | undefined;
  StoppingCondition?: MonitoringStoppingCondition | undefined;
}
export interface DescribeModelCardRequest {
  ModelCardName: string | undefined;
  ModelCardVersion?: number | undefined;
}
export interface DescribeModelCardResponse {
  ModelCardArn: string | undefined;
  ModelCardName: string | undefined;
  ModelCardVersion: number | undefined;
  Content: string | undefined;
  ModelCardStatus: ModelCardStatus | undefined;
  SecurityConfig?: ModelCardSecurityConfig | undefined;
  CreationTime: Date | undefined;
  CreatedBy: UserContext | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
  ModelCardProcessingStatus?: ModelCardProcessingStatus | undefined;
}
export interface DescribeModelCardExportJobRequest {
  ModelCardExportJobArn: string | undefined;
}
export interface ModelCardExportArtifacts {
  S3ExportArtifacts: string | undefined;
}
export interface DescribeModelCardExportJobResponse {
  ModelCardExportJobName: string | undefined;
  ModelCardExportJobArn: string | undefined;
  Status: ModelCardExportJobStatus | undefined;
  ModelCardName: string | undefined;
  ModelCardVersion: number | undefined;
  OutputConfig: ModelCardExportOutputConfig | undefined;
  CreatedAt: Date | undefined;
  LastModifiedAt: Date | undefined;
  FailureReason?: string | undefined;
  ExportArtifacts?: ModelCardExportArtifacts | undefined;
}
export interface DescribeModelExplainabilityJobDefinitionRequest {
  JobDefinitionName: string | undefined;
}
export interface DescribeModelExplainabilityJobDefinitionResponse {
  JobDefinitionArn: string | undefined;
  JobDefinitionName: string | undefined;
  CreationTime: Date | undefined;
  ModelExplainabilityBaselineConfig?:
    | ModelExplainabilityBaselineConfig
    | undefined;
  ModelExplainabilityAppSpecification:
    | ModelExplainabilityAppSpecification
    | undefined;
  ModelExplainabilityJobInput: ModelExplainabilityJobInput | undefined;
  ModelExplainabilityJobOutputConfig: MonitoringOutputConfig | undefined;
  JobResources: MonitoringResources | undefined;
  NetworkConfig?: MonitoringNetworkConfig | undefined;
  RoleArn: string | undefined;
  StoppingCondition?: MonitoringStoppingCondition | undefined;
}
export interface DescribeModelPackageInput {
  ModelPackageName: string | undefined;
}
export interface ModelPackageStatusItem {
  Name: string | undefined;
  Status: DetailedModelPackageStatus | undefined;
  FailureReason?: string | undefined;
}
export interface ModelPackageStatusDetails {
  ValidationStatuses: ModelPackageStatusItem[] | undefined;
  ImageScanStatuses?: ModelPackageStatusItem[] | undefined;
}
export interface DescribeModelPackageOutput {
  ModelPackageName: string | undefined;
  ModelPackageGroupName?: string | undefined;
  ModelPackageVersion?: number | undefined;
  ModelPackageRegistrationType?: ModelPackageRegistrationType | undefined;
  ModelPackageArn: string | undefined;
  ModelPackageDescription?: string | undefined;
  CreationTime: Date | undefined;
  InferenceSpecification?: InferenceSpecification | undefined;
  SourceAlgorithmSpecification?: SourceAlgorithmSpecification | undefined;
  ValidationSpecification?: ModelPackageValidationSpecification | undefined;
  ModelPackageStatus: ModelPackageStatus | undefined;
  ModelPackageStatusDetails: ModelPackageStatusDetails | undefined;
  CertifyForMarketplace?: boolean | undefined;
  ModelApprovalStatus?: ModelApprovalStatus | undefined;
  CreatedBy?: UserContext | undefined;
  MetadataProperties?: MetadataProperties | undefined;
  ModelMetrics?: ModelMetrics | undefined;
  LastModifiedTime?: Date | undefined;
  LastModifiedBy?: UserContext | undefined;
  ApprovalDescription?: string | undefined;
  Domain?: string | undefined;
  Task?: string | undefined;
  SamplePayloadUrl?: string | undefined;
  CustomerMetadataProperties?: Record<string, string> | undefined;
  DriftCheckBaselines?: DriftCheckBaselines | undefined;
  AdditionalInferenceSpecifications?:
    | AdditionalInferenceSpecificationDefinition[]
    | undefined;
  SkipModelValidation?: SkipModelValidation | undefined;
  SourceUri?: string | undefined;
  SecurityConfig?: ModelPackageSecurityConfig | undefined;
  ModelCard?: ModelPackageModelCard | undefined;
  ModelLifeCycle?: ModelLifeCycle | undefined;
}
export interface DescribeModelPackageGroupInput {
  ModelPackageGroupName: string | undefined;
}
export interface DescribeModelPackageGroupOutput {
  ModelPackageGroupName: string | undefined;
  ModelPackageGroupArn: string | undefined;
  ModelPackageGroupDescription?: string | undefined;
  CreationTime: Date | undefined;
  CreatedBy: UserContext | undefined;
  ModelPackageGroupStatus: ModelPackageGroupStatus | undefined;
}
export interface DescribeModelQualityJobDefinitionRequest {
  JobDefinitionName: string | undefined;
}
export interface DescribeModelQualityJobDefinitionResponse {
  JobDefinitionArn: string | undefined;
  JobDefinitionName: string | undefined;
  CreationTime: Date | undefined;
  ModelQualityBaselineConfig?: ModelQualityBaselineConfig | undefined;
  ModelQualityAppSpecification: ModelQualityAppSpecification | undefined;
  ModelQualityJobInput: ModelQualityJobInput | undefined;
  ModelQualityJobOutputConfig: MonitoringOutputConfig | undefined;
  JobResources: MonitoringResources | undefined;
  NetworkConfig?: MonitoringNetworkConfig | undefined;
  RoleArn: string | undefined;
  StoppingCondition?: MonitoringStoppingCondition | undefined;
}
export interface DescribeMonitoringScheduleRequest {
  MonitoringScheduleName: string | undefined;
}
export interface MonitoringExecutionSummary {
  MonitoringScheduleName: string | undefined;
  ScheduledTime: Date | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  MonitoringExecutionStatus: ExecutionStatus | undefined;
  ProcessingJobArn?: string | undefined;
  EndpointName?: string | undefined;
  FailureReason?: string | undefined;
  MonitoringJobDefinitionName?: string | undefined;
  MonitoringType?: MonitoringType | undefined;
}
export interface DescribeMonitoringScheduleResponse {
  MonitoringScheduleArn: string | undefined;
  MonitoringScheduleName: string | undefined;
  MonitoringScheduleStatus: ScheduleStatus | undefined;
  MonitoringType?: MonitoringType | undefined;
  FailureReason?: string | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  MonitoringScheduleConfig: MonitoringScheduleConfig | undefined;
  EndpointName?: string | undefined;
  LastMonitoringExecutionSummary?: MonitoringExecutionSummary | undefined;
}
export interface DescribeNotebookInstanceInput {
  NotebookInstanceName: string | undefined;
}
export interface DescribeNotebookInstanceOutput {
  NotebookInstanceArn?: string | undefined;
  NotebookInstanceName?: string | undefined;
  NotebookInstanceStatus?: NotebookInstanceStatus | undefined;
  FailureReason?: string | undefined;
  Url?: string | undefined;
  InstanceType?: _InstanceType | undefined;
  IpAddressType?: IPAddressType | undefined;
  SubnetId?: string | undefined;
  SecurityGroups?: string[] | undefined;
  RoleArn?: string | undefined;
  KmsKeyId?: string | undefined;
  NetworkInterfaceId?: string | undefined;
  LastModifiedTime?: Date | undefined;
  CreationTime?: Date | undefined;
  NotebookInstanceLifecycleConfigName?: string | undefined;
  DirectInternetAccess?: DirectInternetAccess | undefined;
  VolumeSizeInGB?: number | undefined;
  AcceleratorTypes?: NotebookInstanceAcceleratorType[] | undefined;
  DefaultCodeRepository?: string | undefined;
  AdditionalCodeRepositories?: string[] | undefined;
  RootAccess?: RootAccess | undefined;
  PlatformIdentifier?: string | undefined;
  InstanceMetadataServiceConfiguration?:
    | InstanceMetadataServiceConfiguration
    | undefined;
}
export interface DescribeNotebookInstanceLifecycleConfigInput {
  NotebookInstanceLifecycleConfigName: string | undefined;
}
export interface DescribeNotebookInstanceLifecycleConfigOutput {
  NotebookInstanceLifecycleConfigArn?: string | undefined;
  NotebookInstanceLifecycleConfigName?: string | undefined;
  OnCreate?: NotebookInstanceLifecycleHook[] | undefined;
  OnStart?: NotebookInstanceLifecycleHook[] | undefined;
  LastModifiedTime?: Date | undefined;
  CreationTime?: Date | undefined;
}
export interface DescribeOptimizationJobRequest {
  OptimizationJobName: string | undefined;
}
export interface OptimizationOutput {
  RecommendedInferenceImage?: string | undefined;
}
export interface DescribeOptimizationJobResponse {
  OptimizationJobArn: string | undefined;
  OptimizationJobStatus: OptimizationJobStatus | undefined;
  OptimizationStartTime?: Date | undefined;
  OptimizationEndTime?: Date | undefined;
  CreationTime: Date | undefined;
  LastModifiedTime: Date | undefined;
  FailureReason?: string | undefined;
  OptimizationJobName: string | undefined;
  ModelSource: OptimizationJobModelSource | undefined;
  OptimizationEnvironment?: Record<string, string> | undefined;
  DeploymentInstanceType: OptimizationJobDeploymentInstanceType | undefined;
  MaxInstanceCount?: number | undefined;
  OptimizationConfigs: OptimizationConfig[] | undefined;
  OutputConfig: OptimizationJobOutputConfig | undefined;
  OptimizationOutput?: OptimizationOutput | undefined;
  RoleArn: string | undefined;
  StoppingCondition: StoppingCondition | undefined;
  VpcConfig?: OptimizationVpcConfig | undefined;
}
export interface DescribePartnerAppRequest {
  Arn: string | undefined;
  IncludeAvailableUpgrade?: boolean | undefined;
}
export interface ErrorInfo {
  Code?: string | undefined;
  Reason?: string | undefined;
}
export interface DescribePartnerAppResponse {
  Arn?: string | undefined;
  Name?: string | undefined;
  Type?: PartnerAppType | undefined;
  Status?: PartnerAppStatus | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  ExecutionRoleArn?: string | undefined;
  KmsKeyId?: string | undefined;
  BaseUrl?: string | undefined;
  MaintenanceConfig?: PartnerAppMaintenanceConfig | undefined;
  Tier?: string | undefined;
  Version?: string | undefined;
  ApplicationConfig?: PartnerAppConfig | undefined;
  AuthType?: PartnerAppAuthType | undefined;
  EnableIamSessionBasedIdentity?: boolean | undefined;
  Error?: ErrorInfo | undefined;
  EnableAutoMinorVersionUpgrade?: boolean | undefined;
  CurrentVersionEolDate?: Date | undefined;
  AvailableUpgrade?: AvailableUpgrade | undefined;
}
export interface DescribePipelineRequest {
  PipelineName: string | undefined;
  PipelineVersionId?: number | undefined;
}
export interface DescribePipelineResponse {
  PipelineArn?: string | undefined;
  PipelineName?: string | undefined;
  PipelineDisplayName?: string | undefined;
  PipelineDefinition?: string | undefined;
  PipelineDescription?: string | undefined;
  RoleArn?: string | undefined;
  PipelineStatus?: PipelineStatus | undefined;
  CreationTime?: Date | undefined;
  LastModifiedTime?: Date | undefined;
  LastRunTime?: Date | undefined;
  CreatedBy?: UserContext | undefined;
  LastModifiedBy?: UserContext | undefined;
  ParallelismConfiguration?: ParallelismConfiguration | undefined;
  PipelineVersionDisplayName?: string | undefined;
  PipelineVersionDescription?: string | undefined;
}
export interface DescribePipelineDefinitionForExecutionRequest {
  PipelineExecutionArn: string | undefined;
}
export interface DescribePipelineDefinitionForExecutionResponse {
  PipelineDefinition?: string | undefined;
  CreationTime?: Date | undefined;
}
export interface DescribePipelineExecutionRequest {
  PipelineExecutionArn: string | undefined;
}
export interface MLflowConfiguration {
  MlflowResourceArn?: string | undefined;
  MlflowExperimentName?: string | undefined;
}
export interface PipelineExperimentConfig {
  ExperimentName?: string | undefined;
  TrialName?: string | undefined;
}
export interface SelectedStep {
  StepName: string | undefined;
}
