import { Paginator } from "@smithy/types";
import {
  SearchCommandInput,
  SearchCommandOutput,
} from "../commands/SearchCommand";
import { SageMakerPaginationConfiguration } from "./Interfaces";
export declare const paginateSearch: (
  config: SageMakerPaginationConfiguration,
  input: SearchCommandInput,
  ...rest: any[]
) => Paginator<SearchCommandOutput>;
