const _A = "Alarm";
const _AA = "ActionArn";
const _AAR = "AddAssociationRequest";
const _AARd = "AddAssociationResponse";
const _AAc = "ActionArns";
const _AAd = "AddAssociation";
const _AAl = "AlgorithmArn";
const _AAp = "AppArn";
const _AAr = "ArtifactArn";
const _AArt = "ArtifactArns";
const _ABL = "AbsoluteBorrowLimits";
const _ABLRL = "AbsoluteBorrowLimitResourceList";
const _ABRA = "AmazonBedrockRoleArn";
const _AC = "AgentCount";
const _ACC = "AnnotationConsolidationConfig";
const _ACLA = "AnnotationConsolidationLambdaArn";
const _ACNS = "AddClusterNodeSpecification";
const _ACNSL = "AddClusterNodeSpecificationList";
const _ACNV = "AttachClusterNodeVolume";
const _ACNVR = "AttachClusterNodeVolumeRequest";
const _ACNVRt = "AttachClusterNodeVolumeResponse";
const _ACR = "AdditionalCodeRepositories";
const _ACRE = "AdditionalCodeRepositoryEquals";
const _ACc = "AccessConfig";
const _ACl = "AlgorithmsConfig";
const _ACp = "ApplicationConfig";
const _ACt = "AttemptCount";
const _AD = "AlarmDetails";
const _ADC = "ActiveDeviceCount";
const _ADD = "AthenaDatasetDefinition";
const _ADS = "AccountDefaultStatus";
const _ADl = "AlgorithmDescription";
const _ADp = "AppDetails";
const _ADpp = "ApprovalDescription";
const _ADr = "ArtifactDigest";
const _AE = "AdditionalEnis";
const _AEc = "AcceptEula";
const _AEu = "AuthorizationEndpoint";
const _AFRA = "AmazonForecastRoleArn";
const _AGEN = "AutoGenerateEndpointName";
const _AGP = "AssignedGroupPatterns";
const _AI = "AssociationInfo";
const _AIC = "AsyncInferenceConfig";
const _AICA = "AppImageConfigArn";
const _AICC = "AsyncInferenceClientConfig";
const _AICD = "AppImageConfigDetails";
const _AICL = "AppImageConfigList";
const _AICN = "AppImageConfigName";
const _AICp = "AppImageConfigs";
const _AICv = "AvailableInstanceCount";
const _AIL = "AssociationInfoList";
const _AINC = "AsyncInferenceNotificationConfig";
const _AIOC = "AsyncInferenceOutputConfig";
const _AIS = "AdditionalInferenceSpecifications";
const _AISD = "AdditionalInferenceSpecificationDefinition";
const _AISTA = "AdditionalInferenceSpecificationsToAdd";
const _AIU = "AmountInUsd";
const _AL = "AlarmList";
const _ALM = "AppLifecycleManagement";
const _ALp = "AppList";
const _AM = "AuthMode";
const _AMDS = "AdditionalModelDataSource";
const _AMDSd = "AdditionalModelDataSources";
const _AMHEFS = "AutoMountHomeEFS";
const _AMHLRS = "AwsManagedHumanLoopRequestSource";
const _AMLA = "AutoMLAlgorithms";
const _AMLAC = "AutoMLAlgorithmConfig";
const _AMLACu = "AutoMLAlgorithmsConfig";
const _AMLC = "AutoMLCandidate";
const _AMLCC = "AutoMLComputeConfig";
const _AMLCD = "AutoMLContainerDefinition";
const _AMLCDu = "AutoMLContainerDefinitions";
const _AMLCGC = "AutoMLCandidateGenerationConfig";
const _AMLCS = "AutoMLCandidateStep";
const _AMLCu = "AutoMLChannel";
const _AMLCut = "AutoMLCandidates";
const _AMLDS = "AutoMLDataSource";
const _AMLDSC = "AutoMLDataSplitConfig";
const _AMLICD = "AutoMLInferenceContainerDefinitions";
const _AMLIDC = "AutoMLInputDataConfig";
const _AMLJ = "AutoMLJob";
const _AMLJA = "AutoMLJobArtifacts";
const _AMLJAu = "AutoMLJobArn";
const _AMLJC = "AutoMLJobChannel";
const _AMLJCC = "AutoMLJobCompletionCriteria";
const _AMLJCu = "AutoMLJobConfig";
const _AMLJIDC = "AutoMLJobInputDataConfig";
const _AMLJN = "AutoMLJobName";
const _AMLJO = "AutoMLJobObjective";
const _AMLJS = "AutoMLJobSummary";
const _AMLJSM = "AutoMLJobStepMetadata";
const _AMLJSS = "AutoMLJobSecondaryStatus";
const _AMLJSu = "AutoMLJobStatus";
const _AMLJSut = "AutoMLJobSummaries";
const _AMLODC = "AutoMLOutputDataConfig";
const _AMLPFR = "AutoMLPartialFailureReason";
const _AMLPFRu = "AutoMLPartialFailureReasons";
const _AMLPTC = "AutoMLProblemTypeConfig";
const _AMLPTCN = "AutoMLProblemTypeConfigName";
const _AMLPTRA = "AutoMLProblemTypeResolvedAttributes";
const _AMLRA = "AutoMLResolvedAttributes";
const _AMLSC = "AutoMLSecurityConfig";
const _AMLSDS = "AutoMLS3DataSource";
const _AMR = "AutomaticModelRegistration";
const _AMp = "AppManaged";
const _AN = "ActionName";
const _ANAT = "AppNetworkAccessType";
const _ANl = "AlarmName";
const _ANlg = "AlgorithmName";
const _ANp = "AppName";
const _ANr = "ArtifactName";
const _ANt = "AttributeNames";
const _AO = "ActiveOperations";
const _AOm = "AmiOverride";
const _AP = "AutoParameter";
const _APC = "AcceleratorPartitionConfig";
const _APc = "AcceleratorPartition";
const _APu = "AutoParameters";
const _AQS = "AmazonQSettings";
const _ARA = "AssumableRoleArns";
const _ARAu = "AutoRollbackAlarms";
const _ARC = "AutoRollbackConfig";
const _ARCu = "AutoRollbackConfiguration";
const _AREP = "AuthenticationRequestExtraParams";
const _AS = "ActionSource";
const _ASD = "AlgorithmStatusDetails";
const _ASDS = "AdditionalS3DataSource";
const _ASGM = "AppSecurityGroupManagement";
const _ASI = "AlgorithmStatusItem";
const _ASIC = "AvailableSpareInstanceCount";
const _ASIL = "AlgorithmStatusItemList";
const _ASL = "AlgorithmSummaryList";
const _AST = "ArtifactSourceType";
const _ASTr = "ArtifactSourceTypes";
const _ASTu = "AutoScalerType";
const _ASU = "ArtifactStoreUri";
const _ASUC = "ActiveSoftwareUpdateConfig";
const _ASc = "ActionSummary";
const _AScc = "AccessStatus";
const _ASct = "ActivationState";
const _AScti = "ActionSummaries";
const _ASl = "AlgorithmSpecification";
const _ASle = "AlertStatus";
const _ASlg = "AlgorithmSummary";
const _ASlgo = "AlgorithmStatus";
const _ASll = "AllocationStrategy";
const _ASp = "AppSpecification";
const _ASr = "ArtifactSource";
const _ASrt = "ArtifactSummary";
const _ASrti = "ArtifactSummaries";
const _ASs = "AssociationSummary";
const _ASss = "AssociationSummaries";
const _ASu = "AutoScaling";
const _AT = "ActionType";
const _ATA = "AliasesToAdd";
const _ATC = "AssociateTrialComponent";
const _ATCR = "AssociateTrialComponentRequest";
const _ATCRs = "AssociateTrialComponentResponse";
const _ATD = "AliasesToDelete";
const _ATE = "AppTypeEquals";
const _ATI = "AddTagsInput";
const _ATO = "AddTagsOutput";
const _ATc = "AcceleratorTypes";
const _ATcc = "AcceleratorType";
const _ATd = "AddTags";
const _ATp = "AppType";
const _ATr = "ArtifactType";
const _ATs = "AssociationType";
const _ATt = "AttachTime";
const _ATu = "AuthType";
const _AU = "AuthorizedUrl";
const _AUC = "AuthorizedUrlConfigs";
const _AUd = "AdminUsers";
const _AUr = "ArtifactUrl";
const _AUv = "AvailableUpgrade";
const _AV = "AgentVersion";
const _AVP = "AlgorithmValidationProfile";
const _AVPl = "AlgorithmValidationProfiles";
const _AVS = "AlgorithmValidationSpecification";
const _AVg = "AgentVersions";
const _AVp = "AppVersion";
const _AW = "AssembleWith";
const _AZ = "AvailabilityZone";
const _AZI = "AvailabilityZoneId";
const _Ac = "Accelerators";
const _Acc = "Accelerator";
const _Acce = "Accept";
const _Act = "Actions";
const _Ag = "Aggregation";
const _Al = "Alarms";
const _Ali = "Aliases";
const _Alia = "Alias";
const _Ap = "Apps";
const _Ar = "Arn";
const _Arc = "Arch";
const _Arg = "Arguments";
const _Art = "Artifact";
const _As = "Associations";
const _Au = "Autotune";
const _Av = "Avg";
const _B = "Bias";
const _BACN = "BatchAddClusterNodes";
const _BACNE = "BatchAddClusterNodesError";
const _BACNEL = "BatchAddClusterNodesErrorList";
const _BACNR = "BatchAddClusterNodesRequest";
const _BACNRa = "BatchAddClusterNodesResponse";
const _BC = "BestCandidate";
const _BCM = "BedrockCustomModel";
const _BCMD = "BedrockCustomModelDeployment";
const _BCMDM = "BedrockCustomModelDeploymentMetadata";
const _BCMM = "BedrockCustomModelMetadata";
const _BCa = "BaselineConfig";
const _BDCC = "BatchDataCaptureConfig";
const _BDCN = "BatchDeleteClusterNodes";
const _BDCNE = "BatchDeleteClusterNodesError";
const _BDCNEL = "BatchDeleteClusterNodesErrorList";
const _BDCNLIE = "BatchDeleteClusterNodeLogicalIdsError";
const _BDCNLIEL = "BatchDeleteClusterNodeLogicalIdsErrorList";
const _BDCNR = "BatchDeleteClusterNodesRequest";
const _BDCNRa = "BatchDeleteClusterNodesResponse";
const _BDMP = "BatchDescribeModelPackage";
const _BDMPE = "BatchDescribeModelPackageError";
const _BDMPEM = "BatchDescribeModelPackageErrorMap";
const _BDMPI = "BatchDescribeModelPackageInput";
const _BDMPO = "BatchDescribeModelPackageOutput";
const _BDMPS = "BatchDescribeModelPackageSummary";
const _BGUP = "BlueGreenUpdatePolicy";
const _BI = "BaseImage";
const _BICN = "BaseInferenceComponentName";
const _BILCA = "BuiltInLifecycleConfigArn";
const _BJN = "BaseliningJobName";
const _BL = "BorrowLimit";
const _BM = "BaseModel";
const _BMA = "BaseModelArn";
const _BMI = "BedrockModelImport";
const _BMIM = "BedrockModelImportMetadata";
const _BMN = "BaseModelName";
const _BONI = "BestObjectiveNotImproving";
const _BPMT = "BedrockProvisionedModelThroughput";
const _BPMTM = "BedrockProvisionedModelThroughputMetadata";
const _BR = "BacktestResults";
const _BRCN = "BatchRebootClusterNodes";
const _BRCNE = "BatchRebootClusterNodesError";
const _BRCNEa = "BatchReplaceClusterNodesError";
const _BRCNEat = "BatchRebootClusterNodesErrors";
const _BRCNEatc = "BatchReplaceClusterNodesErrors";
const _BRCNLIE = "BatchRebootClusterNodeLogicalIdsError";
const _BRCNLIEa = "BatchReplaceClusterNodeLogicalIdsError";
const _BRCNLIEat = "BatchRebootClusterNodeLogicalIdsErrors";
const _BRCNLIEatc = "BatchReplaceClusterNodeLogicalIdsErrors";
const _BRCNR = "BatchRebootClusterNodesRequest";
const _BRCNRa = "BatchRebootClusterNodesResponse";
const _BRCNRat = "BatchReplaceClusterNodesRequest";
const _BRCNRatc = "BatchReplaceClusterNodesResponse";
const _BRCNa = "BatchReplaceClusterNodes";
const _BRl = "BlockedReason";
const _BS = "BatchStrategy";
const _BTC = "BillableTokenCount";
const _BTI = "BatchTransformInput";
const _BTIS = "BillableTimeInSeconds";
const _BTJ = "BestTrainingJob";
const _BU = "BaseUrl";
const _BUFDCC = "BaselineUsedForDriftCheckConstraints";
const _BUFDCS = "BaselineUsedForDriftCheckStatistics";
const _Br = "Branch";
const _Bu = "Bucket";
const _C = "Count";
const _CA = "ContainerArguments";
const _CAFO = "CrossAccountFilterOption";
const _CAI = "CreateAlgorithmInput";
const _CAIC = "CreateAppImageConfig";
const _CAICR = "CreateAppImageConfigRequest";
const _CAICRr = "CreateAppImageConfigResponse";
const _CAL = "CandidateArtifactLocations";
const _CAMLJ = "CreateAutoMLJob";
const _CAMLJR = "CreateAutoMLJobRequest";
const _CAMLJRr = "CreateAutoMLJobResponse";
const _CAMLJV = "CreateAutoMLJobV2";
const _CAMLJVR = "CreateAutoMLJobV2Request";
const _CAMLJVRr = "CreateAutoMLJobV2Response";
const _CAMRRA = "CrossAccountModelRegisterRoleArn";
const _CAO = "CreateAlgorithmOutput";
const _CAR = "CreateActionRequest";
const _CARr = "CreateActionResponse";
const _CARre = "CreateAppRequest";
const _CARrea = "CreateAppResponse";
const _CARreat = "CreateArtifactRequest";
const _CARreate = "CreateArtifactResponse";
const _CAS = "CanvasAppSettings";
const _CASC = "ClusterAutoScalingConfig";
const _CASCO = "ClusterAutoScalingConfigOutput";
const _CAl = "ClusterArn";
const _CAo = "ContextArn";
const _CAon = "ContextArns";
const _CAr = "CreatedAt";
const _CAre = "CreatedAfter";
const _CArea = "CreateAction";
const _CAreat = "CreateAlgorithm";
const _CAreate = "CreateApp";
const _CAreater = "CreateArtifact";
const _CB = "CreatedBy";
const _CBC = "CalculatedBaselineConstraints";
const _CBS = "CalculatedBaselineStatistics";
const _CBr = "CreatedBefore";
const _CC = "ClientConfig";
const _CCC = "CurrentCopyCount";
const _CCJ = "CreateCompilationJob";
const _CCJR = "CreateCompilationJobRequest";
const _CCJRr = "CreateCompilationJobResponse";
const _CCQ = "CreateComputeQuota";
const _CCQR = "CreateComputeQuotaRequest";
const _CCQRr = "CreateComputeQuotaResponse";
const _CCR = "ClusterCapacityRequirements";
const _CCRI = "CreateCodeRepositoryInput";
const _CCRO = "CreateCodeRepositoryOutput";
const _CCRr = "CreateClusterRequest";
const _CCRre = "CreateClusterResponse";
const _CCRrea = "CreateContextRequest";
const _CCRreat = "CreateContextResponse";
const _CCRreate = "CreateCodeRepository";
const _CCSC = "CreateClusterSchedulerConfig";
const _CCSCR = "CreateClusterSchedulerConfigRequest";
const _CCSCRr = "CreateClusterSchedulerConfigResponse";
const _CCSM = "ClarifyCheckStepMetadata";
const _CCT = "CsvContentTypes";
const _CCTH = "CaptureContentTypeHeader";
const _CCTP = "CfnCreateTemplateProvider";
const _CCh = "CheckpointConfig";
const _CCl = "ClusterConfig";
const _CCla = "ClarifyCheck";
const _CCo = "CompletionCriteria";
const _CCog = "CognitoConfig";
const _CCol = "CollectionConfiguration";
const _CColl = "CollectionConfigurations";
const _CColle = "CollectionConfig";
const _CCon = "ContainerConfig";
const _CCont = "ContentClassifiers";
const _CConte = "ContentColumn";
const _CCop = "CopyCount";
const _CCou = "CountryCode";
const _CCr = "CreateCluster";
const _CCre = "CreateContext";
const _CCu = "CurrentCount";
const _CCur = "CurrencyCode";
const _CD = "ContainerDefinition";
const _CDC = "ConnectedDeviceCount";
const _CDCo = "CoreDumpConfig";
const _CDF = "CreateDeviceFleet";
const _CDFR = "CreateDeviceFleetRequest";
const _CDL = "ContainerDefinitionList";
const _CDNL = "CandidateDefinitionNotebookLocation";
const _CDQJD = "CreateDataQualityJobDefinition";
const _CDQJDR = "CreateDataQualityJobDefinitionRequest";
const _CDQJDRr = "CreateDataQualityJobDefinitionResponse";
const _CDR = "CreateDomainRequest";
const _CDRr = "CreateDomainResponse";
const _CDT = "ConvergenceDetectedTime";
const _CDo = "ConvergenceDetected";
const _CDon = "ContentDigest";
const _CDr = "CreateDate";
const _CDre = "CreateDomain";
const _CE = "ConflictException";
const _CEAIC = "CodeEditorAppImageConfig";
const _CEAS = "CodeEditorAppSettings";
const _CEC = "ClarifyExplainerConfig";
const _CECI = "CreateEndpointConfigInput";
const _CECO = "CreateEndpointConfigOutput";
const _CECr = "CreateEndpointConfig";
const _CED = "ClusterEventDetail";
const _CEDP = "CreateEdgeDeploymentPlan";
const _CEDPR = "CreateEdgeDeploymentPlanRequest";
const _CEDPRr = "CreateEdgeDeploymentPlanResponse";
const _CEDS = "CreateEdgeDeploymentStage";
const _CEDSR = "CreateEdgeDeploymentStageRequest";
const _CEI = "CreateEndpointInput";
const _CEO = "CreateEndpointOutput";
const _CEPJ = "CreateEdgePackagingJob";
const _CEPJR = "CreateEdgePackagingJobRequest";
const _CER = "CreateExperimentRequest";
const _CERr = "CreateExperimentResponse";
const _CES = "ClusterEventSummary";
const _CESl = "ClusterEventSummaries";
const _CET = "CompilationEndTime";
const _CEV = "ContainerEnvironmentVariables";
const _CEVC = "ClusterEbsVolumeConfig";
const _CEo = "ContainerEntrypoint";
const _CEr = "CreateEndpoint";
const _CEre = "CreateExperiment";
const _CEu = "CustomerEni";
const _CEur = "CurrentEpoch";
const _CF = "ConfigFile";
const _CFD = "CreateFlowDefinition";
const _CFDR = "CreateFlowDefinitionRequest";
const _CFDRr = "CreateFlowDefinitionResponse";
const _CFG = "CreateFeatureGroup";
const _CFGR = "CreateFeatureGroupRequest";
const _CFGRr = "CreateFeatureGroupResponse";
const _CFLC = "ClusterFsxLustreConfig";
const _CFM = "CertifyForMarketplace";
const _CFOZC = "ClusterFsxOpenZfsConfig";
const _CFS = "CustomFileSystems";
const _CFSC = "CustomFileSystemConfigs";
const _CFSCu = "CustomFileSystemConfig";
const _CFSu = "CustomFileSystem";
const _CGC = "CandidateGenerationConfig";
const _CH = "ContainerHostname";
const _CHCPU = "CreateHubContentPresignedUrls";
const _CHCPUR = "CreateHubContentPresignedUrlsRequest";
const _CHCPURr = "CreateHubContentPresignedUrlsResponse";
const _CHCR = "CreateHubContentReference";
const _CHCRR = "CreateHubContentReferenceRequest";
const _CHCRRr = "CreateHubContentReferenceResponse";
const _CHPTJ = "CreateHyperParameterTuningJob";
const _CHPTJR = "CreateHyperParameterTuningJobRequest";
const _CHPTJRr = "CreateHyperParameterTuningJobResponse";
const _CHR = "CacheHitResult";
const _CHRr = "CreateHubRequest";
const _CHRre = "CreateHubResponse";
const _CHTU = "CreateHumanTaskUi";
const _CHTUR = "CreateHumanTaskUiRequest";
const _CHTURr = "CreateHumanTaskUiResponse";
const _CHr = "CreateHub";
const _CI = "CustomImages";
const _CIC = "ClarifyInferenceConfig";
const _CICI = "CreateInferenceComponentInput";
const _CICO = "CreateInferenceComponentOutput";
const _CICr = "CreateInferenceComponent";
const _CICu = "CurrentInstanceCount";
const _CIE = "CreateInferenceExperiment";
const _CIER = "CreateInferenceExperimentRequest";
const _CIERr = "CreateInferenceExperimentResponse";
const _CIGD = "ClusterInstanceGroupDetails";
const _CIGDL = "ClusterInstanceGroupDetailsList";
const _CIGS = "ClusterInstanceGroupSpecification";
const _CIGSl = "ClusterInstanceGroupSpecifications";
const _CII = "CurrentImageId";
const _CIP = "ClusterInstancePlacement";
const _CIR = "CreateImageRequest";
const _CIRJ = "CreateInferenceRecommendationsJob";
const _CIRJR = "CreateInferenceRecommendationsJobRequest";
const _CIRJRr = "CreateInferenceRecommendationsJobResponse";
const _CIRr = "CreateImageResponse";
const _CISC = "ClusterInstanceStorageConfigs";
const _CISCl = "ClusterInstanceStorageConfig";
const _CISD = "ClusterInstanceStatusDetails";
const _CIV = "CreateImageVersion";
const _CIVR = "CreateImageVersionRequest";
const _CIVRr = "CreateImageVersionResponse";
const _CIl = "ClientId";
const _CIlu = "ClusterId";
const _CIo = "ContainerImage";
const _CIom = "CommitId";
const _CIr = "CreateImage";
const _CIu = "CustomImage";
const _CJA = "CheckJobArn";
const _CJAo = "CompilationJobArn";
const _CJN = "CompilationJobName";
const _CJS = "CompilationJobSummary";
const _CJSo = "CompilationJobStatus";
const _CJSom = "CompilationJobSummaries";
const _CKC = "ClusterKubernetesConfig";
const _CKCD = "ClusterKubernetesConfigDetails";
const _CKCND = "ClusterKubernetesConfigNodeDetails";
const _CKT = "ClusterKubernetesTaint";
const _CKTl = "ClusterKubernetesTaints";
const _CL = "CurrentLabels";
const _CLCC = "ClusterLifeCycleConfig";
const _CLJ = "CreateLabelingJob";
const _CLJR = "CreateLabelingJobRequest";
const _CLJRr = "CreateLabelingJobResponse";
const _CM = "CandidateMetrics";
const _CMA = "CreateMlflowApp";
const _CMAR = "CreateMlflowAppRequest";
const _CMARr = "CreateMlflowAppResponse";
const _CMBJD = "CreateModelBiasJobDefinition";
const _CMBJDR = "CreateModelBiasJobDefinitionRequest";
const _CMBJDRr = "CreateModelBiasJobDefinitionResponse";
const _CMC = "CreateModelCard";
const _CMCEJ = "CreateModelCardExportJob";
const _CMCEJR = "CreateModelCardExportJobRequest";
const _CMCEJRr = "CreateModelCardExportJobResponse";
const _CMCR = "CreateModelCardRequest";
const _CMCRr = "CreateModelCardResponse";
const _CMD = "CognitoMemberDefinition";
const _CMEJD = "CreateModelExplainabilityJobDefinition";
const _CMEJDR = "CreateModelExplainabilityJobDefinitionRequest";
const _CMEJDRr = "CreateModelExplainabilityJobDefinitionResponse";
const _CMI = "CreateModelInput";
const _CMO = "CreateModelOutput";
const _CMP = "CustomerMetadataProperties";
const _CMPG = "CreateModelPackageGroup";
const _CMPGI = "CreateModelPackageGroupInput";
const _CMPGO = "CreateModelPackageGroupOutput";
const _CMPI = "CreateModelPackageInput";
const _CMPO = "CreateModelPackageOutput";
const _CMPTR = "CustomerMetadataPropertiesToRemove";
const _CMPr = "CreateModelPackage";
const _CMQJD = "CreateModelQualityJobDefinition";
const _CMQJDR = "CreateModelQualityJobDefinitionRequest";
const _CMQJDRr = "CreateModelQualityJobDefinitionResponse";
const _CMS = "CustomizedMetricSpecification";
const _CMSR = "CreateMonitoringScheduleRequest";
const _CMSRr = "CreateMonitoringScheduleResponse";
const _CMSr = "CreateMonitoringSchedule";
const _CMTS = "CreateMlflowTrackingServer";
const _CMTSR = "CreateMlflowTrackingServerRequest";
const _CMTSRr = "CreateMlflowTrackingServerResponse";
const _CMa = "CaptureMode";
const _CMl = "ClusterMetadata";
const _CMr = "CreateModel";
const _CN = "ChannelName";
const _CND = "ClusterNodeDetails";
const _CNE = "CandidateNameEquals";
const _CNI = "CreateNotebookInstance";
const _CNII = "CreateNotebookInstanceInput";
const _CNILC = "CreateNotebookInstanceLifecycleConfig";
const _CNILCI = "CreateNotebookInstanceLifecycleConfigInput";
const _CNILCO = "CreateNotebookInstanceLifecycleConfigOutput";
const _CNIO = "CreateNotebookInstanceOutput";
const _CNS = "ClusterNodeSummary";
const _CNSl = "ClusterNodeSummaries";
const _CNa = "CandidateName";
const _CNl = "ClusterName";
const _CNo = "CollectionName";
const _CNon = "ContextName";
const _CO = "CaptureOption";
const _COC = "CompleteOnConvergence";
const _COCo = "CompiledOutputConfig";
const _CODO = "ClusterOnDemandOptions";
const _COEC = "ClusterOrchestratorEksConfig";
const _COJ = "CreateOptimizationJob";
const _COJR = "CreateOptimizationJobRequest";
const _COJRr = "CreateOptimizationJobResponse";
const _COL = "CaptureOptionList";
const _COSC = "ClusterOrchestratorSlurmConfig";
const _COa = "CaptureOptions";
const _COl = "ClusterOrchestrator";
const _COo = "CompilerOptions";
const _CP = "CandidateProperties";
const _CPA = "CreatePartnerApp";
const _CPAPU = "CreatePartnerAppPresignedUrl";
const _CPAPUR = "CreatePartnerAppPresignedUrlRequest";
const _CPAPURr = "CreatePartnerAppPresignedUrlResponse";
const _CPAR = "CreatePartnerAppRequest";
const _CPARr = "CreatePartnerAppResponse";
const _CPDU = "CreatePresignedDomainUrl";
const _CPDUR = "CreatePresignedDomainUrlRequest";
const _CPDURr = "CreatePresignedDomainUrlResponse";
const _CPH = "CostPerHour";
const _CPI = "CreateProjectInput";
const _CPIo = "CostPerInference";
const _CPJ = "CreateProcessingJob";
const _CPJR = "CreateProcessingJobRequest";
const _CPJRr = "CreateProcessingJobResponse";
const _CPMAU = "CreatePresignedMlflowAppUrl";
const _CPMAUR = "CreatePresignedMlflowAppUrlRequest";
const _CPMAURr = "CreatePresignedMlflowAppUrlResponse";
const _CPMTSU = "CreatePresignedMlflowTrackingServerUrl";
const _CPMTSUR = "CreatePresignedMlflowTrackingServerUrlRequest";
const _CPMTSURr = "CreatePresignedMlflowTrackingServerUrlResponse";
const _CPNIU = "CreatePresignedNotebookInstanceUrl";
const _CPNIUI = "CreatePresignedNotebookInstanceUrlInput";
const _CPNIUO = "CreatePresignedNotebookInstanceUrlOutput";
const _CPO = "CreateProjectOutput";
const _CPR = "CategoricalParameterRange";
const _CPRS = "CategoricalParameterRangeSpecification";
const _CPRSo = "ContinuousParameterRangeSpecification";
const _CPRa = "CategoricalParameterRanges";
const _CPRo = "ContinuousParameterRange";
const _CPRon = "ContinuousParameterRanges";
const _CPRr = "CreatePipelineRequest";
const _CPRre = "CreatePipelineResponse";
const _CPUC = "CustomPosixUserConfig";
const _CPa = "CategoricalParameter";
const _CPat = "CategoricalParameters";
const _CPo = "CollectionParameters";
const _CPr = "CreatePipeline";
const _CPre = "CreateProject";
const _CQA = "ComputeQuotaArn";
const _CQC = "ComputeQuotaConfig";
const _CQI = "ComputeQuotaId";
const _CQR = "ComputeQuotaResources";
const _CQRC = "ComputeQuotaResourceConfig";
const _CQRCL = "ComputeQuotaResourceConfigList";
const _CQS = "ComputeQuotaSummary";
const _CQSL = "ComputeQuotaSummaryList";
const _CQSo = "ComputeQuotaSummaries";
const _CQT = "ComputeQuotaTarget";
const _CQV = "ComputeQuotaVersion";
const _CR = "CapacityReservation";
const _CRA = "CodeRepositoryArn";
const _CRAl = "ClusterRoleArn";
const _CRC = "CapacityReservationConfig";
const _CRIGD = "ClusterRestrictedInstanceGroupDetails";
const _CRIGDL = "ClusterRestrictedInstanceGroupDetailsList";
const _CRIGS = "ClusterRestrictedInstanceGroupSpecification";
const _CRIGSl = "ClusterRestrictedInstanceGroupSpecifications";
const _CRN = "CodeRepositoryName";
const _CRP = "CapacityReservationPreference";
const _CRR = "ComputeResourceRequirements";
const _CRS = "CodeRepositorySummary";
const _CRSL = "CodeRepositorySummaryList";
const _CRT = "ClientRequestToken";
const _CRa = "CapacityRequirements";
const _CRl = "ClusterRole";
const _CRo = "CodeRepository";
const _CRod = "CodeRepositories";
const _CRon = "ConstraintsResource";
const _CRons = "ConsumedResources";
const _CS = "ClientSecret";
const _CSA = "CandidateStepArn";
const _CSBC = "ClarifyShapBaselineConfig";
const _CSC = "CapacitySizeConfig";
const _CSCA = "ClusterSchedulerConfigArn";
const _CSCD = "ClusterSlurmConfigDetails";
const _CSCI = "ClusterSchedulerConfigId";
const _CSCP = "CfnStackCreateParameter";
const _CSCPf = "CfnStackCreateParameters";
const _CSCS = "ClusterSchedulerConfigSummary";
const _CSCSL = "ClusterSchedulerConfigSummaryList";
const _CSCSl = "ClusterSchedulerConfigSummaries";
const _CSCV = "ClusterSchedulerConfigVersion";
const _CSCl = "ClarifyShapConfig";
const _CSClu = "ClusterSlurmConfig";
const _CSCu = "CurrentServerlessConfig";
const _CSD = "CfnStackDetail";
const _CSHCTIS = "ContainerStartupHealthCheckTimeoutInSeconds";
const _CSIC = "ConfiguredSpareInstanceCount";
const _CSLC = "CreateStudioLifecycleConfig";
const _CSLCR = "CreateStudioLifecycleConfigRequest";
const _CSLCRr = "CreateStudioLifecycleConfigResponse";
const _CSM = "CallbackStepMetadata";
const _CSMo = "ConditionStepMetadata";
const _CSN = "CandidateStepName";
const _CSO = "ClusterSpotOptions";
const _CSP = "CfnStackParameter";
const _CSPf = "CfnStackParameters";
const _CSPu = "CurrentSamplingPercentage";
const _CSR = "CreateSpaceRequest";
const _CSRr = "CreateSpaceResponse";
const _CST = "CandidateStepType";
const _CSTo = "CompilationStartTime";
const _CSUP = "CfnStackUpdateParameter";
const _CSUPf = "CfnStackUpdateParameters";
const _CSa = "CandidateSteps";
const _CSan = "CandidateStatus";
const _CSana = "CanarySize";
const _CSap = "CapacitySize";
const _CSapt = "CaptureStatus";
const _CSh = "ChannelSpecification";
const _CSha = "ChannelSpecifications";
const _CSl = "ClusterSummary";
const _CSlu = "ClusterStatus";
const _CSlus = "ClusterSummaries";
const _CSo = "ContextSource";
const _CSon = "ContextSummary";
const _CSont = "ContextSummaries";
const _CSonte = "ContentSha256";
const _CSr = "CreateSpace";
const _CSu = "CurrentStep";
const _CT = "CreationTime";
const _CTA = "CreationTimeAfter";
const _CTB = "CreationTimeBefore";
const _CTC = "ClarifyTextConfig";
const _CTCR = "CreateTrialComponentRequest";
const _CTCRr = "CreateTrialComponentResponse";
const _CTCr = "CreateTrialComponent";
const _CTD = "CompilationTargetDevice";
const _CTJ = "CreateTrainingJob";
const _CTJR = "CreateTrainingJobRequest";
const _CTJRr = "CreateTrainingJobResponse";
const _CTJRre = "CreateTransformJobRequest";
const _CTJRrea = "CreateTransformJobResponse";
const _CTJr = "CreateTransformJob";
const _CTP = "CreateTemplateProvider";
const _CTPA = "CompilationTargetPlatformArch";
const _CTPAo = "CompilationTargetPlatformAccelerator";
const _CTPD = "CfnTemplateProviderDetail";
const _CTPL = "CreateTemplateProviderList";
const _CTPO = "CompilationTargetPlatformOs";
const _CTPR = "CreateTrainingPlanRequest";
const _CTPRr = "CreateTrainingPlanResponse";
const _CTPf = "CfnTemplateProvider";
const _CTPr = "CreateTrainingPlan";
const _CTR = "CreateTrialRequest";
const _CTRr = "CreateTrialResponse";
const _CTSC = "ClusterTieredStorageConfig";
const _CTa = "CallbackToken";
const _CTap = "CapacityType";
const _CTh = "ChannelType";
const _CThe = "CheckType";
const _CTl = "ClientToken";
const _CTo = "CompressionType";
const _CTol = "CollectionType";
const _CTom = "CompletionTime";
const _CTon = "ContentType";
const _CTont = "ContentTemplate";
const _CTonte = "ContextType";
const _CTr = "CreateTrial";
const _CTu = "CurrentTaints";
const _CTus = "CustomizationTechnique";
const _CU = "ConfigUri";
const _CUP = "CreateUserProfile";
const _CUPR = "CreateUserProfileRequest";
const _CUPRr = "CreateUserProfileResponse";
const _CUTP = "CfnUpdateTemplateProvider";
const _CUp = "CpuUtilization";
const _CVED = "CurrentVersionEolDate";
const _CW = "CurrentWeight";
const _CWR = "CreateWorkforceRequest";
const _CWRr = "CreateWorkforceResponse";
const _CWRre = "CreateWorkteamRequest";
const _CWRrea = "CreateWorkteamResponse";
const _CWr = "CreateWorkforce";
const _CWre = "CreateWorkteam";
const _Ca = "Catalog";
const _Cal = "Callback";
const _Can = "Candidates";
const _Ce = "Cents";
const _Ch = "Channel";
const _Ci = "Cidrs";
const _Cl = "Cluster";
const _Co = "Containers";
const _Cod = "Code";
const _Com = "Completed";
const _Con = "Content";
const _Cond = "Condition";
const _Cons = "Constraints";
const _Cont = "Container";
const _Cs = "Csv";
const _Cu = "Customized";
const _D = "Description";
const _DA = "DestinationArn";
const _DACR = "DisassociateAdditionalCodeRepositories";
const _DAET = "DataAnalysisEndTime";
const _DAI = "DeleteAlgorithmInput";
const _DAIC = "DeleteAppImageConfig";
const _DAICR = "DeleteAppImageConfigRequest";
const _DAICRe = "DescribeAppImageConfigRequest";
const _DAICRes = "DescribeAppImageConfigResponse";
const _DAICe = "DescribeAppImageConfig";
const _DAIe = "DescribeAlgorithmInput";
const _DAIo = "DomainAccountId";
const _DAMLJ = "DescribeAutoMLJob";
const _DAMLJR = "DescribeAutoMLJobRequest";
const _DAMLJRe = "DescribeAutoMLJobResponse";
const _DAMLJV = "DescribeAutoMLJobV2";
const _DAMLJVR = "DescribeAutoMLJobV2Request";
const _DAMLJVRe = "DescribeAutoMLJobV2Response";
const _DAO = "DescribeAlgorithmOutput";
const _DAR = "DeleteActionRequest";
const _DARe = "DeleteActionResponse";
const _DARel = "DeleteAppRequest";
const _DARele = "DeleteArtifactRequest";
const _DARelet = "DeleteArtifactResponse";
const _DARelete = "DeleteAssociationRequest";
const _DAReletes = "DeleteAssociationResponse";
const _DARes = "DescribeActionRequest";
const _DAResc = "DescribeActionResponse";
const _DARescr = "DescribeAppRequest";
const _DARescri = "DescribeAppResponse";
const _DARescrib = "DescribeArtifactRequest";
const _DARescribe = "DescribeArtifactResponse";
const _DAST = "DataAnalysisStartTime";
const _DAT = "DisassociateAcceleratorTypes";
const _DAa = "DatasetArn";
const _DAat = "DataAttributes";
const _DAe = "DeviceArn";
const _DAel = "DeleteAction";
const _DAele = "DeleteAlgorithm";
const _DAelet = "DeleteApp";
const _DAelete = "DeleteArtifact";
const _DAeletes = "DeleteAssociation";
const _DAes = "DescribeAction";
const _DAesc = "DescribeAlgorithm";
const _DAescr = "DescribeApp";
const _DAescri = "DescribeArtifact";
const _DAo = "DomainArn";
const _DC = "DeploymentConfig";
const _DCB = "DriftCheckBaselines";
const _DCBr = "DriftCheckBias";
const _DCC = "DataCaptureConfig";
const _DCCS = "DataCaptureConfigSummary";
const _DCCa = "DataCatalogConfig";
const _DCCat = "DataCacheConfig";
const _DCCe = "DesiredCopyCount";
const _DCDSU = "DataCapturedDestinationS3Uri";
const _DCE = "DriftCheckExplainability";
const _DCER = "DescribeClusterEventRequest";
const _DCERe = "DescribeClusterEventResponse";
const _DCEe = "DescribeClusterEvent";
const _DCJ = "DeleteCompilationJob";
const _DCJR = "DeleteCompilationJobRequest";
const _DCJRe = "DescribeCompilationJobRequest";
const _DCJRes = "DescribeCompilationJobResponse";
const _DCJe = "DescribeCompilationJob";
const _DCMDQ = "DriftCheckModelDataQuality";
const _DCMQ = "DriftCheckModelQuality";
const _DCN = "DescribeClusterNode";
const _DCNR = "DescribeClusterNodeRequest";
const _DCNRe = "DescribeClusterNodeResponse";
const _DCNV = "DetachClusterNodeVolume";
const _DCNVR = "DetachClusterNodeVolumeRequest";
const _DCNVRe = "DetachClusterNodeVolumeResponse";
const _DCP = "DependencyCopyPath";
const _DCQ = "DeleteComputeQuota";
const _DCQR = "DeleteComputeQuotaRequest";
const _DCQRe = "DescribeComputeQuotaRequest";
const _DCQRes = "DescribeComputeQuotaResponse";
const _DCQe = "DescribeComputeQuota";
const _DCR = "DefaultCodeRepository";
const _DCRC = "DefaultCodeRepositoryContains";
const _DCRI = "DeleteCodeRepositoryInput";
const _DCRIe = "DescribeCodeRepositoryInput";
const _DCRO = "DescribeCodeRepositoryOutput";
const _DCRe = "DeleteClusterRequest";
const _DCRel = "DeleteClusterResponse";
const _DCRele = "DeleteContextRequest";
const _DCRelet = "DeleteContextResponse";
const _DCRelete = "DeleteCodeRepository";
const _DCRes = "DescribeClusterRequest";
const _DCResc = "DescribeClusterResponse";
const _DCRescr = "DescribeContextRequest";
const _DCRescri = "DescribeContextResponse";
const _DCRescrib = "DescribeCodeRepository";
const _DCSC = "DeleteClusterSchedulerConfig";
const _DCSCR = "DeleteClusterSchedulerConfigRequest";
const _DCSCRe = "DescribeClusterSchedulerConfigRequest";
const _DCSCRes = "DescribeClusterSchedulerConfigResponse";
const _DCSCe = "DescribeClusterSchedulerConfig";
const _DCe = "DeploymentConfiguration";
const _DCel = "DeleteCluster";
const _DCele = "DeleteContext";
const _DCes = "DescribeCluster";
const _DCesc = "DescribeContext";
const _DD = "DatasetDefinition";
const _DDCR = "DisassociateDefaultCodeRepository";
const _DDF = "DeleteDeviceFleet";
const _DDFR = "DeleteDeviceFleetRequest";
const _DDFRe = "DescribeDeviceFleetRequest";
const _DDFRes = "DescribeDeviceFleetResponse";
const _DDFe = "DescribeDeviceFleet";
const _DDIC = "DerivedDataInputConfig";
const _DDIL = "DefaultDomainIdList";
const _DDQJD = "DeleteDataQualityJobDefinition";
const _DDQJDR = "DeleteDataQualityJobDefinitionRequest";
const _DDQJDRe = "DescribeDataQualityJobDefinitionRequest";
const _DDQJDRes = "DescribeDataQualityJobDefinitionResponse";
const _DDQJDe = "DescribeDataQualityJobDefinition";
const _DDR = "DeleteDomainRequest";
const _DDRe = "DeregisterDevicesRequest";
const _DDRes = "DescribeDeviceRequest";
const _DDResc = "DescribeDeviceResponse";
const _DDRescr = "DescribeDomainRequest";
const _DDRescri = "DescribeDomainResponse";
const _DDS = "DirectDeploySettings";
const _DDSM = "DeviceDeploymentStatusMessage";
const _DDSe = "DeviceDeploymentSummary";
const _DDSev = "DeviceDeploymentStatus";
const _DDSevi = "DeviceDeploymentSummaries";
const _DDT = "DataDistributionType";
const _DDe = "DeleteDomain";
const _DDer = "DeregisterDevices";
const _DDes = "DescribeDevice";
const _DDesc = "DescribeDomain";
const _DDo = "DomainDetails";
const _DE = "DeleteEndpoint";
const _DEC = "DeleteEndpointConfig";
const _DECI = "DeleteEndpointConfigInput";
const _DECIe = "DescribeEndpointConfigInput";
const _DECO = "DescribeEndpointConfigOutput";
const _DECe = "DescribeEndpointConfig";
const _DEDP = "DeleteEdgeDeploymentPlan";
const _DEDPR = "DeleteEdgeDeploymentPlanRequest";
const _DEDPRe = "DescribeEdgeDeploymentPlanRequest";
const _DEDPRes = "DescribeEdgeDeploymentPlanResponse";
const _DEDPe = "DescribeEdgeDeploymentPlan";
const _DEDS = "DeleteEdgeDeploymentStage";
const _DEDSR = "DeleteEdgeDeploymentStageRequest";
const _DEI = "DeleteEndpointInput";
const _DEIe = "DescribeEndpointInput";
const _DENL = "DataExplorationNotebookLocation";
const _DEO = "DescribeEndpointOutput";
const _DEPJ = "DescribeEdgePackagingJob";
const _DEPJR = "DescribeEdgePackagingJobRequest";
const _DEPJRe = "DescribeEdgePackagingJobResponse";
const _DER = "DeleteExperimentRequest";
const _DERA = "DomainExecutionRoleArn";
const _DERe = "DeleteExperimentResponse";
const _DERes = "DescribeExperimentRequest";
const _DEResc = "DescribeExperimentResponse";
const _DESS = "DefaultEbsStorageSettings";
const _DEVSIG = "DefaultEbsVolumeSizeInGb";
const _DEe = "DeleteExperiment";
const _DEes = "DescribeEndpoint";
const _DEesc = "DescribeExperiment";
const _DF = "DatasetFormat";
const _DFA = "DeviceFleetArn";
const _DFD = "DeleteFlowDefinition";
const _DFDI = "DefaultForDomainId";
const _DFDR = "DeleteFlowDefinitionRequest";
const _DFDRe = "DeleteFlowDefinitionResponse";
const _DFDRes = "DescribeFlowDefinitionRequest";
const _DFDResc = "DescribeFlowDefinitionResponse";
const _DFDe = "DescribeFlowDefinition";
const _DFG = "DeleteFeatureGroup";
const _DFGR = "DeleteFeatureGroupRequest";
const _DFGRe = "DescribeFeatureGroupRequest";
const _DFGRes = "DescribeFeatureGroupResponse";
const _DFGe = "DescribeFeatureGroup";
const _DFM = "DescribeFeatureMetadata";
const _DFMR = "DescribeFeatureMetadataRequest";
const _DFMRe = "DescribeFeatureMetadataResponse";
const _DFN = "DeviceFleetName";
const _DFNC = "DeviceFleetNameContains";
const _DFS = "DeviceFleetSummary";
const _DFSe = "DeviceFleetSummaries";
const _DG = "DefaultGid";
const _DGTC = "DisableGlueTableCreation";
const _DH = "DurationHours";
const _DHC = "DebugHookConfig";
const _DHCR = "DeleteHubContentRequest";
const _DHCRR = "DeleteHubContentReferenceRequest";
const _DHCRe = "DescribeHubContentRequest";
const _DHCRel = "DeleteHubContentReference";
const _DHCRes = "DescribeHubContentResponse";
const _DHCe = "DeleteHubContent";
const _DHCes = "DescribeHubContent";
const _DHPTJ = "DeleteHyperParameterTuningJob";
const _DHPTJR = "DeleteHyperParameterTuningJobRequest";
const _DHPTJRe = "DescribeHyperParameterTuningJobRequest";
const _DHPTJRes = "DescribeHyperParameterTuningJobResponse";
const _DHPTJe = "DescribeHyperParameterTuningJob";
const _DHR = "DeleteHubRequest";
const _DHRe = "DescribeHubRequest";
const _DHRes = "DescribeHubResponse";
const _DHTU = "DeleteHumanTaskUi";
const _DHTUR = "DeleteHumanTaskUiRequest";
const _DHTURe = "DeleteHumanTaskUiResponse";
const _DHTURes = "DescribeHumanTaskUiRequest";
const _DHTUResc = "DescribeHumanTaskUiResponse";
const _DHTUe = "DescribeHumanTaskUi";
const _DHe = "DeleteHub";
const _DHes = "DescribeHub";
const _DI = "DomainId";
const _DIA = "DirectInternetAccess";
const _DIC = "DesiredInstanceCount";
const _DICI = "DeleteInferenceComponentInput";
const _DICIe = "DescribeInferenceComponentInput";
const _DICO = "DescribeInferenceComponentOutput";
const _DICa = "DataInputConfig";
const _DICe = "DeleteInferenceComponent";
const _DICes = "DescribeInferenceComponent";
const _DIE = "DomainIdEquals";
const _DIER = "DeleteInferenceExperimentRequest";
const _DIERe = "DeleteInferenceExperimentResponse";
const _DIERes = "DescribeInferenceExperimentRequest";
const _DIEResc = "DescribeInferenceExperimentResponse";
const _DIEe = "DeleteInferenceExperiment";
const _DIEes = "DescribeInferenceExperiment";
const _DII = "DesiredImageId";
const _DIR = "DeleteImageRequest";
const _DIRJ = "DescribeInferenceRecommendationsJob";
const _DIRJR = "DescribeInferenceRecommendationsJobRequest";
const _DIRJRe = "DescribeInferenceRecommendationsJobResponse";
const _DIRe = "DeleteImageResponse";
const _DIRes = "DescribeImageRequest";
const _DIResc = "DescribeImageResponse";
const _DIS = "DurationInSeconds";
const _DIT = "DeploymentInstanceType";
const _DIV = "DeleteImageVersion";
const _DIVR = "DeleteImageVersionRequest";
const _DIVRe = "DeleteImageVersionResponse";
const _DIVRes = "DescribeImageVersionRequest";
const _DIVResc = "DescribeImageVersionResponse";
const _DIVe = "DescribeImageVersion";
const _DIe = "DeployedImage";
const _DIel = "DeleteImage";
const _DIep = "DeployedImages";
const _DIer = "DerivedInformation";
const _DIes = "DescribeImage";
const _DL = "DesiredLabels";
const _DLC = "DisassociateLifecycleConfig";
const _DLG = "DescribeLineageGroup";
const _DLGR = "DescribeLineageGroupRequest";
const _DLGRe = "DescribeLineageGroupResponse";
const _DLJ = "DescribeLabelingJob";
const _DLJR = "DescribeLabelingJobRequest";
const _DLJRe = "DescribeLabelingJobResponse";
const _DLU = "DefaultLandingUri";
const _DLo = "DomainList";
const _DM = "DurationMinutes";
const _DMA = "DeleteMlflowApp";
const _DMAR = "DeleteMlflowAppRequest";
const _DMARe = "DeleteMlflowAppResponse";
const _DMARes = "DescribeMlflowAppRequest";
const _DMAResc = "DescribeMlflowAppResponse";
const _DMAe = "DescribeMlflowApp";
const _DMBJD = "DeleteModelBiasJobDefinition";
const _DMBJDR = "DeleteModelBiasJobDefinitionRequest";
const _DMBJDRe = "DescribeModelBiasJobDefinitionRequest";
const _DMBJDRes = "DescribeModelBiasJobDefinitionResponse";
const _DMBJDe = "DescribeModelBiasJobDefinition";
const _DMC = "DeleteModelCard";
const _DMCEJ = "DescribeModelCardExportJob";
const _DMCEJR = "DescribeModelCardExportJobRequest";
const _DMCEJRe = "DescribeModelCardExportJobResponse";
const _DMCR = "DeleteModelCardRequest";
const _DMCRe = "DescribeModelCardRequest";
const _DMCRes = "DescribeModelCardResponse";
const _DMCe = "DescribeModelCard";
const _DMEJD = "DeleteModelExplainabilityJobDefinition";
const _DMEJDR = "DeleteModelExplainabilityJobDefinitionRequest";
const _DMEJDRe = "DescribeModelExplainabilityJobDefinitionRequest";
const _DMEJDRes = "DescribeModelExplainabilityJobDefinitionResponse";
const _DMEJDe = "DescribeModelExplainabilityJobDefinition";
const _DMI = "DeleteModelInput";
const _DMIe = "DescribeModelInput";
const _DMO = "DescribeModelOutput";
const _DMP = "DeleteModelPackage";
const _DMPG = "DeleteModelPackageGroup";
const _DMPGI = "DeleteModelPackageGroupInput";
const _DMPGIe = "DescribeModelPackageGroupInput";
const _DMPGO = "DescribeModelPackageGroupOutput";
const _DMPGP = "DeleteModelPackageGroupPolicy";
const _DMPGPI = "DeleteModelPackageGroupPolicyInput";
const _DMPGe = "DescribeModelPackageGroup";
const _DMPI = "DeleteModelPackageInput";
const _DMPIe = "DescribeModelPackageInput";
const _DMPO = "DescribeModelPackageOutput";
const _DMPe = "DescribeModelPackage";
const _DMQJD = "DeleteModelQualityJobDefinition";
const _DMQJDR = "DeleteModelQualityJobDefinitionRequest";
const _DMQJDRe = "DescribeModelQualityJobDefinitionRequest";
const _DMQJDRes = "DescribeModelQualityJobDefinitionResponse";
const _DMQJDe = "DescribeModelQualityJobDefinition";
const _DMS = "DeleteMonitoringSchedule";
const _DMSR = "DeleteMonitoringScheduleRequest";
const _DMSRe = "DescribeMonitoringScheduleRequest";
const _DMSRes = "DescribeMonitoringScheduleResponse";
const _DMSe = "DescribeMonitoringSchedule";
const _DMTS = "DeleteMlflowTrackingServer";
const _DMTSR = "DeleteMlflowTrackingServerRequest";
const _DMTSRe = "DeleteMlflowTrackingServerResponse";
const _DMTSRes = "DescribeMlflowTrackingServerRequest";
const _DMTSResc = "DescribeMlflowTrackingServerResponse";
const _DMTSe = "DescribeMlflowTrackingServer";
const _DMV = "DesiredModelVariants";
const _DMe = "DeleteModel";
const _DMes = "DescribeModel";
const _DN = "DestinationName";
const _DNC = "DeviceNameContains";
const _DNI = "DeleteNotebookInstance";
const _DNII = "DeleteNotebookInstanceInput";
const _DNIIe = "DescribeNotebookInstanceInput";
const _DNILC = "DeleteNotebookInstanceLifecycleConfig";
const _DNILCI = "DeleteNotebookInstanceLifecycleConfigInput";
const _DNILCIe = "DescribeNotebookInstanceLifecycleConfigInput";
const _DNILCO = "DescribeNotebookInstanceLifecycleConfigOutput";
const _DNILCe = "DescribeNotebookInstanceLifecycleConfig";
const _DNIO = "DescribeNotebookInstanceOutput";
const _DNIe = "DescribeNotebookInstance";
const _DNe = "DeviceName";
const _DNef = "DefinitionName";
const _DNev = "DeviceNames";
const _DNi = "DisplayName";
const _DNn = "DnsName";
const _DNo = "DomainName";
const _DOJ = "DeleteOptimizationJob";
const _DOJR = "DeleteOptimizationJobRequest";
const _DOJRe = "DescribeOptimizationJobRequest";
const _DOJRes = "DescribeOptimizationJobResponse";
const _DOJe = "DescribeOptimizationJob";
const _DOP = "DependencyOriginPath";
const _DP = "DataProcessing";
const _DPA = "DeletePartnerApp";
const _DPAR = "DeletePartnerAppRequest";
const _DPARe = "DeletePartnerAppResponse";
const _DPARes = "DescribePartnerAppRequest";
const _DPAResc = "DescribePartnerAppResponse";
const _DPAe = "DescribePartnerApp";
const _DPDFE = "DescribePipelineDefinitionForExecution";
const _DPDFER = "DescribePipelineDefinitionForExecutionRequest";
const _DPDFERe = "DescribePipelineDefinitionForExecutionResponse";
const _DPE = "DescribePipelineExecution";
const _DPER = "DescribePipelineExecutionRequest";
const _DPERe = "DescribePipelineExecutionResponse";
const _DPI = "DeleteProjectInput";
const _DPIe = "DescribeProjectInput";
const _DPJ = "DeleteProcessingJob";
const _DPJR = "DeleteProcessingJobRequest";
const _DPJRe = "DescribeProcessingJobRequest";
const _DPJRes = "DescribeProcessingJobResponse";
const _DPJe = "DescribeProcessingJob";
const _DPO = "DescribeProjectOutput";
const _DPR = "DeletePipelineRequest";
const _DPRe = "DeletePipelineResponse";
const _DPRes = "DescribePipelineRequest";
const _DPResc = "DescribePipelineResponse";
const _DPe = "DeleteProperties";
const _DPel = "DeletePipeline";
const _DPele = "DeleteProject";
const _DPes = "DescribePipeline";
const _DPesc = "DescribeProject";
const _DPi = "DirectoryPath";
const _DPis = "DisableProfiler";
const _DQAS = "DataQualityAppSpecification";
const _DQBC = "DataQualityBaselineConfig";
const _DQJI = "DataQualityJobInput";
const _DQJOC = "DataQualityJobOutputConfig";
const _DR = "DeploymentRecommendation";
const _DRC = "DebugRuleConfigurations";
const _DRCR = "DescribeReservedCapacityRequest";
const _DRCRe = "DescribeReservedCapacityResponse";
const _DRCe = "DebugRuleConfiguration";
const _DRCes = "DesiredRuntimeConfig";
const _DRCesc = "DescribeReservedCapacity";
const _DRES = "DebugRuleEvaluationStatus";
const _DRESe = "DebugRuleEvaluationStatuses";
const _DRS = "DefaultResourceSpec";
const _DRo = "DomainRegion";
const _DS = "DataSource";
const _DSC = "DataSplitConfig";
const _DSCa = "DataStorageConfig";
const _DSCe = "DeviceSelectionConfig";
const _DSCes = "DesiredServerlessConfig";
const _DSCy = "DynamicScalingConfiguration";
const _DSFU = "DomainSettingsForUpdate";
const _DSLC = "DeleteStudioLifecycleConfig";
const _DSLCR = "DeleteStudioLifecycleConfigRequest";
const _DSLCRe = "DescribeStudioLifecycleConfigRequest";
const _DSLCRes = "DescribeStudioLifecycleConfigResponse";
const _DSLCe = "DescribeStudioLifecycleConfig";
const _DSN = "DeployedStageName";
const _DSNa = "DataSourceName";
const _DSR = "DeleteSpaceRequest";
const _DSRe = "DescribeSpaceRequest";
const _DSRes = "DescribeSpaceResponse";
const _DSS = "DefaultSpaceSettings";
const _DSSP = "DisableSagemakerServicecatalogPortfolio";
const _DSSPI = "DisableSagemakerServicecatalogPortfolioInput";
const _DSSPO = "DisableSagemakerServicecatalogPortfolioOutput";
const _DSSS = "DefaultSpaceStorageSettings";
const _DSSSe = "DeploymentStageStatusSummary";
const _DSSSep = "DeploymentStageStatusSummaries";
const _DST = "DeploymentStartTime";
const _DSTe = "DeviceSubsetType";
const _DSU = "DestinationS3Uri";
const _DSV = "DocumentSchemaVersion";
const _DSW = "DescribeSubscribedWorkteam";
const _DSWR = "DescribeSubscribedWorkteamRequest";
const _DSWRe = "DescribeSubscribedWorkteamResponse";
const _DSa = "DatasetSource";
const _DSe = "DeploymentStage";
const _DSel = "DeleteSpace";
const _DSep = "DeploymentStatus";
const _DSepl = "DeploymentStages";
const _DSes = "DesiredState";
const _DSesc = "DescribeSpace";
const _DSev = "DeviceStats";
const _DSevi = "DeviceSummary";
const _DSevic = "DeviceSummaries";
const _DSo = "DomainSettings";
const _DSoc = "DockerSettings";
const _DT = "DestinationType";
const _DTA = "DatapointsToAlert";
const _DTC = "DeleteTrialComponent";
const _DTCR = "DeleteTrialComponentRequest";
const _DTCRe = "DeleteTrialComponentResponse";
const _DTCRes = "DescribeTrialComponentRequest";
const _DTCResc = "DescribeTrialComponentResponse";
const _DTCRi = "DisassociateTrialComponentRequest";
const _DTCRis = "DisassociateTrialComponentResponse";
const _DTCe = "DescribeTrialComponent";
const _DTCi = "DisassociateTrialComponent";
const _DTI = "DeleteTagsInput";
const _DTJ = "DeleteTrainingJob";
const _DTJR = "DeleteTrainingJobRequest";
const _DTJRe = "DescribeTrainingJobRequest";
const _DTJRes = "DescribeTrainingJobResponse";
const _DTJResc = "DescribeTransformJobRequest";
const _DTJRescr = "DescribeTransformJobResponse";
const _DTJe = "DescribeTrainingJob";
const _DTJes = "DescribeTransformJob";
const _DTO = "DeleteTagsOutput";
const _DTP = "DescribeTrainingPlan";
const _DTPR = "DescribeTrainingPlanRequest";
const _DTPRe = "DescribeTrainingPlanResponse";
const _DTR = "DeleteTrialRequest";
const _DTRe = "DeleteTrialResponse";
const _DTRes = "DescribeTrialRequest";
const _DTResc = "DescribeTrialResponse";
const _DTe = "DesiredTaints";
const _DTel = "DeleteTags";
const _DTele = "DeleteTrial";
const _DTes = "DescribeTrial";
const _DU = "DefaultUid";
const _DUP = "DeleteUserProfile";
const _DUPR = "DeleteUserProfileRequest";
const _DUPRe = "DescribeUserProfileRequest";
const _DUPRes = "DescribeUserProfileResponse";
const _DUPe = "DescribeUserProfile";
const _DUS = "DefaultUserSettings";
const _DUb = "DbUser";
const _DV = "DefaultValue";
const _DW = "DesiredWeight";
const _DWAC = "DesiredWeightAndCapacity";
const _DWACL = "DesiredWeightAndCapacityList";
const _DWACe = "DesiredWeightsAndCapacities";
const _DWR = "DeleteWorkforceRequest";
const _DWRe = "DeleteWorkforceResponse";
const _DWRel = "DeleteWorkteamRequest";
const _DWRele = "DeleteWorkteamResponse";
const _DWRes = "DescribeWorkforceRequest";
const _DWResc = "DescribeWorkforceResponse";
const _DWRescr = "DescribeWorkteamRequest";
const _DWRescri = "DescribeWorkteamResponse";
const _DWe = "DeleteWorkforce";
const _DWel = "DeleteWorkteam";
const _DWes = "DescribeWorkforce";
const _DWesc = "DescribeWorkteam";
const _Da = "Database";
const _De = "Device";
const _Des = "Destination";
const _Dev = "Devices";
const _Di = "Direction";
const _Dim = "Dimension";
const _Do = "Domain";
const _Dol = "Dollars";
const _Dom = "Domains";
const _E = "Environment";
const _EA = "EndpointArn";
const _EAMVU = "EnableAutoMinorVersionUpgrade";
const _EAv = "EvaluatorArn";
const _EAx = "ExperimentArn";
const _EAxp = "ExportArtifacts";
const _EC = "ErrorCode";
const _ECA = "EndpointConfigArn";
const _ECD = "EnvironmentConfigDetails";
const _ECN = "EndpointConfigName";
const _ECR = "Ec2CapacityReservation";
const _ECRI = "Ec2CapacityReservationId";
const _ECRL = "Ec2CapacityReservationsList";
const _ECRc = "Ec2CapacityReservations";
const _ECS = "EndpointConfigSummary";
const _ECSL = "EndpointConfigSummaryList";
const _ECSM = "EndpointConfigStepMetadata";
const _ECn = "EnvironmentConfig";
const _ECna = "EnableCapture";
const _ECnab = "EnableCaching";
const _ECnd = "EndpointConfiguration";
const _ECndp = "EndpointConfigs";
const _ECndpo = "EndpointConfig";
const _ECndpoi = "EndpointConfigurations";
const _ECx = "ExplainerConfig";
const _ECxp = "ExperimentConfig";
const _ED = "EventDetails";
const _EDA = "EnableDockerAccess";
const _EDC = "EdgeDeploymentConfig";
const _EDDIOS = "ExcludeDevicesDeployedInOtherStage";
const _EDF = "EdgeDeploymentFailed";
const _EDFIS = "EdgeDeploymentFailedInStage";
const _EDMC = "EdgeDeploymentModelConfig";
const _EDMCd = "EdgeDeploymentModelConfigs";
const _EDP = "EdgeDeploymentPending";
const _EDPA = "EdgeDeploymentPlanArn";
const _EDPIS = "EdgeDeploymentPendingInStage";
const _EDPN = "EdgeDeploymentPlanName";
const _EDPS = "EdgeDeploymentPlanSummary";
const _EDPSd = "EdgeDeploymentPlanSummaries";
const _EDS = "EdgeDeploymentSuccess";
const _EDSIS = "EdgeDeploymentSuccessInStage";
const _EDSM = "EdgeDeploymentStatusMessage";
const _EDSST = "EdgeDeploymentStageStartTime";
const _EDSd = "EdgeDeploymentStatus";
const _EE = "EfaEnis";
const _EEM = "EnableEnhancedMetrics";
const _EEn = "EnableExplanations";
const _EFA = "ExcludeFeaturesAttribute";
const _EFSFS = "EFSFileSystem";
const _EFSFSC = "EFSFileSystemConfig";
const _EI = "EventId";
const _EIC = "EndpointInputConfiguration";
const _EICTE = "EnableInterContainerTrafficEncryption";
const _EICn = "EnableInfraCheck";
const _EICnd = "EndpointInputConfigurations";
const _EIRA = "EnableIotRoleAlias";
const _EIS = "ExpiresInSeconds";
const _EISBI = "EnableIamSessionBasedIdentity";
const _EIn = "EndpointInput";
const _EInd = "EndpointInfo";
const _EInv = "EnvironmentId";
const _EIr = "ErrorInfo";
const _EM = "EndpointMetadata";
const _EMJ = "EnableMultipleJobs";
const _EMR = "EMR";
const _EMRSM = "EMRStepMetadata";
const _EMS = "EdgeModelStat";
const _EMST = "EnableManagedSpotTraining";
const _EMSd = "EdgeModelSummary";
const _EMSdg = "EdgeModelStats";
const _EMSdge = "EdgeModelSummaries";
const _EMd = "EdgeModel";
const _EMdg = "EdgeModels";
const _EMn = "EndpointMetrics";
const _EMr = "ErrorMessage";
const _EMv = "EventMetadata";
const _EMx = "ExitMessage";
const _EN = "EndpointName";
const _ENE = "EndpointNameEquals";
const _ENI = "EnableNetworkIsolation";
const _ENx = "ExperimentName";
const _EOC = "EdgeOutputConfig";
const _EOCn = "EndpointOutputConfiguration";
const _EOS = "EnableOnlineStore";
const _EP = "EndpointPerformances";
const _EPDO = "EdgePresetDeploymentOutput";
const _EPJA = "EdgePackagingJobArn";
const _EPJN = "EdgePackagingJobName";
const _EPJS = "EdgePackagingJobStatus";
const _EPJSM = "EdgePackagingJobStatusMessage";
const _EPJSd = "EdgePackagingJobSummary";
const _EPJSdg = "EdgePackagingJobSummaries";
const _EPR = "EnvironmentParameterRanges";
const _EPn = "EndpointPerformance";
const _EPnv = "EnvironmentParameter";
const _EPnvi = "EnvironmentParameters";
const _EPv = "EvaluationPeriod";
const _ER = "ErrorResponse";
const _ERA = "ExecutionRoleArn";
const _ERAE = "EksRoleAccessEntries";
const _ERARN = "ExecutionRoleARN";
const _ERAx = "ExecutionRoleArns";
const _ERD = "EnableRemoteDebug";
const _ERIC = "ExecutionRoleIdentityConfig";
const _ERVP = "ExcludeRetainedVariantProperties";
const _ERx = "ExecutionRole";
const _ES = "EndpointStatus";
const _ESCC = "EmrServerlessComputeConfig";
const _ESL = "EndpointSummaryList";
const _ESM = "EndpointStepMetadata";
const _ESMMTS = "EnableSageMakerMetricsTimeSeries";
const _ESS = "EmrServerlessSettings";
const _ESSMA = "EnableSSMAccess";
const _ESSP = "EnableSagemakerServicecatalogPortfolio";
const _ESSPI = "EnableSagemakerServicecatalogPortfolioInput";
const _ESSPO = "EnableSagemakerServicecatalogPortfolioOutput";
const _ESSb = "EbsStorageSettings";
const _ESTC = "EnableSessionTagChaining";
const _ESU = "ExpectedS3Url";
const _ESm = "EmrSettings";
const _ESn = "EndpointSummary";
const _ESx = "ExperimentSource";
const _ESxp = "ExperimentSummary";
const _ESxpe = "ExperimentSummaries";
const _ET = "ETag";
const _ETA = "EventTimeAfter";
const _ETB = "EventTimeBefore";
const _ETBn = "EndTimeBefore";
const _ETFN = "EventTimeFeatureName";
const _ETIPS = "EffectiveTrustedIdentityPropagationStatus";
const _ETO = "EndTimeOffset";
const _ETn = "EndTime";
const _ETr = "ErrorTopic";
const _ETv = "EventTime";
const _ETva = "EvaluationType";
const _EVC = "EbsVolumeConfig";
const _EVSIG = "EbsVolumeSizeInGb";
const _Ed = "Edge";
const _Edg = "Edges";
const _Ef = "Effect";
const _Ek = "Eks";
const _En = "Endpoint";
const _Ena = "Enabled";
const _End = "Endpoints";
const _Er = "Error";
const _Err = "Errors";
const _Ev = "Events";
const _Ex = "Explainability";
const _Exp = "Experiment";
const _F = "Failed";
const _FA = "FeaturesAttribute";
const _FALMA = "FinalActiveLearningModelArn";
const _FAMLJOM = "FinalAutoMLJobObjectiveMetric";
const _FAe = "FeatureAdditions";
const _FC = "FailedCount";
const _FD = "FeatureDefinitions";
const _FDA = "FlowDefinitionArn";
const _FDN = "FlowDefinitionName";
const _FDOC = "FlowDefinitionOutputConfig";
const _FDS = "FlowDefinitionStatus";
const _FDSl = "FlowDefinitionSummary";
const _FDSlo = "FlowDefinitionSummaries";
const _FDe = "FeatureDefinition";
const _FF = "ForecastFrequency";
const _FG = "FeatureGroup";
const _FGA = "FeatureGroupArn";
const _FGN = "FeatureGroupName";
const _FGS = "FeatureGroupStatus";
const _FGSE = "FeatureGroupStatusEquals";
const _FGSe = "FeatureGroupSummary";
const _FGSea = "FeatureGroupSummaries";
const _FH = "FeatureHeaders";
const _FHP = "FailureHandlingPolicy";
const _FHPTJOM = "FinalHyperParameterTuningJobObjectiveMetric";
const _FHo = "ForecastHorizon";
const _FI = "FlatInvocations";
const _FL = "FilterList";
const _FLC = "FsxLustreConfig";
const _FM = "FailureMessage";
const _FMDL = "FinalMetricDataList";
const _FMe = "FeatureMetadata";
const _FN = "FeatureName";
const _FNLI = "FailedNodeLogicalIds";
const _FNRE = "FailedNonRetryableError";
const _FOZC = "FsxOpenZfsConfig";
const _FP = "FeatureParameter";
const _FPA = "FeatureParameterAdditions";
const _FPe = "FeatureParameters";
const _FQ = "ForecastQuantiles";
const _FR = "FailureReason";
const _FS = "FileSource";
const _FSAM = "FileSystemAccessMode";
const _FSC = "FileSystemConfig";
const _FSDS = "FileSystemDataSource";
const _FSI = "FileSystemId";
const _FSLC = "FSxLustreConfig";
const _FSLFS = "FSxLustreFileSystem";
const _FSLFSC = "FSxLustreFileSystemConfig";
const _FSM = "FailStepMetadata";
const _FSO = "FeatureStoreOutput";
const _FSP = "FileSystemPath";
const _FSSU = "FeatureSpecificationS3Uri";
const _FST = "FileSystemType";
const _FSW = "FairShareWeight";
const _FSa = "FairShare";
const _FT = "FeatureTypes";
const _FTe = "FeatureType";
const _FTi = "FillingTransformations";
const _FV = "FrameworkVersion";
const _Fa = "Fail";
const _Fi = "Filter";
const _Fil = "Filters";
const _Fill = "Filling";
const _Fr = "Framework";
const _G = "Granularity";
const _GAN = "GroupingAttributeNames";
const _GAS = "GenerativeAiSettings";
const _GB = "GeneratedBy";
const _GC = "GitConfig";
const _GCDO = "GenerateCandidateDefinitionsOnly";
const _GCFU = "GitConfigForUpdate";
const _GDFR = "GetDeviceFleetReport";
const _GDFRR = "GetDeviceFleetReportRequest";
const _GDFRRe = "GetDeviceFleetReportResponse";
const _GII = "GenerateInferenceId";
const _GLGP = "GetLineageGroupPolicy";
const _GLGPR = "GetLineageGroupPolicyRequest";
const _GLGPRe = "GetLineageGroupPolicyResponse";
const _GMPGP = "GetModelPackageGroupPolicy";
const _GMPGPI = "GetModelPackageGroupPolicyInput";
const _GMPGPO = "GetModelPackageGroupPolicyOutput";
const _GP = "GroupPatterns";
const _GSCR = "GetScalingConfigurationRecommendation";
const _GSCRR = "GetScalingConfigurationRecommendationRequest";
const _GSCRRe = "GetScalingConfigurationRecommendationResponse";
const _GSS = "GetSearchSuggestions";
const _GSSPS = "GetSagemakerServicecatalogPortfolioStatus";
const _GSSPSI = "GetSagemakerServicecatalogPortfolioStatusInput";
const _GSSPSO = "GetSagemakerServicecatalogPortfolioStatusOutput";
const _GSSR = "GetSearchSuggestionsRequest";
const _GSSRe = "GetSearchSuggestionsResponse";
const _GTSI = "GroundTruthS3Input";
const _Gi = "Gid";
const _Gr = "Groups";
const _H = "Horovod";
const _HA = "HubArn";
const _HAC = "HubAccessConfig";
const _HAT = "HiddenAppTypes";
const _HC = "HolidayConfig";
const _HCA = "HubContentArn";
const _HCAo = "HolidayConfigAttributes";
const _HCD = "HubContentDocument";
const _HCDL = "HubContentDependencyList";
const _HCDN = "HubContentDisplayName";
const _HCDu = "HubContentDescription";
const _HCDub = "HubContentDependencies";
const _HCDubo = "HubContentDependency";
const _HCI = "HubContentInfo";
const _HCIL = "HubContentInfoList";
const _HCM = "HubContentMarkdown";
const _HCN = "HubContentName";
const _HCS = "HubContentStatus";
const _HCSK = "HubContentSearchKeywords";
const _HCSu = "HubContentSummaries";
const _HCT = "HubContentType";
const _HCV = "HubContentVersion";
const _HD = "HubDescription";
const _HDN = "HubDisplayName";
const _HEFS = "HomeEfsFileSystem";
const _HEFSI = "HomeEfsFileSystemId";
const _HEFSKKI = "HomeEfsFileSystemKmsKeyId";
const _HEFSU = "HomeEfsFileSystemUid";
const _HI = "HubInfo";
const _HIL = "HubInfoList";
const _HIT = "HiddenInstanceTypes";
const _HL = "HumanLabeled";
const _HLAC = "HumanLoopActivationConditions";
const _HLACC = "HumanLoopActivationConditionsConfig";
const _HLACu = "HumanLoopActivationConfig";
const _HLC = "HumanLoopConfig";
const _HLRS = "HumanLoopRequestSource";
const _HMT = "HiddenMlTools";
const _HN = "HubName";
const _HP = "HyperParameters";
const _HPAS = "HyperParameterAlgorithmSpecification";
const _HPR = "HyperParameterRanges";
const _HPS = "HyperParameterSpecification";
const _HPSy = "HyperParameterSpecifications";
const _HPTET = "HyperParameterTuningEndTime";
const _HPTIC = "HyperParameterTuningInstanceConfig";
const _HPTICy = "HyperParameterTuningInstanceConfigs";
const _HPTJ = "HyperParameterTuningJob";
const _HPTJA = "HyperParameterTuningJobArn";
const _HPTJC = "HyperParameterTuningJobConfig";
const _HPTJCD = "HyperParameterTuningJobCompletionDetails";
const _HPTJCR = "HyperParameterTuningJobConsumedResources";
const _HPTJD = "HyperParameterTrainingJobDefinition";
const _HPTJDy = "HyperParameterTrainingJobDefinitions";
const _HPTJN = "HyperParameterTuningJobName";
const _HPTJO = "HyperParameterTuningJobObjective";
const _HPTJOy = "HyperParameterTuningJobObjectives";
const _HPTJS = "HyperParameterTuningJobStatus";
const _HPTJSC = "HyperParameterTuningJobStrategyConfig";
const _HPTJSE = "HyperParameterTuningJobSearchEntity";
const _HPTJSy = "HyperParameterTrainingJobSummary";
const _HPTJSyp = "HyperParameterTuningJobSummary";
const _HPTJSype = "HyperParameterTuningJobSummaries";
const _HPTJSyper = "HyperParameterTrainingJobSummaries";
const _HPTJWSC = "HyperParameterTuningJobWarmStartConfig";
const _HPTRC = "HyperParameterTuningResourceConfig";
const _HPo = "HookParameters";
const _HS = "HubStatus";
const _HSC = "HyperbandStrategyConfig";
const _HSK = "HubSearchKeywords";
const _HSMI = "HiddenSageMakerImage";
const _HSMIVA = "HiddenSageMakerImageVersionAliases";
const _HSMIVAL = "HiddenSageMakerImageVersionAliasesList";
const _HSSC = "HubS3StorageConfig";
const _HSe = "HealthStatus";
const _HSu = "HubSummaries";
const _HTC = "HumanTaskConfig";
const _HTUA = "HumanTaskUiArn";
const _HTUN = "HumanTaskUiName";
const _HTUS = "HumanTaskUiStatus";
const _HTUSu = "HumanTaskUiSummary";
const _HTUSum = "HumanTaskUiSummaries";
const _He = "Header";
const _I = "Image";
const _IA = "InferenceAttribute";
const _IALMA = "InitialActiveLearningModelArn";
const _IAT = "IpAddressType";
const _IATR = "InputArtifactsToRemove";
const _IAU = "IncludeAvailableUpgrade";
const _IAV = "InferenceAmiVersion";
const _IAm = "ImageArn";
const _IAn = "InputArtifacts";
const _IAs = "IsActive";
const _IB = "InferenceBenchmark";
const _IC = "InferenceContainers";
const _ICA = "InferenceComponentArn";
const _ICC = "InfraCheckConfig";
const _ICCRR = "InferenceComponentComputeResourceRequirements";
const _ICCS = "InferenceComponentCapacitySize";
const _ICCSS = "InferenceComponentContainerSpecificationSummary";
const _ICCSn = "InferenceComponentContainerSpecification";
const _ICD = "InferenceContainerDefinitions";
const _ICDC = "InferenceComponentDeploymentConfig";
const _ICDCC = "InferenceComponentDataCacheConfig";
const _ICDCCS = "InferenceComponentDataCacheConfigSummary";
const _ICJC = "ImageClassificationJobConfig";
const _ICM = "InferenceComponentMetadata";
const _ICN = "InferenceComponentName";
const _ICRC = "InferenceComponentRuntimeConfig";
const _ICRCS = "InferenceComponentRuntimeConfigSummary";
const _ICRUP = "InferenceComponentRollingUpdatePolicy";
const _ICS = "InferenceComponentStatus";
const _ICSL = "InferenceComponentSummaryList";
const _ICSP = "InferenceComponentStartupParameters";
const _ICSS = "InferenceComponentSpecificationSummary";
const _ICSn = "InferenceComponentSpecification";
const _ICSnf = "InferenceComponentSummary";
const _ICm = "ImageConfig";
const _ICn = "InferenceConfig";
const _ICnf = "InferenceComponents";
const _ICnfe = "InferenceComponent";
const _ICnfr = "InfrastructureConfig";
const _ICnp = "InputConfig";
const _ICns = "InstanceCount";
const _ICnst = "InstanceConfigs";
const _ICs = "IsCheckpoint";
const _ID = "ImageDigest";
const _IDC = "InputDataConfig";
const _IE = "InferenceExperiments";
const _IEA = "InferenceExperimentArn";
const _IEC = "InferenceExecutionConfig";
const _IEDSC = "InferenceExperimentDataStorageConfig";
const _IEL = "InferenceExperimentList";
const _IES = "InferenceExperimentSchedule";
const _IESn = "InferenceExperimentSummary";
const _IET = "InvocationEndTime";
const _IEn = "IncludeEdges";
const _IF = "InputFilter";
const _IG = "InstanceGroups";
const _IGM = "InstanceGroupMetadata";
const _IGN = "InstanceGroupName";
const _IGNC = "InstanceGroupNameContains";
const _IGNn = "InstanceGroupNames";
const _IGS = "InstanceGroupScaling";
const _IGSM = "InstanceGroupScalingMetadata";
const _IGTD = "InstanceGroupsToDelete";
const _IGn = "InstanceGroup";
const _IHAC = "InferenceHubAccessConfig";
const _IHC = "ImportHubContent";
const _IHCR = "ImportHubContentRequest";
const _IHCRm = "ImportHubContentResponse";
const _II = "InstanceId";
const _IIAN = "ItemIdentifierAttributeName";
const _IIC = "InitialInstanceCount";
const _IIRI = "IncludeInferenceResponseIn";
const _IIa = "IamIdentity";
const _IIm = "ImageId";
const _IIn = "InferenceImage";
const _IM = "InputMode";
const _IMAP = "InstanceMemoryAllocationPercentage";
const _IMR = "InvocationsMaxRetries";
const _IMSC = "InstanceMetadataServiceConfiguration";
const _IMn = "InferenceMetrics";
const _IMns = "InstanceMetadata";
const _IN = "ImageName";
const _INLI = "IncludeNodeLogicalIds";
const _INOU = "InitialNumberOfUsers";
const _INn = "InputName";
const _IP = "InProgress";
const _IPC = "IamPolicyConstraints";
const _IPCn = "InstancePlacementConfig";
const _IPI = "InvocationsPerInstance";
const _IPOAS = "IdentityProviderOAuthSettings";
const _IPOASd = "IdentityProviderOAuthSetting";
const _IPR = "IntegerParameterRange";
const _IPRS = "IntegerParameterRangeSpecification";
const _IPRn = "IntegerParameterRanges";
const _IR = "IsRequired";
const _IRA = "IotRoleAlias";
const _IRJ = "InferenceRecommendationsJob";
const _IRJN = "InferenceRecommendationsJobName";
const _IRJS = "InferenceRecommendationsJobStep";
const _IRJSn = "InferenceRecommendationsJobSteps";
const _IRJn = "InferenceRecommendationsJobs";
const _IRS = "IdleResourceSharing";
const _IRn = "InferenceRecommendations";
const _IRnf = "InferenceRecommendation";
const _IS = "IdleSettings";
const _ISC = "InstanceStorageConfigs";
const _ISN = "InferenceSpecificationName";
const _ISP = "InitialSamplingPercentage";
const _ISS = "ImageScanStatuses";
const _IST = "InvocationStartTime";
const _ISm = "ImageStatus";
const _ISn = "InferenceSpecification";
const _ISns = "InstanceStatus";
const _IT = "InstanceType";
const _ITCB = "IncrementTargetCountBy";
const _ITIM = "IdleTimeoutInMinutes";
const _ITIS = "InvocationsTimeoutInSeconds";
const _ITN = "IotThingName";
const _ITn = "InfrastructureType";
const _ITs = "IsTunable";
const _IU = "ImageUri";
const _IUIC = "InUseInstanceCount";
const _IV = "ImageVersion";
const _IVA = "ImageVersionArn";
const _IVN = "ImageVersionNumber";
const _IVS = "ImageVersionStatus";
const _IVW = "InitialVariantWeight";
const _IVm = "ImageVersions";
const _Id = "Id";
const _Im = "Images";
const _In = "Input";
const _Ins = "Instance";
const _Is = "Issuer";
const _J = "Json";
const _JA = "JobArn";
const _JCT = "JsonContentTypes";
const _JD = "JobDescription";
const _JDA = "JobDefinitionArn";
const _JDIS = "JobDurationInSeconds";
const _JDN = "JobDefinitionName";
const _JDS = "JobDefinitionSummaries";
const _JLAIC = "JupyterLabAppImageConfig";
const _JLAS = "JupyterLabAppSettings";
const _JN = "JobName";
const _JR = "JobResources";
const _JRC = "JobReferenceCode";
const _JRCC = "JobReferenceCodeContains";
const _JS = "JoinSource";
const _JSAS = "JupyterServerAppSettings";
const _JT = "JobType";
const _JU = "JwksUri";
const _K = "Key";
const _KAPIS = "KeepAlivePeriodInSeconds";
const _KC = "KubernetesConfig";
const _KGAS = "KernelGatewayAppSettings";
const _KGIC = "KernelGatewayImageConfig";
const _KK = "KmsKey";
const _KKI = "KmsKeyId";
const _KS = "KendraSettings";
const _KSe = "KernelSpecs";
const _KSer = "KernelSpec";
const _L = "Language";
const _LA = "LabelAttribute";
const _LAI = "ListAlgorithmsInput";
const _LAIC = "ListAppImageConfigs";
const _LAICR = "ListAppImageConfigsRequest";
const _LAICRi = "ListAppImageConfigsResponse";
const _LAMLJ = "ListAutoMLJobs";
const _LAMLJR = "ListAutoMLJobsRequest";
const _LAMLJRi = "ListAutoMLJobsResponse";
const _LAN = "LabelAttributeName";
const _LAO = "ListAlgorithmsOutput";
const _LAR = "ListActionsRequest";
const _LARi = "ListActionsResponse";
const _LARis = "ListAliasesRequest";
const _LARist = "ListAliasesResponse";
const _LARistp = "ListAppsRequest";
const _LARistpp = "ListAppsResponse";
const _LARistr = "ListArtifactsRequest";
const _LARistrt = "ListArtifactsResponse";
const _LARists = "ListAssociationsRequest";
const _LARistss = "ListAssociationsResponse";
const _LAi = "ListActions";
const _LAis = "ListAlgorithms";
const _LAist = "ListAliases";
const _LAistp = "ListApps";
const _LAistr = "ListArtifacts";
const _LAists = "ListAssociations";
const _LBTJ = "LastBatchTransformJob";
const _LC = "LabelCounters";
const _LCA = "LifecycleConfigArns";
const _LCAi = "LifecycleConfigArn";
const _LCC = "LifeCycleConfig";
const _LCCSU = "LabelCategoryConfigS3Uri";
const _LCE = "ListClusterEvents";
const _LCER = "ListClusterEventsRequest";
const _LCERi = "ListClusterEventsResponse";
const _LCFAMLJ = "ListCandidatesForAutoMLJob";
const _LCFAMLJR = "ListCandidatesForAutoMLJobRequest";
const _LCFAMLJRi = "ListCandidatesForAutoMLJobResponse";
const _LCFW = "LabelCountersForWorkteam";
const _LCJ = "ListCompilationJobs";
const _LCJR = "ListCompilationJobsRequest";
const _LCJRi = "ListCompilationJobsResponse";
const _LCN = "LifecycleConfigName";
const _LCNR = "ListClusterNodesRequest";
const _LCNRi = "ListClusterNodesResponse";
const _LCNi = "ListClusterNodes";
const _LCQ = "ListComputeQuotas";
const _LCQR = "ListComputeQuotasRequest";
const _LCQRi = "ListComputeQuotasResponse";
const _LCR = "ListClustersRequest";
const _LCRI = "ListCodeRepositoriesInput";
const _LCRO = "ListCodeRepositoriesOutput";
const _LCRi = "ListClustersResponse";
const _LCRis = "ListContextsRequest";
const _LCRist = "ListContextsResponse";
const _LCRisto = "ListCodeRepositories";
const _LCSC = "ListClusterSchedulerConfigs";
const _LCSCR = "ListClusterSchedulerConfigsRequest";
const _LCSCRi = "ListClusterSchedulerConfigsResponse";
const _LCi = "ListClusters";
const _LCis = "ListContexts";
const _LD = "ListDevices";
const _LDC = "LastDeploymentConfig";
const _LDF = "ListDeviceFleets";
const _LDFR = "ListDeviceFleetsRequest";
const _LDFRi = "ListDeviceFleetsResponse";
const _LDQJD = "ListDataQualityJobDefinitions";
const _LDQJDR = "ListDataQualityJobDefinitionsRequest";
const _LDQJDRi = "ListDataQualityJobDefinitionsResponse";
const _LDR = "ListDevicesRequest";
const _LDRi = "ListDevicesResponse";
const _LDRis = "ListDomainsRequest";
const _LDRist = "ListDomainsResponse";
const _LDi = "ListDomains";
const _LE = "LogoutEndpoint";
const _LEC = "ListEndpointConfigs";
const _LECI = "ListEndpointConfigsInput";
const _LECO = "ListEndpointConfigsOutput";
const _LEDP = "ListEdgeDeploymentPlans";
const _LEDPR = "ListEdgeDeploymentPlansRequest";
const _LEDPRi = "ListEdgeDeploymentPlansResponse";
const _LEI = "ListEndpointsInput";
const _LEO = "ListEndpointsOutput";
const _LEPEA = "LastExecutedPipelineExecutionArn";
const _LEPEAa = "LastExecutionPipelineExecutionArn";
const _LEPEDN = "LastExecutedPipelineExecutionDisplayName";
const _LEPES = "LastExecutedPipelineExecutionStatus";
const _LEPJ = "ListEdgePackagingJobs";
const _LEPJR = "ListEdgePackagingJobsRequest";
const _LEPJRi = "ListEdgePackagingJobsResponse";
const _LER = "ListExperimentsRequest";
const _LERi = "ListExperimentsResponse";
const _LES = "LcsExecutionState";
const _LET = "LastExecutionTime";
const _LEi = "ListEndpoints";
const _LEis = "ListExperiments";
const _LFD = "ListFlowDefinitions";
const _LFDR = "ListFlowDefinitionsRequest";
const _LFDRi = "ListFlowDefinitionsResponse";
const _LFG = "ListFeatureGroups";
const _LFGR = "ListFeatureGroupsRequest";
const _LFGRi = "ListFeatureGroupsResponse";
const _LFP = "LogFilePath";
const _LGA = "LineageGroupArn";
const _LGN = "LineageGroupName";
const _LGS = "LineageGroupSummary";
const _LGSi = "LineageGroupSummaries";
const _LH = "LabelHeaders";
const _LHA = "LatestHeartbeatAfter";
const _LHC = "ListHubContents";
const _LHCR = "ListHubContentsRequest";
const _LHCRi = "ListHubContentsResponse";
const _LHCT = "LastHealthCheckTimestamp";
const _LHCV = "ListHubContentVersions";
const _LHCVR = "ListHubContentVersionsRequest";
const _LHCVRi = "ListHubContentVersionsResponse";
const _LHPTJ = "ListHyperParameterTuningJobs";
const _LHPTJR = "ListHyperParameterTuningJobsRequest";
const _LHPTJRi = "ListHyperParameterTuningJobsResponse";
const _LHR = "ListHubsRequest";
const _LHRi = "ListHubsResponse";
const _LHTU = "ListHumanTaskUis";
const _LHTUR = "ListHumanTaskUisRequest";
const _LHTURi = "ListHumanTaskUisResponse";
const _LHa = "LatestHeartbeat";
const _LHi = "ListHubs";
const _LI = "LabelIndex";
const _LIC = "ListInferenceComponents";
const _LICI = "ListInferenceComponentsInput";
const _LICO = "ListInferenceComponentsOutput";
const _LIE = "ListInferenceExperiments";
const _LIER = "ListInferenceExperimentsRequest";
const _LIERi = "ListInferenceExperimentsResponse";
const _LIR = "ListImagesRequest";
const _LIRJ = "ListInferenceRecommendationsJobs";
const _LIRJR = "ListInferenceRecommendationsJobsRequest";
const _LIRJRi = "ListInferenceRecommendationsJobsResponse";
const _LIRJS = "ListInferenceRecommendationsJobSteps";
const _LIRJSR = "ListInferenceRecommendationsJobStepsRequest";
const _LIRJSRi = "ListInferenceRecommendationsJobStepsResponse";
const _LIRi = "ListImagesResponse";
const _LIV = "ListImageVersions";
const _LIVR = "ListImageVersionsRequest";
const _LIVRi = "ListImageVersionsResponse";
const _LIa = "LatestInference";
const _LIi = "ListingId";
const _LIis = "ListImages";
const _LJA = "LabelingJobArn";
const _LJAC = "LabelingJobAlgorithmsConfig";
const _LJASA = "LabelingJobAlgorithmSpecificationArn";
const _LJDA = "LabelingJobDataAttributes";
const _LJDS = "LabelingJobDataSource";
const _LJFWS = "LabelingJobForWorkteamSummary";
const _LJFWSL = "LabelingJobForWorkteamSummaryList";
const _LJIC = "LabelingJobInputConfig";
const _LJN = "LabelingJobName";
const _LJO = "LabelingJobOutput";
const _LJOC = "LabelingJobOutputConfig";
const _LJRC = "LabelingJobResourceConfig";
const _LJS = "LabelingJobStatus";
const _LJSC = "LabelingJobStoppingConditions";
const _LJSDS = "LabelingJobS3DataSource";
const _LJSDSa = "LabelingJobSnsDataSource";
const _LJSL = "LabelingJobSummaryList";
const _LJSa = "LabelingJobSummary";
const _LLG = "ListLineageGroups";
const _LLGR = "ListLineageGroupsRequest";
const _LLGRi = "ListLineageGroupsResponse";
const _LLJ = "ListLabelingJobs";
const _LLJFW = "ListLabelingJobsForWorkteam";
const _LLJFWR = "ListLabelingJobsForWorkteamRequest";
const _LLJFWRi = "ListLabelingJobsForWorkteamResponse";
const _LLJR = "ListLabelingJobsRequest";
const _LLJRi = "ListLabelingJobsResponse";
const _LM = "LifecycleManagement";
const _LMA = "LastModifiedAt";
const _LMAH = "ListMonitoringAlertHistory";
const _LMAHR = "ListMonitoringAlertHistoryRequest";
const _LMAHRi = "ListMonitoringAlertHistoryResponse";
const _LMAR = "ListMlflowAppsRequest";
const _LMARi = "ListMlflowAppsResponse";
const _LMARis = "ListMonitoringAlertsRequest";
const _LMARist = "ListMonitoringAlertsResponse";
const _LMAi = "ListMlflowApps";
const _LMAis = "ListMonitoringAlerts";
const _LMB = "LastModifiedBy";
const _LMBJD = "ListModelBiasJobDefinitions";
const _LMBJDR = "ListModelBiasJobDefinitionsRequest";
const _LMBJDRi = "ListModelBiasJobDefinitionsResponse";
const _LMC = "ListModelCards";
const _LMCEJ = "ListModelCardExportJobs";
const _LMCEJR = "ListModelCardExportJobsRequest";
const _LMCEJRi = "ListModelCardExportJobsResponse";
const _LMCR = "ListModelCardsRequest";
const _LMCRi = "ListModelCardsResponse";
const _LMCV = "ListModelCardVersions";
const _LMCVR = "ListModelCardVersionsRequest";
const _LMCVRi = "ListModelCardVersionsResponse";
const _LME = "ListMonitoringExecutions";
const _LMEJD = "ListModelExplainabilityJobDefinitions";
const _LMEJDR = "ListModelExplainabilityJobDefinitionsRequest";
const _LMEJDRi = "ListModelExplainabilityJobDefinitionsResponse";
const _LMER = "ListMonitoringExecutionsRequest";
const _LMERi = "ListMonitoringExecutionsResponse";
const _LMES = "LastMonitoringExecutionSummary";
const _LMI = "ListModelsInput";
const _LMM = "ListModelMetadata";
const _LMMR = "ListModelMetadataRequest";
const _LMMRi = "ListModelMetadataResponse";
const _LMO = "ListModelsOutput";
const _LMP = "ListModelPackages";
const _LMPG = "ListModelPackageGroups";
const _LMPGI = "ListModelPackageGroupsInput";
const _LMPGO = "ListModelPackageGroupsOutput";
const _LMPI = "ListModelPackagesInput";
const _LMPO = "ListModelPackagesOutput";
const _LMQJD = "ListModelQualityJobDefinitions";
const _LMQJDR = "ListModelQualityJobDefinitionsRequest";
const _LMQJDRi = "ListModelQualityJobDefinitionsResponse";
const _LMS = "ListMonitoringSchedules";
const _LMSR = "ListMonitoringSchedulesRequest";
const _LMSRi = "ListMonitoringSchedulesResponse";
const _LMT = "LastModifiedTime";
const _LMTA = "LastModifiedTimeAfter";
const _LMTB = "LastModifiedTimeBefore";
const _LMTS = "ListMlflowTrackingServers";
const _LMTSR = "ListMlflowTrackingServersRequest";
const _LMTSRi = "ListMlflowTrackingServersResponse";
const _LMi = "LineageMetadata";
const _LMis = "ListModels";
const _LNI = "ListNotebookInstances";
const _LNII = "ListNotebookInstancesInput";
const _LNILC = "ListNotebookInstanceLifecycleConfigs";
const _LNILCI = "ListNotebookInstanceLifecycleConfigsInput";
const _LNILCO = "ListNotebookInstanceLifecycleConfigsOutput";
const _LNIO = "ListNotebookInstancesOutput";
const _LOJ = "ListOptimizationJobs";
const _LOJR = "ListOptimizationJobsRequest";
const _LOJRi = "ListOptimizationJobsResponse";
const _LP = "LocalPath";
const _LPA = "ListPartnerApps";
const _LPAR = "ListPartnerAppsRequest";
const _LPARi = "ListPartnerAppsResponse";
const _LPE = "ListPipelineExecutions";
const _LPER = "ListPipelineExecutionsRequest";
const _LPERi = "ListPipelineExecutionsResponse";
const _LPES = "ListPipelineExecutionSteps";
const _LPESR = "ListPipelineExecutionStepsRequest";
const _LPESRi = "ListPipelineExecutionStepsResponse";
const _LPI = "ListProjectsInput";
const _LPJ = "ListProcessingJobs";
const _LPJR = "ListProcessingJobsRequest";
const _LPJRi = "ListProcessingJobsResponse";
const _LPO = "ListProjectsOutput";
const _LPPFE = "ListPipelineParametersForExecution";
const _LPPFER = "ListPipelineParametersForExecutionRequest";
const _LPPFERi = "ListPipelineParametersForExecutionResponse";
const _LPR = "ListPipelinesRequest";
const _LPRi = "ListPipelinesResponse";
const _LPV = "ListPipelineVersions";
const _LPVR = "ListPipelineVersionsRequest";
const _LPVRi = "ListPipelineVersionsResponse";
const _LPi = "ListPipelines";
const _LPis = "ListProjects";
const _LRC = "ListResourceCatalogs";
const _LRCR = "ListResourceCatalogsRequest";
const _LRCRi = "ListResourceCatalogsResponse";
const _LRT = "LastRunTime";
const _LS = "ListSpaces";
const _LSD = "ListStageDevices";
const _LSDR = "ListStageDevicesRequest";
const _LSDRi = "ListStageDevicesResponse";
const _LSLC = "ListStudioLifecycleConfigs";
const _LSLCR = "ListStudioLifecycleConfigsRequest";
const _LSLCRi = "ListStudioLifecycleConfigsResponse";
const _LSM = "LambdaStepMetadata";
const _LSR = "ListSpacesRequest";
const _LSRi = "ListSpacesResponse";
const _LSS = "LinearStepSize";
const _LST = "LatestSampleTime";
const _LSUT = "LastSoftwareUpdateTime";
const _LSW = "ListSubscribedWorkteams";
const _LSWR = "ListSubscribedWorkteamsRequest";
const _LSWRi = "ListSubscribedWorkteamsResponse";
const _LT = "LaunchTime";
const _LTC = "ListTrialComponents";
const _LTCR = "ListTrialComponentsRequest";
const _LTCRi = "ListTrialComponentsResponse";
const _LTI = "ListTagsInput";
const _LTJ = "ListTrainingJobs";
const _LTJFHPTJ = "ListTrainingJobsForHyperParameterTuningJob";
const _LTJFHPTJR = "ListTrainingJobsForHyperParameterTuningJobRequest";
const _LTJFHPTJRi = "ListTrainingJobsForHyperParameterTuningJobResponse";
const _LTJR = "ListTrainingJobsRequest";
const _LTJRi = "ListTrainingJobsResponse";
const _LTJRis = "ListTransformJobsRequest";
const _LTJRist = "ListTransformJobsResponse";
const _LTJi = "ListTransformJobs";
const _LTO = "ListTagsOutput";
const _LTP = "ListTrainingPlans";
const _LTPR = "ListTrainingPlansRequest";
const _LTPRi = "ListTrainingPlansResponse";
const _LTR = "ListTrialsRequest";
const _LTRi = "ListTrialsResponse";
const _LTi = "LineageTypes";
const _LTin = "LineageType";
const _LTis = "ListTags";
const _LTist = "ListTrials";
const _LU = "LandingUri";
const _LUAT = "LastUserActivityTimestamp";
const _LUD = "LastUpdatedDate";
const _LUP = "ListUserProfiles";
const _LUPR = "ListUserProfilesRequest";
const _LUPRi = "ListUserProfilesResponse";
const _LUS = "LastUpdateStatus";
const _LUSBRC = "ListUltraServersByReservedCapacity";
const _LUSBRCR = "ListUltraServersByReservedCapacityRequest";
const _LUSBRCRi = "ListUltraServersByReservedCapacityResponse";
const _LW = "ListWorkforces";
const _LWR = "ListWorkforcesRequest";
const _LWRi = "ListWorkforcesResponse";
const _LWRis = "ListWorkteamsRequest";
const _LWRist = "ListWorkteamsResponse";
const _LWi = "ListWorkteams";
const _La = "Labels";
const _Lam = "Lambda";
const _Las = "Last";
const _Li = "Line";
const _Lin = "Lineage";
const _M = "Message";
const _MA = "ModelArn";
const _MAA = "MonitoringAlertActions";
const _MAC = "ModelAccessConfig";
const _MAH = "MonitoringAlertHistory";
const _MAHL = "MonitoringAlertHistoryList";
const _MAHS = "MonitoringAlertHistorySummary";
const _MAMLJRIS = "MaxAutoMLJobRuntimeInSeconds";
const _MAN = "MonitoringAlertName";
const _MAS = "ModelApprovalStatus";
const _MASL = "MonitoringAlertSummaryList";
const _MASl = "MlflowAppSummary";
const _MASlf = "MlflowAppSummaries";
const _MASo = "MonitoringAlertSummaries";
const _MASon = "MonitoringAlertSummary";
const _MASoni = "MonitoringAppSpecification";
const _MAo = "ModelArtifacts";
const _MAod = "ModelArtifact";
const _MAodi = "ModifiedAfter";
const _MB = "ModifiedBefore";
const _MBAS = "ModelBiasAppSpecification";
const _MBBC = "ModelBiasBaselineConfig";
const _MBC = "MonitoringBaselineConfig";
const _MBJI = "ModelBiasJobInput";
const _MBJOC = "ModelBiasJobOutputConfig";
const _MBS = "MaximumBatchSize";
const _MC = "MaxCandidates";
const _MCA = "ModelCardArn";
const _MCC = "ModelCardContent";
const _MCCo = "ModelClientConfig";
const _MCCod = "ModelCompilationConfig";
const _MCCon = "MonitoringClusterConfig";
const _MCDF = "MonitoringCsvDatasetFormat";
const _MCEA = "ModelCardExportArtifacts";
const _MCEJA = "ModelCardExportJobArn";
const _MCEJN = "ModelCardExportJobName";
const _MCEJNC = "ModelCardExportJobNameContains";
const _MCEJS = "ModelCardExportJobSummaries";
const _MCEJSL = "ModelCardExportJobSummaryList";
const _MCEJSo = "ModelCardExportJobSummary";
const _MCEOC = "ModelCardExportOutputConfig";
const _MCIPI = "MaxConcurrentInvocationsPerInstance";
const _MCN = "ModelCardName";
const _MCPS = "ModelCardProcessingStatus";
const _MCR = "MonitoringConstraintsResource";
const _MCS = "ModelCardStatus";
const _MCSC = "ModelCardSecurityConfig";
const _MCSL = "ModelCardSummaryList";
const _MCSo = "ModelCardSummaries";
const _MCSod = "ModelCardSummary";
const _MCSode = "ModelCacheSetting";
const _MCT = "MaxConcurrentTransforms";
const _MCTC = "MaxConcurrentTaskCount";
const _MCV = "ModelCardVersion";
const _MCVS = "ModelCardVersionSummary";
const _MCVSL = "ModelCardVersionSummaryList";
const _MCa = "MaintenanceConfig";
const _MCax = "MaxCapacity";
const _MCaxo = "MaxConcurrency";
const _MCe = "MetricsConfig";
const _MCi = "MinCount";
const _MCin = "MinCapacity";
const _MCl = "MlflowConfig";
const _MCo = "ModelConfigs";
const _MCod = "ModelCard";
const _MCode = "ModelConfiguration";
const _MD = "MetricDefinitions";
const _MDC = "ModelDeployConfig";
const _MDDTIS = "ModelDataDownloadTimeoutInSeconds";
const _MDE = "ModelDashboardEndpoint";
const _MDET = "ModelDataETag";
const _MDEo = "ModelDashboardEndpoints";
const _MDF = "MonitoringDatasetFormat";
const _MDI = "ModelDashboardIndicator";
const _MDIA = "ModelDashboardIndicatorAction";
const _MDL = "MetricDataList";
const _MDLe = "MetricDefinitionList";
const _MDM = "ModelDashboardModel";
const _MDMC = "ModelDashboardModelCard";
const _MDMS = "ModelDashboardMonitoringSchedule";
const _MDMSo = "ModelDashboardMonitoringSchedules";
const _MDQ = "ModelDataQuality";
const _MDR = "ModelDeployResult";
const _MDS = "ModelDataSource";
const _MDU = "ModelDataUrl";
const _MDa = "MaxDepth";
const _MDar = "MarketplaceDescription";
const _MDe = "MemberDefinitions";
const _MDem = "MemberDefinition";
const _MDet = "MetricData";
const _MDetr = "MetricDatum";
const _MDetri = "MetricDefinition";
const _MDl = "MlflowDetails";
const _MDo = "ModelDigests";
const _ME = "ManifestEtag";
const _MEAS = "ModelExplainabilityAppSpecification";
const _MEBC = "ModelExplainabilityBaselineConfig";
const _MEI = "MlflowExperimentId";
const _MEJI = "ModelExplainabilityJobInput";
const _MEJOC = "ModelExplainabilityJobOutputConfig";
const _MEN = "MlflowExperimentName";
const _MES = "MonitoringExecutionSummaries";
const _MESL = "MonitoringExecutionSummaryList";
const _MESo = "MonitoringExecutionSummary";
const _MESon = "MonitoringExecutionStatus";
const _METIS = "MaximumExecutionTimeoutInSeconds";
const _MEVSIG = "MaximumEbsVolumeSizeInGb";
const _MEa = "MaxEpoch";
const _MGTSI = "MonitoringGroundTruthS3Input";
const _MH = "ModelHandle";
const _MHLOC = "MaxHumanLabeledObjectCount";
const _MI = "ModelInsights";
const _MIC = "MinInstanceCount";
const _MICa = "MaxInstanceCount";
const _MICo = "ModelInfrastructureConfig";
const _MIGB = "MemoryInGiB";
const _MIMSV = "MinimumInstanceMetadataServiceVersion";
const _MIPM = "MinInvocationsPerMinute";
const _MIPMa = "MaxInvocationsPerMinute";
const _MIS = "ManagedInstanceScaling";
const _MITIM = "MinIdleTimeoutInMinutes";
const _MITIMa = "MaxIdleTimeoutInMinutes";
const _MIa = "MaxInvocations";
const _MIo = "ModelId";
const _MIod = "ModelInput";
const _MIon = "MonitoringInput";
const _MIoni = "MonitoringInputs";
const _MJD = "MonitoringJobDefinition";
const _MJDA = "MonitoringJobDefinitionArn";
const _MJDF = "MonitoringJsonDatasetFormat";
const _MJDN = "MonitoringJobDefinitionName";
const _MJDS = "MonitoringJobDefinitionSummary";
const _MJDSL = "MonitoringJobDefinitionSummaryList";
const _ML = "ModelLatency";
const _MLC = "ModelLifeCycle";
const _MLCf = "MLflowConfig";
const _MLCfl = "MLflowConfiguration";
const _MLF = "MLFramework";
const _MLT = "ModelLatencyThreshold";
const _MLTo = "ModelLatencyThresholds";
const _MLa = "MachineLabeled";
const _MM = "ModelMetrics";
const _MMC = "MultiModelConfig";
const _MMF = "ModelMetadataFilter";
const _MMFo = "ModelMetadataFilters";
const _MMRIM = "MinMemoryRequiredInMb";
const _MMRIMa = "MaxMemoryRequiredInMb";
const _MMS = "ModelMetadataSummaries";
const _MMSE = "ModelMetadataSearchExpression";
const _MMSo = "ModelMetadataSummary";
const _MMa = "MaxModels";
const _MN = "MetricName";
const _MNC = "ModelNameContains";
const _MNCo = "MonitoringNetworkConfig";
const _MNE = "ModelNameEquals";
const _MNOT = "MaxNumberOfTests";
const _MNOTJ = "MaxNumberOfTrainingJobs";
const _MNOTJNI = "MaxNumberOfTrainingJobsNotImproving";
const _MNo = "MountName";
const _MNod = "ModelName";
const _MO = "MonitoringOutput";
const _MOC = "MonitoringOutputConfig";
const _MOo = "MonitoringOutputs";
const _MP = "MountPath";
const _MPA = "ModelPackageArn";
const _MPAL = "ModelPackageArnList";
const _MPC = "ModelPackageConfig";
const _MPCD = "ModelPackageContainerDefinition";
const _MPCDL = "ModelPackageContainerDefinitionList";
const _MPD = "ModelPackageDescription";
const _MPDF = "MonitoringParquetDatasetFormat";
const _MPES = "MaxParallelExecutionSteps";
const _MPFIS = "MetricPublishFrequencyInSeconds";
const _MPG = "ModelPackageGroup";
const _MPGA = "ModelPackageGroupArn";
const _MPGD = "ModelPackageGroupDescription";
const _MPGN = "ModelPackageGroupName";
const _MPGS = "ModelPackageGroupStatus";
const _MPGSL = "ModelPackageGroupSummaryList";
const _MPGSo = "ModelPackageGroupSummary";
const _MPIMB = "MaxPayloadInMB";
const _MPMC = "ModelPackageModelCard";
const _MPN = "ModelPackageName";
const _MPOIDL = "MaxPercentageOfInputDatasetLabeled";
const _MPOT = "MaxParallelOfTests";
const _MPRT = "ModelPackageRegistrationType";
const _MPS = "ModelPackageSummaries";
const _MPSC = "ModelPackageSecurityConfig";
const _MPSD = "ModelPackageStatusDetails";
const _MPSI = "ModelPackageStatusItem";
const _MPSIL = "ModelPackageStatusItemList";
const _MPSL = "ModelPackageSummaryList";
const _MPSo = "ModelPackageStatus";
const _MPSod = "ModelPackageSummary";
const _MPT = "ModelPackageType";
const _MPTIS = "MaxPendingTimeInSeconds";
const _MPTJ = "MaxParallelTrainingJobs";
const _MPV = "ModelPackageVersion";
const _MPVA = "ModelPackageVersionArn";
const _MPVAE = "ModelPackageVersionArnEquals";
const _MPVP = "ModelPackageValidationProfile";
const _MPVPo = "ModelPackageValidationProfiles";
const _MPVS = "ModelPackageValidationSpecification";
const _MPe = "MetadataProperties";
const _MPo = "ModelPackage";
const _MQ = "ModelQuality";
const _MQAS = "ModelQualityAppSpecification";
const _MQBC = "ModelQualityBaselineConfig";
const _MQC = "ModelQuantizationConfig";
const _MQJI = "ModelQualityJobInput";
const _MQJOC = "ModelQualityJobOutputConfig";
const _MR = "MaxResults";
const _MRA = "MlflowResourceArn";
const _MRAa = "MaximumRetryAttempts";
const _MRAl = "MlReservationArn";
const _MRC = "MaxRecordCount";
const _MRI = "MlflowRunId";
const _MRIS = "MaxRuntimeInSeconds";
const _MRM = "ModelRegistrationMode";
const _MRN = "MlflowRunName";
const _MRPTJIS = "MaxRuntimePerTrainingJobInSeconds";
const _MRS = "ModelRegisterSettings";
const _MRa = "MaxResource";
const _MRi = "MinResource";
const _MRo = "MonitoringResources";
const _MS = "ModelSource";
const _MSA = "MonitoringScheduleArn";
const _MSC = "MonitoringScheduleConfig";
const _MSCo = "ModelShardingConfig";
const _MSCon = "MonitoringStoppingCondition";
const _MSDC = "ModelSpeculativeDecodingConfig";
const _MSDTDS = "ModelSpeculativeDecodingTrainingDataSource";
const _MSIMB = "MemorySizeInMB";
const _MSL = "ModelSummaryList";
const _MSLo = "MonitoringScheduleList";
const _MSM = "ModelStepMetadata";
const _MSN = "MonitoringScheduleName";
const _MSO = "MonitoringS3Output";
const _MSR = "MonitoringStatisticsResource";
const _MSS = "MonitoringScheduleStatus";
const _MSSL = "MonitoringScheduleSummaryList";
const _MSSo = "MonitoringScheduleSummaries";
const _MSSon = "MonitoringScheduleSummary";
const _MST = "ModelSetupTime";
const _MSU = "ManifestS3Uri";
const _MSV = "MaxSchemaVersion";
const _MSa = "MaintenanceStatus";
const _MSe = "MetricsSource";
const _MSet = "MetricSpecification";
const _MSo = "ModelSignature";
const _MSod = "ModelStats";
const _MSode = "ModelSummary";
const _MSon = "MonitoringSchedules";
const _MSoni = "MonitoringSchedule";
const _MT = "MimeType";
const _MTA = "ModifiedTimeAfter";
const _MTB = "ModifiedTimeBefore";
const _MTE = "MonitoringTypeEquals";
const _MTa = "MarketplaceTitle";
const _MTe = "MediaType";
const _MTo = "MonitoringType";
const _MU = "MemoryUtilization";
const _MV = "MinValue";
const _MVA = "ModelVariantActions";
const _MVC = "ModelVariantConfig";
const _MVCL = "ModelVariantConfigList";
const _MVCS = "ModelVariantConfigSummary";
const _MVCSL = "ModelVariantConfigSummaryList";
const _MVa = "MaxValue";
const _MVi = "MinVersion";
const _MVl = "MlflowVersion";
const _MVo = "ModelVersion";
const _MVod = "ModelVariants";
const _MWS = "MaintenanceWindowStart";
const _MWTIS = "MaxWaitTimeInSeconds";
const _Ma = "Max";
const _Me = "Metrics";
const _Met = "Metric";
const _Meta = "Metadata";
const _Mi = "Min";
const _Mo = "Mode";
const _Mod = "Models";
const _Mode = "Model";
const _N = "Name";
const _NAR = "NodeAdditionResult";
const _NARL = "NodeAdditionResultList";
const _NC = "NotificationConfig";
const _NCa = "NameContains";
const _NCe = "NetworkConfig";
const _NCo = "NotificationConfiguration";
const _ND = "NodeDetails";
const _NF = "NestedFilters";
const _NFL = "NestedFiltersList";
const _NI = "NodeId";
const _NIA = "NotebookInstanceArn";
const _NII = "NetworkInterfaceId";
const _NILC = "NotebookInstanceLifecycleConfigs";
const _NILCA = "NotebookInstanceLifecycleConfigArn";
const _NILCL = "NotebookInstanceLifecycleConfigList";
const _NILCN = "NotebookInstanceLifecycleConfigName";
const _NILCNC = "NotebookInstanceLifecycleConfigNameContains";
const _NILCS = "NotebookInstanceLifecycleConfigSummary";
const _NILCSL = "NotebookInstanceLifecycleConfigSummaryList";
const _NILH = "NotebookInstanceLifecycleHook";
const _NIN = "NotebookInstanceName";
const _NIS = "NotebookInstanceStatus";
const _NISL = "NotebookInstanceSummaryList";
const _NISo = "NotebookInstanceSummary";
const _NIo = "NodeIds";
const _NIot = "NotebookInstances";
const _NLI = "NodeLogicalId";
const _NLIo = "NodeLogicalIds";
const _NMN = "NearestModelName";
const _NOADR = "NumberOfAcceleratorDevicesRequired";
const _NOCCR = "NumberOfCpuCoresRequired";
const _NOHWPDO = "NumberOfHumanWorkersPerDataObject";
const _NOO = "NotebookOutputOption";
const _NOS = "NumberOfSamples";
const _NOSu = "NumberOfSteps";
const _NOTJONI = "NumberOfTrainingJobsObjectiveNotImproving";
const _NPM = "NodeProvisioningMode";
const _NPN = "NestedPropertyName";
const _NR = "NodeRecovery";
const _NRE = "NonRetryableError";
const _NT = "NodeType";
const _NTA = "NodesToAdd";
const _NTAo = "NotificationTopicArn";
const _NTe = "NextToken";
const _NV = "NumberValue";
const _NVC = "NeoVpcConfig";
const _Na = "Namespace";
const _O = "Outcome";
const _OA = "OutputArtifacts";
const _OATR = "OutputArtifactsToRemove";
const _OBTJ = "OverallBestTrainingJob";
const _OC = "OutputConfig";
const _OCFR = "OidcConfigForResponse";
const _OCT = "OriginalCreationTime";
const _OCi = "OidcConfig";
const _OCn = "OnCreate";
const _OCp = "OptimizationConfigs";
const _OCpt = "OptimizationContains";
const _OCpti = "OptimizationConfig";
const _OCu = "OutputCompression";
const _OD = "OnDemand";
const _ODC = "OutputDataConfig";
const _ODCf = "OfflineDeviceCount";
const _ODSU = "OutputDatasetS3Uri";
const _OE = "OptimizationEnvironment";
const _OET = "OptimizationEndTime";
const _OEv = "OverrideEnvironment";
const _OF = "OutputFormat";
const _OFu = "OutputFilter";
const _OJA = "OptimizationJobArn";
const _OJMS = "OptimizationJobModelSource";
const _OJMSS = "OptimizationJobModelSourceS3";
const _OJN = "OptimizationJobName";
const _OJOC = "OptimizationJobOutputConfig";
const _OJS = "OptimizationJobStatus";
const _OJSp = "OptimizationJobSummaries";
const _OJSpt = "OptimizationJobSummary";
const _OK = "ObjectKey";
const _OMAC = "OptimizationModelAccessConfig";
const _OMD = "OidcMemberDefinition";
const _OMPA = "OutputModelPackageArn";
const _ON = "OutputName";
const _OO = "OptimizationOutput";
const _OP = "OutputParameters";
const _OPL = "OutputParameterList";
const _OPu = "OutputParameter";
const _OS = "ObjectiveStatus";
const _OSC = "OnlineStoreConfig";
const _OSCU = "OnlineStoreConfigUpdate";
const _OSCb = "ObjectiveStatusCounters";
const _OSCf = "OfflineStoreConfig";
const _OSDHC = "OnStartDeepHealthChecks";
const _OSMM = "OptimizationSageMakerModel";
const _OSS = "OfflineStoreStatus";
const _OSSC = "OnlineStoreSecurityConfig";
const _OSSE = "OfflineStoreStatusEquals";
const _OSSw = "OwnershipSettingsSummary";
const _OST = "OptimizationStartTime";
const _OSTSB = "OnlineStoreTotalSizeBytes";
const _OSU = "OutputS3Uri";
const _OSn = "OnStart";
const _OSw = "OwnershipSettings";
const _OT = "OptimizationTypes";
const _OUPN = "OwnerUserProfileName";
const _OVC = "OverrideVpcConfig";
const _OVCp = "OptimizationVpcConfig";
const _Op = "Operator";
const _Or = "Orchestrator";
const _Os = "Os";
const _Ou = "Outputs";
const _P = "Parameters";
const _PA = "ProbabilityAttribute";
const _PAC = "PartnerAppConfig";
const _PAI = "ProvisioningArtifactId";
const _PAMC = "PartnerAppMaintenanceConfig";
const _PAPSU = "PostAnalyticsProcessorSourceUri";
const _PAS = "PartnerAppSummary";
const _PASa = "PartnerAppSummaries";
const _PAa = "ParameterAdditions";
const _PAi = "PipelineArn";
const _PAr = "ProjectArn";
const _PC = "PrimaryContainer";
const _PCC = "ProcessingClusterConfig";
const _PCFU = "ProfilerConfigForUpdate";
const _PCL = "PriorityClassList";
const _PCa = "ParallelismConfiguration";
const _PCay = "PayloadConfig";
const _PCr = "ProfilerConfig";
const _PCri = "PriorityClass";
const _PCrio = "PriorityClasses";
const _PCro = "ProvisionedConcurrency";
const _PD = "PipelineDefinition";
const _PDC = "PresetDeploymentConfig";
const _PDH = "PrivateDnsHostname";
const _PDN = "PipelineDisplayName";
const _PDO = "PresetDeploymentOutput";
const _PDS = "PendingDeploymentSummary";
const _PDSL = "PipelineDefinitionS3Location";
const _PDT = "PresetDeploymentType";
const _PDi = "PipelineDescription";
const _PDr = "ProjectDescription";
const _PE = "PipelineExecution";
const _PEA = "PipelineExecutionArn";
const _PEC = "PipelineExperimentConfig";
const _PED = "PipelineExecutionDescription";
const _PEDN = "PipelineExecutionDisplayName";
const _PEFR = "PipelineExecutionFailureReason";
const _PES = "PipelineExecutionStatus";
const _PESL = "PipelineExecutionStepList";
const _PESLi = "PipelineExecutionSummaryList";
const _PESM = "PipelineExecutionStepMetadata";
const _PESi = "PipelineExecutionSummaries";
const _PESip = "PipelineExecutionSteps";
const _PESipe = "PipelineExecutionStep";
const _PESipel = "PipelineExecutionSummary";
const _PET = "ProcessingEndTime";
const _PFM = "PartialFailureMessage";
const _PFR = "PartialFailureReasons";
const _PFSO = "ProcessingFeatureStoreOutput";
const _PH = "PendingHuman";
const _PHPTJ = "ParentHyperParameterTuningJobs";
const _PHPTJa = "ParentHyperParameterTuningJob";
const _PHTLA = "PreHumanTaskLambdaArn";
const _PI = "ProbabilityIndex";
const _PIIM = "ProfilingIntervalInMilliseconds";
const _PIa = "PathId";
const _PIl = "PlatformIdentifier";
const _PIr = "ProcessingInputs";
const _PIri = "PrincipalId";
const _PIro = "ProjectId";
const _PIroc = "ProcessingInput";
const _PIrod = "ProductId";
const _PIrog = "ProgressInfo";
const _PJ = "ProcessingJob";
const _PJA = "ProcessingJobArn";
const _PJN = "ProcessingJobName";
const _PJS = "ProcessingJobStatus";
const _PJSM = "ProcessingJobStepMetadata";
const _PJSr = "ProcessingJobSummaries";
const _PJSro = "ProcessingJobSummary";
const _PL = "ProgrammingLang";
const _PLI = "ProductListingIds";
const _PLa = "ParameterList";
const _PMPGP = "PutModelPackageGroupPolicy";
const _PMPGPI = "PutModelPackageGroupPolicyInput";
const _PMPGPO = "PutModelPackageGroupPolicyOutput";
const _PMS = "PredefinedMetricSpecification";
const _PMT = "PredefinedMetricType";
const _PN = "ProfileName";
const _PNH = "PropertyNameHint";
const _PNP = "PipelineNamePrefix";
const _PNQ = "PropertyNameQuery";
const _PNS = "PropertyNameSuggestions";
const _PNSL = "PropertyNameSuggestionList";
const _PNSr = "PropertyNameSuggestion";
const _PNa = "PartitionNames";
const _PNi = "PipelineName";
const _PNr = "ProjectName";
const _PNro = "PropertyName";
const _PO = "ProcessingOutput";
const _POC = "ProcessingOutputConfig";
const _POr = "ProcessingOutputs";
const _PP = "PipelineParameters";
const _PPI = "PrivatePrimaryIp";
const _PPIr = "PrivatePrimaryIpv6";
const _PPIro = "ProvisionedProductId";
const _PPSM = "ProvisionedProductStatusMessage";
const _PPVS = "PendingProductionVariantSummary";
const _PPVSL = "PendingProductionVariantSummaryList";
const _PPr = "ProfilingParameters";
const _PPro = "ProvisioningParameter";
const _PProv = "ProvisioningParameters";
const _PR = "ProcessingResources";
const _PRC = "ProfilerRuleConfigurations";
const _PRCU = "ProvisionedReadCapacityUnits";
const _PRCr = "ProfilerRuleConfiguration";
const _PRES = "ProfilerRuleEvaluationStatuses";
const _PRESr = "ProfilerRuleEvaluationStatus";
const _PRa = "ParameterRanges";
const _PRar = "ParameterRange";
const _PRara = "ParameterRemovals";
const _PS = "PipelineStatus";
const _PSC = "ProcessingStoppingCondition";
const _PSI = "ProcessingS3Input";
const _PSL = "ProjectSummaryList";
const _PSLi = "PipelineSummaryList";
const _PSO = "ProcessingS3Output";
const _PSP = "ProjectS3Path";
const _PST = "ProcessingStartTime";
const _PSi = "PipelineSummaries";
const _PSip = "PipelineSummary";
const _PSl = "PlacementSpecifications";
const _PSla = "PlacementSpecification";
const _PSr = "ProjectStatus";
const _PSri = "PrimaryStatus";
const _PSro = "ProfilingStatus";
const _PSroj = "ProjectSummary";
const _PT = "ProblemType";
const _PTA = "ProbabilityThresholdAttribute";
const _PTC = "PreTrainingConstraints";
const _PTCo = "PostTrainingConstraints";
const _PTR = "PreTrainingReport";
const _PTRa = "ParametersToRemove";
const _PTRo = "PostTrainingReport";
const _PTRr = "PropertiesToRemove";
const _PTT = "PreemptTeamTasks";
const _PUAC = "PresignedUrlAccessConfig";
const _PUST = "PerUnitStorageThroughput";
const _PV = "ProductionVariants";
const _PVCDC = "ProductionVariantCoreDumpConfig";
const _PVCRC = "ProductionVariantCapacityReservationConfig";
const _PVCRS = "ProductionVariantCapacityReservationSummary";
const _PVD = "PipelineVersionDescription";
const _PVDN = "PipelineVersionDisplayName";
const _PVI = "PipelineVersionId";
const _PVL = "ProductionVariantList";
const _PVMIS = "ProductionVariantManagedInstanceScaling";
const _PVRC = "ProductionVariantRoutingConfig";
const _PVS = "PipelineVersionSummaries";
const _PVSC = "ProductionVariantServerlessConfig";
const _PVSL = "PipelineVersionSummaryList";
const _PVSLr = "ProductionVariantStatusList";
const _PVSLro = "ProductionVariantSummaryList";
const _PVSUC = "ProductionVariantServerlessUpdateConfig";
const _PVSi = "PipelineVersionSummary";
const _PVSr = "ProductionVariantStatus";
const _PVSro = "ProductionVariantSummary";
const _PVi = "PipelineVersion";
const _PVr = "ProductionVariant";
const _PWCU = "ProvisionedWriteCapacityUnits";
const _PWTP = "PublicWorkforceTaskPrice";
const _Pa = "Parquet";
const _Par = "Parameter";
const _Pare = "Parent";
const _Paren = "Parents";
const _Pe = "Percentage";
const _Pef = "Peft";
const _Pen = "Pending";
const _Per = "Percentile";
const _Ph = "Phase";
const _Pha = "Phases";
const _Pi = "Pipeline";
const _Pl = "Placement";
const _Pr = "Properties";
const _Pre = "Predefined";
const _Pro = "Processor";
const _Proj = "Project";
const _QC = "QualityCheck";
const _QCSM = "QualityCheckStepMetadata";
const _QF = "QueryFilters";
const _QL = "QueryLineage";
const _QLR = "QueryLineageRequest";
const _QLRu = "QueryLineageResponse";
const _QPA = "QProfileArn";
const _QS = "QueryString";
const _R = "Report";
const _RA = "ResourceArn";
const _RAC = "RepositoryAuthConfig";
const _RAM = "RepositoryAccessMode";
const _RARN = "RoleARN";
const _RAVP = "RetainAllVariantProperties";
const _RAe = "ResolvedAttributes";
const _RAem = "RemoteAccess";
const _RAo = "RoleArn";
const _RAoo = "RootAccess";
const _RBJ = "ReusedByJob";
const _RC = "RuntimeConfig";
const _RCA = "ReservedCapacityArn";
const _RCAe = "ResourceCatalogArn";
const _RCFU = "ResourceConfigForUpdate";
const _RCL = "ResourceCatalogList";
const _RCN = "RuleConfigurationName";
const _RCNe = "ResourceCatalogName";
const _RCO = "ReservedCapacityOffering";
const _RCOe = "ReservedCapacityOfferings";
const _RCPA = "RepositoryCredentialsProviderArn";
const _RCS = "ReservedCapacitySummaries";
const _RCSe = "ReservedCapacitySummary";
const _RCT = "ReservedCapacityType";
const _RCe = "ResourceConfig";
const _RCen = "RenderedContent";
const _RCes = "ResourceCatalogs";
const _RCeso = "ResourceCatalog";
const _RCo = "RoutingConfig";
const _RD = "RootlessDocker";
const _RDC = "RemoteDebugConfig";
const _RDCFU = "RemoteDebugConfigForUpdate";
const _RDCe = "RegisteredDeviceCount";
const _RDCet = "RetainDeploymentConfig";
const _RDD = "RedshiftDatasetDefinition";
const _RDP = "RollingDeploymentPolicy";
const _RDR = "RegisterDevicesRequest";
const _RDe = "RegisterDevices";
const _RE = "RenderingError";
const _REI = "RuleEvaluatorImage";
const _REJA = "RuleEvaluationJobArn";
const _REL = "RenderingErrorList";
const _RES = "RuleEvaluationStatus";
const _RETB = "RequestedEndTimeBefore";
const _REe = "RetryableError";
const _RG = "ReportGenerated";
const _RGA = "RoleGroupAssignments";
const _RGAL = "RoleGroupAssignmentsList";
const _RGAo = "RoleGroupAssignment";
const _RI = "ResolvedImage";
const _RIFN = "RecordIdentifierFeatureName";
const _RIG = "RestrictedInstanceGroups";
const _RII = "RecommendedInferenceImage";
const _RIS = "RuntimeInSeconds";
const _RIU = "ResourceInUse";
const _RIe = "RecommendationId";
const _RIes = "ResourceIdentifier";
const _RJCC = "RecommendationJobContainerConfig";
const _RJCOC = "RecommendationJobCompiledOutputConfig";
const _RJIB = "RecommendationJobInferenceBenchmark";
const _RJIC = "RecommendationJobInputConfig";
const _RJOC = "RecommendationJobOutputConfig";
const _RJPC = "RecommendationJobPayloadConfig";
const _RJRL = "RecommendationJobResourceLimit";
const _RJSC = "RecommendationJobStoppingConditions";
const _RJVC = "RecommendationJobVpcConfig";
const _RK = "ResourceKey";
const _RL = "ResourceLimits";
const _RLE = "ResourceLimitExceeded";
const _RLe = "ResourceLimit";
const _RM = "RecoveryMode";
const _RMBS = "RollbackMaximumBatchSize";
const _RMSM = "RegisterModelStepMetadata";
const _RMV = "ReferenceMinVersion";
const _RMe = "RegisterModel";
const _RMec = "RecommendationMetrics";
const _RN = "ReleaseNotes";
const _RNB = "RegisterNewBaseline";
const _RNF = "ResourceNotFound";
const _RNe = "RecipeName";
const _RNo = "RoleName";
const _RNu = "RunName";
const _ROSU = "ResolvedOutputS3Uri";
const _RP = "RuleParameters";
const _RPE = "RetryPipelineExecution";
const _RPER = "RetryPipelineExecutionRequest";
const _RPERe = "RetryPipelineExecutionResponse";
const _RPSU = "RecordPreprocessorSourceUri";
const _RPe = "RetentionPolicy";
const _RPes = "ResourcePolicy";
const _RR = "RiskRating";
const _RRBTIS = "ResourceRetainedBillableTimeInSeconds";
const _RS = "ResourceSpec";
const _RSAS = "RSessionAppSettings";
const _RSC = "ResourceSharingConfig";
const _RSCU = "RStudioConnectUrl";
const _RSPMU = "RStudioPackageManagerUrl";
const _RSSPAS = "RStudioServerProAppSettings";
const _RSSPDS = "RStudioServerProDomainSettings";
const _RSSPDSFU = "RStudioServerProDomainSettingsForUpdate";
const _RSTA = "RequestedStartTimeAfter";
const _RSa = "RandomSeed";
const _RSe = "RetryStrategy";
const _RSec = "RecommendationStatus";
const _RSo = "RoutingStrategy";
const _RT = "ResourceType";
const _RTIC = "RealTimeInferenceConfig";
const _RTIR = "RealTimeInferenceRecommendations";
const _RTIRe = "RealTimeInferenceRecommendation";
const _RTe = "ResolutionTime";
const _RTeg = "RegistrationTime";
const _RTen = "RenderableTask";
const _RU = "RepositoryUrl";
const _RUP = "RollingUpdatePolicy";
const _RUT = "RenderUiTemplate";
const _RUTR = "RenderUiTemplateRequest";
const _RUTRe = "RenderUiTemplateResponse";
const _RV = "RootVolume";
const _RWT = "RecordWrapperType";
const _Ra = "Range";
const _Re = "Reason";
const _Reg = "Regex";
const _Rel = "Relation";
const _Rep = "Repository";
const _Res = "Resource";
const _Resu = "Results";
const _S = "Source";
const _SA = "SourceArn";
const _SAE = "SlrAccessEntry";
const _SAL = "SourceAlgorithmList";
const _SALM = "SpaceAppLifecycleManagement";
const _SAMLJ = "StopAutoMLJob";
const _SAMLJR = "StopAutoMLJobRequest";
const _SAP = "S3ArtifactPath";
const _SAS = "SourceAlgorithmSpecification";
const _SAe = "SecretArn";
const _SAo = "SourceAlgorithm";
const _SAou = "SourceAlgorithms";
const _SAp = "SpaceArn";
const _SAt = "StartArns";
const _SB = "ShapBaseline";
const _SBC = "ShapBaselineConfig";
const _SBU = "ShapBaselineUri";
const _SBo = "SortBy";
const _SC = "SecurityConfig";
const _SCC = "SessionChainingConfig";
const _SCEAS = "SpaceCodeEditorAppSettings";
const _SCJ = "StopCompilationJob";
const _SCJR = "StopCompilationJobRequest";
const _SCPD = "ServiceCatalogProvisioningDetails";
const _SCPPD = "ServiceCatalogProvisionedProductDetails";
const _SCPUD = "ServiceCatalogProvisioningUpdateDetails";
const _SCS = "SlurmConfigStrategy";
const _SCT = "SupportedContentTypes";
const _SCTo = "S3CompressionType";
const _SCTu = "SupportedCompressionTypes";
const _SCc = "SchedulerConfig";
const _SCch = "ScheduleConfig";
const _SCe = "ServerlessConfig";
const _SCh = "ShuffleConfig";
const _SCha = "ShapConfig";
const _SCk = "SkipCheck";
const _SCl = "SlurmConfig";
const _SCt = "StoppingCondition";
const _SCto = "StoppingConditions";
const _SCtr = "StrategyConfig";
const _SD = "StackDetail";
const _SDC = "SamplingDeviceCount";
const _SDDT = "S3DataDistributionType";
const _SDN = "SpaceDisplayName";
const _SDNt = "StepDisplayName";
const _SDS = "S3DataSource";
const _SDSn = "SnsDataSource";
const _SDT = "S3DataType";
const _SDTu = "SupportsDistributedTraining";
const _SDo = "SourceDetail";
const _SDp = "SpaceDetails";
const _SDt = "StatusDetails";
const _SDta = "StageDescription";
const _SDtd = "StdDev";
const _SDte = "StepDescription";
const _SDu = "SubDomain";
const _SE = "StatusEquals";
const _SEA = "S3ExportArtifacts";
const _SEC = "SelectiveExecutionConfig";
const _SEDIS = "SessionExpirationDurationInSeconds";
const _SEDS = "StartEdgeDeploymentStage";
const _SEDSR = "StartEdgeDeploymentStageRequest";
const _SEDSRt = "StopEdgeDeploymentStageRequest";
const _SEDSt = "StopEdgeDeploymentStage";
const _SEL = "SearchExpressionList";
const _SEPJ = "StopEdgePackagingJob";
const _SEPJR = "StopEdgePackagingJobRequest";
const _SER = "SelectiveExecutionResult";
const _SET = "SupportedEndpointType";
const _SEc = "ScheduleExpression";
const _SEe = "SearchExpression";
const _SEu = "SubExpressions";
const _SFP = "S3FailurePath";
const _SFS = "S3FileSystem";
const _SFSC = "S3FileSystemConfig";
const _SG = "SecurityGroups";
const _SGI = "SecurityGroupIds";
const _SGIFDB = "SecurityGroupIdForDomainBoundary";
const _SHP = "StaticHyperParameters";
const _SHPTJ = "StopHyperParameterTuningJob";
const _SHPTJR = "StopHyperParameterTuningJobRequest";
const _SHPu = "SupportedHyperParameters";
const _SI = "SourceId";
const _SIC = "SourceIpConfig";
const _SICPUS = "SpareInstanceCountPerUltraServer";
const _SICc = "ScaleInCooldown";
const _SIE = "StartInferenceExperiment";
const _SIER = "StartInferenceExperimentRequest";
const _SIERt = "StartInferenceExperimentResponse";
const _SIERto = "StopInferenceExperimentRequest";
const _SIERtop = "StopInferenceExperimentResponse";
const _SIEt = "StopInferenceExperiment";
const _SIGB = "SizeInGiB";
const _SIM = "S3InputMode";
const _SIMu = "SupportedInputModes";
const _SIRJ = "StopInferenceRecommendationsJob";
const _SIRJR = "StopInferenceRecommendationsJobRequest";
const _SIS = "SpaceIdleSettings";
const _SIT = "SourceIdType";
const _SITu = "SupportedInstanceTypes";
const _SIe = "SessionId";
const _SIn = "S3Input";
const _SIo = "SourceIdentity";
const _SIou = "SourceIp";
const _SIp = "SpecifiedImage";
const _SIt = "StepId";
const _SIu = "SubnetIds";
const _SIub = "SubnetId";
const _SJC = "ServerlessJobConfig";
const _SJLAS = "SpaceJupyterLabAppSettings";
const _SKKI = "S3KmsKeyId";
const _SL = "SpaceList";
const _SLC = "StudioLifecycleConfigs";
const _SLCA = "StudioLifecycleConfigArn";
const _SLCAT = "StudioLifecycleConfigAppType";
const _SLCC = "StudioLifecycleConfigContent";
const _SLCD = "StudioLifecycleConfigDetails";
const _SLCL = "StudioLifecycleConfigsList";
const _SLCN = "StudioLifecycleConfigName";
const _SLJ = "StopLabelingJob";
const _SLJR = "StopLabelingJobRequest";
const _SM = "StatusMessage";
const _SMA = "S3ModelArtifacts";
const _SMC = "ShadowModeConfig";
const _SMDS = "S3ModelDataSource";
const _SMIA = "SageMakerImageArn";
const _SMIN = "SageMakerImageName";
const _SMIVA = "SageMakerImageVersionAliases";
const _SMIVAa = "SageMakerImageVersionArn";
const _SMIVAag = "SageMakerImageVersionAlias";
const _SMM = "SageMakerModel";
const _SMN = "StandardMetricName";
const _SMPA = "SourceModelPackageArn";
const _SMPHCA = "SageMakerPublicHubContentArn";
const _SMR = "SpaceManagedResources";
const _SMS = "StartMonitoringSchedule";
const _SMSR = "StartMonitoringScheduleRequest";
const _SMSRt = "StopMonitoringScheduleRequest";
const _SMSt = "StopMonitoringSchedule";
const _SMTS = "StartMlflowTrackingServer";
const _SMTSR = "StartMlflowTrackingServerRequest";
const _SMTSRt = "StartMlflowTrackingServerResponse";
const _SMTSRto = "StopMlflowTrackingServerRequest";
const _SMTSRtop = "StopMlflowTrackingServerResponse";
const _SMTSt = "StopMlflowTrackingServer";
const _SMV = "SkipModelValidation";
const _SMVC = "ShadowModelVariantConfig";
const _SMVCL = "ShadowModelVariantConfigList";
const _SMVN = "SourceModelVariantName";
const _SMVNh = "ShadowModelVariantName";
const _SMVh = "ShadowModelVariants";
const _SN = "SpaceName";
const _SNC = "SpaceNameContains";
const _SNE = "SpaceNameEquals";
const _SNI = "StartNotebookInstance";
const _SNII = "StartNotebookInstanceInput";
const _SNIIt = "StopNotebookInstanceInput";
const _SNIt = "StopNotebookInstance";
const _SNLI = "SuccessfulNodeLogicalIds";
const _SNe = "SellerName";
const _SNo = "SourceName";
const _SNt = "StageName";
const _SNte = "StepName";
const _SO = "SortOrder";
const _SOC = "ScaleOutCooldown";
const _SOJ = "StopOptimizationJob";
const _SOJR = "StopOptimizationJobRequest";
const _SOL = "S3OutputLocation";
const _SOP = "S3OutputPath";
const _SOU = "S3OutputUri";
const _SOu = "S3Output";
const _SP = "ScalingPolicies";
const _SPE = "StartPipelineExecution";
const _SPEA = "SourcePipelineExecutionArn";
const _SPER = "StartPipelineExecutionRequest";
const _SPERt = "StartPipelineExecutionResponse";
const _SPERto = "StopPipelineExecutionRequest";
const _SPERtop = "StopPipelineExecutionResponse";
const _SPESF = "SendPipelineExecutionStepFailure";
const _SPESFR = "SendPipelineExecutionStepFailureRequest";
const _SPESFRe = "SendPipelineExecutionStepFailureResponse";
const _SPESS = "SendPipelineExecutionStepSuccess";
const _SPESSR = "SendPipelineExecutionStepSuccessRequest";
const _SPESSRe = "SendPipelineExecutionStepSuccessResponse";
const _SPEt = "StopPipelineExecution";
const _SPJ = "StopProcessingJob";
const _SPJR = "StopProcessingJobRequest";
const _SPM = "ScalingPolicyMetric";
const _SPO = "ScalingPolicyObjective";
const _SPU = "SamplePayloadUrl";
const _SPV = "ShadowProductionVariants";
const _SPa = "SamplingPercentage";
const _SPc = "ScalingPolicy";
const _SPr = "S3Presign";
const _SPt = "StartupParameters";
const _SQ = "SuggestionQuery";
const _SQU = "SqsQueueUrl";
const _SR = "StatisticsResource";
const _SRIIT = "SupportedRealtimeInferenceInstanceTypes";
const _SRL = "SearchResultsList";
const _SRMIMET = "SupportedResponseMIMETypes";
const _SRe = "SearchRecord";
const _SRea = "SearchRequest";
const _SRear = "SearchResponse";
const _SRp = "SpawnRate";
const _SRt = "StatusReason";
const _SS = "SpaceSettings";
const _SSC = "S3StorageConfig";
const _SSL = "SelectedStepList";
const _SSOAA = "SingleSignOnApplicationArn";
const _SSOMAII = "SingleSignOnManagedApplicationInstanceId";
const _SSOUI = "SingleSignOnUserIdentifier";
const _SSOUV = "SingleSignOnUserValue";
const _SSR = "StartSessionRequest";
const _SSRt = "StartSessionResponse";
const _SSS = "SpaceSharingSettings";
const _SSSS = "SpaceSharingSettingsSummary";
const _SSSp = "SpaceStorageSettings";
const _SSSpa = "SpaceSettingsSummary";
const _SST = "SecondaryStatusTransitions";
const _SSTe = "SecondaryStatusTransition";
const _SSU = "SourceS3Uri";
const _SSe = "SecondaryStatus";
const _SSel = "SelectedStep";
const _SSele = "SelectedSteps";
const _SSh = "SharingSettings";
const _SSt = "StageStatus";
const _SSta = "StartSession";
const _SSte = "StepStatus";
const _SSu = "SupportStatus";
const _ST = "SourceType";
const _STA = "SnsTopicArn";
const _STAc = "ScheduledTimeAfter";
const _STAt = "StartTimeAfter";
const _STB = "ScheduledTimeBefore";
const _STBt = "StartTimeBefore";
const _STIT = "SupportedTransformInstanceTypes";
const _STITu = "SupportedTrainingInstanceTypes";
const _STJ = "StopTrainingJob";
const _STJOM = "SupportedTuningJobObjectiveMetrics";
const _STJR = "StopTrainingJobRequest";
const _STJRt = "StopTransformJobRequest";
const _STJt = "StopTransformJob";
const _STO = "StartTimeOffset";
const _STPO = "SearchTrainingPlanOfferings";
const _STPOR = "SearchTrainingPlanOfferingsRequest";
const _STPORe = "SearchTrainingPlanOfferingsResponse";
const _STc = "ScalingType";
const _STch = "ScheduledTime";
const _STh = "SharingType";
const _STo = "SourceTypes";
const _STp = "SplitType";
const _STt = "StartTime";
const _STte = "StepType";
const _STto = "StorageType";
const _STu = "SuccessTopic";
const _SU = "SourceUri";
const _SUC = "ScheduledUpdateConfig";
const _SUCe = "ServerlessUpdateConfig";
const _SUM = "S3UploadMode";
const _SUS = "SoftwareUpdateStatus";
const _SUr = "S3Uri";
const _SUt = "StreamUrl";
const _SV = "StringValue";
const _SW = "SubscribedWorkteam";
const _SWAN = "SampleWeightAttributeName";
const _SWP = "StudioWebPortal";
const _SWPA = "StudioWebPortalAccess";
const _SWPS = "StudioWebPortalSettings";
const _SWu = "SubscribedWorkteams";
const _S_ = "S3";
const _Sc = "Schedule";
const _Sco = "Scope";
const _Se = "Seed";
const _Sea = "Search";
const _Set = "Set";
const _Sl = "Slurm";
const _So = "Sources";
const _Sp = "Spot";
const _Spa = "Spaces";
const _Spe = "Specification";
const _St = "Status";
const _Sta = "Stages";
const _Stag = "Stage";
const _Stai = "Stairs";
const _Stat = "Statistic";
const _Stati = "Statistics";
const _Ste = "Steps";
const _Sto = "Stopped";
const _Str = "Strategy";
const _Su = "Successful";
const _Sub = "Subnets";
const _Suc = "Success";
const _Succ = "Succeeded";
const _Sum = "Summaries";
const _T = "Type";
const _TA = "TrialArn";
const _TALIS = "TaskAvailabilityLifetimeInSeconds";
const _TAN = "TargetAttributeName";
const _TANi = "TimestampAttributeName";
const _TAV = "TransformAmiVersion";
const _TBAS = "TensorBoardAppSettings";
const _TBOC = "TensorBoardOutputConfig";
const _TC = "TextConfig";
const _TCA = "TrialComponentArn";
const _TCAr = "TrialComponentArtifact";
const _TCAri = "TrialComponentArtifacts";
const _TCD = "ThroughputConfigDescription";
const _TCDN = "TrialComponentDisplayName";
const _TCJC = "TextClassificationJobConfig";
const _TCMS = "TrialComponentMetricSummary";
const _TCMSr = "TrialComponentMetricSummaries";
const _TCN = "TrialComponentName";
const _TCP = "TrialComponentParameters";
const _TCPV = "TrialComponentParameterValue";
const _TCS = "TrialComponentSummaries";
const _TCSD = "TrialComponentSourceDetail";
const _TCSS = "TrialComponentSimpleSummary";
const _TCSSr = "TrialComponentSimpleSummaries";
const _TCSr = "TrialComponentSource";
const _TCSri = "TrialComponentStatus";
const _TCSria = "TrialComponentSummary";
const _TCSrial = "TrialComponentSources";
const _TCU = "ThroughputConfigUpdate";
const _TCUPC = "TargetCpuUtilizationPerCore";
const _TCa = "TargetCount";
const _TCas = "TaskCount";
const _TCh = "ThroughputConfig";
const _TCr = "TrialComponent";
const _TCra = "TrainingChannels";
const _TD = "TaskDescription";
const _TDS = "TrainingDataSource";
const _TDSr = "TransformDataSource";
const _TDa = "TargetDevice";
const _TDt = "TtlDuration";
const _TE = "TokenEndpoint";
const _TET = "TrainingEndTime";
const _TETr = "TransformEndTime";
const _TF = "TableFormat";
const _TFOAC = "TenthFractionsOfACent";
const _TGHP = "TextGenerationHyperParameters";
const _TGJC = "TextGenerationJobConfig";
const _TGRA = "TextGenerationResolvedAttributes";
const _TH = "TotalHits";
const _THP = "TunedHyperParameters";
const _TI = "TrainingImage";
const _TIC = "TrainingImageConfig";
const _TICo = "TotalInstanceCount";
const _TID = "TrainingImageDigest";
const _TIM = "TrainingInputMode";
const _TIPS = "TrustedIdentityPropagationSettings";
const _TIr = "TransformInput";
const _TJ = "TrainingJob";
const _TJA = "TrainingJobArn";
const _TJAr = "TransformJobArn";
const _TJAu = "TuningJobArn";
const _TJC = "TabularJobConfig";
const _TJCC = "TuningJobCompletionCriteria";
const _TJCD = "TuningJobCompletionDetails";
const _TJD = "TrainingJobDefinition";
const _TJDN = "TrainingJobDefinitionName";
const _TJDr = "TransformJobDefinition";
const _TJDra = "TrainingJobDefinitions";
const _TJEST = "TrainingJobEarlyStoppingType";
const _TJN = "TrainingJobName";
const _TJNr = "TransformJobName";
const _TJNu = "TuningJobName";
const _TJS = "TrainingJobStatus";
const _TJSC = "TrainingJobStatusCounters";
const _TJSM = "TrainingJobStepMetadata";
const _TJSMD = "TuningJobStepMetaData";
const _TJSMr = "TransformJobStepMetadata";
const _TJSr = "TransformJobStatus";
const _TJSra = "TrainingJobSummaries";
const _TJSrai = "TrainingJobSummary";
const _TJSran = "TransformJobSummaries";
const _TJSrans = "TransformJobSummary";
const _TJr = "TransformJob";
const _TJu = "TuningJob";
const _TK = "TagKeys";
const _TKa = "TaskKeywords";
const _TL = "TotalLabeled";
const _TLC = "TargetLabelColumn";
const _TLa = "TagList";
const _TM = "ThroughputMode";
const _TN = "TrialName";
const _TNa = "TableName";
const _TNe = "TemplateName";
const _TNea = "TeamName";
const _TO = "TransformOutput";
const _TOMV = "TargetObjectiveMetricValue";
const _TOu = "TuningObjective";
const _TP = "TagPropagation";
const _TPA = "TrainingPlanArn";
const _TPAE = "TrainingPlanArnEquals";
const _TPAr = "TrainingPlanArns";
const _TPC = "ThreadsPerCore";
const _TPD = "TemplateProviderDetails";
const _TPDL = "TemplateProviderDetailList";
const _TPDe = "TemplateProviderDetail";
const _TPF = "TrainingPlanFilter";
const _TPFr = "TrainingPlanFilters";
const _TPI = "TrainingProgressInfo";
const _TPN = "TrainingPlanName";
const _TPO = "TrainingPlanOfferings";
const _TPOI = "TrainingPlanOfferingId";
const _TPOr = "TrainingPlanOffering";
const _TPS = "TrainingPlanStatus";
const _TPSr = "TrainingPlanSummaries";
const _TPSra = "TrainingPlanSummary";
const _TPTU = "TemplateProvidersToUpdate";
const _TPa = "TargetPlatform";
const _TPe = "TemplateProviders";
const _TPr = "TrafficPattern";
const _TR = "TransformResources";
const _TRA = "TabularResolvedAttributes";
const _TRAC = "TrainingRepositoryAuthConfig";
const _TRAM = "TrainingRepositoryAccessMode";
const _TRC = "TrafficRoutingConfiguration";
const _TRCPA = "TrainingRepositoryCredentialsProviderArn";
const _TRCr = "TrafficRoutingConfig";
const _TRa = "TargetResources";
const _TS = "TrainingSpecification";
const _TSA = "TrackingServerArn";
const _TSC = "TargetStateCount";
const _TSCPE = "TotalStepCountPerEpoch";
const _TSCi = "TieredStorageConfig";
const _TSCim = "TimeSeriesConfig";
const _TSDS = "TransformS3DataSource";
const _TSFJC = "TimeSeriesForecastingJobConfig";
const _TSFS = "TimeSeriesForecastingSettings";
const _TSMS = "TrackingServerMaintenanceStatus";
const _TSN = "TrackingServerName";
const _TSS = "TrackingServerSize";
const _TSSL = "TrackingServerSummaryList";
const _TSSr = "TrackingServerStatus";
const _TSSra = "TrackingServerSummaries";
const _TSSrac = "TrackingServerSummary";
const _TST = "TrainingStartTime";
const _TSTi = "TimeSeriesTransformations";
const _TSTr = "TransformStartTime";
const _TSU = "TrackingServerUrl";
const _TSi = "TimeStamp";
const _TSr = "TrialSummaries";
const _TSri = "TrialSource";
const _TSria = "TrialSummary";
const _TT = "TaskTitle";
const _TTIS = "TrainingTimeInSeconds";
const _TTLIS = "TaskTimeLimitInSeconds";
const _TTSPC = "TargetTrackingScalingPolicyConfiguration";
const _TTa = "TargetTracking";
const _TTr = "TrafficType";
const _TURL = "TemplateURL";
const _TUSC = "TotalUltraServerCount";
const _TV = "TokenValue";
const _TVa = "TargetValue";
const _TVar = "TargetVersion";
const _TWIS = "TerminationWaitInSeconds";
const _Ta = "Tags";
const _Tag = "Tag";
const _Tai = "Taints";
const _Tas = "Task";
const _Te = "Technique";
const _Ti = "Tier";
const _Tim = "Timestamp";
const _To = "Total";
const _Tr = "Trial";
const _Tra = "Transformations";
const _Ty = "Types";
const _U = "Url";
const _UA = "UpdateAction";
const _UAIC = "UpdateAppImageConfig";
const _UAICR = "UpdateAppImageConfigRequest";
const _UAICRp = "UpdateAppImageConfigResponse";
const _UAR = "UpdateActionRequest";
const _UARp = "UpdateActionResponse";
const _UARpd = "UpdateArtifactRequest";
const _UARpda = "UpdateArtifactResponse";
const _UAp = "UpdateArtifact";
const _UBCE = "UsedByCurrentEndpoint";
const _UC = "UiConfig";
const _UCQ = "UpdateComputeQuota";
const _UCQR = "UpdateComputeQuotaRequest";
const _UCQRp = "UpdateComputeQuotaResponse";
const _UCR = "UpdateClusterRequest";
const _UCRI = "UpdateCodeRepositoryInput";
const _UCRO = "UpdateCodeRepositoryOutput";
const _UCRp = "UpdateClusterResponse";
const _UCRpd = "UpdateContextRequest";
const _UCRpda = "UpdateContextResponse";
const _UCRpdat = "UpdateCodeRepository";
const _UCS = "UpdateClusterSoftware";
const _UCSC = "UpdateClusterSchedulerConfig";
const _UCSCR = "UpdateClusterSchedulerConfigRequest";
const _UCSCRp = "UpdateClusterSchedulerConfigResponse";
const _UCSIG = "UpdateClusterSoftwareInstanceGroups";
const _UCSIGS = "UpdateClusterSoftwareInstanceGroupSpecification";
const _UCSR = "UpdateClusterSoftwareRequest";
const _UCSRp = "UpdateClusterSoftwareResponse";
const _UCp = "UpdateCluster";
const _UCpd = "UpdateContext";
const _UCs = "UserContext";
const _UD = "UpdateDevices";
const _UDF = "UpdateDeviceFleet";
const _UDFR = "UpdateDeviceFleetRequest";
const _UDR = "UpdateDevicesRequest";
const _UDRp = "UpdateDomainRequest";
const _UDRpd = "UpdateDomainResponse";
const _UDp = "UpdateDomain";
const _UE = "UpdateEndpoint";
const _UEI = "UpdateEndpointInput";
const _UEO = "UpdateEndpointOutput";
const _UER = "UpdateExperimentRequest";
const _UERp = "UpdateExperimentResponse";
const _UEWAC = "UpdateEndpointWeightsAndCapacities";
const _UEWACI = "UpdateEndpointWeightsAndCapacitiesInput";
const _UEWACO = "UpdateEndpointWeightsAndCapacitiesOutput";
const _UEp = "UpdateExperiment";
const _UF = "UpfrontFee";
const _UFG = "UpdateFeatureGroup";
const _UFGR = "UpdateFeatureGroupRequest";
const _UFGRp = "UpdateFeatureGroupResponse";
const _UFM = "UpdateFeatureMetadata";
const _UFMR = "UpdateFeatureMetadataRequest";
const _UG = "UserGroup";
const _UH = "UpdateHub";
const _UHC = "UpdateHubContent";
const _UHCR = "UpdateHubContentRequest";
const _UHCRR = "UpdateHubContentReferenceRequest";
const _UHCRRp = "UpdateHubContentReferenceResponse";
const _UHCRp = "UpdateHubContentResponse";
const _UHCRpd = "UpdateHubContentReference";
const _UHR = "UpdateHubRequest";
const _UHRp = "UpdateHubResponse";
const _UI = "UpdateImage";
const _UIC = "UnhealthyInstanceCount";
const _UICI = "UpdateInferenceComponentInput";
const _UICO = "UpdateInferenceComponentOutput";
const _UICRC = "UpdateInferenceComponentRuntimeConfig";
const _UICRCI = "UpdateInferenceComponentRuntimeConfigInput";
const _UICRCO = "UpdateInferenceComponentRuntimeConfigOutput";
const _UICp = "UpdateInferenceComponent";
const _UIE = "UserInfoEndpoint";
const _UIER = "UpdateInferenceExperimentRequest";
const _UIERp = "UpdateInferenceExperimentResponse";
const _UIEp = "UpdateInferenceExperiment";
const _UIR = "UpdateImageRequest";
const _UIRp = "UpdateImageResponse";
const _UIV = "UpdateImageVersion";
const _UIVR = "UpdateImageVersionRequest";
const _UIVRp = "UpdateImageVersionResponse";
const _UL = "UseLogit";
const _UMA = "UpdateMlflowApp";
const _UMAR = "UpdateMlflowAppRequest";
const _UMARp = "UpdateMlflowAppResponse";
const _UMARpd = "UpdateMonitoringAlertRequest";
const _UMARpda = "UpdateMonitoringAlertResponse";
const _UMAp = "UpdateMonitoringAlert";
const _UMC = "UpdateModelCard";
const _UMCR = "UpdateModelCardRequest";
const _UMCRp = "UpdateModelCardResponse";
const _UMP = "UpdateModelPackage";
const _UMPI = "UpdateModelPackageInput";
const _UMPO = "UpdateModelPackageOutput";
const _UMS = "UpdateMonitoringSchedule";
const _UMSR = "UpdateMonitoringScheduleRequest";
const _UMSRp = "UpdateMonitoringScheduleResponse";
const _UMTS = "UpdateMlflowTrackingServer";
const _UMTSR = "UpdateMlflowTrackingServerRequest";
const _UMTSRp = "UpdateMlflowTrackingServerResponse";
const _UNI = "UpdateNotebookInstance";
const _UNII = "UpdateNotebookInstanceInput";
const _UNILC = "UpdateNotebookInstanceLifecycleConfig";
const _UNILCI = "UpdateNotebookInstanceLifecycleConfigInput";
const _UNILCO = "UpdateNotebookInstanceLifecycleConfigOutput";
const _UNIO = "UpdateNotebookInstanceOutput";
const _UP = "UserPool";
const _UPA = "UserProfileArn";
const _UPAR = "UpdatePartnerAppRequest";
const _UPARp = "UpdatePartnerAppResponse";
const _UPAp = "UpdatePartnerApp";
const _UPD = "UserProfileDetails";
const _UPE = "UpdatePipelineExecution";
const _UPER = "UpdatePipelineExecutionRequest";
const _UPERp = "UpdatePipelineExecutionResponse";
const _UPI = "UpdateProjectInput";
const _UPL = "UserProfileList";
const _UPN = "UserProfileName";
const _UPNC = "UserProfileNameContains";
const _UPNE = "UserProfileNameEquals";
const _UPO = "UpdateProjectOutput";
const _UPR = "UpdatePipelineRequest";
const _UPRp = "UpdatePipelineResponse";
const _UPS = "UsersPerStep";
const _UPV = "UpdatePipelineVersion";
const _UPVR = "UpdatePipelineVersionRequest";
const _UPVRp = "UpdatePipelineVersionResponse";
const _UPp = "UpdatePipeline";
const _UPpd = "UpdateProject";
const _UPs = "UserProfiles";
const _US = "UserSettings";
const _USC = "UltraServerCount";
const _USD = "USD";
const _USI = "UltraServerInfo";
const _USIl = "UltraServerId";
const _USR = "UpdateSpaceRequest";
const _USRp = "UpdateSpaceResponse";
const _USS = "UltraServerSummary";
const _USSn = "UnifiedStudioSettings";
const _UST = "UltraServerType";
const _USl = "UltraServers";
const _USlt = "UltraServer";
const _USp = "UpdateSpace";
const _UT = "UiTemplate";
const _UTC = "UpdateTrialComponent";
const _UTCR = "UpdateTrialComponentRequest";
const _UTCRp = "UpdateTrialComponentResponse";
const _UTI = "UiTemplateInfo";
const _UTJ = "UpdateTrainingJob";
const _UTJR = "UpdateTrainingJobRequest";
const _UTJRp = "UpdateTrainingJobResponse";
const _UTP = "UpdateTemplateProvider";
const _UTPL = "UpdateTemplateProviderList";
const _UTR = "UpdateTrialRequest";
const _UTRp = "UpdateTrialResponse";
const _UTSU = "UiTemplateS3Uri";
const _UTp = "UpdateTrial";
const _UUP = "UpdateUserProfile";
const _UUPR = "UpdateUserProfileRequest";
const _UUPRp = "UpdateUserProfileResponse";
const _UW = "UpdateWorkforce";
const _UWR = "UpdateWorkforceRequest";
const _UWRp = "UpdateWorkforceResponse";
const _UWRpd = "UpdateWorkteamRequest";
const _UWRpda = "UpdateWorkteamResponse";
const _UWp = "UpdateWorkteam";
const _Ui = "Uid";
const _Un = "Unlabeled";
const _Uni = "Unit";
const _V = "Version";
const _VA = "VersionAliases";
const _VC = "VpcConfig";
const _VCL = "VisibilityConditionsList";
const _VCe = "VectorConfig";
const _VCi = "VisibilityConditions";
const _VCp = "VCpu";
const _VEI = "VpcEndpointId";
const _VF = "ValidationFraction";
const _VG = "VendorGuidance";
const _VH = "ValueHint";
const _VI = "VolumeId";
const _VIM = "ValueInMilliseconds";
const _VIe = "VersionId";
const _VIp = "VpcId";
const _VKKI = "VolumeKmsKeyId";
const _VN = "VariantName";
const _VNE = "VariantNameEquals";
const _VOTA = "VpcOnlyTrustedAccounts";
const _VP = "ValidationProfiles";
const _VPL = "VariantPropertyList";
const _VPT = "VariantPropertyType";
const _VPa = "VariantProperty";
const _VR = "ValidationRole";
const _VRi = "ViolationReport";
const _VS = "ValidationStatuses";
const _VSI = "VpcSourceIp";
const _VSIGB = "VolumeSizeInGB";
const _VSa = "ValidationSpecification";
const _VSar = "VariantStatus";
const _VT = "ValueType";
const _Va = "Value";
const _Val = "Values";
const _Ve = "Vertices";
const _Ver = "Vertex";
const _W = "Workforce";
const _WA = "WorkforceArn";
const _WAC = "WorkerAccessConfiguration";
const _WAo = "WorkteamArn";
const _WG = "WorkGroup";
const _WIIS = "WaitIntervalInSeconds";
const _WMWS = "WeeklyMaintenanceWindowStart";
const _WN = "WorkforceName";
const _WNo = "WorkteamName";
const _WPS = "WarmPoolStatus";
const _WPSE = "WarmPoolStatusEquals";
const _WRAI = "WorkRequesterAccountId";
const _WS = "WorkspaceSettings";
const _WSC = "WarmStartConfig";
const _WST = "WarmStartType";
const _WVC = "WorkforceVpcConfig";
const _WVCR = "WorkforceVpcConfigRequest";
const _WVCRo = "WorkforceVpcConfigResponse";
const _We = "Weight";
const _Wo = "Workteam";
const _Wor = "Workforces";
const _Work = "Workteams";
const _a = "application/json";
const _c = "client";
const _e = "error";
const _mT = "mediaType";
const _s = "smithy.ts.sdk.synthetic.com.amazonaws.sagemaker";
const n0 = "com.amazonaws.sagemaker";
import { TypeRegistry } from "@smithy/core/schema";
import { ConflictException, ResourceInUse, ResourceLimitExceeded, ResourceNotFound } from "../models/errors";
import { SageMakerServiceException } from "../models/SageMakerServiceException";
const _s_registry = TypeRegistry.for(_s);
export var SageMakerServiceException$ = [-3, _s, "SageMakerServiceException", 0, [], []];
_s_registry.registerError(SageMakerServiceException$, SageMakerServiceException);
const n0_registry = TypeRegistry.for(n0);
export var ConflictException$ = [-3, n0, _CE,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(ConflictException$, ConflictException);
export var ResourceInUse$ = [-3, n0, _RIU,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(ResourceInUse$, ResourceInUse);
export var ResourceLimitExceeded$ = [-3, n0, _RLE,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(ResourceLimitExceeded$, ResourceLimitExceeded);
export var ResourceNotFound$ = [-3, n0, _RNF,
    { [_e]: _c },
    [_M],
    [0]
];
n0_registry.registerError(ResourceNotFound$, ResourceNotFound);
export const errorTypeRegistries = [
    _s_registry,
    n0_registry,
];
var ClientSecret = [0, n0, _CS, 8, 0];
var HumanLoopActivationConditions = [0, n0, _HLAC, { [_mT]: _a }, 0];
var ModelCardContent = [0, n0, _MCC, 8, 0];
export var AcceleratorPartitionConfig$ = [3, n0, _APC,
    0,
    [_T, _C],
    [0, 1], 2
];
export var ActionSource$ = [3, n0, _AS,
    0,
    [_SU, _ST, _SI],
    [0, 0, 0], 1
];
export var ActionSummary$ = [3, n0, _ASc,
    0,
    [_AA, _AN, _S, _AT, _St, _CT, _LMT],
    [0, 0, () => ActionSource$, 0, 0, 4, 4]
];
export var AddAssociationRequest$ = [3, n0, _AAR,
    0,
    [_SA, _DA, _ATs],
    [0, 0, 0], 2
];
export var AddAssociationResponse$ = [3, n0, _AARd,
    0,
    [_SA, _DA],
    [0, 0]
];
export var AddClusterNodeSpecification$ = [3, n0, _ACNS,
    0,
    [_IGN, _ITCB],
    [0, 1], 2
];
export var AdditionalEnis$ = [3, n0, _AE,
    0,
    [_EE],
    [64 | 0]
];
export var AdditionalInferenceSpecificationDefinition$ = [3, n0, _AISD,
    0,
    [_N, _Co, _D, _STIT, _SRIIT, _SCT, _SRMIMET],
    [0, () => ModelPackageContainerDefinitionList, 0, 64 | 0, 64 | 0, 64 | 0, 64 | 0], 2
];
export var AdditionalModelDataSource$ = [3, n0, _AMDS,
    0,
    [_CN, _SDS],
    [0, () => S3ModelDataSource$], 2
];
export var AdditionalS3DataSource$ = [3, n0, _ASDS,
    0,
    [_SDT, _SUr, _CTo, _ET],
    [0, 0, 0, 0], 2
];
export var AddTagsInput$ = [3, n0, _ATI,
    0,
    [_RA, _Ta],
    [0, () => TagList], 2
];
export var AddTagsOutput$ = [3, n0, _ATO,
    0,
    [_Ta],
    [() => TagList]
];
export var AgentVersion$ = [3, n0, _AV,
    0,
    [_V, _AC],
    [0, 1], 2
];
export var Alarm$ = [3, n0, _A,
    0,
    [_ANl],
    [0]
];
export var AlarmDetails$ = [3, n0, _AD,
    0,
    [_ANl],
    [0], 1
];
export var AlgorithmSpecification$ = [3, n0, _ASl,
    0,
    [_TIM, _TI, _ANlg, _MD, _ESMMTS, _CEo, _CA, _TIC],
    [0, 0, 0, () => MetricDefinitionList, 2, 64 | 0, 64 | 0, () => TrainingImageConfig$], 1
];
export var AlgorithmStatusDetails$ = [3, n0, _ASD,
    0,
    [_VS, _ISS],
    [() => AlgorithmStatusItemList, () => AlgorithmStatusItemList]
];
export var AlgorithmStatusItem$ = [3, n0, _ASI,
    0,
    [_N, _St, _FR],
    [0, 0, 0], 2
];
export var AlgorithmSummary$ = [3, n0, _ASlg,
    0,
    [_ANlg, _AAl, _CT, _ASlgo, _ADl],
    [0, 0, 4, 0, 0], 4
];
export var AlgorithmValidationProfile$ = [3, n0, _AVP,
    0,
    [_PN, _TJD, _TJDr],
    [0, () => TrainingJobDefinition$, () => TransformJobDefinition$], 2
];
export var AlgorithmValidationSpecification$ = [3, n0, _AVS,
    0,
    [_VR, _VP],
    [0, () => AlgorithmValidationProfiles], 2
];
export var AmazonQSettings$ = [3, n0, _AQS,
    0,
    [_St, _QPA],
    [0, 0]
];
export var AnnotationConsolidationConfig$ = [3, n0, _ACC,
    0,
    [_ACLA],
    [0], 1
];
export var AppDetails$ = [3, n0, _ADp,
    0,
    [_DI, _UPN, _SN, _ATp, _ANp, _St, _CT, _RS],
    [0, 0, 0, 0, 0, 0, 4, () => ResourceSpec$]
];
export var AppImageConfigDetails$ = [3, n0, _AICD,
    0,
    [_AICA, _AICN, _CT, _LMT, _KGIC, _JLAIC, _CEAIC],
    [0, 0, 4, 4, () => KernelGatewayImageConfig$, () => JupyterLabAppImageConfig$, () => CodeEditorAppImageConfig$]
];
export var AppLifecycleManagement$ = [3, n0, _ALM,
    0,
    [_IS],
    [() => IdleSettings$]
];
export var AppSpecification$ = [3, n0, _ASp,
    0,
    [_IU, _CEo, _CA],
    [0, 64 | 0, 64 | 0], 1
];
export var ArtifactSource$ = [3, n0, _ASr,
    0,
    [_SU, _STo],
    [0, () => ArtifactSourceTypes], 1
];
export var ArtifactSourceType$ = [3, n0, _AST,
    0,
    [_SIT, _Va],
    [0, 0], 2
];
export var ArtifactSummary$ = [3, n0, _ASrt,
    0,
    [_AAr, _ANr, _S, _ATr, _CT, _LMT],
    [0, 0, () => ArtifactSource$, 0, 4, 4]
];
export var AssociateTrialComponentRequest$ = [3, n0, _ATCR,
    0,
    [_TCN, _TN],
    [0, 0], 2
];
export var AssociateTrialComponentResponse$ = [3, n0, _ATCRs,
    0,
    [_TCA, _TA],
    [0, 0]
];
export var AssociationInfo$ = [3, n0, _AI,
    0,
    [_SA, _DA],
    [0, 0], 2
];
export var AssociationSummary$ = [3, n0, _ASs,
    0,
    [_SA, _DA, _ST, _DT, _ATs, _SNo, _DN, _CT, _CB],
    [0, 0, 0, 0, 0, 0, 0, 4, () => UserContext$]
];
export var AsyncInferenceClientConfig$ = [3, n0, _AICC,
    0,
    [_MCIPI],
    [1]
];
export var AsyncInferenceConfig$ = [3, n0, _AIC,
    0,
    [_OC, _CC],
    [() => AsyncInferenceOutputConfig$, () => AsyncInferenceClientConfig$], 1
];
export var AsyncInferenceNotificationConfig$ = [3, n0, _AINC,
    0,
    [_STu, _ETr, _IIRI],
    [0, 0, 64 | 0]
];
export var AsyncInferenceOutputConfig$ = [3, n0, _AIOC,
    0,
    [_KKI, _SOP, _NC, _SFP],
    [0, 0, () => AsyncInferenceNotificationConfig$, 0]
];
export var AthenaDatasetDefinition$ = [3, n0, _ADD,
    0,
    [_Ca, _Da, _QS, _OSU, _OF, _WG, _KKI, _OCu],
    [0, 0, 0, 0, 0, 0, 0, 0], 5
];
export var AttachClusterNodeVolumeRequest$ = [3, n0, _ACNVR,
    0,
    [_CAl, _NI, _VI],
    [0, 0, 0], 3
];
export var AttachClusterNodeVolumeResponse$ = [3, n0, _ACNVRt,
    0,
    [_CAl, _NI, _VI, _ATt, _St, _DNe],
    [0, 0, 0, 4, 0, 0], 6
];
export var AuthorizedUrl$ = [3, n0, _AU,
    0,
    [_U, _LP],
    [0, 0]
];
export var AutoMLAlgorithmConfig$ = [3, n0, _AMLAC,
    0,
    [_AMLA],
    [64 | 0], 1
];
export var AutoMLCandidate$ = [3, n0, _AMLC,
    0,
    [_CNa, _OS, _CSa, _CSan, _CT, _LMT, _FAMLJOM, _IC, _ETn, _FR, _CP, _ICD],
    [0, 0, () => CandidateSteps, 0, 4, 4, () => FinalAutoMLJobObjectiveMetric$, () => AutoMLContainerDefinitions, 4, 0, () => CandidateProperties$, () => AutoMLInferenceContainerDefinitions], 6
];
export var AutoMLCandidateGenerationConfig$ = [3, n0, _AMLCGC,
    0,
    [_FSSU, _ACl],
    [0, () => AutoMLAlgorithmsConfig]
];
export var AutoMLCandidateStep$ = [3, n0, _AMLCS,
    0,
    [_CST, _CSA, _CSN],
    [0, 0, 0], 3
];
export var AutoMLChannel$ = [3, n0, _AMLCu,
    0,
    [_TAN, _DS, _CTo, _CTon, _CTh, _SWAN],
    [0, () => AutoMLDataSource$, 0, 0, 0, 0], 1
];
export var AutoMLComputeConfig$ = [3, n0, _AMLCC,
    0,
    [_ESCC],
    [() => EmrServerlessComputeConfig$]
];
export var AutoMLContainerDefinition$ = [3, n0, _AMLCD,
    0,
    [_I, _MDU, _E],
    [0, 0, 128 | 0], 2
];
export var AutoMLDataSource$ = [3, n0, _AMLDS,
    0,
    [_SDS],
    [() => AutoMLS3DataSource$], 1
];
export var AutoMLDataSplitConfig$ = [3, n0, _AMLDSC,
    0,
    [_VF],
    [1]
];
export var AutoMLJobArtifacts$ = [3, n0, _AMLJA,
    0,
    [_CDNL, _DENL],
    [0, 0]
];
export var AutoMLJobChannel$ = [3, n0, _AMLJC,
    0,
    [_CTh, _CTon, _CTo, _DS],
    [0, 0, 0, () => AutoMLDataSource$]
];
export var AutoMLJobCompletionCriteria$ = [3, n0, _AMLJCC,
    0,
    [_MC, _MRPTJIS, _MAMLJRIS],
    [1, 1, 1]
];
export var AutoMLJobConfig$ = [3, n0, _AMLJCu,
    0,
    [_CCo, _SC, _CGC, _DSC, _Mo],
    [() => AutoMLJobCompletionCriteria$, () => AutoMLSecurityConfig$, () => AutoMLCandidateGenerationConfig$, () => AutoMLDataSplitConfig$, 0]
];
export var AutoMLJobObjective$ = [3, n0, _AMLJO,
    0,
    [_MN],
    [0], 1
];
export var AutoMLJobStepMetadata$ = [3, n0, _AMLJSM,
    0,
    [_Ar],
    [0]
];
export var AutoMLJobSummary$ = [3, n0, _AMLJS,
    0,
    [_AMLJN, _AMLJAu, _AMLJSu, _AMLJSS, _CT, _LMT, _ETn, _FR, _PFR],
    [0, 0, 0, 0, 4, 4, 4, 0, () => AutoMLPartialFailureReasons], 6
];
export var AutoMLOutputDataConfig$ = [3, n0, _AMLODC,
    0,
    [_SOP, _KKI],
    [0, 0], 1
];
export var AutoMLPartialFailureReason$ = [3, n0, _AMLPFR,
    0,
    [_PFM],
    [0]
];
export var AutoMLResolvedAttributes$ = [3, n0, _AMLRA,
    0,
    [_AMLJO, _CCo, _AMLPTRA],
    [() => AutoMLJobObjective$, () => AutoMLJobCompletionCriteria$, () => AutoMLProblemTypeResolvedAttributes$]
];
export var AutoMLS3DataSource$ = [3, n0, _AMLSDS,
    0,
    [_SDT, _SUr],
    [0, 0], 2
];
export var AutoMLSecurityConfig$ = [3, n0, _AMLSC,
    0,
    [_VKKI, _EICTE, _VC],
    [0, 2, () => VpcConfig$]
];
export var AutoParameter$ = [3, n0, _AP,
    0,
    [_N, _VH],
    [0, 0], 2
];
export var AutoRollbackConfig$ = [3, n0, _ARC,
    0,
    [_Al],
    [() => AlarmList]
];
export var Autotune$ = [3, n0, _Au,
    0,
    [_Mo],
    [0], 1
];
export var AvailableUpgrade$ = [3, n0, _AUv,
    0,
    [_V, _RN],
    [0, 64 | 0]
];
export var BaseModel$ = [3, n0, _BM,
    0,
    [_HCN, _HCV, _RNe],
    [0, 0, 0]
];
export var BatchAddClusterNodesError$ = [3, n0, _BACNE,
    0,
    [_IGN, _EC, _FC, _M],
    [0, 0, 1, 0], 3
];
export var BatchAddClusterNodesRequest$ = [3, n0, _BACNR,
    0,
    [_CNl, _NTA, _CTl],
    [0, () => AddClusterNodeSpecificationList, [0, 4]], 2
];
export var BatchAddClusterNodesResponse$ = [3, n0, _BACNRa,
    0,
    [_Su, _F],
    [() => NodeAdditionResultList, () => BatchAddClusterNodesErrorList], 2
];
export var BatchDataCaptureConfig$ = [3, n0, _BDCC,
    0,
    [_DSU, _KKI, _GII],
    [0, 0, 2], 1
];
export var BatchDeleteClusterNodeLogicalIdsError$ = [3, n0, _BDCNLIE,
    0,
    [_Cod, _M, _NLI],
    [0, 0, 0], 3
];
export var BatchDeleteClusterNodesError$ = [3, n0, _BDCNE,
    0,
    [_Cod, _M, _NI],
    [0, 0, 0], 3
];
export var BatchDeleteClusterNodesRequest$ = [3, n0, _BDCNR,
    0,
    [_CNl, _NIo, _NLIo],
    [0, 64 | 0, 64 | 0], 1
];
export var BatchDeleteClusterNodesResponse$ = [3, n0, _BDCNRa,
    0,
    [_F, _Su, _FNLI, _SNLI],
    [() => BatchDeleteClusterNodesErrorList, 64 | 0, () => BatchDeleteClusterNodeLogicalIdsErrorList, 64 | 0]
];
export var BatchDescribeModelPackageError$ = [3, n0, _BDMPE,
    0,
    [_EC, _ER],
    [0, 0], 2
];
export var BatchDescribeModelPackageInput$ = [3, n0, _BDMPI,
    0,
    [_MPAL],
    [64 | 0], 1
];
export var BatchDescribeModelPackageOutput$ = [3, n0, _BDMPO,
    0,
    [_MPS, _BDMPEM],
    [() => ModelPackageSummaries, () => BatchDescribeModelPackageErrorMap]
];
export var BatchDescribeModelPackageSummary$ = [3, n0, _BDMPS,
    0,
    [_MPGN, _MPA, _CT, _ISn, _MPSo, _MPV, _MPD, _MAS, _MPRT],
    [0, 0, 4, () => InferenceSpecification$, 0, 1, 0, 0, 0], 5
];
export var BatchRebootClusterNodeLogicalIdsError$ = [3, n0, _BRCNLIE,
    0,
    [_NLI, _EC, _M],
    [0, 0, 0], 3
];
export var BatchRebootClusterNodesError$ = [3, n0, _BRCNE,
    0,
    [_NI, _EC, _M],
    [0, 0, 0], 3
];
export var BatchRebootClusterNodesRequest$ = [3, n0, _BRCNR,
    0,
    [_CNl, _NIo, _NLIo],
    [0, 64 | 0, 64 | 0], 1
];
export var BatchRebootClusterNodesResponse$ = [3, n0, _BRCNRa,
    0,
    [_Su, _F, _FNLI, _SNLI],
    [64 | 0, () => BatchRebootClusterNodesErrors, () => BatchRebootClusterNodeLogicalIdsErrors, 64 | 0]
];
export var BatchReplaceClusterNodeLogicalIdsError$ = [3, n0, _BRCNLIEa,
    0,
    [_NLI, _EC, _M],
    [0, 0, 0], 3
];
export var BatchReplaceClusterNodesError$ = [3, n0, _BRCNEa,
    0,
    [_NI, _EC, _M],
    [0, 0, 0], 3
];
export var BatchReplaceClusterNodesRequest$ = [3, n0, _BRCNRat,
    0,
    [_CNl, _NIo, _NLIo],
    [0, 64 | 0, 64 | 0], 1
];
export var BatchReplaceClusterNodesResponse$ = [3, n0, _BRCNRatc,
    0,
    [_Su, _F, _FNLI, _SNLI],
    [64 | 0, () => BatchReplaceClusterNodesErrors, () => BatchReplaceClusterNodeLogicalIdsErrors, 64 | 0]
];
export var BatchTransformInput$ = [3, n0, _BTI,
    0,
    [_DCDSU, _DF, _LP, _SIM, _SDDT, _FA, _IA, _PA, _PTA, _STO, _ETO, _EFA],
    [0, () => MonitoringDatasetFormat$, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0], 3
];
export var BedrockCustomModelDeploymentMetadata$ = [3, n0, _BCMDM,
    0,
    [_Ar],
    [0]
];
export var BedrockCustomModelMetadata$ = [3, n0, _BCMM,
    0,
    [_Ar],
    [0]
];
export var BedrockModelImportMetadata$ = [3, n0, _BMIM,
    0,
    [_Ar],
    [0]
];
export var BedrockProvisionedModelThroughputMetadata$ = [3, n0, _BPMTM,
    0,
    [_Ar],
    [0]
];
export var BestObjectiveNotImproving$ = [3, n0, _BONI,
    0,
    [_MNOTJNI],
    [1]
];
export var Bias$ = [3, n0, _B,
    0,
    [_R, _PTR, _PTRo],
    [() => MetricsSource$, () => MetricsSource$, () => MetricsSource$]
];
export var BlueGreenUpdatePolicy$ = [3, n0, _BGUP,
    0,
    [_TRC, _TWIS, _METIS],
    [() => TrafficRoutingConfig$, 1, 1], 1
];
export var CacheHitResult$ = [3, n0, _CHR,
    0,
    [_SPEA],
    [0]
];
export var CallbackStepMetadata$ = [3, n0, _CSM,
    0,
    [_CTa, _SQU, _OP],
    [0, 0, () => OutputParameterList]
];
export var CandidateArtifactLocations$ = [3, n0, _CAL,
    0,
    [_Ex, _MI, _BR],
    [0, 0, 0], 1
];
export var CandidateGenerationConfig$ = [3, n0, _CGC,
    0,
    [_ACl],
    [() => AutoMLAlgorithmsConfig]
];
export var CandidateProperties$ = [3, n0, _CP,
    0,
    [_CAL, _CM],
    [() => CandidateArtifactLocations$, () => MetricDataList]
];
export var CanvasAppSettings$ = [3, n0, _CAS,
    0,
    [_TSFS, _MRS, _WS, _IPOAS, _DDS, _KS, _GAS, _ESS],
    [() => TimeSeriesForecastingSettings$, () => ModelRegisterSettings$, () => WorkspaceSettings$, () => IdentityProviderOAuthSettings, () => DirectDeploySettings$, () => KendraSettings$, () => GenerativeAiSettings$, () => EmrServerlessSettings$]
];
export var CapacityReservation$ = [3, n0, _CR,
    0,
    [_Ar, _T],
    [0, 0]
];
export var CapacitySize$ = [3, n0, _CSap,
    0,
    [_T, _Va],
    [0, 1], 2
];
export var CapacitySizeConfig$ = [3, n0, _CSC,
    0,
    [_T, _Va],
    [0, 1], 2
];
export var CaptureContentTypeHeader$ = [3, n0, _CCTH,
    0,
    [_CCT, _JCT],
    [64 | 0, 64 | 0]
];
export var CaptureOption$ = [3, n0, _CO,
    0,
    [_CMa],
    [0], 1
];
export var CategoricalParameter$ = [3, n0, _CPa,
    0,
    [_N, _Va],
    [0, 64 | 0], 2
];
export var CategoricalParameterRange$ = [3, n0, _CPR,
    0,
    [_N, _Val],
    [0, 64 | 0], 2
];
export var CategoricalParameterRangeSpecification$ = [3, n0, _CPRS,
    0,
    [_Val],
    [64 | 0], 1
];
export var CfnCreateTemplateProvider$ = [3, n0, _CCTP,
    0,
    [_TNe, _TURL, _RARN, _P],
    [0, 0, 0, () => CfnStackCreateParameters], 2
];
export var CfnStackCreateParameter$ = [3, n0, _CSCP,
    0,
    [_K, _Va],
    [0, 0], 1
];
export var CfnStackDetail$ = [3, n0, _CSD,
    0,
    [_SM, _N, _Id],
    [0, 0, 0], 1
];
export var CfnStackParameter$ = [3, n0, _CSP,
    0,
    [_K, _Va],
    [0, 0], 1
];
export var CfnStackUpdateParameter$ = [3, n0, _CSUP,
    0,
    [_K, _Va],
    [0, 0], 1
];
export var CfnTemplateProviderDetail$ = [3, n0, _CTPD,
    0,
    [_TNe, _TURL, _RARN, _P, _SD],
    [0, 0, 0, () => CfnStackParameters, () => CfnStackDetail$], 2
];
export var CfnUpdateTemplateProvider$ = [3, n0, _CUTP,
    0,
    [_TNe, _TURL, _P],
    [0, 0, () => CfnStackUpdateParameters], 2
];
export var Channel$ = [3, n0, _Ch,
    0,
    [_CN, _DS, _CTon, _CTo, _RWT, _IM, _SCh],
    [0, () => DataSource$, 0, 0, 0, 0, () => ShuffleConfig$], 2
];
export var ChannelSpecification$ = [3, n0, _CSh,
    0,
    [_N, _SCT, _SIMu, _D, _IR, _SCTu],
    [0, 64 | 0, 64 | 0, 0, 2, 64 | 0], 3
];
export var CheckpointConfig$ = [3, n0, _CCh,
    0,
    [_SUr, _LP],
    [0, 0], 1
];
export var ClarifyCheckStepMetadata$ = [3, n0, _CCSM,
    0,
    [_CThe, _BUFDCC, _CBC, _MPGN, _VRi, _CJA, _SCk, _RNB],
    [0, 0, 0, 0, 0, 0, 2, 2]
];
export var ClarifyExplainerConfig$ = [3, n0, _CEC,
    0,
    [_SCha, _EEn, _ICn],
    [() => ClarifyShapConfig$, 0, () => ClarifyInferenceConfig$], 1
];
export var ClarifyInferenceConfig$ = [3, n0, _CIC,
    0,
    [_FA, _CTont, _MRC, _MPIMB, _PI, _LI, _PA, _LA, _LH, _FH, _FT],
    [0, 0, 1, 1, 1, 1, 0, 0, 64 | 0, 64 | 0, 64 | 0]
];
export var ClarifyShapBaselineConfig$ = [3, n0, _CSBC,
    0,
    [_MT, _SB, _SBU],
    [0, 0, 0]
];
export var ClarifyShapConfig$ = [3, n0, _CSCl,
    0,
    [_SBC, _NOS, _UL, _Se, _TC],
    [() => ClarifyShapBaselineConfig$, 1, 2, 1, () => ClarifyTextConfig$], 1
];
export var ClarifyTextConfig$ = [3, n0, _CTC,
    0,
    [_L, _G],
    [0, 0], 2
];
export var ClusterAutoScalingConfig$ = [3, n0, _CASC,
    0,
    [_Mo, _ASTu],
    [0, 0], 1
];
export var ClusterAutoScalingConfigOutput$ = [3, n0, _CASCO,
    0,
    [_Mo, _St, _ASTu, _FM],
    [0, 0, 0, 0], 2
];
export var ClusterCapacityRequirements$ = [3, n0, _CCR,
    0,
    [_Sp, _OD],
    [() => ClusterSpotOptions$, () => ClusterOnDemandOptions$]
];
export var ClusterEbsVolumeConfig$ = [3, n0, _CEVC,
    0,
    [_VSIGB, _VKKI, _RV],
    [1, 0, 2]
];
export var ClusterEventDetail$ = [3, n0, _CED,
    0,
    [_EI, _CAl, _CNl, _RT, _ETv, _IGN, _II, _ED, _D],
    [0, 0, 0, 0, 4, 0, 0, () => EventDetails$, 0], 5
];
export var ClusterEventSummary$ = [3, n0, _CES,
    0,
    [_EI, _CAl, _CNl, _RT, _ETv, _IGN, _II, _D],
    [0, 0, 0, 0, 4, 0, 0, 0], 5
];
export var ClusterFsxLustreConfig$ = [3, n0, _CFLC,
    0,
    [_DNn, _MNo, _MP],
    [0, 0, 0], 2
];
export var ClusterFsxOpenZfsConfig$ = [3, n0, _CFOZC,
    0,
    [_DNn, _MP],
    [0, 0], 1
];
export var ClusterInstanceGroupDetails$ = [3, n0, _CIGD,
    0,
    [_CCu, _TCa, _MCi, _IGN, _IT, _LCC, _ERx, _TPC, _ISC, _OSDHC, _St, _TPA, _TPS, _OVC, _SUC, _CII, _DII, _AO, _KC, _CRa, _TSC, _SUS, _ASUC, _SCl],
    [1, 1, 1, 0, 0, () => ClusterLifeCycleConfig$, 0, 1, () => ClusterInstanceStorageConfigs, 64 | 0, 0, 0, 0, () => VpcConfig$, () => ScheduledUpdateConfig$, 0, 0, 128 | 1, () => ClusterKubernetesConfigDetails$, () => ClusterCapacityRequirements$, 1, 0, () => DeploymentConfiguration$, () => ClusterSlurmConfigDetails$]
];
export var ClusterInstanceGroupSpecification$ = [3, n0, _CIGS,
    0,
    [_ICns, _IGN, _IT, _LCC, _ERx, _MIC, _TPC, _ISC, _OSDHC, _TPA, _OVC, _SUC, _IIm, _KC, _SCl, _CRa],
    [1, 0, 0, () => ClusterLifeCycleConfig$, 0, 1, 1, () => ClusterInstanceStorageConfigs, 64 | 0, 0, () => VpcConfig$, () => ScheduledUpdateConfig$, 0, () => ClusterKubernetesConfig$, () => ClusterSlurmConfig$, () => ClusterCapacityRequirements$], 5
];
export var ClusterInstancePlacement$ = [3, n0, _CIP,
    0,
    [_AZ, _AZI],
    [0, 0]
];
export var ClusterInstanceStatusDetails$ = [3, n0, _CISD,
    0,
    [_St, _M],
    [0, 0], 1
];
export var ClusterKubernetesConfig$ = [3, n0, _CKC,
    0,
    [_La, _Tai],
    [128 | 0, () => ClusterKubernetesTaints]
];
export var ClusterKubernetesConfigDetails$ = [3, n0, _CKCD,
    0,
    [_CL, _DL, _CTu, _DTe],
    [128 | 0, 128 | 0, () => ClusterKubernetesTaints, () => ClusterKubernetesTaints]
];
export var ClusterKubernetesConfigNodeDetails$ = [3, n0, _CKCND,
    0,
    [_CL, _DL, _CTu, _DTe],
    [128 | 0, 128 | 0, () => ClusterKubernetesTaints, () => ClusterKubernetesTaints]
];
export var ClusterKubernetesTaint$ = [3, n0, _CKT,
    0,
    [_K, _Ef, _Va],
    [0, 0, 0], 2
];
export var ClusterLifeCycleConfig$ = [3, n0, _CLCC,
    0,
    [_SSU, _OCn],
    [0, 0], 2
];
export var ClusterMetadata$ = [3, n0, _CMl,
    0,
    [_FM, _ERAE, _SAE],
    [0, 64 | 0, 0]
];
export var ClusterNodeDetails$ = [3, n0, _CND,
    0,
    [_IGN, _II, _NLI, _ISns, _IT, _LT, _LSUT, _LCC, _OVC, _TPC, _ISC, _PPI, _PPIr, _PDH, _Pl, _CII, _DII, _USI, _KC, _CTap],
    [0, 0, 0, () => ClusterInstanceStatusDetails$, 0, 4, 4, () => ClusterLifeCycleConfig$, () => VpcConfig$, 1, () => ClusterInstanceStorageConfigs, 0, 0, 0, () => ClusterInstancePlacement$, 0, 0, () => UltraServerInfo$, () => ClusterKubernetesConfigNodeDetails$, 0]
];
export var ClusterNodeSummary$ = [3, n0, _CNS,
    0,
    [_IGN, _II, _IT, _LT, _ISns, _NLI, _LSUT, _USI, _PDH],
    [0, 0, 0, 4, () => ClusterInstanceStatusDetails$, 0, 4, () => UltraServerInfo$, 0], 5
];
export var ClusterOnDemandOptions$ = [3, n0, _CODO,
    0,
    [],
    []
];
export var ClusterOrchestrator$ = [3, n0, _COl,
    0,
    [_Ek, _Sl],
    [() => ClusterOrchestratorEksConfig$, () => ClusterOrchestratorSlurmConfig$]
];
export var ClusterOrchestratorEksConfig$ = [3, n0, _COEC,
    0,
    [_CAl],
    [0], 1
];
export var ClusterOrchestratorSlurmConfig$ = [3, n0, _COSC,
    0,
    [_SCS],
    [0]
];
export var ClusterRestrictedInstanceGroupDetails$ = [3, n0, _CRIGD,
    0,
    [_CCu, _TCa, _IGN, _IT, _ERx, _TPC, _ISC, _OSDHC, _St, _TPA, _TPS, _OVC, _SUC, _ECn],
    [1, 1, 0, 0, 0, 1, () => ClusterInstanceStorageConfigs, 64 | 0, 0, 0, 0, () => VpcConfig$, () => ScheduledUpdateConfig$, () => EnvironmentConfigDetails$]
];
export var ClusterRestrictedInstanceGroupSpecification$ = [3, n0, _CRIGS,
    0,
    [_ICns, _IGN, _IT, _ERx, _ECn, _TPC, _ISC, _OSDHC, _TPA, _OVC, _SUC],
    [1, 0, 0, 0, () => EnvironmentConfig$, 1, () => ClusterInstanceStorageConfigs, 64 | 0, 0, () => VpcConfig$, () => ScheduledUpdateConfig$], 5
];
export var ClusterSchedulerConfigSummary$ = [3, n0, _CSCS,
    0,
    [_CSCA, _CSCI, _N, _CT, _St, _CSCV, _LMT, _CAl],
    [0, 0, 0, 4, 0, 1, 4, 0], 5
];
export var ClusterSlurmConfig$ = [3, n0, _CSClu,
    0,
    [_NT, _PNa],
    [0, 64 | 0], 1
];
export var ClusterSlurmConfigDetails$ = [3, n0, _CSCD,
    0,
    [_NT, _PNa],
    [0, 64 | 0], 1
];
export var ClusterSpotOptions$ = [3, n0, _CSO,
    0,
    [],
    []
];
export var ClusterSummary$ = [3, n0, _CSl,
    0,
    [_CAl, _CNl, _CT, _CSlu, _TPAr],
    [0, 0, 4, 0, 64 | 0], 4
];
export var ClusterTieredStorageConfig$ = [3, n0, _CTSC,
    0,
    [_Mo, _IMAP],
    [0, 1], 1
];
export var CodeEditorAppImageConfig$ = [3, n0, _CEAIC,
    0,
    [_FSC, _CCon],
    [() => FileSystemConfig$, () => ContainerConfig$]
];
export var CodeEditorAppSettings$ = [3, n0, _CEAS,
    0,
    [_DRS, _CI, _LCA, _ALM, _BILCA],
    [() => ResourceSpec$, () => CustomImages, 64 | 0, () => AppLifecycleManagement$, 0]
];
export var CodeRepository$ = [3, n0, _CRo,
    0,
    [_RU],
    [0], 1
];
export var CodeRepositorySummary$ = [3, n0, _CRS,
    0,
    [_CRN, _CRA, _CT, _LMT, _GC],
    [0, 0, 4, 4, () => GitConfig$], 4
];
export var CognitoConfig$ = [3, n0, _CCog,
    0,
    [_UP, _CIl],
    [0, 0], 2
];
export var CognitoMemberDefinition$ = [3, n0, _CMD,
    0,
    [_UP, _UG, _CIl],
    [0, 0, 0], 3
];
export var CollectionConfiguration$ = [3, n0, _CCol,
    0,
    [_CNo, _CPo],
    [0, 128 | 0]
];
export var CompilationJobSummary$ = [3, n0, _CJS,
    0,
    [_CJN, _CJAo, _CT, _CJSo, _CSTo, _CET, _CTD, _CTPO, _CTPA, _CTPAo, _LMT],
    [0, 0, 4, 0, 4, 4, 0, 0, 0, 0, 4], 4
];
export var ComputeQuotaConfig$ = [3, n0, _CQC,
    0,
    [_CQR, _RSC, _PTT],
    [() => ComputeQuotaResourceConfigList, () => ResourceSharingConfig$, 0]
];
export var ComputeQuotaResourceConfig$ = [3, n0, _CQRC,
    0,
    [_IT, _C, _Ac, _VCp, _MIGB, _APc],
    [0, 1, 1, 1, 1, () => AcceleratorPartitionConfig$], 1
];
export var ComputeQuotaSummary$ = [3, n0, _CQS,
    0,
    [_CQA, _CQI, _N, _St, _CQT, _CT, _CQV, _CAl, _CQC, _ASct, _LMT],
    [0, 0, 0, 0, () => ComputeQuotaTarget$, 4, 1, 0, () => ComputeQuotaConfig$, 0, 4], 6
];
export var ComputeQuotaTarget$ = [3, n0, _CQT,
    0,
    [_TNea, _FSW],
    [0, 1], 1
];
export var ConditionStepMetadata$ = [3, n0, _CSMo,
    0,
    [_O],
    [0]
];
export var ContainerConfig$ = [3, n0, _CCon,
    0,
    [_CA, _CEo, _CEV],
    [64 | 0, 64 | 0, 128 | 0]
];
export var ContainerDefinition$ = [3, n0, _CD,
    0,
    [_CH, _I, _ICm, _Mo, _MDU, _MDS, _AMDSd, _E, _MPN, _ISN, _MMC],
    [0, 0, () => ImageConfig$, 0, 0, () => ModelDataSource$, () => AdditionalModelDataSources, 128 | 0, 0, 0, () => MultiModelConfig$]
];
export var ContextSource$ = [3, n0, _CSo,
    0,
    [_SU, _ST, _SI],
    [0, 0, 0], 1
];
export var ContextSummary$ = [3, n0, _CSon,
    0,
    [_CAo, _CNon, _S, _CTonte, _CT, _LMT],
    [0, 0, () => ContextSource$, 0, 4, 4]
];
export var ContinuousParameterRange$ = [3, n0, _CPRo,
    0,
    [_N, _MV, _MVa, _STc],
    [0, 0, 0, 0], 3
];
export var ContinuousParameterRangeSpecification$ = [3, n0, _CPRSo,
    0,
    [_MV, _MVa],
    [0, 0], 2
];
export var ConvergenceDetected$ = [3, n0, _CDo,
    0,
    [_COC],
    [0]
];
export var CreateActionRequest$ = [3, n0, _CAR,
    0,
    [_AN, _S, _AT, _D, _St, _Pr, _MPe, _Ta],
    [0, () => ActionSource$, 0, 0, 0, 128 | 0, () => MetadataProperties$, () => TagList], 3
];
export var CreateActionResponse$ = [3, n0, _CARr,
    0,
    [_AA],
    [0]
];
export var CreateAlgorithmInput$ = [3, n0, _CAI,
    0,
    [_ANlg, _TS, _ADl, _ISn, _VSa, _CFM, _Ta],
    [0, () => TrainingSpecification$, 0, () => InferenceSpecification$, () => AlgorithmValidationSpecification$, 2, () => TagList], 2
];
export var CreateAlgorithmOutput$ = [3, n0, _CAO,
    0,
    [_AAl],
    [0], 1
];
export var CreateAppImageConfigRequest$ = [3, n0, _CAICR,
    0,
    [_AICN, _Ta, _KGIC, _JLAIC, _CEAIC],
    [0, () => TagList, () => KernelGatewayImageConfig$, () => JupyterLabAppImageConfig$, () => CodeEditorAppImageConfig$], 1
];
export var CreateAppImageConfigResponse$ = [3, n0, _CAICRr,
    0,
    [_AICA],
    [0]
];
export var CreateAppRequest$ = [3, n0, _CARre,
    0,
    [_DI, _ATp, _ANp, _UPN, _SN, _Ta, _RS, _RM],
    [0, 0, 0, 0, 0, () => TagList, () => ResourceSpec$, 2], 3
];
export var CreateAppResponse$ = [3, n0, _CARrea,
    0,
    [_AAp],
    [0]
];
export var CreateArtifactRequest$ = [3, n0, _CARreat,
    0,
    [_S, _ATr, _ANr, _Pr, _MPe, _Ta],
    [() => ArtifactSource$, 0, 0, 128 | 0, () => MetadataProperties$, () => TagList], 2
];
export var CreateArtifactResponse$ = [3, n0, _CARreate,
    0,
    [_AAr],
    [0]
];
export var CreateAutoMLJobRequest$ = [3, n0, _CAMLJR,
    0,
    [_AMLJN, _IDC, _ODC, _RAo, _PT, _AMLJO, _AMLJCu, _GCDO, _Ta, _MDC],
    [0, () => AutoMLInputDataConfig, () => AutoMLOutputDataConfig$, 0, 0, () => AutoMLJobObjective$, () => AutoMLJobConfig$, 2, () => TagList, () => ModelDeployConfig$], 4
];
export var CreateAutoMLJobResponse$ = [3, n0, _CAMLJRr,
    0,
    [_AMLJAu],
    [0], 1
];
export var CreateAutoMLJobV2Request$ = [3, n0, _CAMLJVR,
    0,
    [_AMLJN, _AMLJIDC, _ODC, _AMLPTC, _RAo, _Ta, _SC, _AMLJO, _MDC, _DSC, _AMLCC],
    [0, () => AutoMLJobInputDataConfig, () => AutoMLOutputDataConfig$, () => AutoMLProblemTypeConfig$, 0, () => TagList, () => AutoMLSecurityConfig$, () => AutoMLJobObjective$, () => ModelDeployConfig$, () => AutoMLDataSplitConfig$, () => AutoMLComputeConfig$], 5
];
export var CreateAutoMLJobV2Response$ = [3, n0, _CAMLJVRr,
    0,
    [_AMLJAu],
    [0], 1
];
export var CreateClusterRequest$ = [3, n0, _CCRr,
    0,
    [_CNl, _IG, _RIG, _VC, _Ta, _Or, _NR, _TSCi, _NPM, _CRl, _ASu],
    [0, () => ClusterInstanceGroupSpecifications, () => ClusterRestrictedInstanceGroupSpecifications, () => VpcConfig$, () => TagList, () => ClusterOrchestrator$, 0, () => ClusterTieredStorageConfig$, 0, 0, () => ClusterAutoScalingConfig$], 1
];
export var CreateClusterResponse$ = [3, n0, _CCRre,
    0,
    [_CAl],
    [0], 1
];
export var CreateClusterSchedulerConfigRequest$ = [3, n0, _CCSCR,
    0,
    [_N, _CAl, _SCc, _D, _Ta],
    [0, 0, () => SchedulerConfig$, 0, () => TagList], 3
];
export var CreateClusterSchedulerConfigResponse$ = [3, n0, _CCSCRr,
    0,
    [_CSCA, _CSCI],
    [0, 0], 2
];
export var CreateCodeRepositoryInput$ = [3, n0, _CCRI,
    0,
    [_CRN, _GC, _Ta],
    [0, () => GitConfig$, () => TagList], 2
];
export var CreateCodeRepositoryOutput$ = [3, n0, _CCRO,
    0,
    [_CRA],
    [0], 1
];
export var CreateCompilationJobRequest$ = [3, n0, _CCJR,
    0,
    [_CJN, _RAo, _OC, _SCt, _MPVA, _ICnp, _VC, _Ta],
    [0, 0, () => OutputConfig$, () => StoppingCondition$, 0, () => InputConfig$, () => NeoVpcConfig$, () => TagList], 4
];
export var CreateCompilationJobResponse$ = [3, n0, _CCJRr,
    0,
    [_CJAo],
    [0], 1
];
export var CreateComputeQuotaRequest$ = [3, n0, _CCQR,
    0,
    [_N, _CAl, _CQC, _CQT, _D, _ASct, _Ta],
    [0, 0, () => ComputeQuotaConfig$, () => ComputeQuotaTarget$, 0, 0, () => TagList], 4
];
export var CreateComputeQuotaResponse$ = [3, n0, _CCQRr,
    0,
    [_CQA, _CQI],
    [0, 0], 2
];
export var CreateContextRequest$ = [3, n0, _CCRrea,
    0,
    [_CNon, _S, _CTonte, _D, _Pr, _Ta],
    [0, () => ContextSource$, 0, 0, 128 | 0, () => TagList], 3
];
export var CreateContextResponse$ = [3, n0, _CCRreat,
    0,
    [_CAo],
    [0]
];
export var CreateDataQualityJobDefinitionRequest$ = [3, n0, _CDQJDR,
    0,
    [_JDN, _DQAS, _DQJI, _DQJOC, _JR, _RAo, _DQBC, _NCe, _SCt, _Ta],
    [0, () => DataQualityAppSpecification$, () => DataQualityJobInput$, () => MonitoringOutputConfig$, () => MonitoringResources$, 0, () => DataQualityBaselineConfig$, () => MonitoringNetworkConfig$, () => MonitoringStoppingCondition$, () => TagList], 6
];
export var CreateDataQualityJobDefinitionResponse$ = [3, n0, _CDQJDRr,
    0,
    [_JDA],
    [0], 1
];
export var CreateDeviceFleetRequest$ = [3, n0, _CDFR,
    0,
    [_DFN, _OC, _RAo, _D, _Ta, _EIRA],
    [0, () => EdgeOutputConfig$, 0, 0, () => TagList, 2], 2
];
export var CreateDomainRequest$ = [3, n0, _CDR,
    0,
    [_DNo, _AM, _DUS, _DSo, _SIu, _VIp, _Ta, _ANAT, _HEFSKKI, _KKI, _ASGM, _TP, _DSS],
    [0, 0, () => UserSettings$, () => DomainSettings$, 64 | 0, 0, () => TagList, 0, 0, 0, 0, 0, () => DefaultSpaceSettings$], 3
];
export var CreateDomainResponse$ = [3, n0, _CDRr,
    0,
    [_DAo, _DI, _U],
    [0, 0, 0]
];
export var CreateEdgeDeploymentPlanRequest$ = [3, n0, _CEDPR,
    0,
    [_EDPN, _MCo, _DFN, _Sta, _Ta],
    [0, () => EdgeDeploymentModelConfigs, 0, () => DeploymentStages, () => TagList], 3
];
export var CreateEdgeDeploymentPlanResponse$ = [3, n0, _CEDPRr,
    0,
    [_EDPA],
    [0], 1
];
export var CreateEdgeDeploymentStageRequest$ = [3, n0, _CEDSR,
    0,
    [_EDPN, _Sta],
    [0, () => DeploymentStages], 2
];
export var CreateEdgePackagingJobRequest$ = [3, n0, _CEPJR,
    0,
    [_EPJN, _CJN, _MNod, _MVo, _RAo, _OC, _RK, _Ta],
    [0, 0, 0, 0, 0, () => EdgeOutputConfig$, 0, () => TagList], 6
];
export var CreateEndpointConfigInput$ = [3, n0, _CECI,
    0,
    [_ECN, _PV, _DCC, _Ta, _KKI, _AIC, _ECx, _SPV, _ERA, _VC, _ENI, _MCe],
    [0, () => ProductionVariantList, () => DataCaptureConfig$, () => TagList, 0, () => AsyncInferenceConfig$, () => ExplainerConfig$, () => ProductionVariantList, 0, () => VpcConfig$, 2, () => MetricsConfig$], 2
];
export var CreateEndpointConfigOutput$ = [3, n0, _CECO,
    0,
    [_ECA],
    [0], 1
];
export var CreateEndpointInput$ = [3, n0, _CEI,
    0,
    [_EN, _ECN, _DC, _Ta],
    [0, 0, () => DeploymentConfig$, () => TagList], 2
];
export var CreateEndpointOutput$ = [3, n0, _CEO,
    0,
    [_EA],
    [0], 1
];
export var CreateExperimentRequest$ = [3, n0, _CER,
    0,
    [_ENx, _DNi, _D, _Ta],
    [0, 0, 0, () => TagList], 1
];
export var CreateExperimentResponse$ = [3, n0, _CERr,
    0,
    [_EAx],
    [0]
];
export var CreateFeatureGroupRequest$ = [3, n0, _CFGR,
    0,
    [_FGN, _RIFN, _ETFN, _FD, _OSC, _OSCf, _TCh, _RAo, _D, _Ta],
    [0, 0, 0, () => FeatureDefinitions, () => OnlineStoreConfig$, () => OfflineStoreConfig$, () => ThroughputConfig$, 0, 0, () => TagList], 4
];
export var CreateFeatureGroupResponse$ = [3, n0, _CFGRr,
    0,
    [_FGA],
    [0], 1
];
export var CreateFlowDefinitionRequest$ = [3, n0, _CFDR,
    0,
    [_FDN, _OC, _RAo, _HLRS, _HLACu, _HLC, _Ta],
    [0, () => FlowDefinitionOutputConfig$, 0, () => HumanLoopRequestSource$, [() => HumanLoopActivationConfig$, 0], () => HumanLoopConfig$, () => TagList], 3
];
export var CreateFlowDefinitionResponse$ = [3, n0, _CFDRr,
    0,
    [_FDA],
    [0], 1
];
export var CreateHubContentPresignedUrlsRequest$ = [3, n0, _CHCPUR,
    0,
    [_HN, _HCT, _HCN, _HCV, _ACc, _MR, _NTe],
    [0, 0, 0, 0, () => PresignedUrlAccessConfig$, 1, 0], 3
];
export var CreateHubContentPresignedUrlsResponse$ = [3, n0, _CHCPURr,
    0,
    [_AUC, _NTe],
    [() => AuthorizedUrlConfigs, 0], 1
];
export var CreateHubContentReferenceRequest$ = [3, n0, _CHCRR,
    0,
    [_HN, _SMPHCA, _HCN, _MVi, _Ta],
    [0, 0, 0, 0, () => TagList], 2
];
export var CreateHubContentReferenceResponse$ = [3, n0, _CHCRRr,
    0,
    [_HA, _HCA],
    [0, 0], 2
];
export var CreateHubRequest$ = [3, n0, _CHRr,
    0,
    [_HN, _HD, _HDN, _HSK, _SSC, _Ta],
    [0, 0, 0, 64 | 0, () => HubS3StorageConfig$, () => TagList], 2
];
export var CreateHubResponse$ = [3, n0, _CHRre,
    0,
    [_HA],
    [0], 1
];
export var CreateHumanTaskUiRequest$ = [3, n0, _CHTUR,
    0,
    [_HTUN, _UT, _Ta],
    [0, () => UiTemplate$, () => TagList], 2
];
export var CreateHumanTaskUiResponse$ = [3, n0, _CHTURr,
    0,
    [_HTUA],
    [0], 1
];
export var CreateHyperParameterTuningJobRequest$ = [3, n0, _CHPTJR,
    0,
    [_HPTJN, _HPTJC, _TJD, _TJDra, _WSC, _Ta, _Au],
    [0, () => HyperParameterTuningJobConfig$, () => HyperParameterTrainingJobDefinition$, () => HyperParameterTrainingJobDefinitions, () => HyperParameterTuningJobWarmStartConfig$, () => TagList, () => Autotune$], 2
];
export var CreateHyperParameterTuningJobResponse$ = [3, n0, _CHPTJRr,
    0,
    [_HPTJA],
    [0], 1
];
export var CreateImageRequest$ = [3, n0, _CIR,
    0,
    [_IN, _RAo, _D, _DNi, _Ta],
    [0, 0, 0, 0, () => TagList], 2
];
export var CreateImageResponse$ = [3, n0, _CIRr,
    0,
    [_IAm],
    [0]
];
export var CreateImageVersionRequest$ = [3, n0, _CIVR,
    0,
    [_BI, _IN, _CTl, _Ali, _VG, _JT, _MLF, _PL, _Pro, _H, _RN],
    [0, 0, [0, 4], 64 | 0, 0, 0, 0, 0, 0, 2, 0], 2
];
export var CreateImageVersionResponse$ = [3, n0, _CIVRr,
    0,
    [_IVA],
    [0]
];
export var CreateInferenceComponentInput$ = [3, n0, _CICI,
    0,
    [_ICN, _EN, _Spe, _VN, _RC, _Ta],
    [0, 0, () => InferenceComponentSpecification$, 0, () => InferenceComponentRuntimeConfig$, () => TagList], 3
];
export var CreateInferenceComponentOutput$ = [3, n0, _CICO,
    0,
    [_ICA],
    [0], 1
];
export var CreateInferenceExperimentRequest$ = [3, n0, _CIER,
    0,
    [_N, _T, _RAo, _EN, _MVod, _SMC, _Sc, _D, _DSCa, _KK, _Ta],
    [0, 0, 0, 0, () => ModelVariantConfigList, () => ShadowModeConfig$, () => InferenceExperimentSchedule$, 0, () => InferenceExperimentDataStorageConfig$, 0, () => TagList], 6
];
export var CreateInferenceExperimentResponse$ = [3, n0, _CIERr,
    0,
    [_IEA],
    [0], 1
];
export var CreateInferenceRecommendationsJobRequest$ = [3, n0, _CIRJR,
    0,
    [_JN, _JT, _RAo, _ICnp, _JD, _SCto, _OC, _Ta],
    [0, 0, 0, () => RecommendationJobInputConfig$, 0, () => RecommendationJobStoppingConditions$, () => RecommendationJobOutputConfig$, () => TagList], 4
];
export var CreateInferenceRecommendationsJobResponse$ = [3, n0, _CIRJRr,
    0,
    [_JA],
    [0], 1
];
export var CreateLabelingJobRequest$ = [3, n0, _CLJR,
    0,
    [_LJN, _LAN, _ICnp, _OC, _RAo, _HTC, _LCCSU, _SCto, _LJAC, _Ta],
    [0, 0, () => LabelingJobInputConfig$, () => LabelingJobOutputConfig$, 0, () => HumanTaskConfig$, 0, () => LabelingJobStoppingConditions$, () => LabelingJobAlgorithmsConfig$, () => TagList], 6
];
export var CreateLabelingJobResponse$ = [3, n0, _CLJRr,
    0,
    [_LJA],
    [0], 1
];
export var CreateMlflowAppRequest$ = [3, n0, _CMAR,
    0,
    [_N, _ASU, _RAo, _MRM, _WMWS, _ADS, _DDIL, _Ta],
    [0, 0, 0, 0, 0, 0, 64 | 0, () => TagList], 3
];
export var CreateMlflowAppResponse$ = [3, n0, _CMARr,
    0,
    [_Ar],
    [0]
];
export var CreateMlflowTrackingServerRequest$ = [3, n0, _CMTSR,
    0,
    [_TSN, _ASU, _RAo, _TSS, _MVl, _AMR, _WMWS, _Ta],
    [0, 0, 0, 0, 0, 2, 0, () => TagList], 3
];
export var CreateMlflowTrackingServerResponse$ = [3, n0, _CMTSRr,
    0,
    [_TSA],
    [0]
];
export var CreateModelBiasJobDefinitionRequest$ = [3, n0, _CMBJDR,
    0,
    [_JDN, _MBAS, _MBJI, _MBJOC, _JR, _RAo, _MBBC, _NCe, _SCt, _Ta],
    [0, () => ModelBiasAppSpecification$, () => ModelBiasJobInput$, () => MonitoringOutputConfig$, () => MonitoringResources$, 0, () => ModelBiasBaselineConfig$, () => MonitoringNetworkConfig$, () => MonitoringStoppingCondition$, () => TagList], 6
];
export var CreateModelBiasJobDefinitionResponse$ = [3, n0, _CMBJDRr,
    0,
    [_JDA],
    [0], 1
];
export var CreateModelCardExportJobRequest$ = [3, n0, _CMCEJR,
    0,
    [_MCN, _MCEJN, _OC, _MCV],
    [0, 0, () => ModelCardExportOutputConfig$, 1], 3
];
export var CreateModelCardExportJobResponse$ = [3, n0, _CMCEJRr,
    0,
    [_MCEJA],
    [0], 1
];
export var CreateModelCardRequest$ = [3, n0, _CMCR,
    0,
    [_MCN, _Con, _MCS, _SC, _Ta],
    [0, [() => ModelCardContent, 0], 0, () => ModelCardSecurityConfig$, () => TagList], 3
];
export var CreateModelCardResponse$ = [3, n0, _CMCRr,
    0,
    [_MCA],
    [0], 1
];
export var CreateModelExplainabilityJobDefinitionRequest$ = [3, n0, _CMEJDR,
    0,
    [_JDN, _MEAS, _MEJI, _MEJOC, _JR, _RAo, _MEBC, _NCe, _SCt, _Ta],
    [0, () => ModelExplainabilityAppSpecification$, () => ModelExplainabilityJobInput$, () => MonitoringOutputConfig$, () => MonitoringResources$, 0, () => ModelExplainabilityBaselineConfig$, () => MonitoringNetworkConfig$, () => MonitoringStoppingCondition$, () => TagList], 6
];
export var CreateModelExplainabilityJobDefinitionResponse$ = [3, n0, _CMEJDRr,
    0,
    [_JDA],
    [0], 1
];
export var CreateModelInput$ = [3, n0, _CMI,
    0,
    [_MNod, _PC, _Co, _IEC, _ERA, _Ta, _VC, _ENI],
    [0, () => ContainerDefinition$, () => ContainerDefinitionList, () => InferenceExecutionConfig$, 0, () => TagList, () => VpcConfig$, 2], 1
];
export var CreateModelOutput$ = [3, n0, _CMO,
    0,
    [_MA],
    [0], 1
];
export var CreateModelPackageGroupInput$ = [3, n0, _CMPGI,
    0,
    [_MPGN, _MPGD, _Ta],
    [0, 0, () => TagList], 1
];
export var CreateModelPackageGroupOutput$ = [3, n0, _CMPGO,
    0,
    [_MPGA],
    [0], 1
];
export var CreateModelPackageInput$ = [3, n0, _CMPI,
    0,
    [_MPN, _MPGN, _MPD, _MPRT, _ISn, _VSa, _SAS, _CFM, _Ta, _MAS, _MPe, _MM, _CTl, _Do, _Tas, _SPU, _CMP, _DCB, _AIS, _SMV, _SU, _SC, _MCod, _MLC],
    [0, 0, 0, 0, () => InferenceSpecification$, () => ModelPackageValidationSpecification$, () => SourceAlgorithmSpecification$, 2, () => TagList, 0, () => MetadataProperties$, () => ModelMetrics$, [0, 4], 0, 0, 0, 128 | 0, () => DriftCheckBaselines$, () => AdditionalInferenceSpecifications, 0, 0, () => ModelPackageSecurityConfig$, [() => ModelPackageModelCard$, 0], () => ModelLifeCycle$]
];
export var CreateModelPackageOutput$ = [3, n0, _CMPO,
    0,
    [_MPA],
    [0], 1
];
export var CreateModelQualityJobDefinitionRequest$ = [3, n0, _CMQJDR,
    0,
    [_JDN, _MQAS, _MQJI, _MQJOC, _JR, _RAo, _MQBC, _NCe, _SCt, _Ta],
    [0, () => ModelQualityAppSpecification$, () => ModelQualityJobInput$, () => MonitoringOutputConfig$, () => MonitoringResources$, 0, () => ModelQualityBaselineConfig$, () => MonitoringNetworkConfig$, () => MonitoringStoppingCondition$, () => TagList], 6
];
export var CreateModelQualityJobDefinitionResponse$ = [3, n0, _CMQJDRr,
    0,
    [_JDA],
    [0], 1
];
export var CreateMonitoringScheduleRequest$ = [3, n0, _CMSR,
    0,
    [_MSN, _MSC, _Ta],
    [0, () => MonitoringScheduleConfig$, () => TagList], 2
];
export var CreateMonitoringScheduleResponse$ = [3, n0, _CMSRr,
    0,
    [_MSA],
    [0], 1
];
export var CreateNotebookInstanceInput$ = [3, n0, _CNII,
    0,
    [_NIN, _IT, _RAo, _SIub, _SGI, _IAT, _KKI, _Ta, _LCN, _DIA, _VSIGB, _ATc, _DCR, _ACR, _RAoo, _PIl, _IMSC],
    [0, 0, 0, 0, 64 | 0, 0, 0, () => TagList, 0, 0, 1, 64 | 0, 0, 64 | 0, 0, 0, () => InstanceMetadataServiceConfiguration$], 3
];
export var CreateNotebookInstanceLifecycleConfigInput$ = [3, n0, _CNILCI,
    0,
    [_NILCN, _OCn, _OSn, _Ta],
    [0, () => NotebookInstanceLifecycleConfigList, () => NotebookInstanceLifecycleConfigList, () => TagList], 1
];
export var CreateNotebookInstanceLifecycleConfigOutput$ = [3, n0, _CNILCO,
    0,
    [_NILCA],
    [0]
];
export var CreateNotebookInstanceOutput$ = [3, n0, _CNIO,
    0,
    [_NIA],
    [0]
];
export var CreateOptimizationJobRequest$ = [3, n0, _COJR,
    0,
    [_OJN, _RAo, _MS, _DIT, _OCp, _OC, _SCt, _MICa, _OE, _Ta, _VC],
    [0, 0, () => OptimizationJobModelSource$, 0, () => OptimizationConfigs, () => OptimizationJobOutputConfig$, () => StoppingCondition$, 1, 128 | 0, () => TagList, () => OptimizationVpcConfig$], 7
];
export var CreateOptimizationJobResponse$ = [3, n0, _COJRr,
    0,
    [_OJA],
    [0], 1
];
export var CreatePartnerAppPresignedUrlRequest$ = [3, n0, _CPAPUR,
    0,
    [_Ar, _EIS, _SEDIS],
    [0, 1, 1], 1
];
export var CreatePartnerAppPresignedUrlResponse$ = [3, n0, _CPAPURr,
    0,
    [_U],
    [0]
];
export var CreatePartnerAppRequest$ = [3, n0, _CPAR,
    0,
    [_N, _T, _ERA, _Ti, _ATu, _KKI, _MCa, _ACp, _EISBI, _EAMVU, _CTl, _Ta],
    [0, 0, 0, 0, 0, 0, () => PartnerAppMaintenanceConfig$, () => PartnerAppConfig$, 2, 2, [0, 4], () => TagList], 5
];
export var CreatePartnerAppResponse$ = [3, n0, _CPARr,
    0,
    [_Ar],
    [0]
];
export var CreatePipelineRequest$ = [3, n0, _CPRr,
    0,
    [_PNi, _RAo, _PDN, _PD, _PDSL, _PDi, _CRT, _Ta, _PCa],
    [0, 0, 0, 0, () => PipelineDefinitionS3Location$, 0, [0, 4], () => TagList, () => ParallelismConfiguration$], 2
];
export var CreatePipelineResponse$ = [3, n0, _CPRre,
    0,
    [_PAi],
    [0]
];
export var CreatePresignedDomainUrlRequest$ = [3, n0, _CPDUR,
    0,
    [_DI, _UPN, _SEDIS, _EIS, _SN, _LU],
    [0, 0, 1, 1, 0, 0], 2
];
export var CreatePresignedDomainUrlResponse$ = [3, n0, _CPDURr,
    0,
    [_AU],
    [0]
];
export var CreatePresignedMlflowAppUrlRequest$ = [3, n0, _CPMAUR,
    0,
    [_Ar, _EIS, _SEDIS],
    [0, 1, 1], 1
];
export var CreatePresignedMlflowAppUrlResponse$ = [3, n0, _CPMAURr,
    0,
    [_AU],
    [0]
];
export var CreatePresignedMlflowTrackingServerUrlRequest$ = [3, n0, _CPMTSUR,
    0,
    [_TSN, _EIS, _SEDIS],
    [0, 1, 1], 1
];
export var CreatePresignedMlflowTrackingServerUrlResponse$ = [3, n0, _CPMTSURr,
    0,
    [_AU],
    [0]
];
export var CreatePresignedNotebookInstanceUrlInput$ = [3, n0, _CPNIUI,
    0,
    [_NIN, _SEDIS],
    [0, 1], 1
];
export var CreatePresignedNotebookInstanceUrlOutput$ = [3, n0, _CPNIUO,
    0,
    [_AU],
    [0]
];
export var CreateProcessingJobRequest$ = [3, n0, _CPJR,
    0,
    [_PJN, _PR, _ASp, _RAo, _PIr, _POC, _SCt, _E, _NCe, _Ta, _ECxp],
    [0, () => ProcessingResources$, () => AppSpecification$, 0, () => ProcessingInputs, () => ProcessingOutputConfig$, () => ProcessingStoppingCondition$, 128 | 0, () => NetworkConfig$, () => TagList, () => ExperimentConfig$], 4
];
export var CreateProcessingJobResponse$ = [3, n0, _CPJRr,
    0,
    [_PJA],
    [0], 1
];
export var CreateProjectInput$ = [3, n0, _CPI,
    0,
    [_PNr, _PDr, _SCPD, _Ta, _TPe],
    [0, 0, () => ServiceCatalogProvisioningDetails$, () => TagList, () => CreateTemplateProviderList], 1
];
export var CreateProjectOutput$ = [3, n0, _CPO,
    0,
    [_PAr, _PIro],
    [0, 0], 2
];
export var CreateSpaceRequest$ = [3, n0, _CSR,
    0,
    [_DI, _SN, _Ta, _SS, _OSw, _SSS, _SDN],
    [0, 0, () => TagList, () => SpaceSettings$, () => OwnershipSettings$, () => SpaceSharingSettings$, 0], 2
];
export var CreateSpaceResponse$ = [3, n0, _CSRr,
    0,
    [_SAp],
    [0]
];
export var CreateStudioLifecycleConfigRequest$ = [3, n0, _CSLCR,
    0,
    [_SLCN, _SLCC, _SLCAT, _Ta],
    [0, 0, 0, () => TagList], 3
];
export var CreateStudioLifecycleConfigResponse$ = [3, n0, _CSLCRr,
    0,
    [_SLCA],
    [0]
];
export var CreateTemplateProvider$ = [3, n0, _CTP,
    0,
    [_CTPf],
    [() => CfnCreateTemplateProvider$]
];
export var CreateTrainingJobRequest$ = [3, n0, _CTJR,
    0,
    [_TJN, _RAo, _ODC, _HP, _ASl, _IDC, _RCe, _VC, _SCt, _Ta, _ENI, _EICTE, _EMST, _CCh, _DHC, _DRC, _TBOC, _ECxp, _PCr, _PRC, _E, _RSe, _RDC, _ICC, _SCC, _SJC, _MCl, _MPC],
    [0, 0, () => OutputDataConfig$, 128 | 0, () => AlgorithmSpecification$, () => InputDataConfig, () => ResourceConfig$, () => VpcConfig$, () => StoppingCondition$, () => TagList, 2, 2, 2, () => CheckpointConfig$, () => DebugHookConfig$, () => DebugRuleConfigurations, () => TensorBoardOutputConfig$, () => ExperimentConfig$, () => ProfilerConfig$, () => ProfilerRuleConfigurations, 128 | 0, () => RetryStrategy$, () => RemoteDebugConfig$, () => InfraCheckConfig$, () => SessionChainingConfig$, () => ServerlessJobConfig$, () => MlflowConfig$, () => ModelPackageConfig$], 3
];
export var CreateTrainingJobResponse$ = [3, n0, _CTJRr,
    0,
    [_TJA],
    [0], 1
];
export var CreateTrainingPlanRequest$ = [3, n0, _CTPR,
    0,
    [_TPN, _TPOI, _SICPUS, _Ta],
    [0, 0, 1, () => TagList], 2
];
export var CreateTrainingPlanResponse$ = [3, n0, _CTPRr,
    0,
    [_TPA],
    [0], 1
];
export var CreateTransformJobRequest$ = [3, n0, _CTJRre,
    0,
    [_TJNr, _MNod, _TIr, _TO, _TR, _MCT, _MCCo, _MPIMB, _BS, _E, _DCC, _DP, _Ta, _ECxp],
    [0, 0, () => TransformInput$, () => TransformOutput$, () => TransformResources$, 1, () => ModelClientConfig$, 1, 0, 128 | 0, () => BatchDataCaptureConfig$, () => DataProcessing$, () => TagList, () => ExperimentConfig$], 5
];
export var CreateTransformJobResponse$ = [3, n0, _CTJRrea,
    0,
    [_TJAr],
    [0], 1
];
export var CreateTrialComponentRequest$ = [3, n0, _CTCR,
    0,
    [_TCN, _DNi, _St, _STt, _ETn, _P, _IAn, _OA, _MPe, _Ta],
    [0, 0, () => TrialComponentStatus$, 4, 4, () => TrialComponentParameters, () => TrialComponentArtifacts, () => TrialComponentArtifacts, () => MetadataProperties$, () => TagList], 1
];
export var CreateTrialComponentResponse$ = [3, n0, _CTCRr,
    0,
    [_TCA],
    [0]
];
export var CreateTrialRequest$ = [3, n0, _CTR,
    0,
    [_TN, _ENx, _DNi, _MPe, _Ta],
    [0, 0, 0, () => MetadataProperties$, () => TagList], 2
];
export var CreateTrialResponse$ = [3, n0, _CTRr,
    0,
    [_TA],
    [0]
];
export var CreateUserProfileRequest$ = [3, n0, _CUPR,
    0,
    [_DI, _UPN, _SSOUI, _SSOUV, _Ta, _US],
    [0, 0, 0, 0, () => TagList, () => UserSettings$], 2
];
export var CreateUserProfileResponse$ = [3, n0, _CUPRr,
    0,
    [_UPA],
    [0]
];
export var CreateWorkforceRequest$ = [3, n0, _CWR,
    0,
    [_WN, _CCog, _OCi, _SIC, _Ta, _WVC, _IAT],
    [0, () => CognitoConfig$, [() => OidcConfig$, 0], () => SourceIpConfig$, () => TagList, () => WorkforceVpcConfigRequest$, 0], 1
];
export var CreateWorkforceResponse$ = [3, n0, _CWRr,
    0,
    [_WA],
    [0], 1
];
export var CreateWorkteamRequest$ = [3, n0, _CWRre,
    0,
    [_WNo, _MDe, _D, _WN, _NCo, _WAC, _Ta],
    [0, () => MemberDefinitions, 0, 0, () => NotificationConfiguration$, () => WorkerAccessConfiguration$, () => TagList], 3
];
export var CreateWorkteamResponse$ = [3, n0, _CWRrea,
    0,
    [_WAo],
    [0]
];
export var CustomImage$ = [3, n0, _CIu,
    0,
    [_IN, _AICN, _IVN],
    [0, 0, 1], 2
];
export var CustomizedMetricSpecification$ = [3, n0, _CMS,
    0,
    [_MN, _Na, _Stat],
    [0, 0, 0]
];
export var CustomPosixUserConfig$ = [3, n0, _CPUC,
    0,
    [_Ui, _Gi],
    [1, 1], 2
];
export var DataCaptureConfig$ = [3, n0, _DCC,
    0,
    [_ISP, _DSU, _COa, _ECna, _KKI, _CCTH],
    [1, 0, () => CaptureOptionList, 2, 0, () => CaptureContentTypeHeader$], 3
];
export var DataCaptureConfigSummary$ = [3, n0, _DCCS,
    0,
    [_ECna, _CSapt, _CSPu, _DSU, _KKI],
    [2, 0, 1, 0, 0], 5
];
export var DataCatalogConfig$ = [3, n0, _DCCa,
    0,
    [_TNa, _Ca, _Da],
    [0, 0, 0], 3
];
export var DataProcessing$ = [3, n0, _DP,
    0,
    [_IF, _OFu, _JS],
    [0, 0, 0]
];
export var DataQualityAppSpecification$ = [3, n0, _DQAS,
    0,
    [_IU, _CEo, _CA, _RPSU, _PAPSU, _E],
    [0, 64 | 0, 64 | 0, 0, 0, 128 | 0], 1
];
export var DataQualityBaselineConfig$ = [3, n0, _DQBC,
    0,
    [_BJN, _CRon, _SR],
    [0, () => MonitoringConstraintsResource$, () => MonitoringStatisticsResource$]
];
export var DataQualityJobInput$ = [3, n0, _DQJI,
    0,
    [_EIn, _BTI],
    [() => EndpointInput$, () => BatchTransformInput$]
];
export var DatasetDefinition$ = [3, n0, _DD,
    0,
    [_ADD, _RDD, _LP, _DDT, _IM],
    [() => AthenaDatasetDefinition$, () => RedshiftDatasetDefinition$, 0, 0, 0]
];
export var DatasetSource$ = [3, n0, _DSa,
    0,
    [_DAa],
    [0], 1
];
export var DataSource$ = [3, n0, _DS,
    0,
    [_SDS, _FSDS, _DSa],
    [() => S3DataSource$, () => FileSystemDataSource$, () => DatasetSource$]
];
export var DebugHookConfig$ = [3, n0, _DHC,
    0,
    [_SOP, _LP, _HPo, _CColl],
    [0, 0, 128 | 0, () => CollectionConfigurations], 1
];
export var DebugRuleConfiguration$ = [3, n0, _DRCe,
    0,
    [_RCN, _REI, _LP, _SOP, _IT, _VSIGB, _RP],
    [0, 0, 0, 0, 0, 1, 128 | 0], 2
];
export var DebugRuleEvaluationStatus$ = [3, n0, _DRES,
    0,
    [_RCN, _REJA, _RES, _SDt, _LMT],
    [0, 0, 0, 0, 4]
];
export var DefaultEbsStorageSettings$ = [3, n0, _DESS,
    0,
    [_DEVSIG, _MEVSIG],
    [1, 1], 2
];
export var DefaultSpaceSettings$ = [3, n0, _DSS,
    0,
    [_ERx, _SG, _JSAS, _KGAS, _JLAS, _SSSp, _CPUC, _CFSC],
    [0, 64 | 0, () => JupyterServerAppSettings$, () => KernelGatewayAppSettings$, () => JupyterLabAppSettings$, () => DefaultSpaceStorageSettings$, () => CustomPosixUserConfig$, () => CustomFileSystemConfigs]
];
export var DefaultSpaceStorageSettings$ = [3, n0, _DSSS,
    0,
    [_DESS],
    [() => DefaultEbsStorageSettings$]
];
export var DeleteActionRequest$ = [3, n0, _DAR,
    0,
    [_AN],
    [0], 1
];
export var DeleteActionResponse$ = [3, n0, _DARe,
    0,
    [_AA],
    [0]
];
export var DeleteAlgorithmInput$ = [3, n0, _DAI,
    0,
    [_ANlg],
    [0], 1
];
export var DeleteAppImageConfigRequest$ = [3, n0, _DAICR,
    0,
    [_AICN],
    [0], 1
];
export var DeleteAppRequest$ = [3, n0, _DARel,
    0,
    [_DI, _ATp, _ANp, _UPN, _SN],
    [0, 0, 0, 0, 0], 3
];
export var DeleteArtifactRequest$ = [3, n0, _DARele,
    0,
    [_AAr, _S],
    [0, () => ArtifactSource$]
];
export var DeleteArtifactResponse$ = [3, n0, _DARelet,
    0,
    [_AAr],
    [0]
];
export var DeleteAssociationRequest$ = [3, n0, _DARelete,
    0,
    [_SA, _DA],
    [0, 0], 2
];
export var DeleteAssociationResponse$ = [3, n0, _DAReletes,
    0,
    [_SA, _DA],
    [0, 0]
];
export var DeleteClusterRequest$ = [3, n0, _DCRe,
    0,
    [_CNl],
    [0], 1
];
export var DeleteClusterResponse$ = [3, n0, _DCRel,
    0,
    [_CAl],
    [0], 1
];
export var DeleteClusterSchedulerConfigRequest$ = [3, n0, _DCSCR,
    0,
    [_CSCI],
    [0], 1
];
export var DeleteCodeRepositoryInput$ = [3, n0, _DCRI,
    0,
    [_CRN],
    [0], 1
];
export var DeleteCompilationJobRequest$ = [3, n0, _DCJR,
    0,
    [_CJN],
    [0], 1
];
export var DeleteComputeQuotaRequest$ = [3, n0, _DCQR,
    0,
    [_CQI],
    [0], 1
];
export var DeleteContextRequest$ = [3, n0, _DCRele,
    0,
    [_CNon],
    [0], 1
];
export var DeleteContextResponse$ = [3, n0, _DCRelet,
    0,
    [_CAo],
    [0]
];
export var DeleteDataQualityJobDefinitionRequest$ = [3, n0, _DDQJDR,
    0,
    [_JDN],
    [0], 1
];
export var DeleteDeviceFleetRequest$ = [3, n0, _DDFR,
    0,
    [_DFN],
    [0], 1
];
export var DeleteDomainRequest$ = [3, n0, _DDR,
    0,
    [_DI, _RPe],
    [0, () => RetentionPolicy$], 1
];
export var DeleteEdgeDeploymentPlanRequest$ = [3, n0, _DEDPR,
    0,
    [_EDPN],
    [0], 1
];
export var DeleteEdgeDeploymentStageRequest$ = [3, n0, _DEDSR,
    0,
    [_EDPN, _SNt],
    [0, 0], 2
];
export var DeleteEndpointConfigInput$ = [3, n0, _DECI,
    0,
    [_ECN],
    [0], 1
];
export var DeleteEndpointInput$ = [3, n0, _DEI,
    0,
    [_EN],
    [0], 1
];
export var DeleteExperimentRequest$ = [3, n0, _DER,
    0,
    [_ENx],
    [0], 1
];
export var DeleteExperimentResponse$ = [3, n0, _DERe,
    0,
    [_EAx],
    [0]
];
export var DeleteFeatureGroupRequest$ = [3, n0, _DFGR,
    0,
    [_FGN],
    [0], 1
];
export var DeleteFlowDefinitionRequest$ = [3, n0, _DFDR,
    0,
    [_FDN],
    [0], 1
];
export var DeleteFlowDefinitionResponse$ = [3, n0, _DFDRe,
    0,
    [],
    []
];
export var DeleteHubContentReferenceRequest$ = [3, n0, _DHCRR,
    0,
    [_HN, _HCT, _HCN],
    [0, 0, 0], 3
];
export var DeleteHubContentRequest$ = [3, n0, _DHCR,
    0,
    [_HN, _HCT, _HCN, _HCV],
    [0, 0, 0, 0], 4
];
export var DeleteHubRequest$ = [3, n0, _DHR,
    0,
    [_HN],
    [0], 1
];
export var DeleteHumanTaskUiRequest$ = [3, n0, _DHTUR,
    0,
    [_HTUN],
    [0], 1
];
export var DeleteHumanTaskUiResponse$ = [3, n0, _DHTURe,
    0,
    [],
    []
];
export var DeleteHyperParameterTuningJobRequest$ = [3, n0, _DHPTJR,
    0,
    [_HPTJN],
    [0], 1
];
export var DeleteImageRequest$ = [3, n0, _DIR,
    0,
    [_IN],
    [0], 1
];
export var DeleteImageResponse$ = [3, n0, _DIRe,
    0,
    [],
    []
];
export var DeleteImageVersionRequest$ = [3, n0, _DIVR,
    0,
    [_IN, _V, _Alia],
    [0, 1, 0], 1
];
export var DeleteImageVersionResponse$ = [3, n0, _DIVRe,
    0,
    [],
    []
];
export var DeleteInferenceComponentInput$ = [3, n0, _DICI,
    0,
    [_ICN],
    [0], 1
];
export var DeleteInferenceExperimentRequest$ = [3, n0, _DIER,
    0,
    [_N],
    [0], 1
];
export var DeleteInferenceExperimentResponse$ = [3, n0, _DIERe,
    0,
    [_IEA],
    [0], 1
];
export var DeleteMlflowAppRequest$ = [3, n0, _DMAR,
    0,
    [_Ar],
    [0], 1
];
export var DeleteMlflowAppResponse$ = [3, n0, _DMARe,
    0,
    [_Ar],
    [0]
];
export var DeleteMlflowTrackingServerRequest$ = [3, n0, _DMTSR,
    0,
    [_TSN],
    [0], 1
];
export var DeleteMlflowTrackingServerResponse$ = [3, n0, _DMTSRe,
    0,
    [_TSA],
    [0]
];
export var DeleteModelBiasJobDefinitionRequest$ = [3, n0, _DMBJDR,
    0,
    [_JDN],
    [0], 1
];
export var DeleteModelCardRequest$ = [3, n0, _DMCR,
    0,
    [_MCN],
    [0], 1
];
export var DeleteModelExplainabilityJobDefinitionRequest$ = [3, n0, _DMEJDR,
    0,
    [_JDN],
    [0], 1
];
export var DeleteModelInput$ = [3, n0, _DMI,
    0,
    [_MNod],
    [0], 1
];
export var DeleteModelPackageGroupInput$ = [3, n0, _DMPGI,
    0,
    [_MPGN],
    [0], 1
];
export var DeleteModelPackageGroupPolicyInput$ = [3, n0, _DMPGPI,
    0,
    [_MPGN],
    [0], 1
];
export var DeleteModelPackageInput$ = [3, n0, _DMPI,
    0,
    [_MPN],
    [0], 1
];
export var DeleteModelQualityJobDefinitionRequest$ = [3, n0, _DMQJDR,
    0,
    [_JDN],
    [0], 1
];
export var DeleteMonitoringScheduleRequest$ = [3, n0, _DMSR,
    0,
    [_MSN],
    [0], 1
];
export var DeleteNotebookInstanceInput$ = [3, n0, _DNII,
    0,
    [_NIN],
    [0], 1
];
export var DeleteNotebookInstanceLifecycleConfigInput$ = [3, n0, _DNILCI,
    0,
    [_NILCN],
    [0], 1
];
export var DeleteOptimizationJobRequest$ = [3, n0, _DOJR,
    0,
    [_OJN],
    [0], 1
];
export var DeletePartnerAppRequest$ = [3, n0, _DPAR,
    0,
    [_Ar, _CTl],
    [0, [0, 4]], 1
];
export var DeletePartnerAppResponse$ = [3, n0, _DPARe,
    0,
    [_Ar],
    [0]
];
export var DeletePipelineRequest$ = [3, n0, _DPR,
    0,
    [_PNi, _CRT],
    [0, [0, 4]], 1
];
export var DeletePipelineResponse$ = [3, n0, _DPRe,
    0,
    [_PAi],
    [0]
];
export var DeleteProcessingJobRequest$ = [3, n0, _DPJR,
    0,
    [_PJN],
    [0], 1
];
export var DeleteProjectInput$ = [3, n0, _DPI,
    0,
    [_PNr],
    [0], 1
];
export var DeleteSpaceRequest$ = [3, n0, _DSR,
    0,
    [_DI, _SN],
    [0, 0], 2
];
export var DeleteStudioLifecycleConfigRequest$ = [3, n0, _DSLCR,
    0,
    [_SLCN],
    [0], 1
];
export var DeleteTagsInput$ = [3, n0, _DTI,
    0,
    [_RA, _TK],
    [0, 64 | 0], 2
];
export var DeleteTagsOutput$ = [3, n0, _DTO,
    0,
    [],
    []
];
export var DeleteTrainingJobRequest$ = [3, n0, _DTJR,
    0,
    [_TJN],
    [0], 1
];
export var DeleteTrialComponentRequest$ = [3, n0, _DTCR,
    0,
    [_TCN],
    [0], 1
];
export var DeleteTrialComponentResponse$ = [3, n0, _DTCRe,
    0,
    [_TCA],
    [0]
];
export var DeleteTrialRequest$ = [3, n0, _DTR,
    0,
    [_TN],
    [0], 1
];
export var DeleteTrialResponse$ = [3, n0, _DTRe,
    0,
    [_TA],
    [0]
];
export var DeleteUserProfileRequest$ = [3, n0, _DUPR,
    0,
    [_DI, _UPN],
    [0, 0], 2
];
export var DeleteWorkforceRequest$ = [3, n0, _DWR,
    0,
    [_WN],
    [0], 1
];
export var DeleteWorkforceResponse$ = [3, n0, _DWRe,
    0,
    [],
    []
];
export var DeleteWorkteamRequest$ = [3, n0, _DWRel,
    0,
    [_WNo],
    [0], 1
];
export var DeleteWorkteamResponse$ = [3, n0, _DWRele,
    0,
    [_Suc],
    [2], 1
];
export var DeployedImage$ = [3, n0, _DIe,
    0,
    [_SIp, _RI, _RTe],
    [0, 0, 4]
];
export var DeploymentConfig$ = [3, n0, _DC,
    0,
    [_BGUP, _RUP, _ARCu],
    [() => BlueGreenUpdatePolicy$, () => RollingUpdatePolicy$, () => AutoRollbackConfig$]
];
export var DeploymentConfiguration$ = [3, n0, _DCe,
    0,
    [_RUP, _WIIS, _ARCu],
    [() => RollingDeploymentPolicy$, 1, () => AutoRollbackAlarms]
];
export var DeploymentRecommendation$ = [3, n0, _DR,
    0,
    [_RSec, _RTIR],
    [0, () => RealTimeInferenceRecommendations], 1
];
export var DeploymentStage$ = [3, n0, _DSe,
    0,
    [_SNt, _DSCe, _DC],
    [0, () => DeviceSelectionConfig$, () => EdgeDeploymentConfig$], 2
];
export var DeploymentStageStatusSummary$ = [3, n0, _DSSSe,
    0,
    [_SNt, _DSCe, _DC, _DSep],
    [0, () => DeviceSelectionConfig$, () => EdgeDeploymentConfig$, () => EdgeDeploymentStatus$], 4
];
export var DeregisterDevicesRequest$ = [3, n0, _DDRe,
    0,
    [_DFN, _DNev],
    [0, 64 | 0], 2
];
export var DerivedInformation$ = [3, n0, _DIer,
    0,
    [_DDIC],
    [0]
];
export var DescribeActionRequest$ = [3, n0, _DARes,
    0,
    [_AN],
    [0], 1
];
export var DescribeActionResponse$ = [3, n0, _DAResc,
    0,
    [_AN, _AA, _S, _AT, _D, _St, _Pr, _CT, _CB, _LMT, _LMB, _MPe, _LGA],
    [0, 0, () => ActionSource$, 0, 0, 0, 128 | 0, 4, () => UserContext$, 4, () => UserContext$, () => MetadataProperties$, 0]
];
export var DescribeAlgorithmInput$ = [3, n0, _DAIe,
    0,
    [_ANlg],
    [0], 1
];
export var DescribeAlgorithmOutput$ = [3, n0, _DAO,
    0,
    [_ANlg, _AAl, _CT, _TS, _ASlgo, _ASD, _ADl, _ISn, _VSa, _PIrod, _CFM],
    [0, 0, 4, () => TrainingSpecification$, 0, () => AlgorithmStatusDetails$, 0, () => InferenceSpecification$, () => AlgorithmValidationSpecification$, 0, 2], 6
];
export var DescribeAppImageConfigRequest$ = [3, n0, _DAICRe,
    0,
    [_AICN],
    [0], 1
];
export var DescribeAppImageConfigResponse$ = [3, n0, _DAICRes,
    0,
    [_AICA, _AICN, _CT, _LMT, _KGIC, _JLAIC, _CEAIC],
    [0, 0, 4, 4, () => KernelGatewayImageConfig$, () => JupyterLabAppImageConfig$, () => CodeEditorAppImageConfig$]
];
export var DescribeAppRequest$ = [3, n0, _DARescr,
    0,
    [_DI, _ATp, _ANp, _UPN, _SN],
    [0, 0, 0, 0, 0], 3
];
export var DescribeAppResponse$ = [3, n0, _DARescri,
    0,
    [_AAp, _ATp, _ANp, _DI, _UPN, _SN, _St, _ETIPS, _RM, _LHCT, _LUAT, _CT, _FR, _RS, _BILCA],
    [0, 0, 0, 0, 0, 0, 0, 0, 2, 4, 4, 4, 0, () => ResourceSpec$, 0]
];
export var DescribeArtifactRequest$ = [3, n0, _DARescrib,
    0,
    [_AAr],
    [0], 1
];
export var DescribeArtifactResponse$ = [3, n0, _DARescribe,
    0,
    [_ANr, _AAr, _S, _ATr, _Pr, _CT, _CB, _LMT, _LMB, _MPe, _LGA],
    [0, 0, () => ArtifactSource$, 0, 128 | 0, 4, () => UserContext$, 4, () => UserContext$, () => MetadataProperties$, 0]
];
export var DescribeAutoMLJobRequest$ = [3, n0, _DAMLJR,
    0,
    [_AMLJN],
    [0], 1
];
export var DescribeAutoMLJobResponse$ = [3, n0, _DAMLJRe,
    0,
    [_AMLJN, _AMLJAu, _IDC, _ODC, _RAo, _CT, _LMT, _AMLJSu, _AMLJSS, _AMLJO, _PT, _AMLJCu, _ETn, _FR, _PFR, _BC, _GCDO, _AMLJA, _RAe, _MDC, _MDR],
    [0, 0, () => AutoMLInputDataConfig, () => AutoMLOutputDataConfig$, 0, 4, 4, 0, 0, () => AutoMLJobObjective$, 0, () => AutoMLJobConfig$, 4, 0, () => AutoMLPartialFailureReasons, () => AutoMLCandidate$, 2, () => AutoMLJobArtifacts$, () => ResolvedAttributes$, () => ModelDeployConfig$, () => ModelDeployResult$], 9
];
export var DescribeAutoMLJobV2Request$ = [3, n0, _DAMLJVR,
    0,
    [_AMLJN],
    [0], 1
];
export var DescribeAutoMLJobV2Response$ = [3, n0, _DAMLJVRe,
    0,
    [_AMLJN, _AMLJAu, _AMLJIDC, _ODC, _RAo, _CT, _LMT, _AMLJSu, _AMLJSS, _AMLJO, _AMLPTC, _AMLPTCN, _ETn, _FR, _PFR, _BC, _AMLJA, _RAe, _MDC, _MDR, _DSC, _SC, _AMLCC],
    [0, 0, () => AutoMLJobInputDataConfig, () => AutoMLOutputDataConfig$, 0, 4, 4, 0, 0, () => AutoMLJobObjective$, () => AutoMLProblemTypeConfig$, 0, 4, 0, () => AutoMLPartialFailureReasons, () => AutoMLCandidate$, () => AutoMLJobArtifacts$, () => AutoMLResolvedAttributes$, () => ModelDeployConfig$, () => ModelDeployResult$, () => AutoMLDataSplitConfig$, () => AutoMLSecurityConfig$, () => AutoMLComputeConfig$], 9
];
export var DescribeClusterEventRequest$ = [3, n0, _DCER,
    0,
    [_EI, _CNl],
    [0, 0], 2
];
export var DescribeClusterEventResponse$ = [3, n0, _DCERe,
    0,
    [_ED],
    [() => ClusterEventDetail$]
];
export var DescribeClusterNodeRequest$ = [3, n0, _DCNR,
    0,
    [_CNl, _NI, _NLI],
    [0, 0, 0], 1
];
export var DescribeClusterNodeResponse$ = [3, n0, _DCNRe,
    0,
    [_ND],
    [() => ClusterNodeDetails$], 1
];
export var DescribeClusterRequest$ = [3, n0, _DCRes,
    0,
    [_CNl],
    [0], 1
];
export var DescribeClusterResponse$ = [3, n0, _DCResc,
    0,
    [_CAl, _CSlu, _IG, _CNl, _CT, _FM, _RIG, _VC, _Or, _TSCi, _NR, _NPM, _CRl, _ASu],
    [0, 0, () => ClusterInstanceGroupDetailsList, 0, 4, 0, () => ClusterRestrictedInstanceGroupDetailsList, () => VpcConfig$, () => ClusterOrchestrator$, () => ClusterTieredStorageConfig$, 0, 0, 0, () => ClusterAutoScalingConfigOutput$], 3
];
export var DescribeClusterSchedulerConfigRequest$ = [3, n0, _DCSCRe,
    0,
    [_CSCI, _CSCV],
    [0, 1], 1
];
export var DescribeClusterSchedulerConfigResponse$ = [3, n0, _DCSCRes,
    0,
    [_CSCA, _CSCI, _N, _CSCV, _St, _CT, _FR, _SDt, _CAl, _SCc, _D, _CB, _LMT, _LMB],
    [0, 0, 0, 1, 0, 4, 0, 128 | 0, 0, () => SchedulerConfig$, 0, () => UserContext$, 4, () => UserContext$], 6
];
export var DescribeCodeRepositoryInput$ = [3, n0, _DCRIe,
    0,
    [_CRN],
    [0], 1
];
export var DescribeCodeRepositoryOutput$ = [3, n0, _DCRO,
    0,
    [_CRN, _CRA, _CT, _LMT, _GC],
    [0, 0, 4, 4, () => GitConfig$], 4
];
export var DescribeCompilationJobRequest$ = [3, n0, _DCJRe,
    0,
    [_CJN],
    [0], 1
];
export var DescribeCompilationJobResponse$ = [3, n0, _DCJRes,
    0,
    [_CJN, _CJAo, _CJSo, _SCt, _CT, _LMT, _FR, _MAo, _RAo, _ICnp, _OC, _CSTo, _CET, _IIn, _MPVA, _MDo, _VC, _DIer],
    [0, 0, 0, () => StoppingCondition$, 4, 4, 0, () => ModelArtifacts$, 0, () => InputConfig$, () => OutputConfig$, 4, 4, 0, 0, () => ModelDigests$, () => NeoVpcConfig$, () => DerivedInformation$], 11
];
export var DescribeComputeQuotaRequest$ = [3, n0, _DCQRe,
    0,
    [_CQI, _CQV],
    [0, 1], 1
];
export var DescribeComputeQuotaResponse$ = [3, n0, _DCQRes,
    0,
    [_CQA, _CQI, _N, _CQV, _St, _CQT, _CT, _D, _FR, _CAl, _CQC, _ASct, _CB, _LMT, _LMB],
    [0, 0, 0, 1, 0, () => ComputeQuotaTarget$, 4, 0, 0, 0, () => ComputeQuotaConfig$, 0, () => UserContext$, 4, () => UserContext$], 7
];
export var DescribeContextRequest$ = [3, n0, _DCRescr,
    0,
    [_CNon],
    [0], 1
];
export var DescribeContextResponse$ = [3, n0, _DCRescri,
    0,
    [_CNon, _CAo, _S, _CTonte, _D, _Pr, _CT, _CB, _LMT, _LMB, _LGA],
    [0, 0, () => ContextSource$, 0, 0, 128 | 0, 4, () => UserContext$, 4, () => UserContext$, 0]
];
export var DescribeDataQualityJobDefinitionRequest$ = [3, n0, _DDQJDRe,
    0,
    [_JDN],
    [0], 1
];
export var DescribeDataQualityJobDefinitionResponse$ = [3, n0, _DDQJDRes,
    0,
    [_JDA, _JDN, _CT, _DQAS, _DQJI, _DQJOC, _JR, _RAo, _DQBC, _NCe, _SCt],
    [0, 0, 4, () => DataQualityAppSpecification$, () => DataQualityJobInput$, () => MonitoringOutputConfig$, () => MonitoringResources$, 0, () => DataQualityBaselineConfig$, () => MonitoringNetworkConfig$, () => MonitoringStoppingCondition$], 8
];
export var DescribeDeviceFleetRequest$ = [3, n0, _DDFRe,
    0,
    [_DFN],
    [0], 1
];
export var DescribeDeviceFleetResponse$ = [3, n0, _DDFRes,
    0,
    [_DFN, _DFA, _OC, _CT, _LMT, _D, _RAo, _IRA],
    [0, 0, () => EdgeOutputConfig$, 4, 4, 0, 0, 0], 5
];
export var DescribeDeviceRequest$ = [3, n0, _DDRes,
    0,
    [_DNe, _DFN, _NTe],
    [0, 0, 0], 2
];
export var DescribeDeviceResponse$ = [3, n0, _DDResc,
    0,
    [_DNe, _DFN, _RTeg, _DAe, _D, _ITN, _LHa, _Mod, _MMa, _NTe, _AV],
    [0, 0, 4, 0, 0, 0, 4, () => EdgeModels, 1, 0, 0], 3
];
export var DescribeDomainRequest$ = [3, n0, _DDRescr,
    0,
    [_DI],
    [0], 1
];
export var DescribeDomainResponse$ = [3, n0, _DDRescri,
    0,
    [_DAo, _DI, _DNo, _HEFSI, _SSOMAII, _SSOAA, _St, _CT, _LMT, _FR, _SGIFDB, _AM, _DUS, _DSo, _ANAT, _HEFSKKI, _SIu, _U, _VIp, _KKI, _ASGM, _TP, _DSS],
    [0, 0, 0, 0, 0, 0, 0, 4, 4, 0, 0, 0, () => UserSettings$, () => DomainSettings$, 0, 0, 64 | 0, 0, 0, 0, 0, 0, () => DefaultSpaceSettings$]
];
export var DescribeEdgeDeploymentPlanRequest$ = [3, n0, _DEDPRe,
    0,
    [_EDPN, _NTe, _MR],
    [0, 0, 1], 1
];
export var DescribeEdgeDeploymentPlanResponse$ = [3, n0, _DEDPRes,
    0,
    [_EDPA, _EDPN, _MCo, _DFN, _Sta, _EDS, _EDP, _EDF, _NTe, _CT, _LMT],
    [0, 0, () => EdgeDeploymentModelConfigs, 0, () => DeploymentStageStatusSummaries, 1, 1, 1, 0, 4, 4], 5
];
export var DescribeEdgePackagingJobRequest$ = [3, n0, _DEPJR,
    0,
    [_EPJN],
    [0], 1
];
export var DescribeEdgePackagingJobResponse$ = [3, n0, _DEPJRe,
    0,
    [_EPJA, _EPJN, _EPJS, _CJN, _MNod, _MVo, _RAo, _OC, _RK, _EPJSM, _CT, _LMT, _MAod, _MSo, _PDO],
    [0, 0, 0, 0, 0, 0, 0, () => EdgeOutputConfig$, 0, 0, 4, 4, 0, 0, () => EdgePresetDeploymentOutput$], 3
];
export var DescribeEndpointConfigInput$ = [3, n0, _DECIe,
    0,
    [_ECN],
    [0], 1
];
export var DescribeEndpointConfigOutput$ = [3, n0, _DECO,
    0,
    [_ECN, _ECA, _PV, _CT, _DCC, _KKI, _AIC, _ECx, _SPV, _ERA, _VC, _ENI, _MCe],
    [0, 0, () => ProductionVariantList, 4, () => DataCaptureConfig$, 0, () => AsyncInferenceConfig$, () => ExplainerConfig$, () => ProductionVariantList, 0, () => VpcConfig$, 2, () => MetricsConfig$], 4
];
export var DescribeEndpointInput$ = [3, n0, _DEIe,
    0,
    [_EN],
    [0], 1
];
export var DescribeEndpointOutput$ = [3, n0, _DEO,
    0,
    [_EN, _EA, _ES, _CT, _LMT, _ECN, _PV, _DCC, _FR, _LDC, _AIC, _PDS, _ECx, _SPV, _MCe],
    [0, 0, 0, 4, 4, 0, () => ProductionVariantSummaryList, () => DataCaptureConfigSummary$, 0, () => DeploymentConfig$, () => AsyncInferenceConfig$, () => PendingDeploymentSummary$, () => ExplainerConfig$, () => ProductionVariantSummaryList, () => MetricsConfig$], 5
];
export var DescribeExperimentRequest$ = [3, n0, _DERes,
    0,
    [_ENx],
    [0], 1
];
export var DescribeExperimentResponse$ = [3, n0, _DEResc,
    0,
    [_ENx, _EAx, _DNi, _S, _D, _CT, _CB, _LMT, _LMB],
    [0, 0, 0, () => ExperimentSource$, 0, 4, () => UserContext$, 4, () => UserContext$]
];
export var DescribeFeatureGroupRequest$ = [3, n0, _DFGRe,
    0,
    [_FGN, _NTe],
    [0, 0], 1
];
export var DescribeFeatureGroupResponse$ = [3, n0, _DFGRes,
    0,
    [_FGA, _FGN, _RIFN, _ETFN, _FD, _CT, _NTe, _LMT, _OSC, _OSCf, _TCh, _RAo, _FGS, _OSS, _LUS, _FR, _D, _OSTSB],
    [0, 0, 0, 0, () => FeatureDefinitions, 4, 0, 4, () => OnlineStoreConfig$, () => OfflineStoreConfig$, () => ThroughputConfigDescription$, 0, 0, () => OfflineStoreStatus$, () => LastUpdateStatus$, 0, 0, 1], 7
];
export var DescribeFeatureMetadataRequest$ = [3, n0, _DFMR,
    0,
    [_FGN, _FN],
    [0, 0], 2
];
export var DescribeFeatureMetadataResponse$ = [3, n0, _DFMRe,
    0,
    [_FGA, _FGN, _FN, _FTe, _CT, _LMT, _D, _P],
    [0, 0, 0, 0, 4, 4, 0, () => FeatureParameters], 6
];
export var DescribeFlowDefinitionRequest$ = [3, n0, _DFDRes,
    0,
    [_FDN],
    [0], 1
];
export var DescribeFlowDefinitionResponse$ = [3, n0, _DFDResc,
    0,
    [_FDA, _FDN, _FDS, _CT, _OC, _RAo, _HLRS, _HLACu, _HLC, _FR],
    [0, 0, 0, 4, () => FlowDefinitionOutputConfig$, 0, () => HumanLoopRequestSource$, [() => HumanLoopActivationConfig$, 0], () => HumanLoopConfig$, 0], 6
];
export var DescribeHubContentRequest$ = [3, n0, _DHCRe,
    0,
    [_HN, _HCT, _HCN, _HCV],
    [0, 0, 0, 0], 3
];
export var DescribeHubContentResponse$ = [3, n0, _DHCRes,
    0,
    [_HCN, _HCA, _HCV, _HCT, _DSV, _HN, _HA, _HCD, _HCS, _CT, _HCDN, _HCDu, _HCM, _SMPHCA, _RMV, _SSu, _HCSK, _HCDub, _FR, _LMT],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 0, 0, 64 | 0, () => HubContentDependencyList, 0, 4], 10
];
export var DescribeHubRequest$ = [3, n0, _DHRe,
    0,
    [_HN],
    [0], 1
];
export var DescribeHubResponse$ = [3, n0, _DHRes,
    0,
    [_HN, _HA, _HS, _CT, _LMT, _HDN, _HD, _HSK, _SSC, _FR],
    [0, 0, 0, 4, 4, 0, 0, 64 | 0, () => HubS3StorageConfig$, 0], 5
];
export var DescribeHumanTaskUiRequest$ = [3, n0, _DHTURes,
    0,
    [_HTUN],
    [0], 1
];
export var DescribeHumanTaskUiResponse$ = [3, n0, _DHTUResc,
    0,
    [_HTUA, _HTUN, _CT, _UT, _HTUS],
    [0, 0, 4, () => UiTemplateInfo$, 0], 4
];
export var DescribeHyperParameterTuningJobRequest$ = [3, n0, _DHPTJRe,
    0,
    [_HPTJN],
    [0], 1
];
export var DescribeHyperParameterTuningJobResponse$ = [3, n0, _DHPTJRes,
    0,
    [_HPTJN, _HPTJA, _HPTJC, _HPTJS, _CT, _TJSC, _OSCb, _TJD, _TJDra, _HPTET, _LMT, _BTJ, _OBTJ, _WSC, _Au, _FR, _TJCD, _CRons],
    [0, 0, () => HyperParameterTuningJobConfig$, 0, 4, () => TrainingJobStatusCounters$, () => ObjectiveStatusCounters$, () => HyperParameterTrainingJobDefinition$, () => HyperParameterTrainingJobDefinitions, 4, 4, () => HyperParameterTrainingJobSummary$, () => HyperParameterTrainingJobSummary$, () => HyperParameterTuningJobWarmStartConfig$, () => Autotune$, 0, () => HyperParameterTuningJobCompletionDetails$, () => HyperParameterTuningJobConsumedResources$], 7
];
export var DescribeImageRequest$ = [3, n0, _DIRes,
    0,
    [_IN],
    [0], 1
];
export var DescribeImageResponse$ = [3, n0, _DIResc,
    0,
    [_CT, _D, _DNi, _FR, _IAm, _IN, _ISm, _LMT, _RAo],
    [4, 0, 0, 0, 0, 0, 0, 4, 0]
];
export var DescribeImageVersionRequest$ = [3, n0, _DIVRes,
    0,
    [_IN, _V, _Alia],
    [0, 1, 0], 1
];
export var DescribeImageVersionResponse$ = [3, n0, _DIVResc,
    0,
    [_BI, _CIo, _CT, _FR, _IAm, _IVA, _IVS, _LMT, _V, _VG, _JT, _MLF, _PL, _Pro, _H, _RN],
    [0, 0, 4, 0, 0, 0, 0, 4, 1, 0, 0, 0, 0, 0, 2, 0]
];
export var DescribeInferenceComponentInput$ = [3, n0, _DICIe,
    0,
    [_ICN],
    [0], 1
];
export var DescribeInferenceComponentOutput$ = [3, n0, _DICO,
    0,
    [_ICN, _ICA, _EN, _EA, _CT, _LMT, _VN, _FR, _Spe, _RC, _ICS, _LDC],
    [0, 0, 0, 0, 4, 4, 0, 0, () => InferenceComponentSpecificationSummary$, () => InferenceComponentRuntimeConfigSummary$, 0, () => InferenceComponentDeploymentConfig$], 6
];
export var DescribeInferenceExperimentRequest$ = [3, n0, _DIERes,
    0,
    [_N],
    [0], 1
];
export var DescribeInferenceExperimentResponse$ = [3, n0, _DIEResc,
    0,
    [_Ar, _N, _T, _St, _EM, _MVod, _Sc, _SRt, _D, _CT, _CTom, _LMT, _RAo, _DSCa, _SMC, _KK],
    [0, 0, 0, 0, () => EndpointMetadata$, () => ModelVariantConfigSummaryList, () => InferenceExperimentSchedule$, 0, 0, 4, 4, 4, 0, () => InferenceExperimentDataStorageConfig$, () => ShadowModeConfig$, 0], 6
];
export var DescribeInferenceRecommendationsJobRequest$ = [3, n0, _DIRJR,
    0,
    [_JN],
    [0], 1
];
export var DescribeInferenceRecommendationsJobResponse$ = [3, n0, _DIRJRe,
    0,
    [_JN, _JT, _JA, _RAo, _St, _CT, _LMT, _ICnp, _JD, _CTom, _FR, _SCto, _IRn, _EP],
    [0, 0, 0, 0, 0, 4, 4, () => RecommendationJobInputConfig$, 0, 4, 0, () => RecommendationJobStoppingConditions$, () => InferenceRecommendations, () => EndpointPerformances], 8
];
export var DescribeLabelingJobRequest$ = [3, n0, _DLJR,
    0,
    [_LJN],
    [0], 1
];
export var DescribeLabelingJobResponse$ = [3, n0, _DLJRe,
    0,
    [_LJS, _LC, _CT, _LMT, _JRC, _LJN, _LJA, _ICnp, _OC, _RAo, _HTC, _FR, _LAN, _LCCSU, _SCto, _LJAC, _Ta, _LJO],
    [0, () => LabelCounters$, 4, 4, 0, 0, 0, () => LabelingJobInputConfig$, () => LabelingJobOutputConfig$, 0, () => HumanTaskConfig$, 0, 0, 0, () => LabelingJobStoppingConditions$, () => LabelingJobAlgorithmsConfig$, () => TagList, () => LabelingJobOutput$], 11
];
export var DescribeLineageGroupRequest$ = [3, n0, _DLGR,
    0,
    [_LGN],
    [0], 1
];
export var DescribeLineageGroupResponse$ = [3, n0, _DLGRe,
    0,
    [_LGN, _LGA, _DNi, _D, _CT, _CB, _LMT, _LMB],
    [0, 0, 0, 0, 4, () => UserContext$, 4, () => UserContext$]
];
export var DescribeMlflowAppRequest$ = [3, n0, _DMARes,
    0,
    [_Ar],
    [0], 1
];
export var DescribeMlflowAppResponse$ = [3, n0, _DMAResc,
    0,
    [_Ar, _N, _ASU, _MVl, _RAo, _St, _MRM, _ADS, _DDIL, _CT, _CB, _LMT, _LMB, _WMWS, _MSa],
    [0, 0, 0, 0, 0, 0, 0, 0, 64 | 0, 4, () => UserContext$, 4, () => UserContext$, 0, 0]
];
export var DescribeMlflowTrackingServerRequest$ = [3, n0, _DMTSRes,
    0,
    [_TSN],
    [0], 1
];
export var DescribeMlflowTrackingServerResponse$ = [3, n0, _DMTSResc,
    0,
    [_TSA, _TSN, _ASU, _TSS, _MVl, _RAo, _TSSr, _TSMS, _IAs, _TSU, _WMWS, _AMR, _CT, _CB, _LMT, _LMB],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 4, () => UserContext$, 4, () => UserContext$]
];
export var DescribeModelBiasJobDefinitionRequest$ = [3, n0, _DMBJDRe,
    0,
    [_JDN],
    [0], 1
];
export var DescribeModelBiasJobDefinitionResponse$ = [3, n0, _DMBJDRes,
    0,
    [_JDA, _JDN, _CT, _MBAS, _MBJI, _MBJOC, _JR, _RAo, _MBBC, _NCe, _SCt],
    [0, 0, 4, () => ModelBiasAppSpecification$, () => ModelBiasJobInput$, () => MonitoringOutputConfig$, () => MonitoringResources$, 0, () => ModelBiasBaselineConfig$, () => MonitoringNetworkConfig$, () => MonitoringStoppingCondition$], 8
];
export var DescribeModelCardExportJobRequest$ = [3, n0, _DMCEJR,
    0,
    [_MCEJA],
    [0], 1
];
export var DescribeModelCardExportJobResponse$ = [3, n0, _DMCEJRe,
    0,
    [_MCEJN, _MCEJA, _St, _MCN, _MCV, _OC, _CAr, _LMA, _FR, _EAxp],
    [0, 0, 0, 0, 1, () => ModelCardExportOutputConfig$, 4, 4, 0, () => ModelCardExportArtifacts$], 8
];
export var DescribeModelCardRequest$ = [3, n0, _DMCRe,
    0,
    [_MCN, _MCV],
    [0, 1], 1
];
export var DescribeModelCardResponse$ = [3, n0, _DMCRes,
    0,
    [_MCA, _MCN, _MCV, _Con, _MCS, _CT, _CB, _SC, _LMT, _LMB, _MCPS],
    [0, 0, 1, [() => ModelCardContent, 0], 0, 4, () => UserContext$, () => ModelCardSecurityConfig$, 4, () => UserContext$, 0], 7
];
export var DescribeModelExplainabilityJobDefinitionRequest$ = [3, n0, _DMEJDRe,
    0,
    [_JDN],
    [0], 1
];
export var DescribeModelExplainabilityJobDefinitionResponse$ = [3, n0, _DMEJDRes,
    0,
    [_JDA, _JDN, _CT, _MEAS, _MEJI, _MEJOC, _JR, _RAo, _MEBC, _NCe, _SCt],
    [0, 0, 4, () => ModelExplainabilityAppSpecification$, () => ModelExplainabilityJobInput$, () => MonitoringOutputConfig$, () => MonitoringResources$, 0, () => ModelExplainabilityBaselineConfig$, () => MonitoringNetworkConfig$, () => MonitoringStoppingCondition$], 8
];
export var DescribeModelInput$ = [3, n0, _DMIe,
    0,
    [_MNod],
    [0], 1
];
export var DescribeModelOutput$ = [3, n0, _DMO,
    0,
    [_MNod, _CT, _MA, _PC, _Co, _IEC, _ERA, _VC, _ENI, _DR],
    [0, 4, 0, () => ContainerDefinition$, () => ContainerDefinitionList, () => InferenceExecutionConfig$, 0, () => VpcConfig$, 2, () => DeploymentRecommendation$], 3
];
export var DescribeModelPackageGroupInput$ = [3, n0, _DMPGIe,
    0,
    [_MPGN],
    [0], 1
];
export var DescribeModelPackageGroupOutput$ = [3, n0, _DMPGO,
    0,
    [_MPGN, _MPGA, _CT, _CB, _MPGS, _MPGD],
    [0, 0, 4, () => UserContext$, 0, 0], 5
];
export var DescribeModelPackageInput$ = [3, n0, _DMPIe,
    0,
    [_MPN],
    [0], 1
];
export var DescribeModelPackageOutput$ = [3, n0, _DMPO,
    0,
    [_MPN, _MPA, _CT, _MPSo, _MPSD, _MPGN, _MPV, _MPRT, _MPD, _ISn, _SAS, _VSa, _CFM, _MAS, _CB, _MPe, _MM, _LMT, _LMB, _ADpp, _Do, _Tas, _SPU, _CMP, _DCB, _AIS, _SMV, _SU, _SC, _MCod, _MLC],
    [0, 0, 4, 0, () => ModelPackageStatusDetails$, 0, 1, 0, 0, () => InferenceSpecification$, () => SourceAlgorithmSpecification$, () => ModelPackageValidationSpecification$, 2, 0, () => UserContext$, () => MetadataProperties$, () => ModelMetrics$, 4, () => UserContext$, 0, 0, 0, 0, 128 | 0, () => DriftCheckBaselines$, () => AdditionalInferenceSpecifications, 0, 0, () => ModelPackageSecurityConfig$, [() => ModelPackageModelCard$, 0], () => ModelLifeCycle$], 5
];
export var DescribeModelQualityJobDefinitionRequest$ = [3, n0, _DMQJDRe,
    0,
    [_JDN],
    [0], 1
];
export var DescribeModelQualityJobDefinitionResponse$ = [3, n0, _DMQJDRes,
    0,
    [_JDA, _JDN, _CT, _MQAS, _MQJI, _MQJOC, _JR, _RAo, _MQBC, _NCe, _SCt],
    [0, 0, 4, () => ModelQualityAppSpecification$, () => ModelQualityJobInput$, () => MonitoringOutputConfig$, () => MonitoringResources$, 0, () => ModelQualityBaselineConfig$, () => MonitoringNetworkConfig$, () => MonitoringStoppingCondition$], 8
];
export var DescribeMonitoringScheduleRequest$ = [3, n0, _DMSRe,
    0,
    [_MSN],
    [0], 1
];
export var DescribeMonitoringScheduleResponse$ = [3, n0, _DMSRes,
    0,
    [_MSA, _MSN, _MSS, _CT, _LMT, _MSC, _MTo, _FR, _EN, _LMES],
    [0, 0, 0, 4, 4, () => MonitoringScheduleConfig$, 0, 0, 0, () => MonitoringExecutionSummary$], 6
];
export var DescribeNotebookInstanceInput$ = [3, n0, _DNIIe,
    0,
    [_NIN],
    [0], 1
];
export var DescribeNotebookInstanceLifecycleConfigInput$ = [3, n0, _DNILCIe,
    0,
    [_NILCN],
    [0], 1
];
export var DescribeNotebookInstanceLifecycleConfigOutput$ = [3, n0, _DNILCO,
    0,
    [_NILCA, _NILCN, _OCn, _OSn, _LMT, _CT],
    [0, 0, () => NotebookInstanceLifecycleConfigList, () => NotebookInstanceLifecycleConfigList, 4, 4]
];
export var DescribeNotebookInstanceOutput$ = [3, n0, _DNIO,
    0,
    [_NIA, _NIN, _NIS, _FR, _U, _IT, _IAT, _SIub, _SG, _RAo, _KKI, _NII, _LMT, _CT, _NILCN, _DIA, _VSIGB, _ATc, _DCR, _ACR, _RAoo, _PIl, _IMSC],
    [0, 0, 0, 0, 0, 0, 0, 0, 64 | 0, 0, 0, 0, 4, 4, 0, 0, 1, 64 | 0, 0, 64 | 0, 0, 0, () => InstanceMetadataServiceConfiguration$]
];
export var DescribeOptimizationJobRequest$ = [3, n0, _DOJRe,
    0,
    [_OJN],
    [0], 1
];
export var DescribeOptimizationJobResponse$ = [3, n0, _DOJRes,
    0,
    [_OJA, _OJS, _CT, _LMT, _OJN, _MS, _DIT, _OCp, _OC, _RAo, _SCt, _OST, _OET, _FR, _OE, _MICa, _OO, _VC],
    [0, 0, 4, 4, 0, () => OptimizationJobModelSource$, 0, () => OptimizationConfigs, () => OptimizationJobOutputConfig$, 0, () => StoppingCondition$, 4, 4, 0, 128 | 0, 1, () => OptimizationOutput$, () => OptimizationVpcConfig$], 11
];
export var DescribePartnerAppRequest$ = [3, n0, _DPARes,
    0,
    [_Ar, _IAU],
    [0, 2], 1
];
export var DescribePartnerAppResponse$ = [3, n0, _DPAResc,
    0,
    [_Ar, _N, _T, _St, _CT, _LMT, _ERA, _KKI, _BU, _MCa, _Ti, _V, _ACp, _ATu, _EISBI, _Er, _EAMVU, _CVED, _AUv],
    [0, 0, 0, 0, 4, 4, 0, 0, 0, () => PartnerAppMaintenanceConfig$, 0, 0, () => PartnerAppConfig$, 0, 2, () => ErrorInfo$, 2, 4, () => AvailableUpgrade$]
];
export var DescribePipelineDefinitionForExecutionRequest$ = [3, n0, _DPDFER,
    0,
    [_PEA],
    [0], 1
];
export var DescribePipelineDefinitionForExecutionResponse$ = [3, n0, _DPDFERe,
    0,
    [_PD, _CT],
    [0, 4]
];
export var DescribePipelineExecutionRequest$ = [3, n0, _DPER,
    0,
    [_PEA],
    [0], 1
];
export var DescribePipelineExecutionResponse$ = [3, n0, _DPERe,
    0,
    [_PAi, _PEA, _PEDN, _PES, _PED, _PEC, _FR, _CT, _LMT, _CB, _LMB, _PCa, _SEC, _PVI, _MLCf],
    [0, 0, 0, 0, 0, () => PipelineExperimentConfig$, 0, 4, 4, () => UserContext$, () => UserContext$, () => ParallelismConfiguration$, () => SelectiveExecutionConfig$, 1, () => MLflowConfiguration$]
];
export var DescribePipelineRequest$ = [3, n0, _DPRes,
    0,
    [_PNi, _PVI],
    [0, 1], 1
];
export var DescribePipelineResponse$ = [3, n0, _DPResc,
    0,
    [_PAi, _PNi, _PDN, _PD, _PDi, _RAo, _PS, _CT, _LMT, _LRT, _CB, _LMB, _PCa, _PVDN, _PVD],
    [0, 0, 0, 0, 0, 0, 0, 4, 4, 4, () => UserContext$, () => UserContext$, () => ParallelismConfiguration$, 0, 0]
];
export var DescribeProcessingJobRequest$ = [3, n0, _DPJRe,
    0,
    [_PJN],
    [0], 1
];
export var DescribeProcessingJobResponse$ = [3, n0, _DPJRes,
    0,
    [_PJN, _PR, _ASp, _PJA, _PJS, _CT, _PIr, _POC, _SCt, _E, _NCe, _RAo, _ECxp, _EMx, _FR, _PET, _PST, _LMT, _MSA, _AMLJAu, _TJA],
    [0, () => ProcessingResources$, () => AppSpecification$, 0, 0, 4, () => ProcessingInputs, () => ProcessingOutputConfig$, () => ProcessingStoppingCondition$, 128 | 0, () => NetworkConfig$, 0, () => ExperimentConfig$, 0, 0, 4, 4, 4, 0, 0, 0], 6
];
export var DescribeProjectInput$ = [3, n0, _DPIe,
    0,
    [_PNr],
    [0], 1
];
export var DescribeProjectOutput$ = [3, n0, _DPO,
    0,
    [_PAr, _PNr, _PIro, _PSr, _CT, _PDr, _SCPD, _SCPPD, _TPD, _CB, _LMT, _LMB],
    [0, 0, 0, 0, 4, 0, () => ServiceCatalogProvisioningDetails$, () => ServiceCatalogProvisionedProductDetails$, () => TemplateProviderDetailList, () => UserContext$, 4, () => UserContext$], 5
];
export var DescribeReservedCapacityRequest$ = [3, n0, _DRCR,
    0,
    [_RCA],
    [0], 1
];
export var DescribeReservedCapacityResponse$ = [3, n0, _DRCRe,
    0,
    [_RCA, _IT, _TICo, _RCT, _St, _AZ, _DH, _DM, _STt, _ETn, _AICv, _IUIC, _USS],
    [0, 0, 1, 0, 0, 0, 1, 1, 4, 4, 1, 1, () => UltraServerSummary$], 3
];
export var DescribeSpaceRequest$ = [3, n0, _DSRe,
    0,
    [_DI, _SN],
    [0, 0], 2
];
export var DescribeSpaceResponse$ = [3, n0, _DSRes,
    0,
    [_DI, _SAp, _SN, _HEFSU, _St, _LMT, _CT, _FR, _SS, _OSw, _SSS, _SDN, _U],
    [0, 0, 0, 0, 0, 4, 4, 0, () => SpaceSettings$, () => OwnershipSettings$, () => SpaceSharingSettings$, 0, 0]
];
export var DescribeStudioLifecycleConfigRequest$ = [3, n0, _DSLCRe,
    0,
    [_SLCN],
    [0], 1
];
export var DescribeStudioLifecycleConfigResponse$ = [3, n0, _DSLCRes,
    0,
    [_SLCA, _SLCN, _CT, _LMT, _SLCC, _SLCAT],
    [0, 0, 4, 4, 0, 0]
];
export var DescribeSubscribedWorkteamRequest$ = [3, n0, _DSWR,
    0,
    [_WAo],
    [0], 1
];
export var DescribeSubscribedWorkteamResponse$ = [3, n0, _DSWRe,
    0,
    [_SW],
    [() => SubscribedWorkteam$], 1
];
export var DescribeTrainingJobRequest$ = [3, n0, _DTJRe,
    0,
    [_TJN],
    [0], 1
];
export var DescribeTrainingJobResponse$ = [3, n0, _DTJRes,
    0,
    [_TJN, _TJA, _MAo, _TJS, _SSe, _SCt, _CT, _TJAu, _LJA, _AMLJAu, _FR, _HP, _ASl, _RAo, _IDC, _ODC, _RCe, _WPS, _VC, _TST, _TET, _LMT, _SST, _FMDL, _ENI, _EICTE, _EMST, _CCh, _TTIS, _BTIS, _BTC, _DHC, _ECxp, _DRC, _TBOC, _DRESe, _PCr, _PRC, _PRES, _PSro, _E, _RSe, _RDC, _ICC, _SJC, _MCl, _MPC, _MDl, _PIrog, _OMPA],
    [0, 0, () => ModelArtifacts$, 0, 0, () => StoppingCondition$, 4, 0, 0, 0, 0, 128 | 0, () => AlgorithmSpecification$, 0, () => InputDataConfig, () => OutputDataConfig$, () => ResourceConfig$, () => WarmPoolStatus$, () => VpcConfig$, 4, 4, 4, () => SecondaryStatusTransitions, () => FinalMetricDataList, 2, 2, 2, () => CheckpointConfig$, 1, 1, 1, () => DebugHookConfig$, () => ExperimentConfig$, () => DebugRuleConfigurations, () => TensorBoardOutputConfig$, () => DebugRuleEvaluationStatuses, () => ProfilerConfig$, () => ProfilerRuleConfigurations, () => ProfilerRuleEvaluationStatuses, 0, 128 | 0, () => RetryStrategy$, () => RemoteDebugConfig$, () => InfraCheckConfig$, () => ServerlessJobConfig$, () => MlflowConfig$, () => ModelPackageConfig$, () => MlflowDetails$, () => TrainingProgressInfo$, 0], 7
];
export var DescribeTrainingPlanRequest$ = [3, n0, _DTPR,
    0,
    [_TPN],
    [0], 1
];
export var DescribeTrainingPlanResponse$ = [3, n0, _DTPRe,
    0,
    [_TPA, _TPN, _St, _SM, _DH, _DM, _STt, _ETn, _UF, _CCur, _TICo, _AICv, _IUIC, _UIC, _ASIC, _TUSC, _TRa, _RCS],
    [0, 0, 0, 0, 1, 1, 4, 4, 0, 0, 1, 1, 1, 1, 1, 1, 64 | 0, () => ReservedCapacitySummaries], 3
];
export var DescribeTransformJobRequest$ = [3, n0, _DTJResc,
    0,
    [_TJNr],
    [0], 1
];
export var DescribeTransformJobResponse$ = [3, n0, _DTJRescr,
    0,
    [_TJNr, _TJAr, _TJSr, _MNod, _TIr, _TR, _CT, _FR, _MCT, _MCCo, _MPIMB, _BS, _E, _TO, _DCC, _TSTr, _TETr, _LJA, _AMLJAu, _DP, _ECxp],
    [0, 0, 0, 0, () => TransformInput$, () => TransformResources$, 4, 0, 1, () => ModelClientConfig$, 1, 0, 128 | 0, () => TransformOutput$, () => BatchDataCaptureConfig$, 4, 4, 0, 0, () => DataProcessing$, () => ExperimentConfig$], 7
];
export var DescribeTrialComponentRequest$ = [3, n0, _DTCRes,
    0,
    [_TCN],
    [0], 1
];
export var DescribeTrialComponentResponse$ = [3, n0, _DTCResc,
    0,
    [_TCN, _TCA, _DNi, _S, _St, _STt, _ETn, _CT, _CB, _LMT, _LMB, _P, _IAn, _OA, _MPe, _Me, _LGA, _So],
    [0, 0, 0, () => TrialComponentSource$, () => TrialComponentStatus$, 4, 4, 4, () => UserContext$, 4, () => UserContext$, () => TrialComponentParameters, () => TrialComponentArtifacts, () => TrialComponentArtifacts, () => MetadataProperties$, () => TrialComponentMetricSummaries, 0, () => TrialComponentSources]
];
export var DescribeTrialRequest$ = [3, n0, _DTRes,
    0,
    [_TN],
    [0], 1
];
export var DescribeTrialResponse$ = [3, n0, _DTResc,
    0,
    [_TN, _TA, _DNi, _ENx, _S, _CT, _CB, _LMT, _LMB, _MPe],
    [0, 0, 0, 0, () => TrialSource$, 4, () => UserContext$, 4, () => UserContext$, () => MetadataProperties$]
];
export var DescribeUserProfileRequest$ = [3, n0, _DUPRe,
    0,
    [_DI, _UPN],
    [0, 0], 2
];
export var DescribeUserProfileResponse$ = [3, n0, _DUPRes,
    0,
    [_DI, _UPA, _UPN, _HEFSU, _St, _LMT, _CT, _FR, _SSOUI, _SSOUV, _US],
    [0, 0, 0, 0, 0, 4, 4, 0, 0, 0, () => UserSettings$]
];
export var DescribeWorkforceRequest$ = [3, n0, _DWRes,
    0,
    [_WN],
    [0], 1
];
export var DescribeWorkforceResponse$ = [3, n0, _DWResc,
    0,
    [_W],
    [() => Workforce$], 1
];
export var DescribeWorkteamRequest$ = [3, n0, _DWRescr,
    0,
    [_WNo],
    [0], 1
];
export var DescribeWorkteamResponse$ = [3, n0, _DWRescri,
    0,
    [_Wo],
    [() => Workteam$], 1
];
export var DesiredWeightAndCapacity$ = [3, n0, _DWAC,
    0,
    [_VN, _DW, _DIC, _SUCe],
    [0, 1, 1, () => ProductionVariantServerlessUpdateConfig$], 1
];
export var DetachClusterNodeVolumeRequest$ = [3, n0, _DCNVR,
    0,
    [_CAl, _NI, _VI],
    [0, 0, 0], 3
];
export var DetachClusterNodeVolumeResponse$ = [3, n0, _DCNVRe,
    0,
    [_CAl, _NI, _VI, _ATt, _St, _DNe],
    [0, 0, 0, 4, 0, 0], 6
];
export var Device$ = [3, n0, _De,
    0,
    [_DNe, _D, _ITN],
    [0, 0, 0], 1
];
export var DeviceDeploymentSummary$ = [3, n0, _DDSe,
    0,
    [_EDPA, _EDPN, _SNt, _DNe, _DAe, _DSN, _DFN, _DDSev, _DDSM, _D, _DST],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4], 5
];
export var DeviceFleetSummary$ = [3, n0, _DFS,
    0,
    [_DFA, _DFN, _CT, _LMT],
    [0, 0, 4, 4], 2
];
export var DeviceSelectionConfig$ = [3, n0, _DSCe,
    0,
    [_DSTe, _Pe, _DNev, _DNC],
    [0, 1, 64 | 0, 0], 1
];
export var DeviceStats$ = [3, n0, _DSev,
    0,
    [_CDC, _RDCe],
    [1, 1], 2
];
export var DeviceSummary$ = [3, n0, _DSevi,
    0,
    [_DNe, _DAe, _D, _DFN, _ITN, _RTeg, _LHa, _Mod, _AV],
    [0, 0, 0, 0, 0, 4, 4, () => EdgeModelSummaries, 0], 2
];
export var DirectDeploySettings$ = [3, n0, _DDS,
    0,
    [_St],
    [0]
];
export var DisableSagemakerServicecatalogPortfolioInput$ = [3, n0, _DSSPI,
    0,
    [],
    []
];
export var DisableSagemakerServicecatalogPortfolioOutput$ = [3, n0, _DSSPO,
    0,
    [],
    []
];
export var DisassociateTrialComponentRequest$ = [3, n0, _DTCRi,
    0,
    [_TCN, _TN],
    [0, 0], 2
];
export var DisassociateTrialComponentResponse$ = [3, n0, _DTCRis,
    0,
    [_TCA, _TA],
    [0, 0]
];
export var DockerSettings$ = [3, n0, _DSoc,
    0,
    [_EDA, _VOTA, _RD],
    [0, 64 | 0, 0]
];
export var DomainDetails$ = [3, n0, _DDo,
    0,
    [_DAo, _DI, _DNo, _St, _CT, _LMT, _U],
    [0, 0, 0, 0, 4, 4, 0]
];
export var DomainSettings$ = [3, n0, _DSo,
    0,
    [_SGI, _RSSPDS, _ERIC, _TIPS, _DSoc, _AQS, _USSn, _IAT],
    [64 | 0, () => RStudioServerProDomainSettings$, 0, () => TrustedIdentityPropagationSettings$, () => DockerSettings$, () => AmazonQSettings$, () => UnifiedStudioSettings$, 0]
];
export var DomainSettingsForUpdate$ = [3, n0, _DSFU,
    0,
    [_RSSPDSFU, _ERIC, _SGI, _TIPS, _DSoc, _AQS, _USSn, _IAT],
    [() => RStudioServerProDomainSettingsForUpdate$, 0, 64 | 0, () => TrustedIdentityPropagationSettings$, () => DockerSettings$, () => AmazonQSettings$, () => UnifiedStudioSettings$, 0]
];
export var DriftCheckBaselines$ = [3, n0, _DCB,
    0,
    [_B, _Ex, _MQ, _MDQ],
    [() => DriftCheckBias$, () => DriftCheckExplainability$, () => DriftCheckModelQuality$, () => DriftCheckModelDataQuality$]
];
export var DriftCheckBias$ = [3, n0, _DCBr,
    0,
    [_CF, _PTC, _PTCo],
    [() => FileSource$, () => MetricsSource$, () => MetricsSource$]
];
export var DriftCheckExplainability$ = [3, n0, _DCE,
    0,
    [_Cons, _CF],
    [() => MetricsSource$, () => FileSource$]
];
export var DriftCheckModelDataQuality$ = [3, n0, _DCMDQ,
    0,
    [_Stati, _Cons],
    [() => MetricsSource$, () => MetricsSource$]
];
export var DriftCheckModelQuality$ = [3, n0, _DCMQ,
    0,
    [_Stati, _Cons],
    [() => MetricsSource$, () => MetricsSource$]
];
export var DynamicScalingConfiguration$ = [3, n0, _DSCy,
    0,
    [_MCin, _MCax, _SICc, _SOC, _SP],
    [1, 1, 1, 1, () => ScalingPolicies]
];
export var EbsStorageSettings$ = [3, n0, _ESSb,
    0,
    [_EVSIG],
    [1], 1
];
export var Ec2CapacityReservation$ = [3, n0, _ECR,
    0,
    [_ECRI, _TICo, _AICv, _UBCE],
    [0, 1, 1, 1]
];
export var Edge$ = [3, n0, _Ed,
    0,
    [_SA, _DA, _ATs],
    [0, 0, 0]
];
export var EdgeDeploymentConfig$ = [3, n0, _EDC,
    0,
    [_FHP],
    [0], 1
];
export var EdgeDeploymentModelConfig$ = [3, n0, _EDMC,
    0,
    [_MH, _EPJN],
    [0, 0], 2
];
export var EdgeDeploymentPlanSummary$ = [3, n0, _EDPS,
    0,
    [_EDPA, _EDPN, _DFN, _EDS, _EDP, _EDF, _CT, _LMT],
    [0, 0, 0, 1, 1, 1, 4, 4], 6
];
export var EdgeDeploymentStatus$ = [3, n0, _EDSd,
    0,
    [_SSt, _EDSIS, _EDPIS, _EDFIS, _EDSM, _EDSST],
    [0, 1, 1, 1, 0, 4], 4
];
export var EdgeModel$ = [3, n0, _EMd,
    0,
    [_MNod, _MVo, _LST, _LIa],
    [0, 0, 4, 4], 2
];
export var EdgeModelStat$ = [3, n0, _EMS,
    0,
    [_MNod, _MVo, _ODCf, _CDC, _ADC, _SDC],
    [0, 0, 1, 1, 1, 1], 6
];
export var EdgeModelSummary$ = [3, n0, _EMSd,
    0,
    [_MNod, _MVo],
    [0, 0], 2
];
export var EdgeOutputConfig$ = [3, n0, _EOC,
    0,
    [_SOL, _KKI, _PDT, _PDC],
    [0, 0, 0, 0], 1
];
export var EdgePackagingJobSummary$ = [3, n0, _EPJSd,
    0,
    [_EPJA, _EPJN, _EPJS, _CJN, _MNod, _MVo, _CT, _LMT],
    [0, 0, 0, 0, 0, 0, 4, 4], 3
];
export var EdgePresetDeploymentOutput$ = [3, n0, _EPDO,
    0,
    [_T, _Art, _St, _SM],
    [0, 0, 0, 0], 1
];
export var EFSFileSystem$ = [3, n0, _EFSFS,
    0,
    [_FSI],
    [0], 1
];
export var EFSFileSystemConfig$ = [3, n0, _EFSFSC,
    0,
    [_FSI, _FSP],
    [0, 0], 1
];
export var EmrServerlessComputeConfig$ = [3, n0, _ESCC,
    0,
    [_ERARN],
    [0], 1
];
export var EmrServerlessSettings$ = [3, n0, _ESS,
    0,
    [_ERA, _St],
    [0, 0]
];
export var EmrSettings$ = [3, n0, _ESm,
    0,
    [_ARA, _ERAx],
    [64 | 0, 64 | 0]
];
export var EMRStepMetadata$ = [3, n0, _EMRSM,
    0,
    [_CIlu, _SIt, _SNte, _LFP],
    [0, 0, 0, 0]
];
export var EnableSagemakerServicecatalogPortfolioInput$ = [3, n0, _ESSPI,
    0,
    [],
    []
];
export var EnableSagemakerServicecatalogPortfolioOutput$ = [3, n0, _ESSPO,
    0,
    [],
    []
];
export var Endpoint$ = [3, n0, _En,
    0,
    [_EN, _EA, _ECN, _ES, _CT, _LMT, _PV, _DCC, _FR, _MSon, _Ta, _SPV],
    [0, 0, 0, 0, 4, 4, () => ProductionVariantSummaryList, () => DataCaptureConfigSummary$, 0, () => MonitoringScheduleList, () => TagList, () => ProductionVariantSummaryList], 6
];
export var EndpointConfigStepMetadata$ = [3, n0, _ECSM,
    0,
    [_Ar],
    [0]
];
export var EndpointConfigSummary$ = [3, n0, _ECS,
    0,
    [_ECN, _ECA, _CT],
    [0, 0, 4], 3
];
export var EndpointInfo$ = [3, n0, _EInd,
    0,
    [_EN],
    [0]
];
export var EndpointInput$ = [3, n0, _EIn,
    0,
    [_EN, _LP, _SIM, _SDDT, _FA, _IA, _PA, _PTA, _STO, _ETO, _EFA],
    [0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0], 2
];
export var EndpointInputConfiguration$ = [3, n0, _EIC,
    0,
    [_IT, _SCe, _ISN, _EPR],
    [0, () => ProductionVariantServerlessConfig$, 0, () => EnvironmentParameterRanges$]
];
export var EndpointMetadata$ = [3, n0, _EM,
    0,
    [_EN, _ECN, _ES, _FR],
    [0, 0, 0, 0], 1
];
export var EndpointOutputConfiguration$ = [3, n0, _EOCn,
    0,
    [_EN, _VN, _IT, _IIC, _SCe],
    [0, 0, 0, 1, () => ProductionVariantServerlessConfig$], 2
];
export var EndpointPerformance$ = [3, n0, _EPn,
    0,
    [_Me, _EInd],
    [() => InferenceMetrics$, () => EndpointInfo$], 2
];
export var EndpointStepMetadata$ = [3, n0, _ESM,
    0,
    [_Ar],
    [0]
];
export var EndpointSummary$ = [3, n0, _ESn,
    0,
    [_EN, _EA, _CT, _LMT, _ES],
    [0, 0, 4, 4, 0], 5
];
export var EnvironmentConfig$ = [3, n0, _ECn,
    0,
    [_FSLC],
    [() => FSxLustreConfig$]
];
export var EnvironmentConfigDetails$ = [3, n0, _ECD,
    0,
    [_FSLC, _SOP],
    [() => FSxLustreConfig$, 0]
];
export var EnvironmentParameter$ = [3, n0, _EPnv,
    0,
    [_K, _VT, _Va],
    [0, 0, 0], 3
];
export var EnvironmentParameterRanges$ = [3, n0, _EPR,
    0,
    [_CPRa],
    [() => CategoricalParameters]
];
export var ErrorInfo$ = [3, n0, _EIr,
    0,
    [_Cod, _Re],
    [0, 0]
];
export var EventDetails$ = [3, n0, _ED,
    0,
    [_EMv],
    [() => EventMetadata$]
];
export var Experiment$ = [3, n0, _Exp,
    0,
    [_ENx, _EAx, _DNi, _S, _D, _CT, _CB, _LMT, _LMB, _Ta],
    [0, 0, 0, () => ExperimentSource$, 0, 4, () => UserContext$, 4, () => UserContext$, () => TagList]
];
export var ExperimentConfig$ = [3, n0, _ECxp,
    0,
    [_ENx, _TN, _TCDN, _RNu],
    [0, 0, 0, 0]
];
export var ExperimentSource$ = [3, n0, _ESx,
    0,
    [_SA, _ST],
    [0, 0], 1
];
export var ExperimentSummary$ = [3, n0, _ESxp,
    0,
    [_EAx, _ENx, _DNi, _ESx, _CT, _LMT],
    [0, 0, 0, () => ExperimentSource$, 4, 4]
];
export var Explainability$ = [3, n0, _Ex,
    0,
    [_R],
    [() => MetricsSource$]
];
export var ExplainerConfig$ = [3, n0, _ECx,
    0,
    [_CEC],
    [() => ClarifyExplainerConfig$]
];
export var FailStepMetadata$ = [3, n0, _FSM,
    0,
    [_EMr],
    [0]
];
export var FeatureDefinition$ = [3, n0, _FDe,
    0,
    [_FN, _FTe, _CTol, _CColle],
    [0, 0, 0, () => CollectionConfig$], 2
];
export var FeatureGroup$ = [3, n0, _FG,
    0,
    [_FGA, _FGN, _RIFN, _ETFN, _FD, _CT, _LMT, _OSC, _OSCf, _RAo, _FGS, _OSS, _LUS, _FR, _D, _Ta],
    [0, 0, 0, 0, () => FeatureDefinitions, 4, 4, () => OnlineStoreConfig$, () => OfflineStoreConfig$, 0, 0, () => OfflineStoreStatus$, () => LastUpdateStatus$, 0, 0, () => TagList]
];
export var FeatureGroupSummary$ = [3, n0, _FGSe,
    0,
    [_FGN, _FGA, _CT, _FGS, _OSS],
    [0, 0, 4, 0, () => OfflineStoreStatus$], 3
];
export var FeatureMetadata$ = [3, n0, _FMe,
    0,
    [_FGA, _FGN, _FN, _FTe, _CT, _LMT, _D, _P],
    [0, 0, 0, 0, 4, 4, 0, () => FeatureParameters]
];
export var FeatureParameter$ = [3, n0, _FP,
    0,
    [_K, _Va],
    [0, 0]
];
export var FileSource$ = [3, n0, _FS,
    0,
    [_SUr, _CTon, _CDon],
    [0, 0, 0], 1
];
export var FileSystemConfig$ = [3, n0, _FSC,
    0,
    [_MP, _DU, _DG],
    [0, 1, 1]
];
export var FileSystemDataSource$ = [3, n0, _FSDS,
    0,
    [_FSI, _FSAM, _FST, _DPi],
    [0, 0, 0, 0], 4
];
export var Filter$ = [3, n0, _Fi,
    0,
    [_N, _Op, _Va],
    [0, 0, 0], 1
];
export var FinalAutoMLJobObjectiveMetric$ = [3, n0, _FAMLJOM,
    0,
    [_MN, _Va, _T, _SMN],
    [0, 1, 0, 0], 2
];
export var FinalHyperParameterTuningJobObjectiveMetric$ = [3, n0, _FHPTJOM,
    0,
    [_MN, _Va, _T],
    [0, 1, 0], 2
];
export var FlowDefinitionOutputConfig$ = [3, n0, _FDOC,
    0,
    [_SOP, _KKI],
    [0, 0], 1
];
export var FlowDefinitionSummary$ = [3, n0, _FDSl,
    0,
    [_FDN, _FDA, _FDS, _CT, _FR],
    [0, 0, 0, 4, 0], 4
];
export var FSxLustreConfig$ = [3, n0, _FSLC,
    0,
    [_SIGB, _PUST],
    [1, 1], 2
];
export var FSxLustreFileSystem$ = [3, n0, _FSLFS,
    0,
    [_FSI],
    [0], 1
];
export var FSxLustreFileSystemConfig$ = [3, n0, _FSLFSC,
    0,
    [_FSI, _FSP],
    [0, 0], 1
];
export var GenerativeAiSettings$ = [3, n0, _GAS,
    0,
    [_ABRA],
    [0]
];
export var GetDeviceFleetReportRequest$ = [3, n0, _GDFRR,
    0,
    [_DFN],
    [0], 1
];
export var GetDeviceFleetReportResponse$ = [3, n0, _GDFRRe,
    0,
    [_DFA, _DFN, _OC, _D, _RG, _DSev, _AVg, _MSod],
    [0, 0, () => EdgeOutputConfig$, 0, 4, () => DeviceStats$, () => AgentVersions, () => EdgeModelStats], 2
];
export var GetLineageGroupPolicyRequest$ = [3, n0, _GLGPR,
    0,
    [_LGN],
    [0], 1
];
export var GetLineageGroupPolicyResponse$ = [3, n0, _GLGPRe,
    0,
    [_LGA, _RPes],
    [0, 0]
];
export var GetModelPackageGroupPolicyInput$ = [3, n0, _GMPGPI,
    0,
    [_MPGN],
    [0], 1
];
export var GetModelPackageGroupPolicyOutput$ = [3, n0, _GMPGPO,
    0,
    [_RPes],
    [0], 1
];
export var GetSagemakerServicecatalogPortfolioStatusInput$ = [3, n0, _GSSPSI,
    0,
    [],
    []
];
export var GetSagemakerServicecatalogPortfolioStatusOutput$ = [3, n0, _GSSPSO,
    0,
    [_St],
    [0]
];
export var GetScalingConfigurationRecommendationRequest$ = [3, n0, _GSCRR,
    0,
    [_IRJN, _RIe, _EN, _TCUPC, _SPO],
    [0, 0, 0, 1, () => ScalingPolicyObjective$], 1
];
export var GetScalingConfigurationRecommendationResponse$ = [3, n0, _GSCRRe,
    0,
    [_IRJN, _RIe, _EN, _TCUPC, _SPO, _Met, _DSCy],
    [0, 0, 0, 1, () => ScalingPolicyObjective$, () => ScalingPolicyMetric$, () => DynamicScalingConfiguration$]
];
export var GetSearchSuggestionsRequest$ = [3, n0, _GSSR,
    0,
    [_Res, _SQ],
    [0, () => SuggestionQuery$], 1
];
export var GetSearchSuggestionsResponse$ = [3, n0, _GSSRe,
    0,
    [_PNS],
    [() => PropertyNameSuggestionList]
];
export var GitConfig$ = [3, n0, _GC,
    0,
    [_RU, _Br, _SAe],
    [0, 0, 0], 1
];
export var GitConfigForUpdate$ = [3, n0, _GCFU,
    0,
    [_SAe],
    [0]
];
export var HiddenSageMakerImage$ = [3, n0, _HSMI,
    0,
    [_SMIN, _VA],
    [0, 64 | 0]
];
export var HolidayConfigAttributes$ = [3, n0, _HCAo,
    0,
    [_CCou],
    [0]
];
export var HubAccessConfig$ = [3, n0, _HAC,
    0,
    [_HCA],
    [0], 1
];
export var HubContentDependency$ = [3, n0, _HCDubo,
    0,
    [_DOP, _DCP],
    [0, 0]
];
export var HubContentInfo$ = [3, n0, _HCI,
    0,
    [_HCN, _HCA, _HCV, _HCT, _DSV, _HCS, _CT, _SMPHCA, _HCDN, _HCDu, _SSu, _HCSK, _OCT],
    [0, 0, 0, 0, 0, 0, 4, 0, 0, 0, 0, 64 | 0, 4], 7
];
export var HubInfo$ = [3, n0, _HI,
    0,
    [_HN, _HA, _HS, _CT, _LMT, _HDN, _HD, _HSK],
    [0, 0, 0, 4, 4, 0, 0, 64 | 0], 5
];
export var HubS3StorageConfig$ = [3, n0, _HSSC,
    0,
    [_SOP],
    [0]
];
export var HumanLoopActivationConditionsConfig$ = [3, n0, _HLACC,
    0,
    [_HLAC],
    [[() => HumanLoopActivationConditions, 0]], 1
];
export var HumanLoopActivationConfig$ = [3, n0, _HLACu,
    0,
    [_HLACC],
    [[() => HumanLoopActivationConditionsConfig$, 0]], 1
];
export var HumanLoopConfig$ = [3, n0, _HLC,
    0,
    [_WAo, _HTUA, _TT, _TD, _TCas, _TALIS, _TTLIS, _TKa, _PWTP],
    [0, 0, 0, 0, 1, 1, 1, 64 | 0, () => PublicWorkforceTaskPrice$], 5
];
export var HumanLoopRequestSource$ = [3, n0, _HLRS,
    0,
    [_AMHLRS],
    [0], 1
];
export var HumanTaskConfig$ = [3, n0, _HTC,
    0,
    [_WAo, _UC, _TT, _TD, _NOHWPDO, _TTLIS, _PHTLA, _TKa, _TALIS, _MCTC, _ACC, _PWTP],
    [0, () => UiConfig$, 0, 0, 1, 1, 0, 64 | 0, 1, 1, () => AnnotationConsolidationConfig$, () => PublicWorkforceTaskPrice$], 6
];
export var HumanTaskUiSummary$ = [3, n0, _HTUSu,
    0,
    [_HTUN, _HTUA, _CT],
    [0, 0, 4], 3
];
export var HyperbandStrategyConfig$ = [3, n0, _HSC,
    0,
    [_MRi, _MRa],
    [1, 1]
];
export var HyperParameterAlgorithmSpecification$ = [3, n0, _HPAS,
    0,
    [_TIM, _TI, _ANlg, _MD],
    [0, 0, 0, () => MetricDefinitionList], 1
];
export var HyperParameterSpecification$ = [3, n0, _HPS,
    0,
    [_N, _T, _D, _Ra, _ITs, _IR, _DV],
    [0, 0, 0, () => ParameterRange$, 2, 2, 0], 2
];
export var HyperParameterTrainingJobDefinition$ = [3, n0, _HPTJD,
    0,
    [_ASl, _RAo, _ODC, _SCt, _DNef, _TOu, _HPR, _SHP, _IDC, _VC, _RCe, _HPTRC, _ENI, _EICTE, _EMST, _CCh, _RSe, _E],
    [() => HyperParameterAlgorithmSpecification$, 0, () => OutputDataConfig$, () => StoppingCondition$, 0, () => HyperParameterTuningJobObjective$, () => ParameterRanges$, 128 | 0, () => InputDataConfig, () => VpcConfig$, () => ResourceConfig$, () => HyperParameterTuningResourceConfig$, 2, 2, 2, () => CheckpointConfig$, () => RetryStrategy$, 128 | 0], 4
];
export var HyperParameterTrainingJobSummary$ = [3, n0, _HPTJSy,
    0,
    [_TJN, _TJA, _CT, _TJS, _THP, _TJDN, _TJNu, _TST, _TET, _FR, _FHPTJOM, _OS],
    [0, 0, 4, 0, 128 | 0, 0, 0, 4, 4, 0, () => FinalHyperParameterTuningJobObjectiveMetric$, 0], 5
];
export var HyperParameterTuningInstanceConfig$ = [3, n0, _HPTIC,
    0,
    [_IT, _ICns, _VSIGB],
    [0, 1, 1], 3
];
export var HyperParameterTuningJobCompletionDetails$ = [3, n0, _HPTJCD,
    0,
    [_NOTJONI, _CDT],
    [1, 4]
];
export var HyperParameterTuningJobConfig$ = [3, n0, _HPTJC,
    0,
    [_Str, _RL, _SCtr, _HPTJO, _PRa, _TJEST, _TJCC, _RSa],
    [0, () => ResourceLimits$, () => HyperParameterTuningJobStrategyConfig$, () => HyperParameterTuningJobObjective$, () => ParameterRanges$, 0, () => TuningJobCompletionCriteria$, 1], 2
];
export var HyperParameterTuningJobConsumedResources$ = [3, n0, _HPTJCR,
    0,
    [_RIS],
    [1]
];
export var HyperParameterTuningJobObjective$ = [3, n0, _HPTJO,
    0,
    [_T, _MN],
    [0, 0], 2
];
export var HyperParameterTuningJobSearchEntity$ = [3, n0, _HPTJSE,
    0,
    [_HPTJN, _HPTJA, _HPTJC, _TJD, _TJDra, _HPTJS, _CT, _HPTET, _LMT, _TJSC, _OSCb, _BTJ, _OBTJ, _WSC, _FR, _TJCD, _CRons, _Ta],
    [0, 0, () => HyperParameterTuningJobConfig$, () => HyperParameterTrainingJobDefinition$, () => HyperParameterTrainingJobDefinitions, 0, 4, 4, 4, () => TrainingJobStatusCounters$, () => ObjectiveStatusCounters$, () => HyperParameterTrainingJobSummary$, () => HyperParameterTrainingJobSummary$, () => HyperParameterTuningJobWarmStartConfig$, 0, () => HyperParameterTuningJobCompletionDetails$, () => HyperParameterTuningJobConsumedResources$, () => TagList]
];
export var HyperParameterTuningJobStrategyConfig$ = [3, n0, _HPTJSC,
    0,
    [_HSC],
    [() => HyperbandStrategyConfig$]
];
export var HyperParameterTuningJobSummary$ = [3, n0, _HPTJSyp,
    0,
    [_HPTJN, _HPTJA, _HPTJS, _Str, _CT, _TJSC, _OSCb, _HPTET, _LMT, _RL],
    [0, 0, 0, 0, 4, () => TrainingJobStatusCounters$, () => ObjectiveStatusCounters$, 4, 4, () => ResourceLimits$], 7
];
export var HyperParameterTuningJobWarmStartConfig$ = [3, n0, _HPTJWSC,
    0,
    [_PHPTJ, _WST],
    [() => ParentHyperParameterTuningJobs, 0], 2
];
export var HyperParameterTuningResourceConfig$ = [3, n0, _HPTRC,
    0,
    [_IT, _ICns, _VSIGB, _VKKI, _ASll, _ICnst],
    [0, 1, 1, 0, 0, () => HyperParameterTuningInstanceConfigs]
];
export var IamIdentity$ = [3, n0, _IIa,
    0,
    [_Ar, _PIri, _SIo],
    [0, 0, 0]
];
export var IamPolicyConstraints$ = [3, n0, _IPC,
    0,
    [_SIou, _VSI],
    [0, 0]
];
export var IdentityProviderOAuthSetting$ = [3, n0, _IPOASd,
    0,
    [_DSNa, _St, _SAe],
    [0, 0, 0]
];
export var IdleSettings$ = [3, n0, _IS,
    0,
    [_LM, _ITIM, _MITIM, _MITIMa],
    [0, 1, 1, 1]
];
export var Image$ = [3, n0, _I,
    0,
    [_CT, _IAm, _IN, _ISm, _LMT, _D, _DNi, _FR],
    [4, 0, 0, 0, 4, 0, 0, 0], 5
];
export var ImageClassificationJobConfig$ = [3, n0, _ICJC,
    0,
    [_CCo],
    [() => AutoMLJobCompletionCriteria$]
];
export var ImageConfig$ = [3, n0, _ICm,
    0,
    [_RAM, _RAC],
    [0, () => RepositoryAuthConfig$], 1
];
export var ImageVersion$ = [3, n0, _IV,
    0,
    [_CT, _IAm, _IVA, _IVS, _LMT, _V, _FR],
    [4, 0, 0, 0, 4, 1, 0], 6
];
export var ImportHubContentRequest$ = [3, n0, _IHCR,
    0,
    [_HCN, _HCT, _DSV, _HN, _HCD, _HCV, _HCDN, _HCDu, _HCM, _SSu, _HCSK, _Ta],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 64 | 0, () => TagList], 5
];
export var ImportHubContentResponse$ = [3, n0, _IHCRm,
    0,
    [_HA, _HCA],
    [0, 0], 2
];
export var InferenceComponentCapacitySize$ = [3, n0, _ICCS,
    0,
    [_T, _Va],
    [0, 1], 2
];
export var InferenceComponentComputeResourceRequirements$ = [3, n0, _ICCRR,
    0,
    [_MMRIM, _NOCCR, _NOADR, _MMRIMa],
    [1, 1, 1, 1], 1
];
export var InferenceComponentContainerSpecification$ = [3, n0, _ICCSn,
    0,
    [_I, _AUr, _E],
    [0, 0, 128 | 0]
];
export var InferenceComponentContainerSpecificationSummary$ = [3, n0, _ICCSS,
    0,
    [_DIe, _AUr, _E],
    [() => DeployedImage$, 0, 128 | 0]
];
export var InferenceComponentDataCacheConfig$ = [3, n0, _ICDCC,
    0,
    [_ECnab],
    [2], 1
];
export var InferenceComponentDataCacheConfigSummary$ = [3, n0, _ICDCCS,
    0,
    [_ECnab],
    [2], 1
];
export var InferenceComponentDeploymentConfig$ = [3, n0, _ICDC,
    0,
    [_RUP, _ARCu],
    [() => InferenceComponentRollingUpdatePolicy$, () => AutoRollbackConfig$], 1
];
export var InferenceComponentMetadata$ = [3, n0, _ICM,
    0,
    [_Ar],
    [0]
];
export var InferenceComponentRollingUpdatePolicy$ = [3, n0, _ICRUP,
    0,
    [_MBS, _WIIS, _METIS, _RMBS],
    [() => InferenceComponentCapacitySize$, 1, 1, () => InferenceComponentCapacitySize$], 2
];
export var InferenceComponentRuntimeConfig$ = [3, n0, _ICRC,
    0,
    [_CCop],
    [1], 1
];
export var InferenceComponentRuntimeConfigSummary$ = [3, n0, _ICRCS,
    0,
    [_DCCe, _CCC],
    [1, 1]
];
export var InferenceComponentSpecification$ = [3, n0, _ICSn,
    0,
    [_MNod, _Cont, _SPt, _CRR, _BICN, _DCCat],
    [0, () => InferenceComponentContainerSpecification$, () => InferenceComponentStartupParameters$, () => InferenceComponentComputeResourceRequirements$, 0, () => InferenceComponentDataCacheConfig$]
];
export var InferenceComponentSpecificationSummary$ = [3, n0, _ICSS,
    0,
    [_MNod, _Cont, _SPt, _CRR, _BICN, _DCCat],
    [0, () => InferenceComponentContainerSpecificationSummary$, () => InferenceComponentStartupParameters$, () => InferenceComponentComputeResourceRequirements$, 0, () => InferenceComponentDataCacheConfigSummary$]
];
export var InferenceComponentStartupParameters$ = [3, n0, _ICSP,
    0,
    [_MDDTIS, _CSHCTIS],
    [1, 1]
];
export var InferenceComponentSummary$ = [3, n0, _ICSnf,
    0,
    [_CT, _ICA, _ICN, _EA, _EN, _VN, _LMT, _ICS],
    [4, 0, 0, 0, 0, 0, 4, 0], 7
];
export var InferenceExecutionConfig$ = [3, n0, _IEC,
    0,
    [_Mo],
    [0], 1
];
export var InferenceExperimentDataStorageConfig$ = [3, n0, _IEDSC,
    0,
    [_Des, _KK, _CTon],
    [0, 0, () => CaptureContentTypeHeader$], 1
];
export var InferenceExperimentSchedule$ = [3, n0, _IES,
    0,
    [_STt, _ETn],
    [4, 4]
];
export var InferenceExperimentSummary$ = [3, n0, _IESn,
    0,
    [_N, _T, _St, _CT, _LMT, _Sc, _SRt, _D, _CTom, _RAo],
    [0, 0, 0, 4, 4, () => InferenceExperimentSchedule$, 0, 0, 4, 0], 5
];
export var InferenceHubAccessConfig$ = [3, n0, _IHAC,
    0,
    [_HCA],
    [0], 1
];
export var InferenceMetrics$ = [3, n0, _IMn,
    0,
    [_MIa, _ML],
    [1, 1], 2
];
export var InferenceRecommendation$ = [3, n0, _IRnf,
    0,
    [_ECnd, _MCode, _RIe, _Me, _IET, _IST],
    [() => EndpointOutputConfiguration$, () => ModelConfiguration$, 0, () => RecommendationMetrics$, 4, 4], 2
];
export var InferenceRecommendationsJob$ = [3, n0, _IRJ,
    0,
    [_JN, _JD, _JT, _JA, _St, _CT, _RAo, _LMT, _CTom, _FR, _MNod, _SPU, _MPVA],
    [0, 0, 0, 0, 0, 4, 0, 4, 4, 0, 0, 0, 0], 8
];
export var InferenceRecommendationsJobStep$ = [3, n0, _IRJS,
    0,
    [_STte, _JN, _St, _IB],
    [0, 0, 0, () => RecommendationJobInferenceBenchmark$], 3
];
export var InferenceSpecification$ = [3, n0, _ISn,
    0,
    [_Co, _STIT, _SRIIT, _SCT, _SRMIMET],
    [() => ModelPackageContainerDefinitionList, 64 | 0, 64 | 0, 64 | 0, 64 | 0], 1
];
export var InfraCheckConfig$ = [3, n0, _ICC,
    0,
    [_EICn],
    [2]
];
export var InputConfig$ = [3, n0, _ICnp,
    0,
    [_SUr, _Fr, _DICa, _FV],
    [0, 0, 0, 0], 2
];
export var InstanceGroup$ = [3, n0, _IGn,
    0,
    [_IT, _ICns, _IGN],
    [0, 1, 0], 3
];
export var InstanceGroupMetadata$ = [3, n0, _IGM,
    0,
    [_FM, _AZI, _CR, _SIub, _SGI, _AOm],
    [0, 0, () => CapacityReservation$, 0, 64 | 0, 0]
];
export var InstanceGroupScalingMetadata$ = [3, n0, _IGSM,
    0,
    [_ICns, _TCa, _MCi, _FM],
    [1, 1, 1, 0]
];
export var InstanceMetadata$ = [3, n0, _IMns,
    0,
    [_CEu, _AE, _CR, _FM, _LES, _NLI],
    [0, () => AdditionalEnis$, () => CapacityReservation$, 0, 0, 0]
];
export var InstanceMetadataServiceConfiguration$ = [3, n0, _IMSC,
    0,
    [_MIMSV],
    [0], 1
];
export var InstancePlacementConfig$ = [3, n0, _IPCn,
    0,
    [_EMJ, _PSl],
    [2, () => PlacementSpecifications]
];
export var IntegerParameterRange$ = [3, n0, _IPR,
    0,
    [_N, _MV, _MVa, _STc],
    [0, 0, 0, 0], 3
];
export var IntegerParameterRangeSpecification$ = [3, n0, _IPRS,
    0,
    [_MV, _MVa],
    [0, 0], 2
];
export var JupyterLabAppImageConfig$ = [3, n0, _JLAIC,
    0,
    [_FSC, _CCon],
    [() => FileSystemConfig$, () => ContainerConfig$]
];
export var JupyterLabAppSettings$ = [3, n0, _JLAS,
    0,
    [_DRS, _CI, _LCA, _CRod, _ALM, _ESm, _BILCA],
    [() => ResourceSpec$, () => CustomImages, 64 | 0, () => CodeRepositories, () => AppLifecycleManagement$, () => EmrSettings$, 0]
];
export var JupyterServerAppSettings$ = [3, n0, _JSAS,
    0,
    [_DRS, _LCA, _CRod],
    [() => ResourceSpec$, 64 | 0, () => CodeRepositories]
];
export var KendraSettings$ = [3, n0, _KS,
    0,
    [_St],
    [0]
];
export var KernelGatewayAppSettings$ = [3, n0, _KGAS,
    0,
    [_DRS, _CI, _LCA],
    [() => ResourceSpec$, () => CustomImages, 64 | 0]
];
export var KernelGatewayImageConfig$ = [3, n0, _KGIC,
    0,
    [_KSe, _FSC],
    [() => KernelSpecs, () => FileSystemConfig$], 1
];
export var KernelSpec$ = [3, n0, _KSer,
    0,
    [_N, _DNi],
    [0, 0], 1
];
export var LabelCounters$ = [3, n0, _LC,
    0,
    [_TL, _HL, _MLa, _FNRE, _Un],
    [1, 1, 1, 1, 1]
];
export var LabelCountersForWorkteam$ = [3, n0, _LCFW,
    0,
    [_HL, _PH, _To],
    [1, 1, 1]
];
export var LabelingJobAlgorithmsConfig$ = [3, n0, _LJAC,
    0,
    [_LJASA, _IALMA, _LJRC],
    [0, 0, () => LabelingJobResourceConfig$], 1
];
export var LabelingJobDataAttributes$ = [3, n0, _LJDA,
    0,
    [_CCont],
    [64 | 0]
];
export var LabelingJobDataSource$ = [3, n0, _LJDS,
    0,
    [_SDS, _SDSn],
    [() => LabelingJobS3DataSource$, () => LabelingJobSnsDataSource$]
];
export var LabelingJobForWorkteamSummary$ = [3, n0, _LJFWS,
    0,
    [_JRC, _WRAI, _CT, _LJN, _LC, _NOHWPDO],
    [0, 0, 4, 0, () => LabelCountersForWorkteam$, 1], 3
];
export var LabelingJobInputConfig$ = [3, n0, _LJIC,
    0,
    [_DS, _DAat],
    [() => LabelingJobDataSource$, () => LabelingJobDataAttributes$], 1
];
export var LabelingJobOutput$ = [3, n0, _LJO,
    0,
    [_ODSU, _FALMA],
    [0, 0], 1
];
export var LabelingJobOutputConfig$ = [3, n0, _LJOC,
    0,
    [_SOP, _KKI, _STA],
    [0, 0, 0], 1
];
export var LabelingJobResourceConfig$ = [3, n0, _LJRC,
    0,
    [_VKKI, _VC],
    [0, () => VpcConfig$]
];
export var LabelingJobS3DataSource$ = [3, n0, _LJSDS,
    0,
    [_MSU],
    [0], 1
];
export var LabelingJobSnsDataSource$ = [3, n0, _LJSDSa,
    0,
    [_STA],
    [0], 1
];
export var LabelingJobStoppingConditions$ = [3, n0, _LJSC,
    0,
    [_MHLOC, _MPOIDL],
    [1, 1]
];
export var LabelingJobSummary$ = [3, n0, _LJSa,
    0,
    [_LJN, _LJA, _CT, _LMT, _LJS, _LC, _WAo, _PHTLA, _ACLA, _FR, _LJO, _ICnp],
    [0, 0, 4, 4, 0, () => LabelCounters$, 0, 0, 0, 0, () => LabelingJobOutput$, () => LabelingJobInputConfig$], 7
];
export var LambdaStepMetadata$ = [3, n0, _LSM,
    0,
    [_Ar, _OP],
    [0, () => OutputParameterList]
];
export var LastUpdateStatus$ = [3, n0, _LUS,
    0,
    [_St, _FR],
    [0, 0], 1
];
export var LineageGroupSummary$ = [3, n0, _LGS,
    0,
    [_LGA, _LGN, _DNi, _CT, _LMT],
    [0, 0, 0, 4, 4]
];
export var LineageMetadata$ = [3, n0, _LMi,
    0,
    [_AAc, _AArt, _CAon, _As],
    [128 | 0, 128 | 0, 128 | 0, () => AssociationInfoList]
];
export var ListActionsRequest$ = [3, n0, _LAR,
    0,
    [_SU, _AT, _CAre, _CBr, _SBo, _SO, _NTe, _MR],
    [0, 0, 4, 4, 0, 0, 0, 1]
];
export var ListActionsResponse$ = [3, n0, _LARi,
    0,
    [_AScti, _NTe],
    [() => ActionSummaries, 0]
];
export var ListAlgorithmsInput$ = [3, n0, _LAI,
    0,
    [_CTA, _CTB, _MR, _NCa, _NTe, _SBo, _SO],
    [4, 4, 1, 0, 0, 0, 0]
];
export var ListAlgorithmsOutput$ = [3, n0, _LAO,
    0,
    [_ASL, _NTe],
    [() => AlgorithmSummaryList, 0], 1
];
export var ListAliasesRequest$ = [3, n0, _LARis,
    0,
    [_IN, _Alia, _V, _MR, _NTe],
    [0, 0, 1, 1, 0], 1
];
export var ListAliasesResponse$ = [3, n0, _LARist,
    0,
    [_SMIVA, _NTe],
    [64 | 0, 0]
];
export var ListAppImageConfigsRequest$ = [3, n0, _LAICR,
    0,
    [_MR, _NTe, _NCa, _CTB, _CTA, _MTB, _MTA, _SBo, _SO],
    [1, 0, 0, 4, 4, 4, 4, 0, 0]
];
export var ListAppImageConfigsResponse$ = [3, n0, _LAICRi,
    0,
    [_NTe, _AICp],
    [0, () => AppImageConfigList]
];
export var ListAppsRequest$ = [3, n0, _LARistp,
    0,
    [_NTe, _MR, _SO, _SBo, _DIE, _UPNE, _SNE],
    [0, 1, 0, 0, 0, 0, 0]
];
export var ListAppsResponse$ = [3, n0, _LARistpp,
    0,
    [_Ap, _NTe],
    [() => AppList, 0]
];
export var ListArtifactsRequest$ = [3, n0, _LARistr,
    0,
    [_SU, _ATr, _CAre, _CBr, _SBo, _SO, _NTe, _MR],
    [0, 0, 4, 4, 0, 0, 0, 1]
];
export var ListArtifactsResponse$ = [3, n0, _LARistrt,
    0,
    [_ASrti, _NTe],
    [() => ArtifactSummaries, 0]
];
export var ListAssociationsRequest$ = [3, n0, _LARists,
    0,
    [_SA, _DA, _ST, _DT, _ATs, _CAre, _CBr, _SBo, _SO, _NTe, _MR],
    [0, 0, 0, 0, 0, 4, 4, 0, 0, 0, 1]
];
export var ListAssociationsResponse$ = [3, n0, _LARistss,
    0,
    [_ASss, _NTe],
    [() => AssociationSummaries, 0]
];
export var ListAutoMLJobsRequest$ = [3, n0, _LAMLJR,
    0,
    [_CTA, _CTB, _LMTA, _LMTB, _NCa, _SE, _SO, _SBo, _MR, _NTe],
    [4, 4, 4, 4, 0, 0, 0, 0, 1, 0]
];
export var ListAutoMLJobsResponse$ = [3, n0, _LAMLJRi,
    0,
    [_AMLJSut, _NTe],
    [() => AutoMLJobSummaries, 0], 1
];
export var ListCandidatesForAutoMLJobRequest$ = [3, n0, _LCFAMLJR,
    0,
    [_AMLJN, _SE, _CNE, _SO, _SBo, _MR, _NTe],
    [0, 0, 0, 0, 0, 1, 0], 1
];
export var ListCandidatesForAutoMLJobResponse$ = [3, n0, _LCFAMLJRi,
    0,
    [_Can, _NTe],
    [() => AutoMLCandidates, 0], 1
];
export var ListClusterEventsRequest$ = [3, n0, _LCER,
    0,
    [_CNl, _IGN, _NI, _ETA, _ETB, _SBo, _SO, _RT, _MR, _NTe],
    [0, 0, 0, 4, 4, 0, 0, 0, 1, 0], 1
];
export var ListClusterEventsResponse$ = [3, n0, _LCERi,
    0,
    [_NTe, _Ev],
    [0, () => ClusterEventSummaries]
];
export var ListClusterNodesRequest$ = [3, n0, _LCNR,
    0,
    [_CNl, _CTA, _CTB, _IGNC, _MR, _NTe, _SBo, _SO, _INLI],
    [0, 4, 4, 0, 1, 0, 0, 0, 2], 1
];
export var ListClusterNodesResponse$ = [3, n0, _LCNRi,
    0,
    [_CNSl, _NTe],
    [() => ClusterNodeSummaries, 0], 1
];
export var ListClusterSchedulerConfigsRequest$ = [3, n0, _LCSCR,
    0,
    [_CAre, _CBr, _NCa, _CAl, _St, _SBo, _SO, _NTe, _MR],
    [4, 4, 0, 0, 0, 0, 0, 0, 1]
];
export var ListClusterSchedulerConfigsResponse$ = [3, n0, _LCSCRi,
    0,
    [_CSCSl, _NTe],
    [() => ClusterSchedulerConfigSummaryList, 0]
];
export var ListClustersRequest$ = [3, n0, _LCR,
    0,
    [_CTA, _CTB, _MR, _NCa, _NTe, _SBo, _SO, _TPA],
    [4, 4, 1, 0, 0, 0, 0, 0]
];
export var ListClustersResponse$ = [3, n0, _LCRi,
    0,
    [_CSlus, _NTe],
    [() => ClusterSummaries, 0], 1
];
export var ListCodeRepositoriesInput$ = [3, n0, _LCRI,
    0,
    [_CTA, _CTB, _LMTA, _LMTB, _MR, _NCa, _NTe, _SBo, _SO],
    [4, 4, 4, 4, 1, 0, 0, 0, 0]
];
export var ListCodeRepositoriesOutput$ = [3, n0, _LCRO,
    0,
    [_CRSL, _NTe],
    [() => CodeRepositorySummaryList, 0], 1
];
export var ListCompilationJobsRequest$ = [3, n0, _LCJR,
    0,
    [_NTe, _MR, _CTA, _CTB, _LMTA, _LMTB, _NCa, _SE, _SBo, _SO],
    [0, 1, 4, 4, 4, 4, 0, 0, 0, 0]
];
export var ListCompilationJobsResponse$ = [3, n0, _LCJRi,
    0,
    [_CJSom, _NTe],
    [() => CompilationJobSummaries, 0], 1
];
export var ListComputeQuotasRequest$ = [3, n0, _LCQR,
    0,
    [_CAre, _CBr, _NCa, _St, _CAl, _SBo, _SO, _NTe, _MR],
    [4, 4, 0, 0, 0, 0, 0, 0, 1]
];
export var ListComputeQuotasResponse$ = [3, n0, _LCQRi,
    0,
    [_CQSo, _NTe],
    [() => ComputeQuotaSummaryList, 0]
];
export var ListContextsRequest$ = [3, n0, _LCRis,
    0,
    [_SU, _CTonte, _CAre, _CBr, _SBo, _SO, _NTe, _MR],
    [0, 0, 4, 4, 0, 0, 0, 1]
];
export var ListContextsResponse$ = [3, n0, _LCRist,
    0,
    [_CSont, _NTe],
    [() => ContextSummaries, 0]
];
export var ListDataQualityJobDefinitionsRequest$ = [3, n0, _LDQJDR,
    0,
    [_EN, _SBo, _SO, _NTe, _MR, _NCa, _CTB, _CTA],
    [0, 0, 0, 0, 1, 0, 4, 4]
];
export var ListDataQualityJobDefinitionsResponse$ = [3, n0, _LDQJDRi,
    0,
    [_JDS, _NTe],
    [() => MonitoringJobDefinitionSummaryList, 0], 1
];
export var ListDeviceFleetsRequest$ = [3, n0, _LDFR,
    0,
    [_NTe, _MR, _CTA, _CTB, _LMTA, _LMTB, _NCa, _SBo, _SO],
    [0, 1, 4, 4, 4, 4, 0, 0, 0]
];
export var ListDeviceFleetsResponse$ = [3, n0, _LDFRi,
    0,
    [_DFSe, _NTe],
    [() => DeviceFleetSummaries, 0], 1
];
export var ListDevicesRequest$ = [3, n0, _LDR,
    0,
    [_NTe, _MR, _LHA, _MNod, _DFN],
    [0, 1, 4, 0, 0]
];
export var ListDevicesResponse$ = [3, n0, _LDRi,
    0,
    [_DSevic, _NTe],
    [() => DeviceSummaries, 0], 1
];
export var ListDomainsRequest$ = [3, n0, _LDRis,
    0,
    [_NTe, _MR],
    [0, 1]
];
export var ListDomainsResponse$ = [3, n0, _LDRist,
    0,
    [_Dom, _NTe],
    [() => DomainList, 0]
];
export var ListEdgeDeploymentPlansRequest$ = [3, n0, _LEDPR,
    0,
    [_NTe, _MR, _CTA, _CTB, _LMTA, _LMTB, _NCa, _DFNC, _SBo, _SO],
    [0, 1, 4, 4, 4, 4, 0, 0, 0, 0]
];
export var ListEdgeDeploymentPlansResponse$ = [3, n0, _LEDPRi,
    0,
    [_EDPSd, _NTe],
    [() => EdgeDeploymentPlanSummaries, 0], 1
];
export var ListEdgePackagingJobsRequest$ = [3, n0, _LEPJR,
    0,
    [_NTe, _MR, _CTA, _CTB, _LMTA, _LMTB, _NCa, _MNC, _SE, _SBo, _SO],
    [0, 1, 4, 4, 4, 4, 0, 0, 0, 0, 0]
];
export var ListEdgePackagingJobsResponse$ = [3, n0, _LEPJRi,
    0,
    [_EPJSdg, _NTe],
    [() => EdgePackagingJobSummaries, 0], 1
];
export var ListEndpointConfigsInput$ = [3, n0, _LECI,
    0,
    [_SBo, _SO, _NTe, _MR, _NCa, _CTB, _CTA],
    [0, 0, 0, 1, 0, 4, 4]
];
export var ListEndpointConfigsOutput$ = [3, n0, _LECO,
    0,
    [_ECndp, _NTe],
    [() => EndpointConfigSummaryList, 0], 1
];
export var ListEndpointsInput$ = [3, n0, _LEI,
    0,
    [_SBo, _SO, _NTe, _MR, _NCa, _CTB, _CTA, _LMTB, _LMTA, _SE],
    [0, 0, 0, 1, 0, 4, 4, 4, 4, 0]
];
export var ListEndpointsOutput$ = [3, n0, _LEO,
    0,
    [_End, _NTe],
    [() => EndpointSummaryList, 0], 1
];
export var ListExperimentsRequest$ = [3, n0, _LER,
    0,
    [_CAre, _CBr, _SBo, _SO, _NTe, _MR],
    [4, 4, 0, 0, 0, 1]
];
export var ListExperimentsResponse$ = [3, n0, _LERi,
    0,
    [_ESxpe, _NTe],
    [() => ExperimentSummaries, 0]
];
export var ListFeatureGroupsRequest$ = [3, n0, _LFGR,
    0,
    [_NCa, _FGSE, _OSSE, _CTA, _CTB, _SO, _SBo, _MR, _NTe],
    [0, 0, 0, 4, 4, 0, 0, 1, 0]
];
export var ListFeatureGroupsResponse$ = [3, n0, _LFGRi,
    0,
    [_FGSea, _NTe],
    [() => FeatureGroupSummaries, 0], 1
];
export var ListFlowDefinitionsRequest$ = [3, n0, _LFDR,
    0,
    [_CTA, _CTB, _SO, _NTe, _MR],
    [4, 4, 0, 0, 1]
];
export var ListFlowDefinitionsResponse$ = [3, n0, _LFDRi,
    0,
    [_FDSlo, _NTe],
    [() => FlowDefinitionSummaries, 0], 1
];
export var ListHubContentsRequest$ = [3, n0, _LHCR,
    0,
    [_HN, _HCT, _NCa, _MSV, _CTB, _CTA, _SBo, _SO, _MR, _NTe],
    [0, 0, 0, 0, 4, 4, 0, 0, 1, 0], 2
];
export var ListHubContentsResponse$ = [3, n0, _LHCRi,
    0,
    [_HCSu, _NTe],
    [() => HubContentInfoList, 0], 1
];
export var ListHubContentVersionsRequest$ = [3, n0, _LHCVR,
    0,
    [_HN, _HCT, _HCN, _MVi, _MSV, _CTB, _CTA, _SBo, _SO, _MR, _NTe],
    [0, 0, 0, 0, 0, 4, 4, 0, 0, 1, 0], 3
];
export var ListHubContentVersionsResponse$ = [3, n0, _LHCVRi,
    0,
    [_HCSu, _NTe],
    [() => HubContentInfoList, 0], 1
];
export var ListHubsRequest$ = [3, n0, _LHR,
    0,
    [_NCa, _CTB, _CTA, _LMTB, _LMTA, _SBo, _SO, _MR, _NTe],
    [0, 4, 4, 4, 4, 0, 0, 1, 0]
];
export var ListHubsResponse$ = [3, n0, _LHRi,
    0,
    [_HSu, _NTe],
    [() => HubInfoList, 0], 1
];
export var ListHumanTaskUisRequest$ = [3, n0, _LHTUR,
    0,
    [_CTA, _CTB, _SO, _NTe, _MR],
    [4, 4, 0, 0, 1]
];
export var ListHumanTaskUisResponse$ = [3, n0, _LHTURi,
    0,
    [_HTUSum, _NTe],
    [() => HumanTaskUiSummaries, 0], 1
];
export var ListHyperParameterTuningJobsRequest$ = [3, n0, _LHPTJR,
    0,
    [_NTe, _MR, _SBo, _SO, _NCa, _CTA, _CTB, _LMTA, _LMTB, _SE],
    [0, 1, 0, 0, 0, 4, 4, 4, 4, 0]
];
export var ListHyperParameterTuningJobsResponse$ = [3, n0, _LHPTJRi,
    0,
    [_HPTJSype, _NTe],
    [() => HyperParameterTuningJobSummaries, 0], 1
];
export var ListImagesRequest$ = [3, n0, _LIR,
    0,
    [_CTA, _CTB, _LMTA, _LMTB, _MR, _NCa, _NTe, _SBo, _SO],
    [4, 4, 4, 4, 1, 0, 0, 0, 0]
];
export var ListImagesResponse$ = [3, n0, _LIRi,
    0,
    [_Im, _NTe],
    [() => Images, 0]
];
export var ListImageVersionsRequest$ = [3, n0, _LIVR,
    0,
    [_IN, _CTA, _CTB, _LMTA, _LMTB, _MR, _NTe, _SBo, _SO],
    [0, 4, 4, 4, 4, 1, 0, 0, 0], 1
];
export var ListImageVersionsResponse$ = [3, n0, _LIVRi,
    0,
    [_IVm, _NTe],
    [() => ImageVersions, 0]
];
export var ListInferenceComponentsInput$ = [3, n0, _LICI,
    0,
    [_SBo, _SO, _NTe, _MR, _NCa, _CTB, _CTA, _LMTB, _LMTA, _SE, _ENE, _VNE],
    [0, 0, 0, 1, 0, 4, 4, 4, 4, 0, 0, 0]
];
export var ListInferenceComponentsOutput$ = [3, n0, _LICO,
    0,
    [_ICnf, _NTe],
    [() => InferenceComponentSummaryList, 0], 1
];
export var ListInferenceExperimentsRequest$ = [3, n0, _LIER,
    0,
    [_NCa, _T, _SE, _CTA, _CTB, _LMTA, _LMTB, _SBo, _SO, _NTe, _MR],
    [0, 0, 0, 4, 4, 4, 4, 0, 0, 0, 1]
];
export var ListInferenceExperimentsResponse$ = [3, n0, _LIERi,
    0,
    [_IE, _NTe],
    [() => InferenceExperimentList, 0]
];
export var ListInferenceRecommendationsJobsRequest$ = [3, n0, _LIRJR,
    0,
    [_CTA, _CTB, _LMTA, _LMTB, _NCa, _SE, _SBo, _SO, _NTe, _MR, _MNE, _MPVAE],
    [4, 4, 4, 4, 0, 0, 0, 0, 0, 1, 0, 0]
];
export var ListInferenceRecommendationsJobsResponse$ = [3, n0, _LIRJRi,
    0,
    [_IRJn, _NTe],
    [() => InferenceRecommendationsJobs, 0], 1
];
export var ListInferenceRecommendationsJobStepsRequest$ = [3, n0, _LIRJSR,
    0,
    [_JN, _St, _STte, _MR, _NTe],
    [0, 0, 0, 1, 0], 1
];
export var ListInferenceRecommendationsJobStepsResponse$ = [3, n0, _LIRJSRi,
    0,
    [_Ste, _NTe],
    [() => InferenceRecommendationsJobSteps, 0]
];
export var ListLabelingJobsForWorkteamRequest$ = [3, n0, _LLJFWR,
    0,
    [_WAo, _MR, _NTe, _CTA, _CTB, _JRCC, _SBo, _SO],
    [0, 1, 0, 4, 4, 0, 0, 0], 1
];
export var ListLabelingJobsForWorkteamResponse$ = [3, n0, _LLJFWRi,
    0,
    [_LJSL, _NTe],
    [() => LabelingJobForWorkteamSummaryList, 0], 1
];
export var ListLabelingJobsRequest$ = [3, n0, _LLJR,
    0,
    [_CTA, _CTB, _LMTA, _LMTB, _MR, _NTe, _NCa, _SBo, _SO, _SE],
    [4, 4, 4, 4, 1, 0, 0, 0, 0, 0]
];
export var ListLabelingJobsResponse$ = [3, n0, _LLJRi,
    0,
    [_LJSL, _NTe],
    [() => LabelingJobSummaryList, 0]
];
export var ListLineageGroupsRequest$ = [3, n0, _LLGR,
    0,
    [_CAre, _CBr, _SBo, _SO, _NTe, _MR],
    [4, 4, 0, 0, 0, 1]
];
export var ListLineageGroupsResponse$ = [3, n0, _LLGRi,
    0,
    [_LGSi, _NTe],
    [() => LineageGroupSummaries, 0]
];
export var ListMlflowAppsRequest$ = [3, n0, _LMAR,
    0,
    [_CAre, _CBr, _St, _MVl, _DFDI, _ADS, _SBo, _SO, _NTe, _MR],
    [4, 4, 0, 0, 0, 0, 0, 0, 0, 1]
];
export var ListMlflowAppsResponse$ = [3, n0, _LMARi,
    0,
    [_Sum, _NTe],
    [() => MlflowAppSummaries, 0]
];
export var ListMlflowTrackingServersRequest$ = [3, n0, _LMTSR,
    0,
    [_CAre, _CBr, _TSSr, _MVl, _SBo, _SO, _NTe, _MR],
    [4, 4, 0, 0, 0, 0, 0, 1]
];
export var ListMlflowTrackingServersResponse$ = [3, n0, _LMTSRi,
    0,
    [_TSSra, _NTe],
    [() => TrackingServerSummaryList, 0]
];
export var ListModelBiasJobDefinitionsRequest$ = [3, n0, _LMBJDR,
    0,
    [_EN, _SBo, _SO, _NTe, _MR, _NCa, _CTB, _CTA],
    [0, 0, 0, 0, 1, 0, 4, 4]
];
export var ListModelBiasJobDefinitionsResponse$ = [3, n0, _LMBJDRi,
    0,
    [_JDS, _NTe],
    [() => MonitoringJobDefinitionSummaryList, 0], 1
];
export var ListModelCardExportJobsRequest$ = [3, n0, _LMCEJR,
    0,
    [_MCN, _MCV, _CTA, _CTB, _MCEJNC, _SE, _SBo, _SO, _NTe, _MR],
    [0, 1, 4, 4, 0, 0, 0, 0, 0, 1], 1
];
export var ListModelCardExportJobsResponse$ = [3, n0, _LMCEJRi,
    0,
    [_MCEJS, _NTe],
    [() => ModelCardExportJobSummaryList, 0], 1
];
export var ListModelCardsRequest$ = [3, n0, _LMCR,
    0,
    [_CTA, _CTB, _MR, _NCa, _MCS, _NTe, _SBo, _SO],
    [4, 4, 1, 0, 0, 0, 0, 0]
];
export var ListModelCardsResponse$ = [3, n0, _LMCRi,
    0,
    [_MCSo, _NTe],
    [() => ModelCardSummaryList, 0], 1
];
export var ListModelCardVersionsRequest$ = [3, n0, _LMCVR,
    0,
    [_MCN, _CTA, _CTB, _MR, _MCS, _NTe, _SBo, _SO],
    [0, 4, 4, 1, 0, 0, 0, 0], 1
];
export var ListModelCardVersionsResponse$ = [3, n0, _LMCVRi,
    0,
    [_MCVSL, _NTe],
    [() => ModelCardVersionSummaryList, 0], 1
];
export var ListModelExplainabilityJobDefinitionsRequest$ = [3, n0, _LMEJDR,
    0,
    [_EN, _SBo, _SO, _NTe, _MR, _NCa, _CTB, _CTA],
    [0, 0, 0, 0, 1, 0, 4, 4]
];
export var ListModelExplainabilityJobDefinitionsResponse$ = [3, n0, _LMEJDRi,
    0,
    [_JDS, _NTe],
    [() => MonitoringJobDefinitionSummaryList, 0], 1
];
export var ListModelMetadataRequest$ = [3, n0, _LMMR,
    0,
    [_SEe, _NTe, _MR],
    [() => ModelMetadataSearchExpression$, 0, 1]
];
export var ListModelMetadataResponse$ = [3, n0, _LMMRi,
    0,
    [_MMS, _NTe],
    [() => ModelMetadataSummaries, 0], 1
];
export var ListModelPackageGroupsInput$ = [3, n0, _LMPGI,
    0,
    [_CTA, _CTB, _MR, _NCa, _NTe, _SBo, _SO, _CAFO],
    [4, 4, 1, 0, 0, 0, 0, 0]
];
export var ListModelPackageGroupsOutput$ = [3, n0, _LMPGO,
    0,
    [_MPGSL, _NTe],
    [() => ModelPackageGroupSummaryList, 0], 1
];
export var ListModelPackagesInput$ = [3, n0, _LMPI,
    0,
    [_CTA, _CTB, _MR, _NCa, _MAS, _MPGN, _MPT, _NTe, _SBo, _SO],
    [4, 4, 1, 0, 0, 0, 0, 0, 0, 0]
];
export var ListModelPackagesOutput$ = [3, n0, _LMPO,
    0,
    [_MPSL, _NTe],
    [() => ModelPackageSummaryList, 0], 1
];
export var ListModelQualityJobDefinitionsRequest$ = [3, n0, _LMQJDR,
    0,
    [_EN, _SBo, _SO, _NTe, _MR, _NCa, _CTB, _CTA],
    [0, 0, 0, 0, 1, 0, 4, 4]
];
export var ListModelQualityJobDefinitionsResponse$ = [3, n0, _LMQJDRi,
    0,
    [_JDS, _NTe],
    [() => MonitoringJobDefinitionSummaryList, 0], 1
];
export var ListModelsInput$ = [3, n0, _LMI,
    0,
    [_SBo, _SO, _NTe, _MR, _NCa, _CTB, _CTA],
    [0, 0, 0, 1, 0, 4, 4]
];
export var ListModelsOutput$ = [3, n0, _LMO,
    0,
    [_Mod, _NTe],
    [() => ModelSummaryList, 0], 1
];
export var ListMonitoringAlertHistoryRequest$ = [3, n0, _LMAHR,
    0,
    [_MSN, _MAN, _SBo, _SO, _NTe, _MR, _CTB, _CTA, _SE],
    [0, 0, 0, 0, 0, 1, 4, 4, 0]
];
export var ListMonitoringAlertHistoryResponse$ = [3, n0, _LMAHRi,
    0,
    [_MAH, _NTe],
    [() => MonitoringAlertHistoryList, 0]
];
export var ListMonitoringAlertsRequest$ = [3, n0, _LMARis,
    0,
    [_MSN, _NTe, _MR],
    [0, 0, 1], 1
];
export var ListMonitoringAlertsResponse$ = [3, n0, _LMARist,
    0,
    [_MASo, _NTe],
    [() => MonitoringAlertSummaryList, 0]
];
export var ListMonitoringExecutionsRequest$ = [3, n0, _LMER,
    0,
    [_MSN, _EN, _SBo, _SO, _NTe, _MR, _STB, _STAc, _CTB, _CTA, _LMTB, _LMTA, _SE, _MJDN, _MTE],
    [0, 0, 0, 0, 0, 1, 4, 4, 4, 4, 4, 4, 0, 0, 0]
];
export var ListMonitoringExecutionsResponse$ = [3, n0, _LMERi,
    0,
    [_MES, _NTe],
    [() => MonitoringExecutionSummaryList, 0], 1
];
export var ListMonitoringSchedulesRequest$ = [3, n0, _LMSR,
    0,
    [_EN, _SBo, _SO, _NTe, _MR, _NCa, _CTB, _CTA, _LMTB, _LMTA, _SE, _MJDN, _MTE],
    [0, 0, 0, 0, 1, 0, 4, 4, 4, 4, 0, 0, 0]
];
export var ListMonitoringSchedulesResponse$ = [3, n0, _LMSRi,
    0,
    [_MSSo, _NTe],
    [() => MonitoringScheduleSummaryList, 0], 1
];
export var ListNotebookInstanceLifecycleConfigsInput$ = [3, n0, _LNILCI,
    0,
    [_NTe, _MR, _SBo, _SO, _NCa, _CTB, _CTA, _LMTB, _LMTA],
    [0, 1, 0, 0, 0, 4, 4, 4, 4]
];
export var ListNotebookInstanceLifecycleConfigsOutput$ = [3, n0, _LNILCO,
    0,
    [_NTe, _NILC],
    [0, () => NotebookInstanceLifecycleConfigSummaryList]
];
export var ListNotebookInstancesInput$ = [3, n0, _LNII,
    0,
    [_NTe, _MR, _SBo, _SO, _NCa, _CTB, _CTA, _LMTB, _LMTA, _SE, _NILCNC, _DCRC, _ACRE],
    [0, 1, 0, 0, 0, 4, 4, 4, 4, 0, 0, 0, 0]
];
export var ListNotebookInstancesOutput$ = [3, n0, _LNIO,
    0,
    [_NTe, _NIot],
    [0, () => NotebookInstanceSummaryList]
];
export var ListOptimizationJobsRequest$ = [3, n0, _LOJR,
    0,
    [_NTe, _MR, _CTA, _CTB, _LMTA, _LMTB, _OCpt, _NCa, _SE, _SBo, _SO],
    [0, 1, 4, 4, 4, 4, 0, 0, 0, 0, 0]
];
export var ListOptimizationJobsResponse$ = [3, n0, _LOJRi,
    0,
    [_OJSp, _NTe],
    [() => OptimizationJobSummaries, 0], 1
];
export var ListPartnerAppsRequest$ = [3, n0, _LPAR,
    0,
    [_MR, _NTe],
    [1, 0]
];
export var ListPartnerAppsResponse$ = [3, n0, _LPARi,
    0,
    [_Sum, _NTe],
    [() => PartnerAppSummaries, 0]
];
export var ListPipelineExecutionsRequest$ = [3, n0, _LPER,
    0,
    [_PNi, _CAre, _CBr, _SBo, _SO, _NTe, _MR],
    [0, 4, 4, 0, 0, 0, 1], 1
];
export var ListPipelineExecutionsResponse$ = [3, n0, _LPERi,
    0,
    [_PESi, _NTe],
    [() => PipelineExecutionSummaryList, 0]
];
export var ListPipelineExecutionStepsRequest$ = [3, n0, _LPESR,
    0,
    [_PEA, _NTe, _MR, _SO],
    [0, 0, 1, 0]
];
export var ListPipelineExecutionStepsResponse$ = [3, n0, _LPESRi,
    0,
    [_PESip, _NTe],
    [() => PipelineExecutionStepList, 0]
];
export var ListPipelineParametersForExecutionRequest$ = [3, n0, _LPPFER,
    0,
    [_PEA, _NTe, _MR],
    [0, 0, 1], 1
];
export var ListPipelineParametersForExecutionResponse$ = [3, n0, _LPPFERi,
    0,
    [_PP, _NTe],
    [() => ParameterList, 0]
];
export var ListPipelinesRequest$ = [3, n0, _LPR,
    0,
    [_PNP, _CAre, _CBr, _SBo, _SO, _NTe, _MR],
    [0, 4, 4, 0, 0, 0, 1]
];
export var ListPipelinesResponse$ = [3, n0, _LPRi,
    0,
    [_PSi, _NTe],
    [() => PipelineSummaryList, 0]
];
export var ListPipelineVersionsRequest$ = [3, n0, _LPVR,
    0,
    [_PNi, _CAre, _CBr, _SO, _NTe, _MR],
    [0, 4, 4, 0, 0, 1], 1
];
export var ListPipelineVersionsResponse$ = [3, n0, _LPVRi,
    0,
    [_PVS, _NTe],
    [() => PipelineVersionSummaryList, 0]
];
export var ListProcessingJobsRequest$ = [3, n0, _LPJR,
    0,
    [_CTA, _CTB, _LMTA, _LMTB, _NCa, _SE, _SBo, _SO, _NTe, _MR],
    [4, 4, 4, 4, 0, 0, 0, 0, 0, 1]
];
export var ListProcessingJobsResponse$ = [3, n0, _LPJRi,
    0,
    [_PJSr, _NTe],
    [() => ProcessingJobSummaries, 0], 1
];
export var ListProjectsInput$ = [3, n0, _LPI,
    0,
    [_CTA, _CTB, _MR, _NCa, _NTe, _SBo, _SO],
    [4, 4, 1, 0, 0, 0, 0]
];
export var ListProjectsOutput$ = [3, n0, _LPO,
    0,
    [_PSL, _NTe],
    [() => ProjectSummaryList, 0], 1
];
export var ListResourceCatalogsRequest$ = [3, n0, _LRCR,
    0,
    [_NCa, _CTA, _CTB, _SO, _SBo, _MR, _NTe],
    [0, 4, 4, 0, 0, 1, 0]
];
export var ListResourceCatalogsResponse$ = [3, n0, _LRCRi,
    0,
    [_RCes, _NTe],
    [() => ResourceCatalogList, 0]
];
export var ListSpacesRequest$ = [3, n0, _LSR,
    0,
    [_NTe, _MR, _SO, _SBo, _DIE, _SNC],
    [0, 1, 0, 0, 0, 0]
];
export var ListSpacesResponse$ = [3, n0, _LSRi,
    0,
    [_Spa, _NTe],
    [() => SpaceList, 0]
];
export var ListStageDevicesRequest$ = [3, n0, _LSDR,
    0,
    [_EDPN, _SNt, _NTe, _MR, _EDDIOS],
    [0, 0, 0, 1, 2], 2
];
export var ListStageDevicesResponse$ = [3, n0, _LSDRi,
    0,
    [_DDSevi, _NTe],
    [() => DeviceDeploymentSummaries, 0], 1
];
export var ListStudioLifecycleConfigsRequest$ = [3, n0, _LSLCR,
    0,
    [_MR, _NTe, _NCa, _ATE, _CTB, _CTA, _MTB, _MTA, _SBo, _SO],
    [1, 0, 0, 0, 4, 4, 4, 4, 0, 0]
];
export var ListStudioLifecycleConfigsResponse$ = [3, n0, _LSLCRi,
    0,
    [_NTe, _SLC],
    [0, () => StudioLifecycleConfigsList]
];
export var ListSubscribedWorkteamsRequest$ = [3, n0, _LSWR,
    0,
    [_NCa, _NTe, _MR],
    [0, 0, 1]
];
export var ListSubscribedWorkteamsResponse$ = [3, n0, _LSWRi,
    0,
    [_SWu, _NTe],
    [() => SubscribedWorkteams, 0], 1
];
export var ListTagsInput$ = [3, n0, _LTI,
    0,
    [_RA, _NTe, _MR],
    [0, 0, 1], 1
];
export var ListTagsOutput$ = [3, n0, _LTO,
    0,
    [_Ta, _NTe],
    [() => TagList, 0]
];
export var ListTrainingJobsForHyperParameterTuningJobRequest$ = [3, n0, _LTJFHPTJR,
    0,
    [_HPTJN, _NTe, _MR, _SE, _SBo, _SO],
    [0, 0, 1, 0, 0, 0], 1
];
export var ListTrainingJobsForHyperParameterTuningJobResponse$ = [3, n0, _LTJFHPTJRi,
    0,
    [_TJSra, _NTe],
    [() => HyperParameterTrainingJobSummaries, 0], 1
];
export var ListTrainingJobsRequest$ = [3, n0, _LTJR,
    0,
    [_NTe, _MR, _CTA, _CTB, _LMTA, _LMTB, _NCa, _SE, _SBo, _SO, _WPSE, _TPAE],
    [0, 1, 4, 4, 4, 4, 0, 0, 0, 0, 0, 0]
];
export var ListTrainingJobsResponse$ = [3, n0, _LTJRi,
    0,
    [_TJSra, _NTe],
    [() => TrainingJobSummaries, 0], 1
];
export var ListTrainingPlansRequest$ = [3, n0, _LTPR,
    0,
    [_NTe, _MR, _STAt, _STBt, _SBo, _SO, _Fil],
    [0, 1, 4, 4, 0, 0, () => TrainingPlanFilters]
];
export var ListTrainingPlansResponse$ = [3, n0, _LTPRi,
    0,
    [_TPSr, _NTe],
    [() => TrainingPlanSummaries, 0], 1
];
export var ListTransformJobsRequest$ = [3, n0, _LTJRis,
    0,
    [_CTA, _CTB, _LMTA, _LMTB, _NCa, _SE, _SBo, _SO, _NTe, _MR],
    [4, 4, 4, 4, 0, 0, 0, 0, 0, 1]
];
export var ListTransformJobsResponse$ = [3, n0, _LTJRist,
    0,
    [_TJSran, _NTe],
    [() => TransformJobSummaries, 0], 1
];
export var ListTrialComponentsRequest$ = [3, n0, _LTCR,
    0,
    [_ENx, _TN, _SA, _CAre, _CBr, _SBo, _SO, _MR, _NTe],
    [0, 0, 0, 4, 4, 0, 0, 1, 0]
];
export var ListTrialComponentsResponse$ = [3, n0, _LTCRi,
    0,
    [_TCS, _NTe],
    [() => TrialComponentSummaries, 0]
];
export var ListTrialsRequest$ = [3, n0, _LTR,
    0,
    [_ENx, _TCN, _CAre, _CBr, _SBo, _SO, _MR, _NTe],
    [0, 0, 4, 4, 0, 0, 1, 0]
];
export var ListTrialsResponse$ = [3, n0, _LTRi,
    0,
    [_TSr, _NTe],
    [() => TrialSummaries, 0]
];
export var ListUltraServersByReservedCapacityRequest$ = [3, n0, _LUSBRCR,
    0,
    [_RCA, _MR, _NTe],
    [0, 1, 0], 1
];
export var ListUltraServersByReservedCapacityResponse$ = [3, n0, _LUSBRCRi,
    0,
    [_USl, _NTe],
    [() => UltraServers, 0], 1
];
export var ListUserProfilesRequest$ = [3, n0, _LUPR,
    0,
    [_NTe, _MR, _SO, _SBo, _DIE, _UPNC],
    [0, 1, 0, 0, 0, 0]
];
export var ListUserProfilesResponse$ = [3, n0, _LUPRi,
    0,
    [_UPs, _NTe],
    [() => UserProfileList, 0]
];
export var ListWorkforcesRequest$ = [3, n0, _LWR,
    0,
    [_SBo, _SO, _NCa, _NTe, _MR],
    [0, 0, 0, 0, 1]
];
export var ListWorkforcesResponse$ = [3, n0, _LWRi,
    0,
    [_Wor, _NTe],
    [() => Workforces, 0], 1
];
export var ListWorkteamsRequest$ = [3, n0, _LWRis,
    0,
    [_SBo, _SO, _NCa, _NTe, _MR],
    [0, 0, 0, 0, 1]
];
export var ListWorkteamsResponse$ = [3, n0, _LWRist,
    0,
    [_Work, _NTe],
    [() => Workteams, 0], 1
];
export var MemberDefinition$ = [3, n0, _MDem,
    0,
    [_CMD, _OMD],
    [() => CognitoMemberDefinition$, () => OidcMemberDefinition$]
];
export var MetadataProperties$ = [3, n0, _MPe,
    0,
    [_CIom, _Rep, _GB, _PIro],
    [0, 0, 0, 0]
];
export var MetricData$ = [3, n0, _MDet,
    0,
    [_MN, _Va, _Tim],
    [0, 1, 4]
];
export var MetricDatum$ = [3, n0, _MDetr,
    0,
    [_MN, _SMN, _Va, _Set],
    [0, 0, 1, 0]
];
export var MetricDefinition$ = [3, n0, _MDetri,
    0,
    [_N, _Reg],
    [0, 0], 2
];
export var MetricsConfig$ = [3, n0, _MCe,
    0,
    [_EEM, _MPFIS],
    [2, 1]
];
export var MetricsSource$ = [3, n0, _MSe,
    0,
    [_CTon, _SUr, _CDon],
    [0, 0, 0], 2
];
export var MlflowAppSummary$ = [3, n0, _MASl,
    0,
    [_Ar, _N, _St, _CT, _LMT, _MVl],
    [0, 0, 0, 4, 4, 0]
];
export var MlflowConfig$ = [3, n0, _MCl,
    0,
    [_MRA, _MEN, _MRN],
    [0, 0, 0], 1
];
export var MLflowConfiguration$ = [3, n0, _MLCfl,
    0,
    [_MRA, _MEN],
    [0, 0]
];
export var MlflowDetails$ = [3, n0, _MDl,
    0,
    [_MEI, _MRI],
    [0, 0]
];
export var Model$ = [3, n0, _Mode,
    0,
    [_MNod, _PC, _Co, _IEC, _ERA, _VC, _CT, _MA, _ENI, _Ta, _DR],
    [0, () => ContainerDefinition$, () => ContainerDefinitionList, () => InferenceExecutionConfig$, 0, () => VpcConfig$, 4, 0, 2, () => TagList, () => DeploymentRecommendation$]
];
export var ModelAccessConfig$ = [3, n0, _MAC,
    0,
    [_AEc],
    [2], 1
];
export var ModelArtifacts$ = [3, n0, _MAo,
    0,
    [_SMA],
    [0], 1
];
export var ModelBiasAppSpecification$ = [3, n0, _MBAS,
    0,
    [_IU, _CU, _E],
    [0, 0, 128 | 0], 2
];
export var ModelBiasBaselineConfig$ = [3, n0, _MBBC,
    0,
    [_BJN, _CRon],
    [0, () => MonitoringConstraintsResource$]
];
export var ModelBiasJobInput$ = [3, n0, _MBJI,
    0,
    [_GTSI, _EIn, _BTI],
    [() => MonitoringGroundTruthS3Input$, () => EndpointInput$, () => BatchTransformInput$], 1
];
export var ModelCard$ = [3, n0, _MCod,
    0,
    [_MCA, _MCN, _MCV, _Con, _MCS, _SC, _CT, _CB, _LMT, _LMB, _Ta, _MIo, _RR, _MPGN],
    [0, 0, 1, [() => ModelCardContent, 0], 0, () => ModelCardSecurityConfig$, 4, () => UserContext$, 4, () => UserContext$, () => TagList, 0, 0, 0]
];
export var ModelCardExportArtifacts$ = [3, n0, _MCEA,
    0,
    [_SEA],
    [0], 1
];
export var ModelCardExportJobSummary$ = [3, n0, _MCEJSo,
    0,
    [_MCEJN, _MCEJA, _St, _MCN, _MCV, _CAr, _LMA],
    [0, 0, 0, 0, 1, 4, 4], 7
];
export var ModelCardExportOutputConfig$ = [3, n0, _MCEOC,
    0,
    [_SOP],
    [0], 1
];
export var ModelCardSecurityConfig$ = [3, n0, _MCSC,
    0,
    [_KKI],
    [0]
];
export var ModelCardSummary$ = [3, n0, _MCSod,
    0,
    [_MCN, _MCA, _MCS, _CT, _LMT],
    [0, 0, 0, 4, 4], 4
];
export var ModelCardVersionSummary$ = [3, n0, _MCVS,
    0,
    [_MCN, _MCA, _MCS, _MCV, _CT, _LMT],
    [0, 0, 0, 1, 4, 4], 5
];
export var ModelClientConfig$ = [3, n0, _MCCo,
    0,
    [_ITIS, _IMR],
    [1, 1]
];
export var ModelCompilationConfig$ = [3, n0, _MCCod,
    0,
    [_I, _OEv],
    [0, 128 | 0]
];
export var ModelConfiguration$ = [3, n0, _MCode,
    0,
    [_ISN, _EPnvi, _CJN],
    [0, () => EnvironmentParameters, 0]
];
export var ModelDashboardEndpoint$ = [3, n0, _MDE,
    0,
    [_EN, _EA, _CT, _LMT, _ES],
    [0, 0, 4, 4, 0], 5
];
export var ModelDashboardIndicatorAction$ = [3, n0, _MDIA,
    0,
    [_Ena],
    [2]
];
export var ModelDashboardModel$ = [3, n0, _MDM,
    0,
    [_Mode, _End, _LBTJ, _MSon, _MCod],
    [() => Model$, () => ModelDashboardEndpoints, () => TransformJob$, () => ModelDashboardMonitoringSchedules, () => ModelDashboardModelCard$]
];
export var ModelDashboardModelCard$ = [3, n0, _MDMC,
    0,
    [_MCA, _MCN, _MCV, _MCS, _SC, _CT, _CB, _LMT, _LMB, _Ta, _MIo, _RR],
    [0, 0, 1, 0, () => ModelCardSecurityConfig$, 4, () => UserContext$, 4, () => UserContext$, () => TagList, 0, 0]
];
export var ModelDashboardMonitoringSchedule$ = [3, n0, _MDMS,
    0,
    [_MSA, _MSN, _MSS, _MTo, _FR, _CT, _LMT, _MSC, _EN, _MASo, _LMES, _BTI],
    [0, 0, 0, 0, 0, 4, 4, () => MonitoringScheduleConfig$, 0, () => MonitoringAlertSummaryList, () => MonitoringExecutionSummary$, () => BatchTransformInput$]
];
export var ModelDataQuality$ = [3, n0, _MDQ,
    0,
    [_Stati, _Cons],
    [() => MetricsSource$, () => MetricsSource$]
];
export var ModelDataSource$ = [3, n0, _MDS,
    0,
    [_SDS],
    [() => S3ModelDataSource$]
];
export var ModelDeployConfig$ = [3, n0, _MDC,
    0,
    [_AGEN, _EN],
    [2, 0]
];
export var ModelDeployResult$ = [3, n0, _MDR,
    0,
    [_EN],
    [0]
];
export var ModelDigests$ = [3, n0, _MDo,
    0,
    [_ADr],
    [0]
];
export var ModelExplainabilityAppSpecification$ = [3, n0, _MEAS,
    0,
    [_IU, _CU, _E],
    [0, 0, 128 | 0], 2
];
export var ModelExplainabilityBaselineConfig$ = [3, n0, _MEBC,
    0,
    [_BJN, _CRon],
    [0, () => MonitoringConstraintsResource$]
];
export var ModelExplainabilityJobInput$ = [3, n0, _MEJI,
    0,
    [_EIn, _BTI],
    [() => EndpointInput$, () => BatchTransformInput$]
];
export var ModelInfrastructureConfig$ = [3, n0, _MICo,
    0,
    [_ITn, _RTIC],
    [0, () => RealTimeInferenceConfig$], 2
];
export var ModelInput$ = [3, n0, _MIod,
    0,
    [_DICa],
    [0], 1
];
export var ModelLatencyThreshold$ = [3, n0, _MLT,
    0,
    [_Per, _VIM],
    [0, 1]
];
export var ModelLifeCycle$ = [3, n0, _MLC,
    0,
    [_Stag, _SSt, _SDta],
    [0, 0, 0], 2
];
export var ModelMetadataFilter$ = [3, n0, _MMF,
    0,
    [_N, _Va],
    [0, 0], 2
];
export var ModelMetadataSearchExpression$ = [3, n0, _MMSE,
    0,
    [_Fil],
    [() => ModelMetadataFilters]
];
export var ModelMetadataSummary$ = [3, n0, _MMSo,
    0,
    [_Do, _Fr, _Tas, _Mode, _FV],
    [0, 0, 0, 0, 0], 5
];
export var ModelMetrics$ = [3, n0, _MM,
    0,
    [_MQ, _MDQ, _B, _Ex],
    [() => ModelQuality$, () => ModelDataQuality$, () => Bias$, () => Explainability$]
];
export var ModelPackage$ = [3, n0, _MPo,
    0,
    [_MPN, _MPGN, _MPV, _MPRT, _MPA, _MPD, _CT, _ISn, _SAS, _VSa, _MPSo, _MPSD, _CFM, _MAS, _CB, _MPe, _MM, _LMT, _LMB, _ADpp, _Do, _Tas, _SPU, _AIS, _SU, _SC, _MCod, _MLC, _Ta, _CMP, _DCB, _SMV],
    [0, 0, 1, 0, 0, 0, 4, () => InferenceSpecification$, () => SourceAlgorithmSpecification$, () => ModelPackageValidationSpecification$, 0, () => ModelPackageStatusDetails$, 2, 0, () => UserContext$, () => MetadataProperties$, () => ModelMetrics$, 4, () => UserContext$, 0, 0, 0, 0, () => AdditionalInferenceSpecifications, 0, () => ModelPackageSecurityConfig$, [() => ModelPackageModelCard$, 0], () => ModelLifeCycle$, () => TagList, 128 | 0, () => DriftCheckBaselines$, 0]
];
export var ModelPackageConfig$ = [3, n0, _MPC,
    0,
    [_MPGA, _SMPA],
    [0, 0], 1
];
export var ModelPackageContainerDefinition$ = [3, n0, _MPCD,
    0,
    [_CH, _I, _ID, _MDU, _MDS, _PIrod, _E, _MIod, _Fr, _FV, _NMN, _ASDS, _MDET, _ICs, _BM],
    [0, 0, 0, 0, () => ModelDataSource$, 0, 128 | 0, () => ModelInput$, 0, 0, 0, () => AdditionalS3DataSource$, 0, 2, () => BaseModel$]
];
export var ModelPackageGroup$ = [3, n0, _MPG,
    0,
    [_MPGN, _MPGA, _MPGD, _CT, _CB, _MPGS, _Ta],
    [0, 0, 0, 4, () => UserContext$, 0, () => TagList]
];
export var ModelPackageGroupSummary$ = [3, n0, _MPGSo,
    0,
    [_MPGN, _MPGA, _CT, _MPGS, _MPGD],
    [0, 0, 4, 0, 0], 4
];
export var ModelPackageModelCard$ = [3, n0, _MPMC,
    0,
    [_MCC, _MCS],
    [[() => ModelCardContent, 0], 0]
];
export var ModelPackageSecurityConfig$ = [3, n0, _MPSC,
    0,
    [_KKI],
    [0], 1
];
export var ModelPackageStatusDetails$ = [3, n0, _MPSD,
    0,
    [_VS, _ISS],
    [() => ModelPackageStatusItemList, () => ModelPackageStatusItemList], 1
];
export var ModelPackageStatusItem$ = [3, n0, _MPSI,
    0,
    [_N, _St, _FR],
    [0, 0, 0], 2
];
export var ModelPackageSummary$ = [3, n0, _MPSod,
    0,
    [_MPA, _CT, _MPSo, _MPN, _MPGN, _MPV, _MPD, _MAS, _MLC, _MPRT],
    [0, 4, 0, 0, 0, 1, 0, 0, () => ModelLifeCycle$, 0], 3
];
export var ModelPackageValidationProfile$ = [3, n0, _MPVP,
    0,
    [_PN, _TJDr],
    [0, () => TransformJobDefinition$], 2
];
export var ModelPackageValidationSpecification$ = [3, n0, _MPVS,
    0,
    [_VR, _VP],
    [0, () => ModelPackageValidationProfiles], 2
];
export var ModelQuality$ = [3, n0, _MQ,
    0,
    [_Stati, _Cons],
    [() => MetricsSource$, () => MetricsSource$]
];
export var ModelQualityAppSpecification$ = [3, n0, _MQAS,
    0,
    [_IU, _CEo, _CA, _RPSU, _PAPSU, _PT, _E],
    [0, 64 | 0, 64 | 0, 0, 0, 0, 128 | 0], 1
];
export var ModelQualityBaselineConfig$ = [3, n0, _MQBC,
    0,
    [_BJN, _CRon],
    [0, () => MonitoringConstraintsResource$]
];
export var ModelQualityJobInput$ = [3, n0, _MQJI,
    0,
    [_GTSI, _EIn, _BTI],
    [() => MonitoringGroundTruthS3Input$, () => EndpointInput$, () => BatchTransformInput$], 1
];
export var ModelQuantizationConfig$ = [3, n0, _MQC,
    0,
    [_I, _OEv],
    [0, 128 | 0]
];
export var ModelRegisterSettings$ = [3, n0, _MRS,
    0,
    [_St, _CAMRRA],
    [0, 0]
];
export var ModelShardingConfig$ = [3, n0, _MSCo,
    0,
    [_I, _OEv],
    [0, 128 | 0]
];
export var ModelSpeculativeDecodingConfig$ = [3, n0, _MSDC,
    0,
    [_Te, _TDS],
    [0, () => ModelSpeculativeDecodingTrainingDataSource$], 1
];
export var ModelSpeculativeDecodingTrainingDataSource$ = [3, n0, _MSDTDS,
    0,
    [_SUr, _SDT],
    [0, 0], 2
];
export var ModelStepMetadata$ = [3, n0, _MSM,
    0,
    [_Ar],
    [0]
];
export var ModelSummary$ = [3, n0, _MSode,
    0,
    [_MNod, _MA, _CT],
    [0, 0, 4], 3
];
export var ModelVariantConfig$ = [3, n0, _MVC,
    0,
    [_MNod, _VN, _ICnfr],
    [0, 0, () => ModelInfrastructureConfig$], 3
];
export var ModelVariantConfigSummary$ = [3, n0, _MVCS,
    0,
    [_MNod, _VN, _ICnfr, _St],
    [0, 0, () => ModelInfrastructureConfig$, 0], 4
];
export var MonitoringAlertActions$ = [3, n0, _MAA,
    0,
    [_MDI],
    [() => ModelDashboardIndicatorAction$]
];
export var MonitoringAlertHistorySummary$ = [3, n0, _MAHS,
    0,
    [_MSN, _MAN, _CT, _ASle],
    [0, 0, 4, 0], 4
];
export var MonitoringAlertSummary$ = [3, n0, _MASon,
    0,
    [_MAN, _CT, _LMT, _ASle, _DTA, _EPv, _Act],
    [0, 4, 4, 0, 1, 1, () => MonitoringAlertActions$], 7
];
export var MonitoringAppSpecification$ = [3, n0, _MASoni,
    0,
    [_IU, _CEo, _CA, _RPSU, _PAPSU],
    [0, 64 | 0, 64 | 0, 0, 0], 1
];
export var MonitoringBaselineConfig$ = [3, n0, _MBC,
    0,
    [_BJN, _CRon, _SR],
    [0, () => MonitoringConstraintsResource$, () => MonitoringStatisticsResource$]
];
export var MonitoringClusterConfig$ = [3, n0, _MCCon,
    0,
    [_ICns, _IT, _VSIGB, _VKKI],
    [1, 0, 1, 0], 3
];
export var MonitoringConstraintsResource$ = [3, n0, _MCR,
    0,
    [_SUr],
    [0]
];
export var MonitoringCsvDatasetFormat$ = [3, n0, _MCDF,
    0,
    [_He],
    [2]
];
export var MonitoringDatasetFormat$ = [3, n0, _MDF,
    0,
    [_Cs, _J, _Pa],
    [() => MonitoringCsvDatasetFormat$, () => MonitoringJsonDatasetFormat$, () => MonitoringParquetDatasetFormat$]
];
export var MonitoringExecutionSummary$ = [3, n0, _MESo,
    0,
    [_MSN, _STch, _CT, _LMT, _MESon, _PJA, _EN, _FR, _MJDN, _MTo],
    [0, 4, 4, 4, 0, 0, 0, 0, 0, 0], 5
];
export var MonitoringGroundTruthS3Input$ = [3, n0, _MGTSI,
    0,
    [_SUr],
    [0]
];
export var MonitoringInput$ = [3, n0, _MIon,
    0,
    [_EIn, _BTI],
    [() => EndpointInput$, () => BatchTransformInput$]
];
export var MonitoringJobDefinition$ = [3, n0, _MJD,
    0,
    [_MIoni, _MOC, _MRo, _MASoni, _RAo, _BCa, _SCt, _E, _NCe],
    [() => MonitoringInputs, () => MonitoringOutputConfig$, () => MonitoringResources$, () => MonitoringAppSpecification$, 0, () => MonitoringBaselineConfig$, () => MonitoringStoppingCondition$, 128 | 0, () => NetworkConfig$], 5
];
export var MonitoringJobDefinitionSummary$ = [3, n0, _MJDS,
    0,
    [_MJDN, _MJDA, _CT, _EN],
    [0, 0, 4, 0], 4
];
export var MonitoringJsonDatasetFormat$ = [3, n0, _MJDF,
    0,
    [_Li],
    [2]
];
export var MonitoringNetworkConfig$ = [3, n0, _MNCo,
    0,
    [_EICTE, _ENI, _VC],
    [2, 2, () => VpcConfig$]
];
export var MonitoringOutput$ = [3, n0, _MO,
    0,
    [_SOu],
    [() => MonitoringS3Output$], 1
];
export var MonitoringOutputConfig$ = [3, n0, _MOC,
    0,
    [_MOo, _KKI],
    [() => MonitoringOutputs, 0], 1
];
export var MonitoringParquetDatasetFormat$ = [3, n0, _MPDF,
    0,
    [],
    []
];
export var MonitoringResources$ = [3, n0, _MRo,
    0,
    [_CCl],
    [() => MonitoringClusterConfig$], 1
];
export var MonitoringS3Output$ = [3, n0, _MSO,
    0,
    [_SUr, _LP, _SUM],
    [0, 0, 0], 2
];
export var MonitoringSchedule$ = [3, n0, _MSoni,
    0,
    [_MSA, _MSN, _MSS, _MTo, _FR, _CT, _LMT, _MSC, _EN, _LMES, _Ta],
    [0, 0, 0, 0, 0, 4, 4, () => MonitoringScheduleConfig$, 0, () => MonitoringExecutionSummary$, () => TagList]
];
export var MonitoringScheduleConfig$ = [3, n0, _MSC,
    0,
    [_SCch, _MJD, _MJDN, _MTo],
    [() => ScheduleConfig$, () => MonitoringJobDefinition$, 0, 0]
];
export var MonitoringScheduleSummary$ = [3, n0, _MSSon,
    0,
    [_MSN, _MSA, _CT, _LMT, _MSS, _EN, _MJDN, _MTo],
    [0, 0, 4, 4, 0, 0, 0, 0], 5
];
export var MonitoringStatisticsResource$ = [3, n0, _MSR,
    0,
    [_SUr],
    [0]
];
export var MonitoringStoppingCondition$ = [3, n0, _MSCon,
    0,
    [_MRIS],
    [1], 1
];
export var MultiModelConfig$ = [3, n0, _MMC,
    0,
    [_MCSode],
    [0]
];
export var NeoVpcConfig$ = [3, n0, _NVC,
    0,
    [_SGI, _Sub],
    [64 | 0, 64 | 0], 2
];
export var NestedFilters$ = [3, n0, _NF,
    0,
    [_NPN, _Fil],
    [0, () => FilterList], 2
];
export var NetworkConfig$ = [3, n0, _NCe,
    0,
    [_EICTE, _ENI, _VC],
    [2, 2, () => VpcConfig$]
];
export var NodeAdditionResult$ = [3, n0, _NAR,
    0,
    [_NLI, _IGN, _St],
    [0, 0, 0], 3
];
export var NotebookInstanceLifecycleConfigSummary$ = [3, n0, _NILCS,
    0,
    [_NILCN, _NILCA, _CT, _LMT],
    [0, 0, 4, 4], 2
];
export var NotebookInstanceLifecycleHook$ = [3, n0, _NILH,
    0,
    [_Con],
    [0]
];
export var NotebookInstanceSummary$ = [3, n0, _NISo,
    0,
    [_NIN, _NIA, _NIS, _U, _IT, _CT, _LMT, _NILCN, _DCR, _ACR],
    [0, 0, 0, 0, 0, 4, 4, 0, 0, 64 | 0], 2
];
export var NotificationConfiguration$ = [3, n0, _NCo,
    0,
    [_NTAo],
    [0]
];
export var ObjectiveStatusCounters$ = [3, n0, _OSCb,
    0,
    [_Succ, _Pen, _F],
    [1, 1, 1]
];
export var OfflineStoreConfig$ = [3, n0, _OSCf,
    0,
    [_SSC, _DGTC, _DCCa, _TF],
    [() => S3StorageConfig$, 2, () => DataCatalogConfig$, 0], 1
];
export var OfflineStoreStatus$ = [3, n0, _OSS,
    0,
    [_St, _BRl],
    [0, 0], 1
];
export var OidcConfig$ = [3, n0, _OCi,
    0,
    [_CIl, _CS, _Is, _AEu, _TE, _UIE, _LE, _JU, _Sco, _AREP],
    [0, [() => ClientSecret, 0], 0, 0, 0, 0, 0, 0, 0, 128 | 0], 8
];
export var OidcConfigForResponse$ = [3, n0, _OCFR,
    0,
    [_CIl, _Is, _AEu, _TE, _UIE, _LE, _JU, _Sco, _AREP],
    [0, 0, 0, 0, 0, 0, 0, 0, 128 | 0]
];
export var OidcMemberDefinition$ = [3, n0, _OMD,
    0,
    [_Gr],
    [64 | 0]
];
export var OnlineStoreConfig$ = [3, n0, _OSC,
    0,
    [_SC, _EOS, _TDt, _STto],
    [() => OnlineStoreSecurityConfig$, 2, () => TtlDuration$, 0]
];
export var OnlineStoreConfigUpdate$ = [3, n0, _OSCU,
    0,
    [_TDt],
    [() => TtlDuration$]
];
export var OnlineStoreSecurityConfig$ = [3, n0, _OSSC,
    0,
    [_KKI],
    [0]
];
export var OptimizationJobModelSource$ = [3, n0, _OJMS,
    0,
    [_S_, _SMM],
    [() => OptimizationJobModelSourceS3$, () => OptimizationSageMakerModel$]
];
export var OptimizationJobModelSourceS3$ = [3, n0, _OJMSS,
    0,
    [_SUr, _MAC],
    [0, () => OptimizationModelAccessConfig$]
];
export var OptimizationJobOutputConfig$ = [3, n0, _OJOC,
    0,
    [_SOL, _KKI, _SMM],
    [0, 0, () => OptimizationSageMakerModel$], 1
];
export var OptimizationJobSummary$ = [3, n0, _OJSpt,
    0,
    [_OJN, _OJA, _CT, _OJS, _DIT, _OT, _OST, _OET, _LMT, _MICa],
    [0, 0, 4, 0, 0, 64 | 0, 4, 4, 4, 1], 6
];
export var OptimizationModelAccessConfig$ = [3, n0, _OMAC,
    0,
    [_AEc],
    [2], 1
];
export var OptimizationOutput$ = [3, n0, _OO,
    0,
    [_RII],
    [0]
];
export var OptimizationSageMakerModel$ = [3, n0, _OSMM,
    0,
    [_MNod],
    [0]
];
export var OptimizationVpcConfig$ = [3, n0, _OVCp,
    0,
    [_SGI, _Sub],
    [64 | 0, 64 | 0], 2
];
export var OutputConfig$ = [3, n0, _OC,
    0,
    [_SOL, _TDa, _TPa, _COo, _KKI],
    [0, 0, () => TargetPlatform$, 0, 0], 1
];
export var OutputDataConfig$ = [3, n0, _ODC,
    0,
    [_SOP, _KKI, _CTo],
    [0, 0, 0], 1
];
export var OutputParameter$ = [3, n0, _OPu,
    0,
    [_N, _Va],
    [0, 0], 2
];
export var OwnershipSettings$ = [3, n0, _OSw,
    0,
    [_OUPN],
    [0], 1
];
export var OwnershipSettingsSummary$ = [3, n0, _OSSw,
    0,
    [_OUPN],
    [0]
];
export var ParallelismConfiguration$ = [3, n0, _PCa,
    0,
    [_MPES],
    [1], 1
];
export var Parameter$ = [3, n0, _Par,
    0,
    [_N, _Va],
    [0, 0], 2
];
export var ParameterRange$ = [3, n0, _PRar,
    0,
    [_IPRS, _CPRSo, _CPRS],
    [() => IntegerParameterRangeSpecification$, () => ContinuousParameterRangeSpecification$, () => CategoricalParameterRangeSpecification$]
];
export var ParameterRanges$ = [3, n0, _PRa,
    0,
    [_IPRn, _CPRon, _CPRa, _APu],
    [() => IntegerParameterRanges, () => ContinuousParameterRanges, () => CategoricalParameterRanges, () => AutoParameters]
];
export var Parent$ = [3, n0, _Pare,
    0,
    [_TN, _ENx],
    [0, 0]
];
export var ParentHyperParameterTuningJob$ = [3, n0, _PHPTJa,
    0,
    [_HPTJN],
    [0]
];
export var PartnerAppConfig$ = [3, n0, _PAC,
    0,
    [_AUd, _Arg, _AGP, _RGA],
    [64 | 0, 128 | 0, 64 | 0, () => RoleGroupAssignmentsList]
];
export var PartnerAppMaintenanceConfig$ = [3, n0, _PAMC,
    0,
    [_MWS],
    [0]
];
export var PartnerAppSummary$ = [3, n0, _PAS,
    0,
    [_Ar, _N, _T, _St, _CT],
    [0, 0, 0, 0, 4]
];
export var PendingDeploymentSummary$ = [3, n0, _PDS,
    0,
    [_ECN, _PV, _STt, _SPV],
    [0, () => PendingProductionVariantSummaryList, 4, () => PendingProductionVariantSummaryList], 1
];
export var PendingProductionVariantSummary$ = [3, n0, _PPVS,
    0,
    [_VN, _DIep, _CW, _DW, _CICu, _DIC, _IT, _ATcc, _VSar, _CSCu, _DSCes, _MIS, _RCo],
    [0, () => DeployedImages, 1, 1, 1, 1, 0, 0, () => ProductionVariantStatusList, () => ProductionVariantServerlessConfig$, () => ProductionVariantServerlessConfig$, () => ProductionVariantManagedInstanceScaling$, () => ProductionVariantRoutingConfig$], 1
];
export var Phase$ = [3, n0, _Ph,
    0,
    [_INOU, _SRp, _DIS],
    [1, 1, 1]
];
export var Pipeline$ = [3, n0, _Pi,
    0,
    [_PAi, _PNi, _PDN, _PDi, _RAo, _PS, _CT, _LMT, _LRT, _CB, _LMB, _PCa, _Ta],
    [0, 0, 0, 0, 0, 0, 4, 4, 4, () => UserContext$, () => UserContext$, () => ParallelismConfiguration$, () => TagList]
];
export var PipelineDefinitionS3Location$ = [3, n0, _PDSL,
    0,
    [_Bu, _OK, _VIe],
    [0, 0, 0], 2
];
export var PipelineExecution$ = [3, n0, _PE,
    0,
    [_PAi, _PEA, _PEDN, _PES, _PED, _PEC, _FR, _CT, _LMT, _CB, _LMB, _PCa, _SEC, _PP, _PVI, _PVDN],
    [0, 0, 0, 0, 0, () => PipelineExperimentConfig$, 0, 4, 4, () => UserContext$, () => UserContext$, () => ParallelismConfiguration$, () => SelectiveExecutionConfig$, () => ParameterList, 1, 0]
];
export var PipelineExecutionStep$ = [3, n0, _PESipe,
    0,
    [_SNte, _SDNt, _SDte, _STt, _ETn, _SSte, _CHR, _FR, _Meta, _ACt, _SER],
    [0, 0, 0, 4, 4, 0, () => CacheHitResult$, 0, () => PipelineExecutionStepMetadata$, 1, () => SelectiveExecutionResult$]
];
export var PipelineExecutionStepMetadata$ = [3, n0, _PESM,
    0,
    [_TJ, _PJ, _TJr, _TJu, _Mode, _RMe, _Cond, _Cal, _Lam, _EMR, _QC, _CCla, _Fa, _AMLJ, _En, _ECndpo, _BCM, _BCMD, _BPMT, _BMI, _ICnfe, _Lin],
    [() => TrainingJobStepMetadata$, () => ProcessingJobStepMetadata$, () => TransformJobStepMetadata$, () => TuningJobStepMetaData$, () => ModelStepMetadata$, () => RegisterModelStepMetadata$, () => ConditionStepMetadata$, () => CallbackStepMetadata$, () => LambdaStepMetadata$, () => EMRStepMetadata$, () => QualityCheckStepMetadata$, () => ClarifyCheckStepMetadata$, () => FailStepMetadata$, () => AutoMLJobStepMetadata$, () => EndpointStepMetadata$, () => EndpointConfigStepMetadata$, () => BedrockCustomModelMetadata$, () => BedrockCustomModelDeploymentMetadata$, () => BedrockProvisionedModelThroughputMetadata$, () => BedrockModelImportMetadata$, () => InferenceComponentMetadata$, () => LineageMetadata$]
];
export var PipelineExecutionSummary$ = [3, n0, _PESipel,
    0,
    [_PEA, _STt, _PES, _PED, _PEDN, _PEFR],
    [0, 4, 0, 0, 0, 0]
];
export var PipelineExperimentConfig$ = [3, n0, _PEC,
    0,
    [_ENx, _TN],
    [0, 0]
];
export var PipelineSummary$ = [3, n0, _PSip,
    0,
    [_PAi, _PNi, _PDN, _PDi, _RAo, _CT, _LMT, _LET],
    [0, 0, 0, 0, 0, 4, 4, 4]
];
export var PipelineVersion$ = [3, n0, _PVi,
    0,
    [_PAi, _PVI, _PVDN, _PVD, _CT, _LMT, _CB, _LMB, _LEPEA, _LEPEDN, _LEPES],
    [0, 1, 0, 0, 4, 4, () => UserContext$, () => UserContext$, 0, 0, 0]
];
export var PipelineVersionSummary$ = [3, n0, _PVSi,
    0,
    [_PAi, _PVI, _CT, _PVD, _PVDN, _LEPEAa],
    [0, 1, 4, 0, 0, 0]
];
export var PlacementSpecification$ = [3, n0, _PSla,
    0,
    [_ICns, _USIl],
    [1, 0], 1
];
export var PredefinedMetricSpecification$ = [3, n0, _PMS,
    0,
    [_PMT],
    [0]
];
export var PresignedUrlAccessConfig$ = [3, n0, _PUAC,
    0,
    [_AEc, _ESU],
    [2, 0]
];
export var PriorityClass$ = [3, n0, _PCri,
    0,
    [_N, _We],
    [0, 1], 2
];
export var ProcessingClusterConfig$ = [3, n0, _PCC,
    0,
    [_ICns, _IT, _VSIGB, _VKKI],
    [1, 0, 1, 0], 3
];
export var ProcessingFeatureStoreOutput$ = [3, n0, _PFSO,
    0,
    [_FGN],
    [0], 1
];
export var ProcessingInput$ = [3, n0, _PIroc,
    0,
    [_INn, _AMp, _SIn, _DD],
    [0, 2, () => ProcessingS3Input$, () => DatasetDefinition$], 1
];
export var ProcessingJob$ = [3, n0, _PJ,
    0,
    [_PIr, _POC, _PJN, _PR, _SCt, _ASp, _E, _NCe, _RAo, _ECxp, _PJA, _PJS, _EMx, _FR, _PET, _PST, _LMT, _CT, _MSA, _AMLJAu, _TJA, _Ta],
    [() => ProcessingInputs, () => ProcessingOutputConfig$, 0, () => ProcessingResources$, () => ProcessingStoppingCondition$, () => AppSpecification$, 128 | 0, () => NetworkConfig$, 0, () => ExperimentConfig$, 0, 0, 0, 0, 4, 4, 4, 4, 0, 0, 0, () => TagList]
];
export var ProcessingJobStepMetadata$ = [3, n0, _PJSM,
    0,
    [_Ar],
    [0]
];
export var ProcessingJobSummary$ = [3, n0, _PJSro,
    0,
    [_PJN, _PJA, _CT, _PJS, _PET, _LMT, _FR, _EMx],
    [0, 0, 4, 0, 4, 4, 0, 0], 4
];
export var ProcessingOutput$ = [3, n0, _PO,
    0,
    [_ON, _SOu, _FSO, _AMp],
    [0, () => ProcessingS3Output$, () => ProcessingFeatureStoreOutput$, 2], 1
];
export var ProcessingOutputConfig$ = [3, n0, _POC,
    0,
    [_Ou, _KKI],
    [() => ProcessingOutputs, 0], 1
];
export var ProcessingResources$ = [3, n0, _PR,
    0,
    [_CCl],
    [() => ProcessingClusterConfig$], 1
];
export var ProcessingS3Input$ = [3, n0, _PSI,
    0,
    [_SUr, _SDT, _LP, _SIM, _SDDT, _SCTo],
    [0, 0, 0, 0, 0, 0], 2
];
export var ProcessingS3Output$ = [3, n0, _PSO,
    0,
    [_SUr, _SUM, _LP],
    [0, 0, 0], 2
];
export var ProcessingStoppingCondition$ = [3, n0, _PSC,
    0,
    [_MRIS],
    [1], 1
];
export var ProductionVariant$ = [3, n0, _PVr,
    0,
    [_VN, _MNod, _IIC, _IT, _IVW, _ATcc, _CDCo, _SCe, _VSIGB, _MDDTIS, _CSHCTIS, _ESSMA, _MIS, _RCo, _IAV, _CRC],
    [0, 0, 1, 0, 1, 0, () => ProductionVariantCoreDumpConfig$, () => ProductionVariantServerlessConfig$, 1, 1, 1, 2, () => ProductionVariantManagedInstanceScaling$, () => ProductionVariantRoutingConfig$, 0, () => ProductionVariantCapacityReservationConfig$], 1
];
export var ProductionVariantCapacityReservationConfig$ = [3, n0, _PVCRC,
    0,
    [_CRP, _MRAl],
    [0, 0]
];
export var ProductionVariantCapacityReservationSummary$ = [3, n0, _PVCRS,
    0,
    [_MRAl, _CRP, _TICo, _AICv, _UBCE, _ECRc],
    [0, 0, 1, 1, 1, () => Ec2CapacityReservationsList]
];
export var ProductionVariantCoreDumpConfig$ = [3, n0, _PVCDC,
    0,
    [_DSU, _KKI],
    [0, 0], 1
];
export var ProductionVariantManagedInstanceScaling$ = [3, n0, _PVMIS,
    0,
    [_St, _MIC, _MICa],
    [0, 1, 1]
];
export var ProductionVariantRoutingConfig$ = [3, n0, _PVRC,
    0,
    [_RSo],
    [0], 1
];
export var ProductionVariantServerlessConfig$ = [3, n0, _PVSC,
    0,
    [_MSIMB, _MCaxo, _PCro],
    [1, 1, 1], 2
];
export var ProductionVariantServerlessUpdateConfig$ = [3, n0, _PVSUC,
    0,
    [_MCaxo, _PCro],
    [1, 1]
];
export var ProductionVariantStatus$ = [3, n0, _PVSr,
    0,
    [_St, _SM, _STt],
    [0, 0, 4], 1
];
export var ProductionVariantSummary$ = [3, n0, _PVSro,
    0,
    [_VN, _DIep, _CW, _DW, _CICu, _DIC, _VSar, _CSCu, _DSCes, _MIS, _RCo, _CRC],
    [0, () => DeployedImages, 1, 1, 1, 1, () => ProductionVariantStatusList, () => ProductionVariantServerlessConfig$, () => ProductionVariantServerlessConfig$, () => ProductionVariantManagedInstanceScaling$, () => ProductionVariantRoutingConfig$, () => ProductionVariantCapacityReservationSummary$], 1
];
export var ProfilerConfig$ = [3, n0, _PCr,
    0,
    [_SOP, _PIIM, _PPr, _DPis],
    [0, 1, 128 | 0, 2]
];
export var ProfilerConfigForUpdate$ = [3, n0, _PCFU,
    0,
    [_SOP, _PIIM, _PPr, _DPis],
    [0, 1, 128 | 0, 2]
];
export var ProfilerRuleConfiguration$ = [3, n0, _PRCr,
    0,
    [_RCN, _REI, _LP, _SOP, _IT, _VSIGB, _RP],
    [0, 0, 0, 0, 0, 1, 128 | 0], 2
];
export var ProfilerRuleEvaluationStatus$ = [3, n0, _PRESr,
    0,
    [_RCN, _REJA, _RES, _SDt, _LMT],
    [0, 0, 0, 0, 4]
];
export var Project$ = [3, n0, _Proj,
    0,
    [_PAr, _PNr, _PIro, _PDr, _SCPD, _SCPPD, _PSr, _CB, _CT, _TPD, _Ta, _LMT, _LMB],
    [0, 0, 0, 0, () => ServiceCatalogProvisioningDetails$, () => ServiceCatalogProvisionedProductDetails$, 0, () => UserContext$, 4, () => TemplateProviderDetailList, () => TagList, 4, () => UserContext$]
];
export var ProjectSummary$ = [3, n0, _PSroj,
    0,
    [_PNr, _PAr, _PIro, _CT, _PSr, _PDr],
    [0, 0, 0, 4, 0, 0], 5
];
export var PropertyNameQuery$ = [3, n0, _PNQ,
    0,
    [_PNH],
    [0], 1
];
export var PropertyNameSuggestion$ = [3, n0, _PNSr,
    0,
    [_PNro],
    [0]
];
export var ProvisioningParameter$ = [3, n0, _PPro,
    0,
    [_K, _Va],
    [0, 0]
];
export var PublicWorkforceTaskPrice$ = [3, n0, _PWTP,
    0,
    [_AIU],
    [() => USD$]
];
export var PutModelPackageGroupPolicyInput$ = [3, n0, _PMPGPI,
    0,
    [_MPGN, _RPes],
    [0, 0], 2
];
export var PutModelPackageGroupPolicyOutput$ = [3, n0, _PMPGPO,
    0,
    [_MPGA],
    [0], 1
];
export var QualityCheckStepMetadata$ = [3, n0, _QCSM,
    0,
    [_CThe, _BUFDCS, _BUFDCC, _CBS, _CBC, _MPGN, _VRi, _CJA, _SCk, _RNB],
    [0, 0, 0, 0, 0, 0, 0, 0, 2, 2]
];
export var QueryFilters$ = [3, n0, _QF,
    0,
    [_Ty, _LTi, _CBr, _CAre, _MB, _MAodi, _Pr],
    [64 | 0, 64 | 0, 4, 4, 4, 4, 128 | 0]
];
export var QueryLineageRequest$ = [3, n0, _QLR,
    0,
    [_SAt, _Di, _IEn, _Fil, _MDa, _MR, _NTe],
    [64 | 0, 0, 2, () => QueryFilters$, 1, 1, 0]
];
export var QueryLineageResponse$ = [3, n0, _QLRu,
    0,
    [_Ve, _Edg, _NTe],
    [() => Vertices, () => Edges, 0]
];
export var RealTimeInferenceConfig$ = [3, n0, _RTIC,
    0,
    [_IT, _ICns],
    [0, 1], 2
];
export var RealTimeInferenceRecommendation$ = [3, n0, _RTIRe,
    0,
    [_RIe, _IT, _E],
    [0, 0, 128 | 0], 2
];
export var RecommendationJobCompiledOutputConfig$ = [3, n0, _RJCOC,
    0,
    [_SOU],
    [0]
];
export var RecommendationJobContainerConfig$ = [3, n0, _RJCC,
    0,
    [_Do, _Tas, _Fr, _FV, _PCay, _NMN, _SITu, _SET, _DICa, _SRMIMET],
    [0, 0, 0, 0, () => RecommendationJobPayloadConfig$, 0, 64 | 0, 0, 0, 64 | 0]
];
export var RecommendationJobInferenceBenchmark$ = [3, n0, _RJIB,
    0,
    [_MCode, _Me, _EMn, _ECnd, _FR, _IET, _IST],
    [() => ModelConfiguration$, () => RecommendationMetrics$, () => InferenceMetrics$, () => EndpointOutputConfiguration$, 0, 4, 4], 1
];
export var RecommendationJobInputConfig$ = [3, n0, _RJIC,
    0,
    [_MPVA, _MNod, _JDIS, _TPr, _RLe, _ECndpoi, _VKKI, _CCon, _End, _VC],
    [0, 0, 1, () => TrafficPattern$, () => RecommendationJobResourceLimit$, () => EndpointInputConfigurations, 0, () => RecommendationJobContainerConfig$, () => Endpoints, () => RecommendationJobVpcConfig$]
];
export var RecommendationJobOutputConfig$ = [3, n0, _RJOC,
    0,
    [_KKI, _COCo],
    [0, () => RecommendationJobCompiledOutputConfig$]
];
export var RecommendationJobPayloadConfig$ = [3, n0, _RJPC,
    0,
    [_SPU, _SCT],
    [0, 64 | 0]
];
export var RecommendationJobResourceLimit$ = [3, n0, _RJRL,
    0,
    [_MNOT, _MPOT],
    [1, 1]
];
export var RecommendationJobStoppingConditions$ = [3, n0, _RJSC,
    0,
    [_MIa, _MLTo, _FI],
    [1, () => ModelLatencyThresholds, 0]
];
export var RecommendationJobVpcConfig$ = [3, n0, _RJVC,
    0,
    [_SGI, _Sub],
    [64 | 0, 64 | 0], 2
];
export var RecommendationMetrics$ = [3, n0, _RMec,
    0,
    [_CPH, _CPIo, _MIa, _ML, _CUp, _MU, _MST],
    [1, 1, 1, 1, 1, 1, 1]
];
export var RedshiftDatasetDefinition$ = [3, n0, _RDD,
    0,
    [_CIlu, _Da, _DUb, _QS, _CRAl, _OSU, _OF, _KKI, _OCu],
    [0, 0, 0, 0, 0, 0, 0, 0, 0], 7
];
export var RegisterDevicesRequest$ = [3, n0, _RDR,
    0,
    [_DFN, _Dev, _Ta],
    [0, () => Devices, () => TagList], 2
];
export var RegisterModelStepMetadata$ = [3, n0, _RMSM,
    0,
    [_Ar],
    [0]
];
export var RemoteDebugConfig$ = [3, n0, _RDC,
    0,
    [_ERD],
    [2]
];
export var RemoteDebugConfigForUpdate$ = [3, n0, _RDCFU,
    0,
    [_ERD],
    [2]
];
export var RenderableTask$ = [3, n0, _RTen,
    0,
    [_In],
    [0], 1
];
export var RenderingError$ = [3, n0, _RE,
    0,
    [_Cod, _M],
    [0, 0], 2
];
export var RenderUiTemplateRequest$ = [3, n0, _RUTR,
    0,
    [_Tas, _RAo, _UT, _HTUA],
    [() => RenderableTask$, 0, () => UiTemplate$, 0], 2
];
export var RenderUiTemplateResponse$ = [3, n0, _RUTRe,
    0,
    [_RCen, _Err],
    [0, () => RenderingErrorList], 2
];
export var RepositoryAuthConfig$ = [3, n0, _RAC,
    0,
    [_RCPA],
    [0], 1
];
export var ReservedCapacityOffering$ = [3, n0, _RCO,
    0,
    [_IT, _ICns, _RCT, _UST, _USC, _AZ, _DH, _DM, _STt, _ETn],
    [0, 1, 0, 0, 1, 0, 1, 1, 4, 4], 2
];
export var ReservedCapacitySummary$ = [3, n0, _RCSe,
    0,
    [_RCA, _IT, _TICo, _St, _RCT, _UST, _USC, _AZ, _DH, _DM, _STt, _ETn],
    [0, 0, 1, 0, 0, 0, 1, 0, 1, 1, 4, 4], 4
];
export var ResolvedAttributes$ = [3, n0, _RAe,
    0,
    [_AMLJO, _PT, _CCo],
    [() => AutoMLJobObjective$, 0, () => AutoMLJobCompletionCriteria$]
];
export var ResourceCatalog$ = [3, n0, _RCeso,
    0,
    [_RCAe, _RCNe, _D, _CT],
    [0, 0, 0, 4], 4
];
export var ResourceConfig$ = [3, n0, _RCe,
    0,
    [_IT, _ICns, _VSIGB, _VKKI, _KAPIS, _IG, _TPA, _IPCn],
    [0, 1, 1, 0, 1, () => InstanceGroups, 0, () => InstancePlacementConfig$]
];
export var ResourceConfigForUpdate$ = [3, n0, _RCFU,
    0,
    [_KAPIS],
    [1], 1
];
export var ResourceLimits$ = [3, n0, _RL,
    0,
    [_MPTJ, _MNOTJ, _MRIS],
    [1, 1, 1], 1
];
export var ResourceSharingConfig$ = [3, n0, _RSC,
    0,
    [_Str, _BL, _ABL],
    [0, 1, () => AbsoluteBorrowLimitResourceList], 1
];
export var ResourceSpec$ = [3, n0, _RS,
    0,
    [_SMIA, _SMIVAa, _SMIVAag, _IT, _LCAi],
    [0, 0, 0, 0, 0]
];
export var RetentionPolicy$ = [3, n0, _RPe,
    0,
    [_HEFS],
    [0]
];
export var RetryPipelineExecutionRequest$ = [3, n0, _RPER,
    0,
    [_PEA, _CRT, _PCa],
    [0, [0, 4], () => ParallelismConfiguration$], 1
];
export var RetryPipelineExecutionResponse$ = [3, n0, _RPERe,
    0,
    [_PEA],
    [0]
];
export var RetryStrategy$ = [3, n0, _RSe,
    0,
    [_MRAa],
    [1], 1
];
export var RoleGroupAssignment$ = [3, n0, _RGAo,
    0,
    [_RNo, _GP],
    [0, 64 | 0], 2
];
export var RollingDeploymentPolicy$ = [3, n0, _RDP,
    0,
    [_MBS, _RMBS],
    [() => CapacitySizeConfig$, () => CapacitySizeConfig$], 1
];
export var RollingUpdatePolicy$ = [3, n0, _RUP,
    0,
    [_MBS, _WIIS, _METIS, _RMBS],
    [() => CapacitySize$, 1, 1, () => CapacitySize$], 2
];
export var RSessionAppSettings$ = [3, n0, _RSAS,
    0,
    [_DRS, _CI],
    [() => ResourceSpec$, () => CustomImages]
];
export var RStudioServerProAppSettings$ = [3, n0, _RSSPAS,
    0,
    [_AScc, _UG],
    [0, 0]
];
export var RStudioServerProDomainSettings$ = [3, n0, _RSSPDS,
    0,
    [_DERA, _RSCU, _RSPMU, _DRS],
    [0, 0, 0, () => ResourceSpec$], 1
];
export var RStudioServerProDomainSettingsForUpdate$ = [3, n0, _RSSPDSFU,
    0,
    [_DERA, _DRS, _RSCU, _RSPMU],
    [0, () => ResourceSpec$, 0, 0], 1
];
export var S3DataSource$ = [3, n0, _SDS,
    0,
    [_SDT, _SUr, _SDDT, _ANt, _IGNn, _MAC, _HAC],
    [0, 0, 0, 64 | 0, 64 | 0, () => ModelAccessConfig$, () => HubAccessConfig$], 2
];
export var S3FileSystem$ = [3, n0, _SFS,
    0,
    [_SUr],
    [0], 1
];
export var S3FileSystemConfig$ = [3, n0, _SFSC,
    0,
    [_SUr, _MP],
    [0, 0], 1
];
export var S3ModelDataSource$ = [3, n0, _SMDS,
    0,
    [_SUr, _SDT, _CTo, _MAC, _HAC, _MSU, _ET, _ME],
    [0, 0, 0, () => ModelAccessConfig$, () => InferenceHubAccessConfig$, 0, 0, 0], 3
];
export var S3Presign$ = [3, n0, _SPr,
    0,
    [_IPC],
    [() => IamPolicyConstraints$]
];
export var S3StorageConfig$ = [3, n0, _SSC,
    0,
    [_SUr, _KKI, _ROSU],
    [0, 0, 0], 1
];
export var ScalingPolicyMetric$ = [3, n0, _SPM,
    0,
    [_IPI, _ML],
    [1, 1]
];
export var ScalingPolicyObjective$ = [3, n0, _SPO,
    0,
    [_MIPM, _MIPMa],
    [1, 1]
];
export var ScheduleConfig$ = [3, n0, _SCch,
    0,
    [_SEc, _DAST, _DAET],
    [0, 0, 0], 1
];
export var ScheduledUpdateConfig$ = [3, n0, _SUC,
    0,
    [_SEc, _DC],
    [0, () => DeploymentConfiguration$], 1
];
export var SchedulerConfig$ = [3, n0, _SCc,
    0,
    [_PCrio, _FSa, _IRS],
    [() => PriorityClassList, 0, 0]
];
export var SearchExpression$ = [3, n0, _SEe,
    0,
    [_Fil, _NF, _SEu, _Op],
    [() => FilterList, () => NestedFiltersList, () => SearchExpressionList, 0]
];
export var SearchRecord$ = [3, n0, _SRe,
    0,
    [_TJ, _Exp, _Tr, _TCr, _En, _MPo, _MPG, _Pi, _PE, _PVi, _FG, _FMe, _Proj, _HPTJ, _MCod, _Mode],
    [() => TrainingJob$, () => Experiment$, () => Trial$, () => TrialComponent$, () => Endpoint$, [() => ModelPackage$, 0], () => ModelPackageGroup$, () => Pipeline$, () => PipelineExecution$, () => PipelineVersion$, () => FeatureGroup$, () => FeatureMetadata$, () => Project$, () => HyperParameterTuningJobSearchEntity$, [() => ModelCard$, 0], () => ModelDashboardModel$]
];
export var SearchRequest$ = [3, n0, _SRea,
    0,
    [_Res, _SEe, _SBo, _SO, _NTe, _MR, _CAFO, _VCi],
    [0, () => SearchExpression$, 0, 0, 0, 1, 0, () => VisibilityConditionsList], 1
];
export var SearchResponse$ = [3, n0, _SRear,
    0,
    [_Resu, _NTe, _TH],
    [[() => SearchResultsList, 0], 0, () => TotalHits$]
];
export var SearchTrainingPlanOfferingsRequest$ = [3, n0, _STPOR,
    0,
    [_IT, _ICns, _UST, _USC, _STAt, _ETBn, _DH, _TRa],
    [0, 1, 0, 1, 4, 4, 1, 64 | 0]
];
export var SearchTrainingPlanOfferingsResponse$ = [3, n0, _STPORe,
    0,
    [_TPO],
    [() => TrainingPlanOfferings], 1
];
export var SecondaryStatusTransition$ = [3, n0, _SSTe,
    0,
    [_St, _STt, _ETn, _SM],
    [0, 4, 4, 0], 2
];
export var SelectedStep$ = [3, n0, _SSel,
    0,
    [_SNte],
    [0], 1
];
export var SelectiveExecutionConfig$ = [3, n0, _SEC,
    0,
    [_SSele, _SPEA],
    [() => SelectedStepList, 0], 1
];
export var SelectiveExecutionResult$ = [3, n0, _SER,
    0,
    [_SPEA],
    [0]
];
export var SendPipelineExecutionStepFailureRequest$ = [3, n0, _SPESFR,
    0,
    [_CTa, _FR, _CRT],
    [0, 0, [0, 4]], 1
];
export var SendPipelineExecutionStepFailureResponse$ = [3, n0, _SPESFRe,
    0,
    [_PEA],
    [0]
];
export var SendPipelineExecutionStepSuccessRequest$ = [3, n0, _SPESSR,
    0,
    [_CTa, _OP, _CRT],
    [0, () => OutputParameterList, [0, 4]], 1
];
export var SendPipelineExecutionStepSuccessResponse$ = [3, n0, _SPESSRe,
    0,
    [_PEA],
    [0]
];
export var ServerlessJobConfig$ = [3, n0, _SJC,
    0,
    [_BMA, _JT, _AEc, _CTus, _Pef, _ETva, _EAv],
    [0, 0, 2, 0, 0, 0, 0], 2
];
export var ServiceCatalogProvisionedProductDetails$ = [3, n0, _SCPPD,
    0,
    [_PPIro, _PPSM],
    [0, 0]
];
export var ServiceCatalogProvisioningDetails$ = [3, n0, _SCPD,
    0,
    [_PIrod, _PAI, _PIa, _PProv],
    [0, 0, 0, () => ProvisioningParameters], 1
];
export var ServiceCatalogProvisioningUpdateDetails$ = [3, n0, _SCPUD,
    0,
    [_PAI, _PProv],
    [0, () => ProvisioningParameters]
];
export var SessionChainingConfig$ = [3, n0, _SCC,
    0,
    [_ESTC],
    [2]
];
export var ShadowModeConfig$ = [3, n0, _SMC,
    0,
    [_SMVN, _SMVh],
    [0, () => ShadowModelVariantConfigList], 2
];
export var ShadowModelVariantConfig$ = [3, n0, _SMVC,
    0,
    [_SMVNh, _SPa],
    [0, 1], 2
];
export var SharingSettings$ = [3, n0, _SSh,
    0,
    [_NOO, _SOP, _SKKI],
    [0, 0, 0]
];
export var ShuffleConfig$ = [3, n0, _SCh,
    0,
    [_Se],
    [1], 1
];
export var SourceAlgorithm$ = [3, n0, _SAo,
    0,
    [_ANlg, _MDU, _MDS, _MDET],
    [0, 0, () => ModelDataSource$, 0], 1
];
export var SourceAlgorithmSpecification$ = [3, n0, _SAS,
    0,
    [_SAou],
    [() => SourceAlgorithmList], 1
];
export var SourceIpConfig$ = [3, n0, _SIC,
    0,
    [_Ci],
    [64 | 0], 1
];
export var SpaceAppLifecycleManagement$ = [3, n0, _SALM,
    0,
    [_IS],
    [() => SpaceIdleSettings$]
];
export var SpaceCodeEditorAppSettings$ = [3, n0, _SCEAS,
    0,
    [_DRS, _ALM],
    [() => ResourceSpec$, () => SpaceAppLifecycleManagement$]
];
export var SpaceDetails$ = [3, n0, _SDp,
    0,
    [_DI, _SN, _St, _CT, _LMT, _SSSpa, _SSSS, _OSSw, _SDN],
    [0, 0, 0, 4, 4, () => SpaceSettingsSummary$, () => SpaceSharingSettingsSummary$, () => OwnershipSettingsSummary$, 0]
];
export var SpaceIdleSettings$ = [3, n0, _SIS,
    0,
    [_ITIM],
    [1]
];
export var SpaceJupyterLabAppSettings$ = [3, n0, _SJLAS,
    0,
    [_DRS, _CRod, _ALM],
    [() => ResourceSpec$, () => CodeRepositories, () => SpaceAppLifecycleManagement$]
];
export var SpaceSettings$ = [3, n0, _SS,
    0,
    [_JSAS, _KGAS, _CEAS, _JLAS, _ATp, _SSSp, _SMR, _CFS, _RAem],
    [() => JupyterServerAppSettings$, () => KernelGatewayAppSettings$, () => SpaceCodeEditorAppSettings$, () => SpaceJupyterLabAppSettings$, 0, () => SpaceStorageSettings$, 0, () => CustomFileSystems, 0]
];
export var SpaceSettingsSummary$ = [3, n0, _SSSpa,
    0,
    [_ATp, _RAem, _SSSp],
    [0, 0, () => SpaceStorageSettings$]
];
export var SpaceSharingSettings$ = [3, n0, _SSS,
    0,
    [_STh],
    [0], 1
];
export var SpaceSharingSettingsSummary$ = [3, n0, _SSSS,
    0,
    [_STh],
    [0]
];
export var SpaceStorageSettings$ = [3, n0, _SSSp,
    0,
    [_ESSb],
    [() => EbsStorageSettings$]
];
export var Stairs$ = [3, n0, _Stai,
    0,
    [_DIS, _NOSu, _UPS],
    [1, 1, 1]
];
export var StartEdgeDeploymentStageRequest$ = [3, n0, _SEDSR,
    0,
    [_EDPN, _SNt],
    [0, 0], 2
];
export var StartInferenceExperimentRequest$ = [3, n0, _SIER,
    0,
    [_N],
    [0], 1
];
export var StartInferenceExperimentResponse$ = [3, n0, _SIERt,
    0,
    [_IEA],
    [0], 1
];
export var StartMlflowTrackingServerRequest$ = [3, n0, _SMTSR,
    0,
    [_TSN],
    [0], 1
];
export var StartMlflowTrackingServerResponse$ = [3, n0, _SMTSRt,
    0,
    [_TSA],
    [0]
];
export var StartMonitoringScheduleRequest$ = [3, n0, _SMSR,
    0,
    [_MSN],
    [0], 1
];
export var StartNotebookInstanceInput$ = [3, n0, _SNII,
    0,
    [_NIN],
    [0], 1
];
export var StartPipelineExecutionRequest$ = [3, n0, _SPER,
    0,
    [_PNi, _PEDN, _PP, _PED, _CRT, _PCa, _SEC, _PVI, _MEN],
    [0, 0, () => ParameterList, 0, [0, 4], () => ParallelismConfiguration$, () => SelectiveExecutionConfig$, 1, 0], 1
];
export var StartPipelineExecutionResponse$ = [3, n0, _SPERt,
    0,
    [_PEA],
    [0]
];
export var StartSessionRequest$ = [3, n0, _SSR,
    0,
    [_RIes],
    [0], 1
];
export var StartSessionResponse$ = [3, n0, _SSRt,
    0,
    [_SIe, _SUt, _TV],
    [0, 0, 0]
];
export var StopAutoMLJobRequest$ = [3, n0, _SAMLJR,
    0,
    [_AMLJN],
    [0], 1
];
export var StopCompilationJobRequest$ = [3, n0, _SCJR,
    0,
    [_CJN],
    [0], 1
];
export var StopEdgeDeploymentStageRequest$ = [3, n0, _SEDSRt,
    0,
    [_EDPN, _SNt],
    [0, 0], 2
];
export var StopEdgePackagingJobRequest$ = [3, n0, _SEPJR,
    0,
    [_EPJN],
    [0], 1
];
export var StopHyperParameterTuningJobRequest$ = [3, n0, _SHPTJR,
    0,
    [_HPTJN],
    [0], 1
];
export var StopInferenceExperimentRequest$ = [3, n0, _SIERto,
    0,
    [_N, _MVA, _DMV, _DSes, _Re],
    [0, 128 | 0, () => ModelVariantConfigList, 0, 0], 2
];
export var StopInferenceExperimentResponse$ = [3, n0, _SIERtop,
    0,
    [_IEA],
    [0], 1
];
export var StopInferenceRecommendationsJobRequest$ = [3, n0, _SIRJR,
    0,
    [_JN],
    [0], 1
];
export var StopLabelingJobRequest$ = [3, n0, _SLJR,
    0,
    [_LJN],
    [0], 1
];
export var StopMlflowTrackingServerRequest$ = [3, n0, _SMTSRto,
    0,
    [_TSN],
    [0], 1
];
export var StopMlflowTrackingServerResponse$ = [3, n0, _SMTSRtop,
    0,
    [_TSA],
    [0]
];
export var StopMonitoringScheduleRequest$ = [3, n0, _SMSRt,
    0,
    [_MSN],
    [0], 1
];
export var StopNotebookInstanceInput$ = [3, n0, _SNIIt,
    0,
    [_NIN],
    [0], 1
];
export var StopOptimizationJobRequest$ = [3, n0, _SOJR,
    0,
    [_OJN],
    [0], 1
];
export var StoppingCondition$ = [3, n0, _SCt,
    0,
    [_MRIS, _MWTIS, _MPTIS],
    [1, 1, 1]
];
export var StopPipelineExecutionRequest$ = [3, n0, _SPERto,
    0,
    [_PEA, _CRT],
    [0, [0, 4]], 1
];
export var StopPipelineExecutionResponse$ = [3, n0, _SPERtop,
    0,
    [_PEA],
    [0]
];
export var StopProcessingJobRequest$ = [3, n0, _SPJR,
    0,
    [_PJN],
    [0], 1
];
export var StopTrainingJobRequest$ = [3, n0, _STJR,
    0,
    [_TJN],
    [0], 1
];
export var StopTransformJobRequest$ = [3, n0, _STJRt,
    0,
    [_TJNr],
    [0], 1
];
export var StudioLifecycleConfigDetails$ = [3, n0, _SLCD,
    0,
    [_SLCA, _SLCN, _CT, _LMT, _SLCAT],
    [0, 0, 4, 4, 0]
];
export var StudioWebPortalSettings$ = [3, n0, _SWPS,
    0,
    [_HMT, _HAT, _HIT, _HSMIVA],
    [64 | 0, 64 | 0, 64 | 0, () => HiddenSageMakerImageVersionAliasesList]
];
export var SubscribedWorkteam$ = [3, n0, _SW,
    0,
    [_WAo, _MTa, _SNe, _MDar, _LIi],
    [0, 0, 0, 0, 0], 1
];
export var SuggestionQuery$ = [3, n0, _SQ,
    0,
    [_PNQ],
    [() => PropertyNameQuery$]
];
export var TabularJobConfig$ = [3, n0, _TJC,
    0,
    [_TAN, _CGC, _CCo, _FSSU, _Mo, _GCDO, _PT, _SWAN],
    [0, () => CandidateGenerationConfig$, () => AutoMLJobCompletionCriteria$, 0, 0, 2, 0, 0], 1
];
export var TabularResolvedAttributes$ = [3, n0, _TRA,
    0,
    [_PT],
    [0]
];
export var Tag$ = [3, n0, _Tag,
    0,
    [_K, _Va],
    [0, 0], 2
];
export var TargetPlatform$ = [3, n0, _TPa,
    0,
    [_Os, _Arc, _Acc],
    [0, 0, 0], 2
];
export var TargetTrackingScalingPolicyConfiguration$ = [3, n0, _TTSPC,
    0,
    [_MSet, _TVa],
    [() => MetricSpecification$, 1]
];
export var TemplateProviderDetail$ = [3, n0, _TPDe,
    0,
    [_CTPD],
    [() => CfnTemplateProviderDetail$]
];
export var TensorBoardAppSettings$ = [3, n0, _TBAS,
    0,
    [_DRS],
    [() => ResourceSpec$]
];
export var TensorBoardOutputConfig$ = [3, n0, _TBOC,
    0,
    [_SOP, _LP],
    [0, 0], 1
];
export var TextClassificationJobConfig$ = [3, n0, _TCJC,
    0,
    [_CConte, _TLC, _CCo],
    [0, 0, () => AutoMLJobCompletionCriteria$], 2
];
export var TextGenerationJobConfig$ = [3, n0, _TGJC,
    0,
    [_CCo, _BMN, _TGHP, _MAC],
    [() => AutoMLJobCompletionCriteria$, 0, 128 | 0, () => ModelAccessConfig$]
];
export var TextGenerationResolvedAttributes$ = [3, n0, _TGRA,
    0,
    [_BMN],
    [0]
];
export var ThroughputConfig$ = [3, n0, _TCh,
    0,
    [_TM, _PRCU, _PWCU],
    [0, 1, 1], 1
];
export var ThroughputConfigDescription$ = [3, n0, _TCD,
    0,
    [_TM, _PRCU, _PWCU],
    [0, 1, 1], 1
];
export var ThroughputConfigUpdate$ = [3, n0, _TCU,
    0,
    [_TM, _PRCU, _PWCU],
    [0, 1, 1]
];
export var TimeSeriesConfig$ = [3, n0, _TSCim,
    0,
    [_TAN, _TANi, _IIAN, _GAN],
    [0, 0, 0, 64 | 0], 3
];
export var TimeSeriesForecastingJobConfig$ = [3, n0, _TSFJC,
    0,
    [_FF, _FHo, _TSCim, _FSSU, _CCo, _FQ, _Tra, _HC, _CGC],
    [0, 1, () => TimeSeriesConfig$, 0, () => AutoMLJobCompletionCriteria$, 64 | 0, () => TimeSeriesTransformations$, () => HolidayConfig, () => CandidateGenerationConfig$], 3
];
export var TimeSeriesForecastingSettings$ = [3, n0, _TSFS,
    0,
    [_St, _AFRA],
    [0, 0]
];
export var TimeSeriesTransformations$ = [3, n0, _TSTi,
    0,
    [_Fill, _Ag],
    [[2, n0, _FTi, 0, 0, 128 | 0], 128 | 0]
];
export var TotalHits$ = [3, n0, _TH,
    0,
    [_Va, _Rel],
    [1, 0]
];
export var TrackingServerSummary$ = [3, n0, _TSSrac,
    0,
    [_TSA, _TSN, _CT, _LMT, _TSSr, _IAs, _MVl],
    [0, 0, 4, 4, 0, 0, 0]
];
export var TrafficPattern$ = [3, n0, _TPr,
    0,
    [_TTr, _Pha, _Stai],
    [0, () => Phases, () => Stairs$]
];
export var TrafficRoutingConfig$ = [3, n0, _TRCr,
    0,
    [_T, _WIIS, _CSana, _LSS],
    [0, 1, () => CapacitySize$, () => CapacitySize$], 2
];
export var TrainingImageConfig$ = [3, n0, _TIC,
    0,
    [_TRAM, _TRAC],
    [0, () => TrainingRepositoryAuthConfig$], 1
];
export var TrainingJob$ = [3, n0, _TJ,
    0,
    [_TJN, _TJA, _TJAu, _LJA, _AMLJAu, _MAo, _TJS, _SSe, _FR, _HP, _ASl, _RAo, _IDC, _ODC, _RCe, _VC, _SCt, _CT, _TST, _TET, _LMT, _SST, _FMDL, _ENI, _EICTE, _EMST, _CCh, _TTIS, _BTIS, _DHC, _ECxp, _DRC, _TBOC, _DRESe, _OMPA, _MPC, _PCr, _E, _RSe, _Ta],
    [0, 0, 0, 0, 0, () => ModelArtifacts$, 0, 0, 0, 128 | 0, () => AlgorithmSpecification$, 0, () => InputDataConfig, () => OutputDataConfig$, () => ResourceConfig$, () => VpcConfig$, () => StoppingCondition$, 4, 4, 4, 4, () => SecondaryStatusTransitions, () => FinalMetricDataList, 2, 2, 2, () => CheckpointConfig$, 1, 1, () => DebugHookConfig$, () => ExperimentConfig$, () => DebugRuleConfigurations, () => TensorBoardOutputConfig$, () => DebugRuleEvaluationStatuses, 0, () => ModelPackageConfig$, () => ProfilerConfig$, 128 | 0, () => RetryStrategy$, () => TagList]
];
export var TrainingJobDefinition$ = [3, n0, _TJD,
    0,
    [_TIM, _IDC, _ODC, _RCe, _SCt, _HP],
    [0, () => InputDataConfig, () => OutputDataConfig$, () => ResourceConfig$, () => StoppingCondition$, 128 | 0], 5
];
export var TrainingJobStatusCounters$ = [3, n0, _TJSC,
    0,
    [_Com, _IP, _REe, _NRE, _Sto],
    [1, 1, 1, 1, 1]
];
export var TrainingJobStepMetadata$ = [3, n0, _TJSM,
    0,
    [_Ar],
    [0]
];
export var TrainingJobSummary$ = [3, n0, _TJSrai,
    0,
    [_TJN, _TJA, _CT, _TJS, _TET, _LMT, _SSe, _WPS, _TPA],
    [0, 0, 4, 0, 4, 4, 0, () => WarmPoolStatus$, 0], 4
];
export var TrainingPlanFilter$ = [3, n0, _TPF,
    0,
    [_N, _Va],
    [0, 0], 2
];
export var TrainingPlanOffering$ = [3, n0, _TPOr,
    0,
    [_TPOI, _TRa, _RSTA, _RETB, _DH, _DM, _UF, _CCur, _RCOe],
    [0, 64 | 0, 4, 4, 1, 1, 0, 0, () => ReservedCapacityOfferings], 2
];
export var TrainingPlanSummary$ = [3, n0, _TPSra,
    0,
    [_TPA, _TPN, _St, _SM, _DH, _DM, _STt, _ETn, _UF, _CCur, _TICo, _AICv, _IUIC, _TUSC, _TRa, _RCS],
    [0, 0, 0, 0, 1, 1, 4, 4, 0, 0, 1, 1, 1, 1, 64 | 0, () => ReservedCapacitySummaries], 3
];
export var TrainingProgressInfo$ = [3, n0, _TPI,
    0,
    [_TSCPE, _CSu, _CEur, _MEa],
    [1, 1, 1, 1]
];
export var TrainingRepositoryAuthConfig$ = [3, n0, _TRAC,
    0,
    [_TRCPA],
    [0], 1
];
export var TrainingSpecification$ = [3, n0, _TS,
    0,
    [_TI, _STITu, _TCra, _TID, _SHPu, _SDTu, _MD, _STJOM, _ASDS],
    [0, 64 | 0, () => ChannelSpecifications, 0, () => HyperParameterSpecifications, 2, () => MetricDefinitionList, () => HyperParameterTuningJobObjectives, () => AdditionalS3DataSource$], 3
];
export var TransformDataSource$ = [3, n0, _TDSr,
    0,
    [_SDS],
    [() => TransformS3DataSource$], 1
];
export var TransformInput$ = [3, n0, _TIr,
    0,
    [_DS, _CTon, _CTo, _STp],
    [() => TransformDataSource$, 0, 0, 0], 1
];
export var TransformJob$ = [3, n0, _TJr,
    0,
    [_TJNr, _TJAr, _TJSr, _FR, _MNod, _MCT, _MCCo, _MPIMB, _BS, _E, _TIr, _TO, _DCC, _TR, _CT, _TSTr, _TETr, _LJA, _AMLJAu, _DP, _ECxp, _Ta],
    [0, 0, 0, 0, 0, 1, () => ModelClientConfig$, 1, 0, 128 | 0, () => TransformInput$, () => TransformOutput$, () => BatchDataCaptureConfig$, () => TransformResources$, 4, 4, 4, 0, 0, () => DataProcessing$, () => ExperimentConfig$, () => TagList]
];
export var TransformJobDefinition$ = [3, n0, _TJDr,
    0,
    [_TIr, _TO, _TR, _MCT, _MPIMB, _BS, _E],
    [() => TransformInput$, () => TransformOutput$, () => TransformResources$, 1, 1, 0, 128 | 0], 3
];
export var TransformJobStepMetadata$ = [3, n0, _TJSMr,
    0,
    [_Ar],
    [0]
];
export var TransformJobSummary$ = [3, n0, _TJSrans,
    0,
    [_TJNr, _TJAr, _CT, _TJSr, _TETr, _LMT, _FR],
    [0, 0, 4, 0, 4, 4, 0], 4
];
export var TransformOutput$ = [3, n0, _TO,
    0,
    [_SOP, _Acce, _AW, _KKI],
    [0, 0, 0, 0], 1
];
export var TransformResources$ = [3, n0, _TR,
    0,
    [_IT, _ICns, _VKKI, _TAV],
    [0, 1, 0, 0], 2
];
export var TransformS3DataSource$ = [3, n0, _TSDS,
    0,
    [_SDT, _SUr],
    [0, 0], 2
];
export var Trial$ = [3, n0, _Tr,
    0,
    [_TN, _TA, _DNi, _ENx, _S, _CT, _CB, _LMT, _LMB, _MPe, _Ta, _TCS],
    [0, 0, 0, 0, () => TrialSource$, 4, () => UserContext$, 4, () => UserContext$, () => MetadataProperties$, () => TagList, () => TrialComponentSimpleSummaries]
];
export var TrialComponent$ = [3, n0, _TCr,
    0,
    [_TCN, _DNi, _TCA, _S, _St, _STt, _ETn, _CT, _CB, _LMT, _LMB, _P, _IAn, _OA, _Me, _MPe, _SDo, _LGA, _Ta, _Paren, _RNu],
    [0, 0, 0, () => TrialComponentSource$, () => TrialComponentStatus$, 4, 4, 4, () => UserContext$, 4, () => UserContext$, () => TrialComponentParameters, () => TrialComponentArtifacts, () => TrialComponentArtifacts, () => TrialComponentMetricSummaries, () => MetadataProperties$, () => TrialComponentSourceDetail$, 0, () => TagList, () => Parents, 0]
];
export var TrialComponentArtifact$ = [3, n0, _TCAr,
    0,
    [_Va, _MTe],
    [0, 0], 1
];
export var TrialComponentMetricSummary$ = [3, n0, _TCMS,
    0,
    [_MN, _SA, _TSi, _Ma, _Mi, _Las, _C, _Av, _SDtd],
    [0, 0, 4, 1, 1, 1, 1, 1, 1]
];
export var TrialComponentSimpleSummary$ = [3, n0, _TCSS,
    0,
    [_TCN, _TCA, _TCSr, _CT, _CB],
    [0, 0, () => TrialComponentSource$, 4, () => UserContext$]
];
export var TrialComponentSource$ = [3, n0, _TCSr,
    0,
    [_SA, _ST],
    [0, 0], 1
];
export var TrialComponentSourceDetail$ = [3, n0, _TCSD,
    0,
    [_SA, _TJ, _PJ, _TJr],
    [0, () => TrainingJob$, () => ProcessingJob$, () => TransformJob$]
];
export var TrialComponentStatus$ = [3, n0, _TCSri,
    0,
    [_PSri, _M],
    [0, 0]
];
export var TrialComponentSummary$ = [3, n0, _TCSria,
    0,
    [_TCN, _TCA, _DNi, _TCSr, _St, _STt, _ETn, _CT, _CB, _LMT, _LMB],
    [0, 0, 0, () => TrialComponentSource$, () => TrialComponentStatus$, 4, 4, 4, () => UserContext$, 4, () => UserContext$]
];
export var TrialSource$ = [3, n0, _TSri,
    0,
    [_SA, _ST],
    [0, 0], 1
];
export var TrialSummary$ = [3, n0, _TSria,
    0,
    [_TA, _TN, _DNi, _TSri, _CT, _LMT],
    [0, 0, 0, () => TrialSource$, 4, 4]
];
export var TrustedIdentityPropagationSettings$ = [3, n0, _TIPS,
    0,
    [_St],
    [0], 1
];
export var TtlDuration$ = [3, n0, _TDt,
    0,
    [_Uni, _Va],
    [0, 1]
];
export var TuningJobCompletionCriteria$ = [3, n0, _TJCC,
    0,
    [_TOMV, _BONI, _CDo],
    [1, () => BestObjectiveNotImproving$, () => ConvergenceDetected$]
];
export var TuningJobStepMetaData$ = [3, n0, _TJSMD,
    0,
    [_Ar],
    [0]
];
export var UiConfig$ = [3, n0, _UC,
    0,
    [_UTSU, _HTUA],
    [0, 0]
];
export var UiTemplate$ = [3, n0, _UT,
    0,
    [_Con],
    [0], 1
];
export var UiTemplateInfo$ = [3, n0, _UTI,
    0,
    [_U, _CSonte],
    [0, 0]
];
export var UltraServer$ = [3, n0, _USlt,
    0,
    [_USIl, _UST, _AZ, _IT, _TICo, _CSIC, _AICv, _IUIC, _ASIC, _UIC, _HSe],
    [0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 0], 5
];
export var UltraServerInfo$ = [3, n0, _USI,
    0,
    [_Id, _T],
    [0, 0]
];
export var UltraServerSummary$ = [3, n0, _USS,
    0,
    [_UST, _IT, _USC, _ASIC, _UIC],
    [0, 0, 1, 1, 1], 2
];
export var UnifiedStudioSettings$ = [3, n0, _USSn,
    0,
    [_SWPA, _DAIo, _DRo, _DI, _PIro, _EInv, _PSP, _SSOAA],
    [0, 0, 0, 0, 0, 0, 0, 0]
];
export var UpdateActionRequest$ = [3, n0, _UAR,
    0,
    [_AN, _D, _St, _Pr, _PTRr],
    [0, 0, 0, 128 | 0, 64 | 0], 1
];
export var UpdateActionResponse$ = [3, n0, _UARp,
    0,
    [_AA],
    [0]
];
export var UpdateAppImageConfigRequest$ = [3, n0, _UAICR,
    0,
    [_AICN, _KGIC, _JLAIC, _CEAIC],
    [0, () => KernelGatewayImageConfig$, () => JupyterLabAppImageConfig$, () => CodeEditorAppImageConfig$], 1
];
export var UpdateAppImageConfigResponse$ = [3, n0, _UAICRp,
    0,
    [_AICA],
    [0]
];
export var UpdateArtifactRequest$ = [3, n0, _UARpd,
    0,
    [_AAr, _ANr, _Pr, _PTRr],
    [0, 0, 128 | 0, 64 | 0], 1
];
export var UpdateArtifactResponse$ = [3, n0, _UARpda,
    0,
    [_AAr],
    [0]
];
export var UpdateClusterRequest$ = [3, n0, _UCR,
    0,
    [_CNl, _IG, _RIG, _TSCi, _NR, _IGTD, _NPM, _CRl, _ASu, _Or],
    [0, () => ClusterInstanceGroupSpecifications, () => ClusterRestrictedInstanceGroupSpecifications, () => ClusterTieredStorageConfig$, 0, 64 | 0, 0, 0, () => ClusterAutoScalingConfig$, () => ClusterOrchestrator$], 1
];
export var UpdateClusterResponse$ = [3, n0, _UCRp,
    0,
    [_CAl],
    [0], 1
];
export var UpdateClusterSchedulerConfigRequest$ = [3, n0, _UCSCR,
    0,
    [_CSCI, _TVar, _SCc, _D],
    [0, 1, () => SchedulerConfig$, 0], 2
];
export var UpdateClusterSchedulerConfigResponse$ = [3, n0, _UCSCRp,
    0,
    [_CSCA, _CSCV],
    [0, 1], 2
];
export var UpdateClusterSoftwareInstanceGroupSpecification$ = [3, n0, _UCSIGS,
    0,
    [_IGN],
    [0], 1
];
export var UpdateClusterSoftwareRequest$ = [3, n0, _UCSR,
    0,
    [_CNl, _IG, _DC, _IIm],
    [0, () => UpdateClusterSoftwareInstanceGroups, () => DeploymentConfiguration$, 0], 1
];
export var UpdateClusterSoftwareResponse$ = [3, n0, _UCSRp,
    0,
    [_CAl],
    [0], 1
];
export var UpdateCodeRepositoryInput$ = [3, n0, _UCRI,
    0,
    [_CRN, _GC],
    [0, () => GitConfigForUpdate$], 1
];
export var UpdateCodeRepositoryOutput$ = [3, n0, _UCRO,
    0,
    [_CRA],
    [0], 1
];
export var UpdateComputeQuotaRequest$ = [3, n0, _UCQR,
    0,
    [_CQI, _TVar, _CQC, _CQT, _ASct, _D],
    [0, 1, () => ComputeQuotaConfig$, () => ComputeQuotaTarget$, 0, 0], 2
];
export var UpdateComputeQuotaResponse$ = [3, n0, _UCQRp,
    0,
    [_CQA, _CQV],
    [0, 1], 2
];
export var UpdateContextRequest$ = [3, n0, _UCRpd,
    0,
    [_CNon, _D, _Pr, _PTRr],
    [0, 0, 128 | 0, 64 | 0], 1
];
export var UpdateContextResponse$ = [3, n0, _UCRpda,
    0,
    [_CAo],
    [0]
];
export var UpdateDeviceFleetRequest$ = [3, n0, _UDFR,
    0,
    [_DFN, _OC, _RAo, _D, _EIRA],
    [0, () => EdgeOutputConfig$, 0, 0, 2], 2
];
export var UpdateDevicesRequest$ = [3, n0, _UDR,
    0,
    [_DFN, _Dev],
    [0, () => Devices], 2
];
export var UpdateDomainRequest$ = [3, n0, _UDRp,
    0,
    [_DI, _DUS, _DSFU, _ASGM, _DSS, _SIu, _ANAT, _TP, _VIp],
    [0, () => UserSettings$, () => DomainSettingsForUpdate$, 0, () => DefaultSpaceSettings$, 64 | 0, 0, 0, 0], 1
];
export var UpdateDomainResponse$ = [3, n0, _UDRpd,
    0,
    [_DAo],
    [0]
];
export var UpdateEndpointInput$ = [3, n0, _UEI,
    0,
    [_EN, _ECN, _RAVP, _ERVP, _DC, _RDCet],
    [0, 0, 2, () => VariantPropertyList, () => DeploymentConfig$, 2], 2
];
export var UpdateEndpointOutput$ = [3, n0, _UEO,
    0,
    [_EA],
    [0], 1
];
export var UpdateEndpointWeightsAndCapacitiesInput$ = [3, n0, _UEWACI,
    0,
    [_EN, _DWACe],
    [0, () => DesiredWeightAndCapacityList], 2
];
export var UpdateEndpointWeightsAndCapacitiesOutput$ = [3, n0, _UEWACO,
    0,
    [_EA],
    [0], 1
];
export var UpdateExperimentRequest$ = [3, n0, _UER,
    0,
    [_ENx, _DNi, _D],
    [0, 0, 0], 1
];
export var UpdateExperimentResponse$ = [3, n0, _UERp,
    0,
    [_EAx],
    [0]
];
export var UpdateFeatureGroupRequest$ = [3, n0, _UFGR,
    0,
    [_FGN, _FAe, _OSC, _TCh],
    [0, () => FeatureAdditions, () => OnlineStoreConfigUpdate$, () => ThroughputConfigUpdate$], 1
];
export var UpdateFeatureGroupResponse$ = [3, n0, _UFGRp,
    0,
    [_FGA],
    [0], 1
];
export var UpdateFeatureMetadataRequest$ = [3, n0, _UFMR,
    0,
    [_FGN, _FN, _D, _PAa, _PRara],
    [0, 0, 0, () => FeatureParameterAdditions, 64 | 0], 2
];
export var UpdateHubContentReferenceRequest$ = [3, n0, _UHCRR,
    0,
    [_HN, _HCN, _HCT, _MVi],
    [0, 0, 0, 0], 3
];
export var UpdateHubContentReferenceResponse$ = [3, n0, _UHCRRp,
    0,
    [_HA, _HCA],
    [0, 0], 2
];
export var UpdateHubContentRequest$ = [3, n0, _UHCR,
    0,
    [_HN, _HCN, _HCT, _HCV, _HCDN, _HCDu, _HCM, _HCSK, _SSu],
    [0, 0, 0, 0, 0, 0, 0, 64 | 0, 0], 4
];
export var UpdateHubContentResponse$ = [3, n0, _UHCRp,
    0,
    [_HA, _HCA],
    [0, 0], 2
];
export var UpdateHubRequest$ = [3, n0, _UHR,
    0,
    [_HN, _HD, _HDN, _HSK],
    [0, 0, 0, 64 | 0], 1
];
export var UpdateHubResponse$ = [3, n0, _UHRp,
    0,
    [_HA],
    [0], 1
];
export var UpdateImageRequest$ = [3, n0, _UIR,
    0,
    [_IN, _DPe, _D, _DNi, _RAo],
    [0, 64 | 0, 0, 0, 0], 1
];
export var UpdateImageResponse$ = [3, n0, _UIRp,
    0,
    [_IAm],
    [0]
];
export var UpdateImageVersionRequest$ = [3, n0, _UIVR,
    0,
    [_IN, _Alia, _V, _ATA, _ATD, _VG, _JT, _MLF, _PL, _Pro, _H, _RN],
    [0, 0, 1, 64 | 0, 64 | 0, 0, 0, 0, 0, 0, 2, 0], 1
];
export var UpdateImageVersionResponse$ = [3, n0, _UIVRp,
    0,
    [_IVA],
    [0]
];
export var UpdateInferenceComponentInput$ = [3, n0, _UICI,
    0,
    [_ICN, _Spe, _RC, _DC],
    [0, () => InferenceComponentSpecification$, () => InferenceComponentRuntimeConfig$, () => InferenceComponentDeploymentConfig$], 1
];
export var UpdateInferenceComponentOutput$ = [3, n0, _UICO,
    0,
    [_ICA],
    [0], 1
];
export var UpdateInferenceComponentRuntimeConfigInput$ = [3, n0, _UICRCI,
    0,
    [_ICN, _DRCes],
    [0, () => InferenceComponentRuntimeConfig$], 2
];
export var UpdateInferenceComponentRuntimeConfigOutput$ = [3, n0, _UICRCO,
    0,
    [_ICA],
    [0], 1
];
export var UpdateInferenceExperimentRequest$ = [3, n0, _UIER,
    0,
    [_N, _Sc, _D, _MVod, _DSCa, _SMC],
    [0, () => InferenceExperimentSchedule$, 0, () => ModelVariantConfigList, () => InferenceExperimentDataStorageConfig$, () => ShadowModeConfig$], 1
];
export var UpdateInferenceExperimentResponse$ = [3, n0, _UIERp,
    0,
    [_IEA],
    [0], 1
];
export var UpdateMlflowAppRequest$ = [3, n0, _UMAR,
    0,
    [_Ar, _N, _ASU, _MRM, _WMWS, _DDIL, _ADS],
    [0, 0, 0, 0, 0, 64 | 0, 0], 1
];
export var UpdateMlflowAppResponse$ = [3, n0, _UMARp,
    0,
    [_Ar],
    [0]
];
export var UpdateMlflowTrackingServerRequest$ = [3, n0, _UMTSR,
    0,
    [_TSN, _ASU, _TSS, _AMR, _WMWS],
    [0, 0, 0, 2, 0], 1
];
export var UpdateMlflowTrackingServerResponse$ = [3, n0, _UMTSRp,
    0,
    [_TSA],
    [0]
];
export var UpdateModelCardRequest$ = [3, n0, _UMCR,
    0,
    [_MCN, _Con, _MCS],
    [0, [() => ModelCardContent, 0], 0], 1
];
export var UpdateModelCardResponse$ = [3, n0, _UMCRp,
    0,
    [_MCA],
    [0], 1
];
export var UpdateModelPackageInput$ = [3, n0, _UMPI,
    0,
    [_MPA, _MAS, _MPRT, _ADpp, _CMP, _CMPTR, _AISTA, _ISn, _SU, _MCod, _MLC, _CTl],
    [0, 0, 0, 0, 128 | 0, 64 | 0, () => AdditionalInferenceSpecifications, () => InferenceSpecification$, 0, [() => ModelPackageModelCard$, 0], () => ModelLifeCycle$, 0], 1
];
export var UpdateModelPackageOutput$ = [3, n0, _UMPO,
    0,
    [_MPA],
    [0], 1
];
export var UpdateMonitoringAlertRequest$ = [3, n0, _UMARpd,
    0,
    [_MSN, _MAN, _DTA, _EPv],
    [0, 0, 1, 1], 4
];
export var UpdateMonitoringAlertResponse$ = [3, n0, _UMARpda,
    0,
    [_MSA, _MAN],
    [0, 0], 1
];
export var UpdateMonitoringScheduleRequest$ = [3, n0, _UMSR,
    0,
    [_MSN, _MSC],
    [0, () => MonitoringScheduleConfig$], 2
];
export var UpdateMonitoringScheduleResponse$ = [3, n0, _UMSRp,
    0,
    [_MSA],
    [0], 1
];
export var UpdateNotebookInstanceInput$ = [3, n0, _UNII,
    0,
    [_NIN, _IT, _IAT, _PIl, _RAo, _LCN, _DLC, _VSIGB, _DCR, _ACR, _ATc, _DAT, _DDCR, _DACR, _RAoo, _IMSC],
    [0, 0, 0, 0, 0, 0, 2, 1, 0, 64 | 0, 64 | 0, 2, 2, 2, 0, () => InstanceMetadataServiceConfiguration$], 1
];
export var UpdateNotebookInstanceLifecycleConfigInput$ = [3, n0, _UNILCI,
    0,
    [_NILCN, _OCn, _OSn],
    [0, () => NotebookInstanceLifecycleConfigList, () => NotebookInstanceLifecycleConfigList], 1
];
export var UpdateNotebookInstanceLifecycleConfigOutput$ = [3, n0, _UNILCO,
    0,
    [],
    []
];
export var UpdateNotebookInstanceOutput$ = [3, n0, _UNIO,
    0,
    [],
    []
];
export var UpdatePartnerAppRequest$ = [3, n0, _UPAR,
    0,
    [_Ar, _MCa, _Ti, _ACp, _EISBI, _EAMVU, _AVp, _CTl, _Ta],
    [0, () => PartnerAppMaintenanceConfig$, 0, () => PartnerAppConfig$, 2, 2, 0, [0, 4], () => TagList], 1
];
export var UpdatePartnerAppResponse$ = [3, n0, _UPARp,
    0,
    [_Ar],
    [0]
];
export var UpdatePipelineExecutionRequest$ = [3, n0, _UPER,
    0,
    [_PEA, _PED, _PEDN, _PCa],
    [0, 0, 0, () => ParallelismConfiguration$], 1
];
export var UpdatePipelineExecutionResponse$ = [3, n0, _UPERp,
    0,
    [_PEA],
    [0]
];
export var UpdatePipelineRequest$ = [3, n0, _UPR,
    0,
    [_PNi, _PDN, _PD, _PDSL, _PDi, _RAo, _PCa],
    [0, 0, 0, () => PipelineDefinitionS3Location$, 0, 0, () => ParallelismConfiguration$], 1
];
export var UpdatePipelineResponse$ = [3, n0, _UPRp,
    0,
    [_PAi, _PVI],
    [0, 1]
];
export var UpdatePipelineVersionRequest$ = [3, n0, _UPVR,
    0,
    [_PAi, _PVI, _PVDN, _PVD],
    [0, 1, 0, 0], 2
];
export var UpdatePipelineVersionResponse$ = [3, n0, _UPVRp,
    0,
    [_PAi, _PVI],
    [0, 1]
];
export var UpdateProjectInput$ = [3, n0, _UPI,
    0,
    [_PNr, _PDr, _SCPUD, _Ta, _TPTU],
    [0, 0, () => ServiceCatalogProvisioningUpdateDetails$, () => TagList, () => UpdateTemplateProviderList], 1
];
export var UpdateProjectOutput$ = [3, n0, _UPO,
    0,
    [_PAr],
    [0], 1
];
export var UpdateSpaceRequest$ = [3, n0, _USR,
    0,
    [_DI, _SN, _SS, _SDN],
    [0, 0, () => SpaceSettings$, 0], 2
];
export var UpdateSpaceResponse$ = [3, n0, _USRp,
    0,
    [_SAp],
    [0]
];
export var UpdateTemplateProvider$ = [3, n0, _UTP,
    0,
    [_CTPf],
    [() => CfnUpdateTemplateProvider$]
];
export var UpdateTrainingJobRequest$ = [3, n0, _UTJR,
    0,
    [_TJN, _PCr, _PRC, _RCe, _RDC],
    [0, () => ProfilerConfigForUpdate$, () => ProfilerRuleConfigurations, () => ResourceConfigForUpdate$, () => RemoteDebugConfigForUpdate$], 1
];
export var UpdateTrainingJobResponse$ = [3, n0, _UTJRp,
    0,
    [_TJA],
    [0], 1
];
export var UpdateTrialComponentRequest$ = [3, n0, _UTCR,
    0,
    [_TCN, _DNi, _St, _STt, _ETn, _P, _PTRa, _IAn, _IATR, _OA, _OATR],
    [0, 0, () => TrialComponentStatus$, 4, 4, () => TrialComponentParameters, 64 | 0, () => TrialComponentArtifacts, 64 | 0, () => TrialComponentArtifacts, 64 | 0], 1
];
export var UpdateTrialComponentResponse$ = [3, n0, _UTCRp,
    0,
    [_TCA],
    [0]
];
export var UpdateTrialRequest$ = [3, n0, _UTR,
    0,
    [_TN, _DNi],
    [0, 0], 1
];
export var UpdateTrialResponse$ = [3, n0, _UTRp,
    0,
    [_TA],
    [0]
];
export var UpdateUserProfileRequest$ = [3, n0, _UUPR,
    0,
    [_DI, _UPN, _US],
    [0, 0, () => UserSettings$], 2
];
export var UpdateUserProfileResponse$ = [3, n0, _UUPRp,
    0,
    [_UPA],
    [0]
];
export var UpdateWorkforceRequest$ = [3, n0, _UWR,
    0,
    [_WN, _SIC, _OCi, _WVC, _IAT],
    [0, () => SourceIpConfig$, [() => OidcConfig$, 0], () => WorkforceVpcConfigRequest$, 0], 1
];
export var UpdateWorkforceResponse$ = [3, n0, _UWRp,
    0,
    [_W],
    [() => Workforce$], 1
];
export var UpdateWorkteamRequest$ = [3, n0, _UWRpd,
    0,
    [_WNo, _MDe, _D, _NCo, _WAC],
    [0, () => MemberDefinitions, 0, () => NotificationConfiguration$, () => WorkerAccessConfiguration$], 1
];
export var UpdateWorkteamResponse$ = [3, n0, _UWRpda,
    0,
    [_Wo],
    [() => Workteam$], 1
];
export var USD$ = [3, n0, _USD,
    0,
    [_Dol, _Ce, _TFOAC],
    [1, 1, 1]
];
export var UserContext$ = [3, n0, _UCs,
    0,
    [_UPA, _UPN, _DI, _IIa],
    [0, 0, 0, () => IamIdentity$]
];
export var UserProfileDetails$ = [3, n0, _UPD,
    0,
    [_DI, _UPN, _St, _CT, _LMT],
    [0, 0, 0, 4, 4]
];
export var UserSettings$ = [3, n0, _US,
    0,
    [_ERx, _SG, _SSh, _JSAS, _KGAS, _TBAS, _RSSPAS, _RSAS, _CAS, _CEAS, _JLAS, _SSSp, _DLU, _SWP, _CPUC, _CFSC, _SWPS, _AMHEFS],
    [0, 64 | 0, () => SharingSettings$, () => JupyterServerAppSettings$, () => KernelGatewayAppSettings$, () => TensorBoardAppSettings$, () => RStudioServerProAppSettings$, () => RSessionAppSettings$, () => CanvasAppSettings$, () => CodeEditorAppSettings$, () => JupyterLabAppSettings$, () => DefaultSpaceStorageSettings$, 0, 0, () => CustomPosixUserConfig$, () => CustomFileSystemConfigs, () => StudioWebPortalSettings$, 0]
];
export var VariantProperty$ = [3, n0, _VPa,
    0,
    [_VPT],
    [0], 1
];
export var VectorConfig$ = [3, n0, _VCe,
    0,
    [_Dim],
    [1], 1
];
export var Vertex$ = [3, n0, _Ver,
    0,
    [_Ar, _T, _LTin],
    [0, 0, 0]
];
export var VisibilityConditions$ = [3, n0, _VCi,
    0,
    [_K, _Va],
    [0, 0]
];
export var VpcConfig$ = [3, n0, _VC,
    0,
    [_SGI, _Sub],
    [64 | 0, 64 | 0], 2
];
export var WarmPoolStatus$ = [3, n0, _WPS,
    0,
    [_St, _RRBTIS, _RBJ],
    [0, 1, 0], 1
];
export var WorkerAccessConfiguration$ = [3, n0, _WAC,
    0,
    [_SPr],
    [() => S3Presign$]
];
export var Workforce$ = [3, n0, _W,
    0,
    [_WN, _WA, _LUD, _SIC, _SDu, _CCog, _OCi, _CDr, _WVC, _St, _FR, _IAT],
    [0, 0, 4, () => SourceIpConfig$, 0, () => CognitoConfig$, () => OidcConfigForResponse$, 4, () => WorkforceVpcConfigResponse$, 0, 0, 0], 2
];
export var WorkforceVpcConfigRequest$ = [3, n0, _WVCR,
    0,
    [_VIp, _SGI, _Sub],
    [0, 64 | 0, 64 | 0]
];
export var WorkforceVpcConfigResponse$ = [3, n0, _WVCRo,
    0,
    [_VIp, _SGI, _Sub, _VEI],
    [0, 64 | 0, 64 | 0, 0], 3
];
export var WorkspaceSettings$ = [3, n0, _WS,
    0,
    [_SAP, _SKKI],
    [0, 0]
];
export var Workteam$ = [3, n0, _Wo,
    0,
    [_WNo, _MDe, _WAo, _D, _WA, _PLI, _SDu, _CDr, _LUD, _NCo, _WAC],
    [0, () => MemberDefinitions, 0, 0, 0, 64 | 0, 0, 4, 4, () => NotificationConfiguration$, () => WorkerAccessConfiguration$], 4
];
var __Unit = "unit";
var AbsoluteBorrowLimitResourceList = [1, n0, _ABLRL,
    0, () => ComputeQuotaResourceConfig$
];
var ActionSummaries = [1, n0, _AScti,
    0, () => ActionSummary$
];
var AddClusterNodeSpecificationList = [1, n0, _ACNSL,
    0, () => AddClusterNodeSpecification$
];
var AdditionalCodeRepositoryNamesOrUrls = 64 | 0;
var AdditionalInferenceSpecifications = [1, n0, _AIS,
    0, () => AdditionalInferenceSpecificationDefinition$
];
var AdditionalModelDataSources = [1, n0, _AMDSd,
    0, () => AdditionalModelDataSource$
];
var AgentVersions = [1, n0, _AVg,
    0, () => AgentVersion$
];
var AlarmList = [1, n0, _AL,
    0, () => Alarm$
];
var AlgorithmStatusItemList = [1, n0, _ASIL,
    0, () => AlgorithmStatusItem$
];
var AlgorithmSummaryList = [1, n0, _ASL,
    0, () => AlgorithmSummary$
];
var AlgorithmValidationProfiles = [1, n0, _AVPl,
    0, () => AlgorithmValidationProfile$
];
var AppImageConfigList = [1, n0, _AICL,
    0, () => AppImageConfigDetails$
];
var AppList = [1, n0, _ALp,
    0, () => AppDetails$
];
var ArtifactSourceTypes = [1, n0, _ASTr,
    0, () => ArtifactSourceType$
];
var ArtifactSummaries = [1, n0, _ASrti,
    0, () => ArtifactSummary$
];
var AssignedGroupPatternsList = 64 | 0;
var AssociationInfoList = [1, n0, _AIL,
    0, () => AssociationInfo$
];
var AssociationSummaries = [1, n0, _ASss,
    0, () => AssociationSummary$
];
var AssumableRoleArns = 64 | 0;
var AsyncNotificationTopicTypeList = 64 | 0;
var AttributeNames = 64 | 0;
var AuthorizedUrlConfigs = [1, n0, _AUC,
    0, () => AuthorizedUrl$
];
var AutoMLAlgorithms = 64 | 0;
var AutoMLAlgorithmsConfig = [1, n0, _AMLACu,
    0, () => AutoMLAlgorithmConfig$
];
var AutoMLCandidates = [1, n0, _AMLCut,
    0, () => AutoMLCandidate$
];
var AutoMLContainerDefinitions = [1, n0, _AMLCDu,
    0, () => AutoMLContainerDefinition$
];
var AutoMLInputDataConfig = [1, n0, _AMLIDC,
    0, () => AutoMLChannel$
];
var AutoMLJobInputDataConfig = [1, n0, _AMLJIDC,
    0, () => AutoMLJobChannel$
];
var AutoMLJobSummaries = [1, n0, _AMLJSut,
    0, () => AutoMLJobSummary$
];
var AutoMLPartialFailureReasons = [1, n0, _AMLPFRu,
    0, () => AutoMLPartialFailureReason$
];
var AutoParameters = [1, n0, _APu,
    0, () => AutoParameter$
];
var AutoRollbackAlarms = [1, n0, _ARAu,
    0, () => AlarmDetails$
];
var BatchAddClusterNodesErrorList = [1, n0, _BACNEL,
    0, () => BatchAddClusterNodesError$
];
var BatchDeleteClusterNodeLogicalIdsErrorList = [1, n0, _BDCNLIEL,
    0, () => BatchDeleteClusterNodeLogicalIdsError$
];
var BatchDeleteClusterNodesErrorList = [1, n0, _BDCNEL,
    0, () => BatchDeleteClusterNodesError$
];
var BatchRebootClusterNodeLogicalIdsErrors = [1, n0, _BRCNLIEat,
    0, () => BatchRebootClusterNodeLogicalIdsError$
];
var BatchRebootClusterNodesErrors = [1, n0, _BRCNEat,
    0, () => BatchRebootClusterNodesError$
];
var BatchReplaceClusterNodeLogicalIdsErrors = [1, n0, _BRCNLIEatc,
    0, () => BatchReplaceClusterNodeLogicalIdsError$
];
var BatchReplaceClusterNodesErrors = [1, n0, _BRCNEatc,
    0, () => BatchReplaceClusterNodesError$
];
var CandidateSteps = [1, n0, _CSa,
    0, () => AutoMLCandidateStep$
];
var CaptureOptionList = [1, n0, _COL,
    0, () => CaptureOption$
];
var CategoricalParameterRanges = [1, n0, _CPRa,
    0, () => CategoricalParameterRange$
];
var CategoricalParameterRangeValues = 64 | 0;
var CategoricalParameters = [1, n0, _CPat,
    0, () => CategoricalParameter$
];
var CfnStackCreateParameters = [1, n0, _CSCPf,
    0, () => CfnStackCreateParameter$
];
var CfnStackParameters = [1, n0, _CSPf,
    0, () => CfnStackParameter$
];
var CfnStackUpdateParameters = [1, n0, _CSUPf,
    0, () => CfnStackUpdateParameter$
];
var ChannelSpecifications = [1, n0, _CSha,
    0, () => ChannelSpecification$
];
var Cidrs = 64 | 0;
var ClarifyFeatureHeaders = 64 | 0;
var ClarifyFeatureTypes = 64 | 0;
var ClarifyLabelHeaders = 64 | 0;
var ClusterEventSummaries = [1, n0, _CESl,
    0, () => ClusterEventSummary$
];
var ClusterInstanceGroupDetailsList = [1, n0, _CIGDL,
    0, () => ClusterInstanceGroupDetails$
];
var ClusterInstanceGroupSpecifications = [1, n0, _CIGSl,
    0, () => ClusterInstanceGroupSpecification$
];
var ClusterInstanceGroupsToDelete = 64 | 0;
var ClusterInstanceStorageConfigs = [1, n0, _CISC,
    0, () => ClusterInstanceStorageConfig$
];
var ClusterKubernetesTaints = [1, n0, _CKTl,
    0, () => ClusterKubernetesTaint$
];
var ClusterNodeIds = 64 | 0;
var ClusterNodeLogicalIdList = 64 | 0;
var ClusterNodeSummaries = [1, n0, _CNSl,
    0, () => ClusterNodeSummary$
];
var ClusterPartitionNames = 64 | 0;
var ClusterRestrictedInstanceGroupDetailsList = [1, n0, _CRIGDL,
    0, () => ClusterRestrictedInstanceGroupDetails$
];
var ClusterRestrictedInstanceGroupSpecifications = [1, n0, _CRIGSl,
    0, () => ClusterRestrictedInstanceGroupSpecification$
];
var ClusterSchedulerConfigSummaryList = [1, n0, _CSCSL,
    0, () => ClusterSchedulerConfigSummary$
];
var ClusterSummaries = [1, n0, _CSlus,
    0, () => ClusterSummary$
];
var CodeRepositories = [1, n0, _CRod,
    0, () => CodeRepository$
];
var CodeRepositorySummaryList = [1, n0, _CRSL,
    0, () => CodeRepositorySummary$
];
var CollectionConfigurations = [1, n0, _CColl,
    0, () => CollectionConfiguration$
];
var CompilationJobSummaries = [1, n0, _CJSom,
    0, () => CompilationJobSummary$
];
var CompressionTypes = 64 | 0;
var ComputeQuotaResourceConfigList = [1, n0, _CQRCL,
    0, () => ComputeQuotaResourceConfig$
];
var ComputeQuotaSummaryList = [1, n0, _CQSL,
    0, () => ComputeQuotaSummary$
];
var ContainerArguments = 64 | 0;
var ContainerDefinitionList = [1, n0, _CDL,
    0, () => ContainerDefinition$
];
var ContainerEntrypoint = 64 | 0;
var ContentClassifiers = 64 | 0;
var ContentTypes = 64 | 0;
var ContextSummaries = [1, n0, _CSont,
    0, () => ContextSummary$
];
var ContinuousParameterRanges = [1, n0, _CPRon,
    0, () => ContinuousParameterRange$
];
var CreateTemplateProviderList = [1, n0, _CTPL,
    0, () => CreateTemplateProvider$
];
var CsvContentTypes = 64 | 0;
var CustomerMetadataKeyList = 64 | 0;
var CustomFileSystemConfigs = [1, n0, _CFSC,
    0, () => CustomFileSystemConfig$
];
var CustomFileSystems = [1, n0, _CFS,
    0, () => CustomFileSystem$
];
var CustomImageContainerArguments = 64 | 0;
var CustomImageContainerEntrypoint = 64 | 0;
var CustomImages = [1, n0, _CI,
    0, () => CustomImage$
];
var DebugRuleConfigurations = [1, n0, _DRC,
    0, () => DebugRuleConfiguration$
];
var DebugRuleEvaluationStatuses = [1, n0, _DRESe,
    0, () => DebugRuleEvaluationStatus$
];
var DefaultDomainIdList = 64 | 0;
var DeployedImages = [1, n0, _DIep,
    0, () => DeployedImage$
];
var DeploymentStages = [1, n0, _DSepl,
    0, () => DeploymentStage$
];
var DeploymentStageStatusSummaries = [1, n0, _DSSSep,
    0, () => DeploymentStageStatusSummary$
];
var DesiredWeightAndCapacityList = [1, n0, _DWACL,
    0, () => DesiredWeightAndCapacity$
];
var DeviceDeploymentSummaries = [1, n0, _DDSevi,
    0, () => DeviceDeploymentSummary$
];
var DeviceFleetSummaries = [1, n0, _DFSe,
    0, () => DeviceFleetSummary$
];
var DeviceNames = 64 | 0;
var Devices = [1, n0, _Dev,
    0, () => Device$
];
var DeviceSummaries = [1, n0, _DSevic,
    0, () => DeviceSummary$
];
var DomainList = [1, n0, _DLo,
    0, () => DomainDetails$
];
var DomainSecurityGroupIds = 64 | 0;
var Ec2CapacityReservationsList = [1, n0, _ECRL,
    0, () => Ec2CapacityReservation$
];
var EdgeDeploymentModelConfigs = [1, n0, _EDMCd,
    0, () => EdgeDeploymentModelConfig$
];
var EdgeDeploymentPlanSummaries = [1, n0, _EDPSd,
    0, () => EdgeDeploymentPlanSummary$
];
var EdgeModels = [1, n0, _EMdg,
    0, () => EdgeModel$
];
var EdgeModelStats = [1, n0, _EMSdg,
    0, () => EdgeModelStat$
];
var EdgeModelSummaries = [1, n0, _EMSdge,
    0, () => EdgeModelSummary$
];
var EdgePackagingJobSummaries = [1, n0, _EPJSdg,
    0, () => EdgePackagingJobSummary$
];
var Edges = [1, n0, _Edg,
    0, () => Edge$
];
var EfaEnis = 64 | 0;
var EksRoleAccessEntries = 64 | 0;
var EndpointConfigSummaryList = [1, n0, _ECSL,
    0, () => EndpointConfigSummary$
];
var EndpointInputConfigurations = [1, n0, _EICnd,
    0, () => EndpointInputConfiguration$
];
var EndpointPerformances = [1, n0, _EP,
    0, () => EndpointPerformance$
];
var Endpoints = [1, n0, _End,
    0, () => EndpointInfo$
];
var EndpointSummaryList = [1, n0, _ESL,
    0, () => EndpointSummary$
];
var EnvironmentParameters = [1, n0, _EPnvi,
    0, () => EnvironmentParameter$
];
var ExecutionRoleArns = 64 | 0;
var ExperimentSummaries = [1, n0, _ESxpe,
    0, () => ExperimentSummary$
];
var FeatureAdditions = [1, n0, _FAe,
    0, () => FeatureDefinition$
];
var FeatureDefinitions = [1, n0, _FD,
    0, () => FeatureDefinition$
];
var FeatureGroupSummaries = [1, n0, _FGSea,
    0, () => FeatureGroupSummary$
];
var FeatureParameterAdditions = [1, n0, _FPA,
    0, () => FeatureParameter$
];
var FeatureParameterRemovals = 64 | 0;
var FeatureParameters = [1, n0, _FPe,
    0, () => FeatureParameter$
];
var FilterList = [1, n0, _FL,
    0, () => Filter$
];
var FinalMetricDataList = [1, n0, _FMDL,
    0, () => MetricData$
];
var FlowDefinitionSummaries = [1, n0, _FDSlo,
    0, () => FlowDefinitionSummary$
];
var FlowDefinitionTaskKeywords = 64 | 0;
var ForecastQuantiles = 64 | 0;
var GroupingAttributeNames = 64 | 0;
var GroupPatternsList = 64 | 0;
var Groups = 64 | 0;
var HiddenAppTypesList = 64 | 0;
var HiddenInstanceTypesList = 64 | 0;
var HiddenMlToolsList = 64 | 0;
var HiddenSageMakerImageVersionAliasesList = [1, n0, _HSMIVAL,
    0, () => HiddenSageMakerImage$
];
var HolidayConfig = [1, n0, _HC,
    0, () => HolidayConfigAttributes$
];
var HubContentDependencyList = [1, n0, _HCDL,
    0, () => HubContentDependency$
];
var HubContentInfoList = [1, n0, _HCIL,
    0, () => HubContentInfo$
];
var HubContentSearchKeywordList = 64 | 0;
var HubInfoList = [1, n0, _HIL,
    0, () => HubInfo$
];
var HubSearchKeywordList = 64 | 0;
var HumanTaskUiSummaries = [1, n0, _HTUSum,
    0, () => HumanTaskUiSummary$
];
var HyperParameterSpecifications = [1, n0, _HPSy,
    0, () => HyperParameterSpecification$
];
var HyperParameterTrainingJobDefinitions = [1, n0, _HPTJDy,
    0, () => HyperParameterTrainingJobDefinition$
];
var HyperParameterTrainingJobSummaries = [1, n0, _HPTJSyper,
    0, () => HyperParameterTrainingJobSummary$
];
var HyperParameterTuningInstanceConfigs = [1, n0, _HPTICy,
    0, () => HyperParameterTuningInstanceConfig$
];
var HyperParameterTuningJobObjectives = [1, n0, _HPTJOy,
    0, () => HyperParameterTuningJobObjective$
];
var HyperParameterTuningJobSummaries = [1, n0, _HPTJSype,
    0, () => HyperParameterTuningJobSummary$
];
var IdentityProviderOAuthSettings = [1, n0, _IPOAS,
    0, () => IdentityProviderOAuthSetting$
];
var ImageDeletePropertyList = 64 | 0;
var Images = [1, n0, _Im,
    0, () => Image$
];
var ImageVersions = [1, n0, _IVm,
    0, () => ImageVersion$
];
var InferenceComponentSummaryList = [1, n0, _ICSL,
    0, () => InferenceComponentSummary$
];
var InferenceExperimentList = [1, n0, _IEL,
    0, () => InferenceExperimentSummary$
];
var InferenceRecommendations = [1, n0, _IRn,
    0, () => InferenceRecommendation$
];
var InferenceRecommendationsJobs = [1, n0, _IRJn,
    0, () => InferenceRecommendationsJob$
];
var InferenceRecommendationsJobSteps = [1, n0, _IRJSn,
    0, () => InferenceRecommendationsJobStep$
];
var InputDataConfig = [1, n0, _IDC,
    0, () => Channel$
];
var InputModes = 64 | 0;
var InstanceGroupNames = 64 | 0;
var InstanceGroups = [1, n0, _IG,
    0, () => InstanceGroup$
];
var IntegerParameterRanges = [1, n0, _IPRn,
    0, () => IntegerParameterRange$
];
var JsonContentTypes = 64 | 0;
var KernelSpecs = [1, n0, _KSe,
    0, () => KernelSpec$
];
var LabelingJobForWorkteamSummaryList = [1, n0, _LJFWSL,
    0, () => LabelingJobForWorkteamSummary$
];
var LabelingJobSummaryList = [1, n0, _LJSL,
    0, () => LabelingJobSummary$
];
var LifecycleConfigArns = 64 | 0;
var LineageGroupSummaries = [1, n0, _LGSi,
    0, () => LineageGroupSummary$
];
var ListLineageEntityParameterKey = 64 | 0;
var ListTrialComponentKey256 = 64 | 0;
var MemberDefinitions = [1, n0, _MDe,
    0, () => MemberDefinition$
];
var MetricDataList = [1, n0, _MDL,
    0, () => MetricDatum$
];
var MetricDefinitionList = [1, n0, _MDLe,
    0, () => MetricDefinition$
];
var MlflowAppSummaries = [1, n0, _MASlf,
    0, () => MlflowAppSummary$
];
var ModelCardExportJobSummaryList = [1, n0, _MCEJSL,
    0, () => ModelCardExportJobSummary$
];
var ModelCardSummaryList = [1, n0, _MCSL,
    0, () => ModelCardSummary$
];
var ModelCardVersionSummaryList = [1, n0, _MCVSL,
    0, () => ModelCardVersionSummary$
];
var ModelDashboardEndpoints = [1, n0, _MDEo,
    0, () => ModelDashboardEndpoint$
];
var ModelDashboardMonitoringSchedules = [1, n0, _MDMSo,
    0, () => ModelDashboardMonitoringSchedule$
];
var ModelLatencyThresholds = [1, n0, _MLTo,
    0, () => ModelLatencyThreshold$
];
var ModelMetadataFilters = [1, n0, _MMFo,
    0, () => ModelMetadataFilter$
];
var ModelMetadataSummaries = [1, n0, _MMS,
    0, () => ModelMetadataSummary$
];
var ModelPackageArnList = 64 | 0;
var ModelPackageContainerDefinitionList = [1, n0, _MPCDL,
    0, () => ModelPackageContainerDefinition$
];
var ModelPackageGroupSummaryList = [1, n0, _MPGSL,
    0, () => ModelPackageGroupSummary$
];
var ModelPackageStatusItemList = [1, n0, _MPSIL,
    0, () => ModelPackageStatusItem$
];
var ModelPackageSummaryList = [1, n0, _MPSL,
    0, () => ModelPackageSummary$
];
var ModelPackageValidationProfiles = [1, n0, _MPVPo,
    0, () => ModelPackageValidationProfile$
];
var ModelSummaryList = [1, n0, _MSL,
    0, () => ModelSummary$
];
var ModelVariantConfigList = [1, n0, _MVCL,
    0, () => ModelVariantConfig$
];
var ModelVariantConfigSummaryList = [1, n0, _MVCSL,
    0, () => ModelVariantConfigSummary$
];
var MonitoringAlertHistoryList = [1, n0, _MAHL,
    0, () => MonitoringAlertHistorySummary$
];
var MonitoringAlertSummaryList = [1, n0, _MASL,
    0, () => MonitoringAlertSummary$
];
var MonitoringContainerArguments = 64 | 0;
var MonitoringExecutionSummaryList = [1, n0, _MESL,
    0, () => MonitoringExecutionSummary$
];
var MonitoringInputs = [1, n0, _MIoni,
    0, () => MonitoringInput$
];
var MonitoringJobDefinitionSummaryList = [1, n0, _MJDSL,
    0, () => MonitoringJobDefinitionSummary$
];
var MonitoringOutputs = [1, n0, _MOo,
    0, () => MonitoringOutput$
];
var MonitoringScheduleList = [1, n0, _MSLo,
    0, () => MonitoringSchedule$
];
var MonitoringScheduleSummaryList = [1, n0, _MSSL,
    0, () => MonitoringScheduleSummary$
];
var NeoVpcSecurityGroupIds = 64 | 0;
var NeoVpcSubnets = 64 | 0;
var NestedFiltersList = [1, n0, _NFL,
    0, () => NestedFilters$
];
var NodeAdditionResultList = [1, n0, _NARL,
    0, () => NodeAdditionResult$
];
var NotebookInstanceAcceleratorTypes = 64 | 0;
var NotebookInstanceLifecycleConfigList = [1, n0, _NILCL,
    0, () => NotebookInstanceLifecycleHook$
];
var NotebookInstanceLifecycleConfigSummaryList = [1, n0, _NILCSL,
    0, () => NotebookInstanceLifecycleConfigSummary$
];
var NotebookInstanceSummaryList = [1, n0, _NISL,
    0, () => NotebookInstanceSummary$
];
var OnStartDeepHealthChecks = 64 | 0;
var OptimizationConfigs = [1, n0, _OCp,
    0, () => OptimizationConfig$
];
var OptimizationJobSummaries = [1, n0, _OJSp,
    0, () => OptimizationJobSummary$
];
var OptimizationTypes = 64 | 0;
var OptimizationVpcSecurityGroupIds = 64 | 0;
var OptimizationVpcSubnets = 64 | 0;
var OutputParameterList = [1, n0, _OPL,
    0, () => OutputParameter$
];
var ParameterList = [1, n0, _PLa,
    0, () => Parameter$
];
var ParameterValues = 64 | 0;
var ParentHyperParameterTuningJobs = [1, n0, _PHPTJ,
    0, () => ParentHyperParameterTuningJob$
];
var Parents = [1, n0, _Paren,
    0, () => Parent$
];
var PartnerAppAdminUserList = 64 | 0;
var PartnerAppSummaries = [1, n0, _PASa,
    0, () => PartnerAppSummary$
];
var PendingProductionVariantSummaryList = [1, n0, _PPVSL,
    0, () => PendingProductionVariantSummary$
];
var Phases = [1, n0, _Pha,
    0, () => Phase$
];
var PipelineExecutionStepList = [1, n0, _PESL,
    0, () => PipelineExecutionStep$
];
var PipelineExecutionSummaryList = [1, n0, _PESLi,
    0, () => PipelineExecutionSummary$
];
var PipelineSummaryList = [1, n0, _PSLi,
    0, () => PipelineSummary$
];
var PipelineVersionSummaryList = [1, n0, _PVSL,
    0, () => PipelineVersionSummary$
];
var PlacementSpecifications = [1, n0, _PSl,
    0, () => PlacementSpecification$
];
var PriorityClassList = [1, n0, _PCL,
    0, () => PriorityClass$
];
var ProcessingInputs = [1, n0, _PIr,
    0, () => ProcessingInput$
];
var ProcessingJobSummaries = [1, n0, _PJSr,
    0, () => ProcessingJobSummary$
];
var ProcessingOutputs = [1, n0, _POr,
    0, () => ProcessingOutput$
];
var ProductionVariantList = [1, n0, _PVL,
    0, () => ProductionVariant$
];
var ProductionVariantStatusList = [1, n0, _PVSLr,
    0, () => ProductionVariantStatus$
];
var ProductionVariantSummaryList = [1, n0, _PVSLro,
    0, () => ProductionVariantSummary$
];
var ProductListings = 64 | 0;
var ProfilerRuleConfigurations = [1, n0, _PRC,
    0, () => ProfilerRuleConfiguration$
];
var ProfilerRuleEvaluationStatuses = [1, n0, _PRES,
    0, () => ProfilerRuleEvaluationStatus$
];
var ProjectSummaryList = [1, n0, _PSL,
    0, () => ProjectSummary$
];
var PropertyNameSuggestionList = [1, n0, _PNSL,
    0, () => PropertyNameSuggestion$
];
var ProvisioningParameters = [1, n0, _PProv,
    0, () => ProvisioningParameter$
];
var QueryLineageStartArns = 64 | 0;
var QueryLineageTypes = 64 | 0;
var QueryTypes = 64 | 0;
var RealtimeInferenceInstanceTypes = 64 | 0;
var RealTimeInferenceRecommendations = [1, n0, _RTIR,
    0, () => RealTimeInferenceRecommendation$
];
var RecommendationJobSupportedContentTypes = 64 | 0;
var RecommendationJobSupportedInstanceTypes = 64 | 0;
var RecommendationJobSupportedResponseMIMETypes = 64 | 0;
var RecommendationJobVpcSecurityGroupIds = 64 | 0;
var RecommendationJobVpcSubnets = 64 | 0;
var ReleaseNotesList = 64 | 0;
var RenderingErrorList = [1, n0, _REL,
    0, () => RenderingError$
];
var ReservedCapacityOfferings = [1, n0, _RCOe,
    0, () => ReservedCapacityOffering$
];
var ReservedCapacitySummaries = [1, n0, _RCS,
    0, () => ReservedCapacitySummary$
];
var ResourceCatalogList = [1, n0, _RCL,
    0, () => ResourceCatalog$
];
var ResponseMIMETypes = 64 | 0;
var RoleGroupAssignmentsList = [1, n0, _RGAL,
    0, () => RoleGroupAssignment$
];
var SageMakerImageVersionAliases = 64 | 0;
var SageMakerResourceNames = 64 | 0;
var ScalingPolicies = [1, n0, _SP,
    0, () => ScalingPolicy$
];
var SearchExpressionList = [1, n0, _SEL,
    0, () => SearchExpression$
];
var SearchResultsList = [1, n0, _SRL,
    0, [() => SearchRecord$,
        0]
];
var SecondaryStatusTransitions = [1, n0, _SST,
    0, () => SecondaryStatusTransition$
];
var SecurityGroupIds = 64 | 0;
var SelectedStepList = [1, n0, _SSL,
    0, () => SelectedStep$
];
var ShadowModelVariantConfigList = [1, n0, _SMVCL,
    0, () => ShadowModelVariantConfig$
];
var SourceAlgorithmList = [1, n0, _SAL,
    0, () => SourceAlgorithm$
];
var SpaceList = [1, n0, _SL,
    0, () => SpaceDetails$
];
var StudioLifecycleConfigsList = [1, n0, _SLCL,
    0, () => StudioLifecycleConfigDetails$
];
var Subnets = 64 | 0;
var SubscribedWorkteams = [1, n0, _SWu,
    0, () => SubscribedWorkteam$
];
var TagKeyList = 64 | 0;
var TagList = [1, n0, _TLa,
    0, () => Tag$
];
var TaskKeywords = 64 | 0;
var TemplateProviderDetailList = [1, n0, _TPDL,
    0, () => TemplateProviderDetail$
];
var TrackingServerSummaryList = [1, n0, _TSSL,
    0, () => TrackingServerSummary$
];
var TrainingContainerArguments = 64 | 0;
var TrainingContainerEntrypoint = 64 | 0;
var TrainingInstanceTypes = 64 | 0;
var TrainingJobSummaries = [1, n0, _TJSra,
    0, () => TrainingJobSummary$
];
var TrainingPlanArns = 64 | 0;
var TrainingPlanFilters = [1, n0, _TPFr,
    0, () => TrainingPlanFilter$
];
var TrainingPlanOfferings = [1, n0, _TPO,
    0, () => TrainingPlanOffering$
];
var TrainingPlanSummaries = [1, n0, _TPSr,
    0, () => TrainingPlanSummary$
];
var TransformInstanceTypes = 64 | 0;
var TransformJobSummaries = [1, n0, _TJSran,
    0, () => TransformJobSummary$
];
var TrialComponentMetricSummaries = [1, n0, _TCMSr,
    0, () => TrialComponentMetricSummary$
];
var TrialComponentSimpleSummaries = [1, n0, _TCSSr,
    0, () => TrialComponentSimpleSummary$
];
var TrialComponentSources = [1, n0, _TCSrial,
    0, () => TrialComponentSource$
];
var TrialComponentSummaries = [1, n0, _TCS,
    0, () => TrialComponentSummary$
];
var TrialSummaries = [1, n0, _TSr,
    0, () => TrialSummary$
];
var UltraServers = [1, n0, _USl,
    0, () => UltraServer$
];
var UpdateClusterSoftwareInstanceGroups = [1, n0, _UCSIG,
    0, () => UpdateClusterSoftwareInstanceGroupSpecification$
];
var UpdateTemplateProviderList = [1, n0, _UTPL,
    0, () => UpdateTemplateProvider$
];
var UserProfileList = [1, n0, _UPL,
    0, () => UserProfileDetails$
];
var VariantPropertyList = [1, n0, _VPL,
    0, () => VariantProperty$
];
var VersionAliasesList = 64 | 0;
var Vertices = [1, n0, _Ve,
    0, () => Vertex$
];
var VisibilityConditionsList = [1, n0, _VCL,
    0, () => VisibilityConditions$
];
var VpcOnlyTrustedAccounts = 64 | 0;
var VpcSecurityGroupIds = 64 | 0;
var Workforces = [1, n0, _Wor,
    0, () => Workforce$
];
var WorkforceSecurityGroupIds = 64 | 0;
var WorkforceSubnets = 64 | 0;
var Workteams = [1, n0, _Work,
    0, () => Workteam$
];
var ActiveOperations = 128 | 1;
var AggregationTransformations = 128 | 0;
var ArtifactProperties = 128 | 0;
var AuthenticationRequestExtraParams = 128 | 0;
var AutoMLInferenceContainerDefinitions = [2, n0, _AMLICD,
    0, 0, () => AutoMLContainerDefinitions
];
var BatchDescribeModelPackageErrorMap = [2, n0, _BDMPEM,
    0, 0, () => BatchDescribeModelPackageError$
];
var ClusterKubernetesLabels = 128 | 0;
var CollectionParameters = 128 | 0;
var CustomerMetadataMap = 128 | 0;
var CustomImageContainerEnvironmentVariables = 128 | 0;
var EnvironmentMap = 128 | 0;
var FillingTransformationMap = 128 | 0;
var FillingTransformations = [2, n0, _FTi,
    0, 0, 128 | 0
];
var HookParameters = 128 | 0;
var HyperParameters = 128 | 0;
var HyperParameterTrainingJobEnvironmentMap = 128 | 0;
var LineageEntityParameters = 128 | 0;
var MapString2048 = 128 | 0;
var ModelPackageSummaries = [2, n0, _MPS,
    0, 0, () => BatchDescribeModelPackageSummary$
];
var ModelVariantActionMap = 128 | 0;
var MonitoringEnvironmentMap = 128 | 0;
var OptimizationJobEnvironmentVariables = 128 | 0;
var PartnerAppArguments = 128 | 0;
var ProcessingEnvironmentMap = 128 | 0;
var ProfilingParameters = 128 | 0;
var QueryProperties = 128 | 0;
var RuleParameters = 128 | 0;
var StatusDetailsMap = 128 | 0;
var TextGenerationHyperParameters = 128 | 0;
var TrainingEnvironmentMap = 128 | 0;
var TransformEnvironmentMap = 128 | 0;
var TrialComponentArtifacts = [2, n0, _TCAri,
    0, 0, () => TrialComponentArtifact$
];
var TrialComponentParameters = [2, n0, _TCP,
    0, 0, () => TrialComponentParameterValue$
];
export var AutoMLProblemTypeConfig$ = [4, n0, _AMLPTC,
    0,
    [_ICJC, _TCJC, _TSFJC, _TJC, _TGJC],
    [() => ImageClassificationJobConfig$, () => TextClassificationJobConfig$, () => TimeSeriesForecastingJobConfig$, () => TabularJobConfig$, () => TextGenerationJobConfig$]
];
export var AutoMLProblemTypeResolvedAttributes$ = [4, n0, _AMLPTRA,
    0,
    [_TRA, _TGRA],
    [() => TabularResolvedAttributes$, () => TextGenerationResolvedAttributes$]
];
export var ClusterInstanceStorageConfig$ = [4, n0, _CISCl,
    0,
    [_EVC, _FLC, _FOZC],
    [() => ClusterEbsVolumeConfig$, () => ClusterFsxLustreConfig$, () => ClusterFsxOpenZfsConfig$]
];
export var CollectionConfig$ = [4, n0, _CColle,
    0,
    [_VCe],
    [() => VectorConfig$]
];
export var CustomFileSystem$ = [4, n0, _CFSu,
    0,
    [_EFSFS, _FSLFS, _SFS],
    [() => EFSFileSystem$, () => FSxLustreFileSystem$, () => S3FileSystem$]
];
export var CustomFileSystemConfig$ = [4, n0, _CFSCu,
    0,
    [_EFSFSC, _FSLFSC, _SFSC],
    [() => EFSFileSystemConfig$, () => FSxLustreFileSystemConfig$, () => S3FileSystemConfig$]
];
export var EventMetadata$ = [4, n0, _EMv,
    0,
    [_Cl, _IGn, _IGS, _Ins],
    [() => ClusterMetadata$, () => InstanceGroupMetadata$, () => InstanceGroupScalingMetadata$, () => InstanceMetadata$]
];
export var MetricSpecification$ = [4, n0, _MSet,
    0,
    [_Pre, _Cu],
    [() => PredefinedMetricSpecification$, () => CustomizedMetricSpecification$]
];
export var OptimizationConfig$ = [4, n0, _OCpti,
    0,
    [_MQC, _MCCod, _MSCo, _MSDC],
    [() => ModelQuantizationConfig$, () => ModelCompilationConfig$, () => ModelShardingConfig$, () => ModelSpeculativeDecodingConfig$]
];
export var ScalingPolicy$ = [4, n0, _SPc,
    0,
    [_TTa],
    [() => TargetTrackingScalingPolicyConfiguration$]
];
export var TrialComponentParameterValue$ = [4, n0, _TCPV,
    0,
    [_SV, _NV],
    [0, 1]
];
export var AddAssociation$ = [9, n0, _AAd,
    0, () => AddAssociationRequest$, () => AddAssociationResponse$
];
export var AddTags$ = [9, n0, _ATd,
    0, () => AddTagsInput$, () => AddTagsOutput$
];
export var AssociateTrialComponent$ = [9, n0, _ATC,
    0, () => AssociateTrialComponentRequest$, () => AssociateTrialComponentResponse$
];
export var AttachClusterNodeVolume$ = [9, n0, _ACNV,
    0, () => AttachClusterNodeVolumeRequest$, () => AttachClusterNodeVolumeResponse$
];
export var BatchAddClusterNodes$ = [9, n0, _BACN,
    0, () => BatchAddClusterNodesRequest$, () => BatchAddClusterNodesResponse$
];
export var BatchDeleteClusterNodes$ = [9, n0, _BDCN,
    0, () => BatchDeleteClusterNodesRequest$, () => BatchDeleteClusterNodesResponse$
];
export var BatchDescribeModelPackage$ = [9, n0, _BDMP,
    0, () => BatchDescribeModelPackageInput$, () => BatchDescribeModelPackageOutput$
];
export var BatchRebootClusterNodes$ = [9, n0, _BRCN,
    0, () => BatchRebootClusterNodesRequest$, () => BatchRebootClusterNodesResponse$
];
export var BatchReplaceClusterNodes$ = [9, n0, _BRCNa,
    0, () => BatchReplaceClusterNodesRequest$, () => BatchReplaceClusterNodesResponse$
];
export var CreateAction$ = [9, n0, _CArea,
    0, () => CreateActionRequest$, () => CreateActionResponse$
];
export var CreateAlgorithm$ = [9, n0, _CAreat,
    0, () => CreateAlgorithmInput$, () => CreateAlgorithmOutput$
];
export var CreateApp$ = [9, n0, _CAreate,
    0, () => CreateAppRequest$, () => CreateAppResponse$
];
export var CreateAppImageConfig$ = [9, n0, _CAIC,
    0, () => CreateAppImageConfigRequest$, () => CreateAppImageConfigResponse$
];
export var CreateArtifact$ = [9, n0, _CAreater,
    0, () => CreateArtifactRequest$, () => CreateArtifactResponse$
];
export var CreateAutoMLJob$ = [9, n0, _CAMLJ,
    0, () => CreateAutoMLJobRequest$, () => CreateAutoMLJobResponse$
];
export var CreateAutoMLJobV2$ = [9, n0, _CAMLJV,
    0, () => CreateAutoMLJobV2Request$, () => CreateAutoMLJobV2Response$
];
export var CreateCluster$ = [9, n0, _CCr,
    0, () => CreateClusterRequest$, () => CreateClusterResponse$
];
export var CreateClusterSchedulerConfig$ = [9, n0, _CCSC,
    0, () => CreateClusterSchedulerConfigRequest$, () => CreateClusterSchedulerConfigResponse$
];
export var CreateCodeRepository$ = [9, n0, _CCRreate,
    0, () => CreateCodeRepositoryInput$, () => CreateCodeRepositoryOutput$
];
export var CreateCompilationJob$ = [9, n0, _CCJ,
    0, () => CreateCompilationJobRequest$, () => CreateCompilationJobResponse$
];
export var CreateComputeQuota$ = [9, n0, _CCQ,
    0, () => CreateComputeQuotaRequest$, () => CreateComputeQuotaResponse$
];
export var CreateContext$ = [9, n0, _CCre,
    0, () => CreateContextRequest$, () => CreateContextResponse$
];
export var CreateDataQualityJobDefinition$ = [9, n0, _CDQJD,
    0, () => CreateDataQualityJobDefinitionRequest$, () => CreateDataQualityJobDefinitionResponse$
];
export var CreateDeviceFleet$ = [9, n0, _CDF,
    0, () => CreateDeviceFleetRequest$, () => __Unit
];
export var CreateDomain$ = [9, n0, _CDre,
    0, () => CreateDomainRequest$, () => CreateDomainResponse$
];
export var CreateEdgeDeploymentPlan$ = [9, n0, _CEDP,
    0, () => CreateEdgeDeploymentPlanRequest$, () => CreateEdgeDeploymentPlanResponse$
];
export var CreateEdgeDeploymentStage$ = [9, n0, _CEDS,
    0, () => CreateEdgeDeploymentStageRequest$, () => __Unit
];
export var CreateEdgePackagingJob$ = [9, n0, _CEPJ,
    0, () => CreateEdgePackagingJobRequest$, () => __Unit
];
export var CreateEndpoint$ = [9, n0, _CEr,
    0, () => CreateEndpointInput$, () => CreateEndpointOutput$
];
export var CreateEndpointConfig$ = [9, n0, _CECr,
    0, () => CreateEndpointConfigInput$, () => CreateEndpointConfigOutput$
];
export var CreateExperiment$ = [9, n0, _CEre,
    0, () => CreateExperimentRequest$, () => CreateExperimentResponse$
];
export var CreateFeatureGroup$ = [9, n0, _CFG,
    0, () => CreateFeatureGroupRequest$, () => CreateFeatureGroupResponse$
];
export var CreateFlowDefinition$ = [9, n0, _CFD,
    0, () => CreateFlowDefinitionRequest$, () => CreateFlowDefinitionResponse$
];
export var CreateHub$ = [9, n0, _CHr,
    0, () => CreateHubRequest$, () => CreateHubResponse$
];
export var CreateHubContentPresignedUrls$ = [9, n0, _CHCPU,
    0, () => CreateHubContentPresignedUrlsRequest$, () => CreateHubContentPresignedUrlsResponse$
];
export var CreateHubContentReference$ = [9, n0, _CHCR,
    0, () => CreateHubContentReferenceRequest$, () => CreateHubContentReferenceResponse$
];
export var CreateHumanTaskUi$ = [9, n0, _CHTU,
    0, () => CreateHumanTaskUiRequest$, () => CreateHumanTaskUiResponse$
];
export var CreateHyperParameterTuningJob$ = [9, n0, _CHPTJ,
    0, () => CreateHyperParameterTuningJobRequest$, () => CreateHyperParameterTuningJobResponse$
];
export var CreateImage$ = [9, n0, _CIr,
    0, () => CreateImageRequest$, () => CreateImageResponse$
];
export var CreateImageVersion$ = [9, n0, _CIV,
    0, () => CreateImageVersionRequest$, () => CreateImageVersionResponse$
];
export var CreateInferenceComponent$ = [9, n0, _CICr,
    0, () => CreateInferenceComponentInput$, () => CreateInferenceComponentOutput$
];
export var CreateInferenceExperiment$ = [9, n0, _CIE,
    0, () => CreateInferenceExperimentRequest$, () => CreateInferenceExperimentResponse$
];
export var CreateInferenceRecommendationsJob$ = [9, n0, _CIRJ,
    0, () => CreateInferenceRecommendationsJobRequest$, () => CreateInferenceRecommendationsJobResponse$
];
export var CreateLabelingJob$ = [9, n0, _CLJ,
    0, () => CreateLabelingJobRequest$, () => CreateLabelingJobResponse$
];
export var CreateMlflowApp$ = [9, n0, _CMA,
    0, () => CreateMlflowAppRequest$, () => CreateMlflowAppResponse$
];
export var CreateMlflowTrackingServer$ = [9, n0, _CMTS,
    0, () => CreateMlflowTrackingServerRequest$, () => CreateMlflowTrackingServerResponse$
];
export var CreateModel$ = [9, n0, _CMr,
    0, () => CreateModelInput$, () => CreateModelOutput$
];
export var CreateModelBiasJobDefinition$ = [9, n0, _CMBJD,
    0, () => CreateModelBiasJobDefinitionRequest$, () => CreateModelBiasJobDefinitionResponse$
];
export var CreateModelCard$ = [9, n0, _CMC,
    0, () => CreateModelCardRequest$, () => CreateModelCardResponse$
];
export var CreateModelCardExportJob$ = [9, n0, _CMCEJ,
    0, () => CreateModelCardExportJobRequest$, () => CreateModelCardExportJobResponse$
];
export var CreateModelExplainabilityJobDefinition$ = [9, n0, _CMEJD,
    0, () => CreateModelExplainabilityJobDefinitionRequest$, () => CreateModelExplainabilityJobDefinitionResponse$
];
export var CreateModelPackage$ = [9, n0, _CMPr,
    0, () => CreateModelPackageInput$, () => CreateModelPackageOutput$
];
export var CreateModelPackageGroup$ = [9, n0, _CMPG,
    0, () => CreateModelPackageGroupInput$, () => CreateModelPackageGroupOutput$
];
export var CreateModelQualityJobDefinition$ = [9, n0, _CMQJD,
    0, () => CreateModelQualityJobDefinitionRequest$, () => CreateModelQualityJobDefinitionResponse$
];
export var CreateMonitoringSchedule$ = [9, n0, _CMSr,
    0, () => CreateMonitoringScheduleRequest$, () => CreateMonitoringScheduleResponse$
];
export var CreateNotebookInstance$ = [9, n0, _CNI,
    0, () => CreateNotebookInstanceInput$, () => CreateNotebookInstanceOutput$
];
export var CreateNotebookInstanceLifecycleConfig$ = [9, n0, _CNILC,
    0, () => CreateNotebookInstanceLifecycleConfigInput$, () => CreateNotebookInstanceLifecycleConfigOutput$
];
export var CreateOptimizationJob$ = [9, n0, _COJ,
    0, () => CreateOptimizationJobRequest$, () => CreateOptimizationJobResponse$
];
export var CreatePartnerApp$ = [9, n0, _CPA,
    0, () => CreatePartnerAppRequest$, () => CreatePartnerAppResponse$
];
export var CreatePartnerAppPresignedUrl$ = [9, n0, _CPAPU,
    0, () => CreatePartnerAppPresignedUrlRequest$, () => CreatePartnerAppPresignedUrlResponse$
];
export var CreatePipeline$ = [9, n0, _CPr,
    0, () => CreatePipelineRequest$, () => CreatePipelineResponse$
];
export var CreatePresignedDomainUrl$ = [9, n0, _CPDU,
    0, () => CreatePresignedDomainUrlRequest$, () => CreatePresignedDomainUrlResponse$
];
export var CreatePresignedMlflowAppUrl$ = [9, n0, _CPMAU,
    0, () => CreatePresignedMlflowAppUrlRequest$, () => CreatePresignedMlflowAppUrlResponse$
];
export var CreatePresignedMlflowTrackingServerUrl$ = [9, n0, _CPMTSU,
    0, () => CreatePresignedMlflowTrackingServerUrlRequest$, () => CreatePresignedMlflowTrackingServerUrlResponse$
];
export var CreatePresignedNotebookInstanceUrl$ = [9, n0, _CPNIU,
    0, () => CreatePresignedNotebookInstanceUrlInput$, () => CreatePresignedNotebookInstanceUrlOutput$
];
export var CreateProcessingJob$ = [9, n0, _CPJ,
    0, () => CreateProcessingJobRequest$, () => CreateProcessingJobResponse$
];
export var CreateProject$ = [9, n0, _CPre,
    0, () => CreateProjectInput$, () => CreateProjectOutput$
];
export var CreateSpace$ = [9, n0, _CSr,
    0, () => CreateSpaceRequest$, () => CreateSpaceResponse$
];
export var CreateStudioLifecycleConfig$ = [9, n0, _CSLC,
    0, () => CreateStudioLifecycleConfigRequest$, () => CreateStudioLifecycleConfigResponse$
];
export var CreateTrainingJob$ = [9, n0, _CTJ,
    0, () => CreateTrainingJobRequest$, () => CreateTrainingJobResponse$
];
export var CreateTrainingPlan$ = [9, n0, _CTPr,
    0, () => CreateTrainingPlanRequest$, () => CreateTrainingPlanResponse$
];
export var CreateTransformJob$ = [9, n0, _CTJr,
    0, () => CreateTransformJobRequest$, () => CreateTransformJobResponse$
];
export var CreateTrial$ = [9, n0, _CTr,
    0, () => CreateTrialRequest$, () => CreateTrialResponse$
];
export var CreateTrialComponent$ = [9, n0, _CTCr,
    0, () => CreateTrialComponentRequest$, () => CreateTrialComponentResponse$
];
export var CreateUserProfile$ = [9, n0, _CUP,
    0, () => CreateUserProfileRequest$, () => CreateUserProfileResponse$
];
export var CreateWorkforce$ = [9, n0, _CWr,
    0, () => CreateWorkforceRequest$, () => CreateWorkforceResponse$
];
export var CreateWorkteam$ = [9, n0, _CWre,
    0, () => CreateWorkteamRequest$, () => CreateWorkteamResponse$
];
export var DeleteAction$ = [9, n0, _DAel,
    0, () => DeleteActionRequest$, () => DeleteActionResponse$
];
export var DeleteAlgorithm$ = [9, n0, _DAele,
    0, () => DeleteAlgorithmInput$, () => __Unit
];
export var DeleteApp$ = [9, n0, _DAelet,
    0, () => DeleteAppRequest$, () => __Unit
];
export var DeleteAppImageConfig$ = [9, n0, _DAIC,
    0, () => DeleteAppImageConfigRequest$, () => __Unit
];
export var DeleteArtifact$ = [9, n0, _DAelete,
    0, () => DeleteArtifactRequest$, () => DeleteArtifactResponse$
];
export var DeleteAssociation$ = [9, n0, _DAeletes,
    0, () => DeleteAssociationRequest$, () => DeleteAssociationResponse$
];
export var DeleteCluster$ = [9, n0, _DCel,
    0, () => DeleteClusterRequest$, () => DeleteClusterResponse$
];
export var DeleteClusterSchedulerConfig$ = [9, n0, _DCSC,
    0, () => DeleteClusterSchedulerConfigRequest$, () => __Unit
];
export var DeleteCodeRepository$ = [9, n0, _DCRelete,
    0, () => DeleteCodeRepositoryInput$, () => __Unit
];
export var DeleteCompilationJob$ = [9, n0, _DCJ,
    0, () => DeleteCompilationJobRequest$, () => __Unit
];
export var DeleteComputeQuota$ = [9, n0, _DCQ,
    0, () => DeleteComputeQuotaRequest$, () => __Unit
];
export var DeleteContext$ = [9, n0, _DCele,
    0, () => DeleteContextRequest$, () => DeleteContextResponse$
];
export var DeleteDataQualityJobDefinition$ = [9, n0, _DDQJD,
    0, () => DeleteDataQualityJobDefinitionRequest$, () => __Unit
];
export var DeleteDeviceFleet$ = [9, n0, _DDF,
    0, () => DeleteDeviceFleetRequest$, () => __Unit
];
export var DeleteDomain$ = [9, n0, _DDe,
    0, () => DeleteDomainRequest$, () => __Unit
];
export var DeleteEdgeDeploymentPlan$ = [9, n0, _DEDP,
    0, () => DeleteEdgeDeploymentPlanRequest$, () => __Unit
];
export var DeleteEdgeDeploymentStage$ = [9, n0, _DEDS,
    0, () => DeleteEdgeDeploymentStageRequest$, () => __Unit
];
export var DeleteEndpoint$ = [9, n0, _DE,
    0, () => DeleteEndpointInput$, () => __Unit
];
export var DeleteEndpointConfig$ = [9, n0, _DEC,
    0, () => DeleteEndpointConfigInput$, () => __Unit
];
export var DeleteExperiment$ = [9, n0, _DEe,
    0, () => DeleteExperimentRequest$, () => DeleteExperimentResponse$
];
export var DeleteFeatureGroup$ = [9, n0, _DFG,
    0, () => DeleteFeatureGroupRequest$, () => __Unit
];
export var DeleteFlowDefinition$ = [9, n0, _DFD,
    0, () => DeleteFlowDefinitionRequest$, () => DeleteFlowDefinitionResponse$
];
export var DeleteHub$ = [9, n0, _DHe,
    0, () => DeleteHubRequest$, () => __Unit
];
export var DeleteHubContent$ = [9, n0, _DHCe,
    0, () => DeleteHubContentRequest$, () => __Unit
];
export var DeleteHubContentReference$ = [9, n0, _DHCRel,
    0, () => DeleteHubContentReferenceRequest$, () => __Unit
];
export var DeleteHumanTaskUi$ = [9, n0, _DHTU,
    0, () => DeleteHumanTaskUiRequest$, () => DeleteHumanTaskUiResponse$
];
export var DeleteHyperParameterTuningJob$ = [9, n0, _DHPTJ,
    0, () => DeleteHyperParameterTuningJobRequest$, () => __Unit
];
export var DeleteImage$ = [9, n0, _DIel,
    0, () => DeleteImageRequest$, () => DeleteImageResponse$
];
export var DeleteImageVersion$ = [9, n0, _DIV,
    0, () => DeleteImageVersionRequest$, () => DeleteImageVersionResponse$
];
export var DeleteInferenceComponent$ = [9, n0, _DICe,
    0, () => DeleteInferenceComponentInput$, () => __Unit
];
export var DeleteInferenceExperiment$ = [9, n0, _DIEe,
    0, () => DeleteInferenceExperimentRequest$, () => DeleteInferenceExperimentResponse$
];
export var DeleteMlflowApp$ = [9, n0, _DMA,
    0, () => DeleteMlflowAppRequest$, () => DeleteMlflowAppResponse$
];
export var DeleteMlflowTrackingServer$ = [9, n0, _DMTS,
    0, () => DeleteMlflowTrackingServerRequest$, () => DeleteMlflowTrackingServerResponse$
];
export var DeleteModel$ = [9, n0, _DMe,
    0, () => DeleteModelInput$, () => __Unit
];
export var DeleteModelBiasJobDefinition$ = [9, n0, _DMBJD,
    0, () => DeleteModelBiasJobDefinitionRequest$, () => __Unit
];
export var DeleteModelCard$ = [9, n0, _DMC,
    0, () => DeleteModelCardRequest$, () => __Unit
];
export var DeleteModelExplainabilityJobDefinition$ = [9, n0, _DMEJD,
    0, () => DeleteModelExplainabilityJobDefinitionRequest$, () => __Unit
];
export var DeleteModelPackage$ = [9, n0, _DMP,
    0, () => DeleteModelPackageInput$, () => __Unit
];
export var DeleteModelPackageGroup$ = [9, n0, _DMPG,
    0, () => DeleteModelPackageGroupInput$, () => __Unit
];
export var DeleteModelPackageGroupPolicy$ = [9, n0, _DMPGP,
    0, () => DeleteModelPackageGroupPolicyInput$, () => __Unit
];
export var DeleteModelQualityJobDefinition$ = [9, n0, _DMQJD,
    0, () => DeleteModelQualityJobDefinitionRequest$, () => __Unit
];
export var DeleteMonitoringSchedule$ = [9, n0, _DMS,
    0, () => DeleteMonitoringScheduleRequest$, () => __Unit
];
export var DeleteNotebookInstance$ = [9, n0, _DNI,
    0, () => DeleteNotebookInstanceInput$, () => __Unit
];
export var DeleteNotebookInstanceLifecycleConfig$ = [9, n0, _DNILC,
    0, () => DeleteNotebookInstanceLifecycleConfigInput$, () => __Unit
];
export var DeleteOptimizationJob$ = [9, n0, _DOJ,
    0, () => DeleteOptimizationJobRequest$, () => __Unit
];
export var DeletePartnerApp$ = [9, n0, _DPA,
    0, () => DeletePartnerAppRequest$, () => DeletePartnerAppResponse$
];
export var DeletePipeline$ = [9, n0, _DPel,
    0, () => DeletePipelineRequest$, () => DeletePipelineResponse$
];
export var DeleteProcessingJob$ = [9, n0, _DPJ,
    0, () => DeleteProcessingJobRequest$, () => __Unit
];
export var DeleteProject$ = [9, n0, _DPele,
    0, () => DeleteProjectInput$, () => __Unit
];
export var DeleteSpace$ = [9, n0, _DSel,
    0, () => DeleteSpaceRequest$, () => __Unit
];
export var DeleteStudioLifecycleConfig$ = [9, n0, _DSLC,
    0, () => DeleteStudioLifecycleConfigRequest$, () => __Unit
];
export var DeleteTags$ = [9, n0, _DTel,
    0, () => DeleteTagsInput$, () => DeleteTagsOutput$
];
export var DeleteTrainingJob$ = [9, n0, _DTJ,
    0, () => DeleteTrainingJobRequest$, () => __Unit
];
export var DeleteTrial$ = [9, n0, _DTele,
    0, () => DeleteTrialRequest$, () => DeleteTrialResponse$
];
export var DeleteTrialComponent$ = [9, n0, _DTC,
    0, () => DeleteTrialComponentRequest$, () => DeleteTrialComponentResponse$
];
export var DeleteUserProfile$ = [9, n0, _DUP,
    0, () => DeleteUserProfileRequest$, () => __Unit
];
export var DeleteWorkforce$ = [9, n0, _DWe,
    0, () => DeleteWorkforceRequest$, () => DeleteWorkforceResponse$
];
export var DeleteWorkteam$ = [9, n0, _DWel,
    0, () => DeleteWorkteamRequest$, () => DeleteWorkteamResponse$
];
export var DeregisterDevices$ = [9, n0, _DDer,
    0, () => DeregisterDevicesRequest$, () => __Unit
];
export var DescribeAction$ = [9, n0, _DAes,
    0, () => DescribeActionRequest$, () => DescribeActionResponse$
];
export var DescribeAlgorithm$ = [9, n0, _DAesc,
    0, () => DescribeAlgorithmInput$, () => DescribeAlgorithmOutput$
];
export var DescribeApp$ = [9, n0, _DAescr,
    0, () => DescribeAppRequest$, () => DescribeAppResponse$
];
export var DescribeAppImageConfig$ = [9, n0, _DAICe,
    0, () => DescribeAppImageConfigRequest$, () => DescribeAppImageConfigResponse$
];
export var DescribeArtifact$ = [9, n0, _DAescri,
    0, () => DescribeArtifactRequest$, () => DescribeArtifactResponse$
];
export var DescribeAutoMLJob$ = [9, n0, _DAMLJ,
    0, () => DescribeAutoMLJobRequest$, () => DescribeAutoMLJobResponse$
];
export var DescribeAutoMLJobV2$ = [9, n0, _DAMLJV,
    0, () => DescribeAutoMLJobV2Request$, () => DescribeAutoMLJobV2Response$
];
export var DescribeCluster$ = [9, n0, _DCes,
    0, () => DescribeClusterRequest$, () => DescribeClusterResponse$
];
export var DescribeClusterEvent$ = [9, n0, _DCEe,
    0, () => DescribeClusterEventRequest$, () => DescribeClusterEventResponse$
];
export var DescribeClusterNode$ = [9, n0, _DCN,
    0, () => DescribeClusterNodeRequest$, () => DescribeClusterNodeResponse$
];
export var DescribeClusterSchedulerConfig$ = [9, n0, _DCSCe,
    0, () => DescribeClusterSchedulerConfigRequest$, () => DescribeClusterSchedulerConfigResponse$
];
export var DescribeCodeRepository$ = [9, n0, _DCRescrib,
    0, () => DescribeCodeRepositoryInput$, () => DescribeCodeRepositoryOutput$
];
export var DescribeCompilationJob$ = [9, n0, _DCJe,
    0, () => DescribeCompilationJobRequest$, () => DescribeCompilationJobResponse$
];
export var DescribeComputeQuota$ = [9, n0, _DCQe,
    0, () => DescribeComputeQuotaRequest$, () => DescribeComputeQuotaResponse$
];
export var DescribeContext$ = [9, n0, _DCesc,
    0, () => DescribeContextRequest$, () => DescribeContextResponse$
];
export var DescribeDataQualityJobDefinition$ = [9, n0, _DDQJDe,
    0, () => DescribeDataQualityJobDefinitionRequest$, () => DescribeDataQualityJobDefinitionResponse$
];
export var DescribeDevice$ = [9, n0, _DDes,
    0, () => DescribeDeviceRequest$, () => DescribeDeviceResponse$
];
export var DescribeDeviceFleet$ = [9, n0, _DDFe,
    0, () => DescribeDeviceFleetRequest$, () => DescribeDeviceFleetResponse$
];
export var DescribeDomain$ = [9, n0, _DDesc,
    0, () => DescribeDomainRequest$, () => DescribeDomainResponse$
];
export var DescribeEdgeDeploymentPlan$ = [9, n0, _DEDPe,
    0, () => DescribeEdgeDeploymentPlanRequest$, () => DescribeEdgeDeploymentPlanResponse$
];
export var DescribeEdgePackagingJob$ = [9, n0, _DEPJ,
    0, () => DescribeEdgePackagingJobRequest$, () => DescribeEdgePackagingJobResponse$
];
export var DescribeEndpoint$ = [9, n0, _DEes,
    0, () => DescribeEndpointInput$, () => DescribeEndpointOutput$
];
export var DescribeEndpointConfig$ = [9, n0, _DECe,
    0, () => DescribeEndpointConfigInput$, () => DescribeEndpointConfigOutput$
];
export var DescribeExperiment$ = [9, n0, _DEesc,
    0, () => DescribeExperimentRequest$, () => DescribeExperimentResponse$
];
export var DescribeFeatureGroup$ = [9, n0, _DFGe,
    0, () => DescribeFeatureGroupRequest$, () => DescribeFeatureGroupResponse$
];
export var DescribeFeatureMetadata$ = [9, n0, _DFM,
    0, () => DescribeFeatureMetadataRequest$, () => DescribeFeatureMetadataResponse$
];
export var DescribeFlowDefinition$ = [9, n0, _DFDe,
    0, () => DescribeFlowDefinitionRequest$, () => DescribeFlowDefinitionResponse$
];
export var DescribeHub$ = [9, n0, _DHes,
    0, () => DescribeHubRequest$, () => DescribeHubResponse$
];
export var DescribeHubContent$ = [9, n0, _DHCes,
    0, () => DescribeHubContentRequest$, () => DescribeHubContentResponse$
];
export var DescribeHumanTaskUi$ = [9, n0, _DHTUe,
    0, () => DescribeHumanTaskUiRequest$, () => DescribeHumanTaskUiResponse$
];
export var DescribeHyperParameterTuningJob$ = [9, n0, _DHPTJe,
    0, () => DescribeHyperParameterTuningJobRequest$, () => DescribeHyperParameterTuningJobResponse$
];
export var DescribeImage$ = [9, n0, _DIes,
    0, () => DescribeImageRequest$, () => DescribeImageResponse$
];
export var DescribeImageVersion$ = [9, n0, _DIVe,
    0, () => DescribeImageVersionRequest$, () => DescribeImageVersionResponse$
];
export var DescribeInferenceComponent$ = [9, n0, _DICes,
    0, () => DescribeInferenceComponentInput$, () => DescribeInferenceComponentOutput$
];
export var DescribeInferenceExperiment$ = [9, n0, _DIEes,
    0, () => DescribeInferenceExperimentRequest$, () => DescribeInferenceExperimentResponse$
];
export var DescribeInferenceRecommendationsJob$ = [9, n0, _DIRJ,
    0, () => DescribeInferenceRecommendationsJobRequest$, () => DescribeInferenceRecommendationsJobResponse$
];
export var DescribeLabelingJob$ = [9, n0, _DLJ,
    0, () => DescribeLabelingJobRequest$, () => DescribeLabelingJobResponse$
];
export var DescribeLineageGroup$ = [9, n0, _DLG,
    0, () => DescribeLineageGroupRequest$, () => DescribeLineageGroupResponse$
];
export var DescribeMlflowApp$ = [9, n0, _DMAe,
    0, () => DescribeMlflowAppRequest$, () => DescribeMlflowAppResponse$
];
export var DescribeMlflowTrackingServer$ = [9, n0, _DMTSe,
    0, () => DescribeMlflowTrackingServerRequest$, () => DescribeMlflowTrackingServerResponse$
];
export var DescribeModel$ = [9, n0, _DMes,
    0, () => DescribeModelInput$, () => DescribeModelOutput$
];
export var DescribeModelBiasJobDefinition$ = [9, n0, _DMBJDe,
    0, () => DescribeModelBiasJobDefinitionRequest$, () => DescribeModelBiasJobDefinitionResponse$
];
export var DescribeModelCard$ = [9, n0, _DMCe,
    0, () => DescribeModelCardRequest$, () => DescribeModelCardResponse$
];
export var DescribeModelCardExportJob$ = [9, n0, _DMCEJ,
    0, () => DescribeModelCardExportJobRequest$, () => DescribeModelCardExportJobResponse$
];
export var DescribeModelExplainabilityJobDefinition$ = [9, n0, _DMEJDe,
    0, () => DescribeModelExplainabilityJobDefinitionRequest$, () => DescribeModelExplainabilityJobDefinitionResponse$
];
export var DescribeModelPackage$ = [9, n0, _DMPe,
    0, () => DescribeModelPackageInput$, () => DescribeModelPackageOutput$
];
export var DescribeModelPackageGroup$ = [9, n0, _DMPGe,
    0, () => DescribeModelPackageGroupInput$, () => DescribeModelPackageGroupOutput$
];
export var DescribeModelQualityJobDefinition$ = [9, n0, _DMQJDe,
    0, () => DescribeModelQualityJobDefinitionRequest$, () => DescribeModelQualityJobDefinitionResponse$
];
export var DescribeMonitoringSchedule$ = [9, n0, _DMSe,
    0, () => DescribeMonitoringScheduleRequest$, () => DescribeMonitoringScheduleResponse$
];
export var DescribeNotebookInstance$ = [9, n0, _DNIe,
    0, () => DescribeNotebookInstanceInput$, () => DescribeNotebookInstanceOutput$
];
export var DescribeNotebookInstanceLifecycleConfig$ = [9, n0, _DNILCe,
    0, () => DescribeNotebookInstanceLifecycleConfigInput$, () => DescribeNotebookInstanceLifecycleConfigOutput$
];
export var DescribeOptimizationJob$ = [9, n0, _DOJe,
    0, () => DescribeOptimizationJobRequest$, () => DescribeOptimizationJobResponse$
];
export var DescribePartnerApp$ = [9, n0, _DPAe,
    0, () => DescribePartnerAppRequest$, () => DescribePartnerAppResponse$
];
export var DescribePipeline$ = [9, n0, _DPes,
    0, () => DescribePipelineRequest$, () => DescribePipelineResponse$
];
export var DescribePipelineDefinitionForExecution$ = [9, n0, _DPDFE,
    0, () => DescribePipelineDefinitionForExecutionRequest$, () => DescribePipelineDefinitionForExecutionResponse$
];
export var DescribePipelineExecution$ = [9, n0, _DPE,
    0, () => DescribePipelineExecutionRequest$, () => DescribePipelineExecutionResponse$
];
export var DescribeProcessingJob$ = [9, n0, _DPJe,
    0, () => DescribeProcessingJobRequest$, () => DescribeProcessingJobResponse$
];
export var DescribeProject$ = [9, n0, _DPesc,
    0, () => DescribeProjectInput$, () => DescribeProjectOutput$
];
export var DescribeReservedCapacity$ = [9, n0, _DRCesc,
    0, () => DescribeReservedCapacityRequest$, () => DescribeReservedCapacityResponse$
];
export var DescribeSpace$ = [9, n0, _DSesc,
    0, () => DescribeSpaceRequest$, () => DescribeSpaceResponse$
];
export var DescribeStudioLifecycleConfig$ = [9, n0, _DSLCe,
    0, () => DescribeStudioLifecycleConfigRequest$, () => DescribeStudioLifecycleConfigResponse$
];
export var DescribeSubscribedWorkteam$ = [9, n0, _DSW,
    0, () => DescribeSubscribedWorkteamRequest$, () => DescribeSubscribedWorkteamResponse$
];
export var DescribeTrainingJob$ = [9, n0, _DTJe,
    0, () => DescribeTrainingJobRequest$, () => DescribeTrainingJobResponse$
];
export var DescribeTrainingPlan$ = [9, n0, _DTP,
    0, () => DescribeTrainingPlanRequest$, () => DescribeTrainingPlanResponse$
];
export var DescribeTransformJob$ = [9, n0, _DTJes,
    0, () => DescribeTransformJobRequest$, () => DescribeTransformJobResponse$
];
export var DescribeTrial$ = [9, n0, _DTes,
    0, () => DescribeTrialRequest$, () => DescribeTrialResponse$
];
export var DescribeTrialComponent$ = [9, n0, _DTCe,
    0, () => DescribeTrialComponentRequest$, () => DescribeTrialComponentResponse$
];
export var DescribeUserProfile$ = [9, n0, _DUPe,
    0, () => DescribeUserProfileRequest$, () => DescribeUserProfileResponse$
];
export var DescribeWorkforce$ = [9, n0, _DWes,
    0, () => DescribeWorkforceRequest$, () => DescribeWorkforceResponse$
];
export var DescribeWorkteam$ = [9, n0, _DWesc,
    0, () => DescribeWorkteamRequest$, () => DescribeWorkteamResponse$
];
export var DetachClusterNodeVolume$ = [9, n0, _DCNV,
    0, () => DetachClusterNodeVolumeRequest$, () => DetachClusterNodeVolumeResponse$
];
export var DisableSagemakerServicecatalogPortfolio$ = [9, n0, _DSSP,
    0, () => DisableSagemakerServicecatalogPortfolioInput$, () => DisableSagemakerServicecatalogPortfolioOutput$
];
export var DisassociateTrialComponent$ = [9, n0, _DTCi,
    0, () => DisassociateTrialComponentRequest$, () => DisassociateTrialComponentResponse$
];
export var EnableSagemakerServicecatalogPortfolio$ = [9, n0, _ESSP,
    0, () => EnableSagemakerServicecatalogPortfolioInput$, () => EnableSagemakerServicecatalogPortfolioOutput$
];
export var GetDeviceFleetReport$ = [9, n0, _GDFR,
    0, () => GetDeviceFleetReportRequest$, () => GetDeviceFleetReportResponse$
];
export var GetLineageGroupPolicy$ = [9, n0, _GLGP,
    0, () => GetLineageGroupPolicyRequest$, () => GetLineageGroupPolicyResponse$
];
export var GetModelPackageGroupPolicy$ = [9, n0, _GMPGP,
    0, () => GetModelPackageGroupPolicyInput$, () => GetModelPackageGroupPolicyOutput$
];
export var GetSagemakerServicecatalogPortfolioStatus$ = [9, n0, _GSSPS,
    0, () => GetSagemakerServicecatalogPortfolioStatusInput$, () => GetSagemakerServicecatalogPortfolioStatusOutput$
];
export var GetScalingConfigurationRecommendation$ = [9, n0, _GSCR,
    0, () => GetScalingConfigurationRecommendationRequest$, () => GetScalingConfigurationRecommendationResponse$
];
export var GetSearchSuggestions$ = [9, n0, _GSS,
    0, () => GetSearchSuggestionsRequest$, () => GetSearchSuggestionsResponse$
];
export var ImportHubContent$ = [9, n0, _IHC,
    0, () => ImportHubContentRequest$, () => ImportHubContentResponse$
];
export var ListActions$ = [9, n0, _LAi,
    0, () => ListActionsRequest$, () => ListActionsResponse$
];
export var ListAlgorithms$ = [9, n0, _LAis,
    0, () => ListAlgorithmsInput$, () => ListAlgorithmsOutput$
];
export var ListAliases$ = [9, n0, _LAist,
    0, () => ListAliasesRequest$, () => ListAliasesResponse$
];
export var ListAppImageConfigs$ = [9, n0, _LAIC,
    0, () => ListAppImageConfigsRequest$, () => ListAppImageConfigsResponse$
];
export var ListApps$ = [9, n0, _LAistp,
    0, () => ListAppsRequest$, () => ListAppsResponse$
];
export var ListArtifacts$ = [9, n0, _LAistr,
    0, () => ListArtifactsRequest$, () => ListArtifactsResponse$
];
export var ListAssociations$ = [9, n0, _LAists,
    0, () => ListAssociationsRequest$, () => ListAssociationsResponse$
];
export var ListAutoMLJobs$ = [9, n0, _LAMLJ,
    0, () => ListAutoMLJobsRequest$, () => ListAutoMLJobsResponse$
];
export var ListCandidatesForAutoMLJob$ = [9, n0, _LCFAMLJ,
    0, () => ListCandidatesForAutoMLJobRequest$, () => ListCandidatesForAutoMLJobResponse$
];
export var ListClusterEvents$ = [9, n0, _LCE,
    0, () => ListClusterEventsRequest$, () => ListClusterEventsResponse$
];
export var ListClusterNodes$ = [9, n0, _LCNi,
    0, () => ListClusterNodesRequest$, () => ListClusterNodesResponse$
];
export var ListClusters$ = [9, n0, _LCi,
    0, () => ListClustersRequest$, () => ListClustersResponse$
];
export var ListClusterSchedulerConfigs$ = [9, n0, _LCSC,
    0, () => ListClusterSchedulerConfigsRequest$, () => ListClusterSchedulerConfigsResponse$
];
export var ListCodeRepositories$ = [9, n0, _LCRisto,
    0, () => ListCodeRepositoriesInput$, () => ListCodeRepositoriesOutput$
];
export var ListCompilationJobs$ = [9, n0, _LCJ,
    0, () => ListCompilationJobsRequest$, () => ListCompilationJobsResponse$
];
export var ListComputeQuotas$ = [9, n0, _LCQ,
    0, () => ListComputeQuotasRequest$, () => ListComputeQuotasResponse$
];
export var ListContexts$ = [9, n0, _LCis,
    0, () => ListContextsRequest$, () => ListContextsResponse$
];
export var ListDataQualityJobDefinitions$ = [9, n0, _LDQJD,
    0, () => ListDataQualityJobDefinitionsRequest$, () => ListDataQualityJobDefinitionsResponse$
];
export var ListDeviceFleets$ = [9, n0, _LDF,
    0, () => ListDeviceFleetsRequest$, () => ListDeviceFleetsResponse$
];
export var ListDevices$ = [9, n0, _LD,
    0, () => ListDevicesRequest$, () => ListDevicesResponse$
];
export var ListDomains$ = [9, n0, _LDi,
    0, () => ListDomainsRequest$, () => ListDomainsResponse$
];
export var ListEdgeDeploymentPlans$ = [9, n0, _LEDP,
    0, () => ListEdgeDeploymentPlansRequest$, () => ListEdgeDeploymentPlansResponse$
];
export var ListEdgePackagingJobs$ = [9, n0, _LEPJ,
    0, () => ListEdgePackagingJobsRequest$, () => ListEdgePackagingJobsResponse$
];
export var ListEndpointConfigs$ = [9, n0, _LEC,
    0, () => ListEndpointConfigsInput$, () => ListEndpointConfigsOutput$
];
export var ListEndpoints$ = [9, n0, _LEi,
    0, () => ListEndpointsInput$, () => ListEndpointsOutput$
];
export var ListExperiments$ = [9, n0, _LEis,
    0, () => ListExperimentsRequest$, () => ListExperimentsResponse$
];
export var ListFeatureGroups$ = [9, n0, _LFG,
    0, () => ListFeatureGroupsRequest$, () => ListFeatureGroupsResponse$
];
export var ListFlowDefinitions$ = [9, n0, _LFD,
    0, () => ListFlowDefinitionsRequest$, () => ListFlowDefinitionsResponse$
];
export var ListHubContents$ = [9, n0, _LHC,
    0, () => ListHubContentsRequest$, () => ListHubContentsResponse$
];
export var ListHubContentVersions$ = [9, n0, _LHCV,
    0, () => ListHubContentVersionsRequest$, () => ListHubContentVersionsResponse$
];
export var ListHubs$ = [9, n0, _LHi,
    0, () => ListHubsRequest$, () => ListHubsResponse$
];
export var ListHumanTaskUis$ = [9, n0, _LHTU,
    0, () => ListHumanTaskUisRequest$, () => ListHumanTaskUisResponse$
];
export var ListHyperParameterTuningJobs$ = [9, n0, _LHPTJ,
    0, () => ListHyperParameterTuningJobsRequest$, () => ListHyperParameterTuningJobsResponse$
];
export var ListImages$ = [9, n0, _LIis,
    0, () => ListImagesRequest$, () => ListImagesResponse$
];
export var ListImageVersions$ = [9, n0, _LIV,
    0, () => ListImageVersionsRequest$, () => ListImageVersionsResponse$
];
export var ListInferenceComponents$ = [9, n0, _LIC,
    0, () => ListInferenceComponentsInput$, () => ListInferenceComponentsOutput$
];
export var ListInferenceExperiments$ = [9, n0, _LIE,
    0, () => ListInferenceExperimentsRequest$, () => ListInferenceExperimentsResponse$
];
export var ListInferenceRecommendationsJobs$ = [9, n0, _LIRJ,
    0, () => ListInferenceRecommendationsJobsRequest$, () => ListInferenceRecommendationsJobsResponse$
];
export var ListInferenceRecommendationsJobSteps$ = [9, n0, _LIRJS,
    0, () => ListInferenceRecommendationsJobStepsRequest$, () => ListInferenceRecommendationsJobStepsResponse$
];
export var ListLabelingJobs$ = [9, n0, _LLJ,
    0, () => ListLabelingJobsRequest$, () => ListLabelingJobsResponse$
];
export var ListLabelingJobsForWorkteam$ = [9, n0, _LLJFW,
    0, () => ListLabelingJobsForWorkteamRequest$, () => ListLabelingJobsForWorkteamResponse$
];
export var ListLineageGroups$ = [9, n0, _LLG,
    0, () => ListLineageGroupsRequest$, () => ListLineageGroupsResponse$
];
export var ListMlflowApps$ = [9, n0, _LMAi,
    0, () => ListMlflowAppsRequest$, () => ListMlflowAppsResponse$
];
export var ListMlflowTrackingServers$ = [9, n0, _LMTS,
    0, () => ListMlflowTrackingServersRequest$, () => ListMlflowTrackingServersResponse$
];
export var ListModelBiasJobDefinitions$ = [9, n0, _LMBJD,
    0, () => ListModelBiasJobDefinitionsRequest$, () => ListModelBiasJobDefinitionsResponse$
];
export var ListModelCardExportJobs$ = [9, n0, _LMCEJ,
    0, () => ListModelCardExportJobsRequest$, () => ListModelCardExportJobsResponse$
];
export var ListModelCards$ = [9, n0, _LMC,
    0, () => ListModelCardsRequest$, () => ListModelCardsResponse$
];
export var ListModelCardVersions$ = [9, n0, _LMCV,
    0, () => ListModelCardVersionsRequest$, () => ListModelCardVersionsResponse$
];
export var ListModelExplainabilityJobDefinitions$ = [9, n0, _LMEJD,
    0, () => ListModelExplainabilityJobDefinitionsRequest$, () => ListModelExplainabilityJobDefinitionsResponse$
];
export var ListModelMetadata$ = [9, n0, _LMM,
    0, () => ListModelMetadataRequest$, () => ListModelMetadataResponse$
];
export var ListModelPackageGroups$ = [9, n0, _LMPG,
    0, () => ListModelPackageGroupsInput$, () => ListModelPackageGroupsOutput$
];
export var ListModelPackages$ = [9, n0, _LMP,
    0, () => ListModelPackagesInput$, () => ListModelPackagesOutput$
];
export var ListModelQualityJobDefinitions$ = [9, n0, _LMQJD,
    0, () => ListModelQualityJobDefinitionsRequest$, () => ListModelQualityJobDefinitionsResponse$
];
export var ListModels$ = [9, n0, _LMis,
    0, () => ListModelsInput$, () => ListModelsOutput$
];
export var ListMonitoringAlertHistory$ = [9, n0, _LMAH,
    0, () => ListMonitoringAlertHistoryRequest$, () => ListMonitoringAlertHistoryResponse$
];
export var ListMonitoringAlerts$ = [9, n0, _LMAis,
    0, () => ListMonitoringAlertsRequest$, () => ListMonitoringAlertsResponse$
];
export var ListMonitoringExecutions$ = [9, n0, _LME,
    0, () => ListMonitoringExecutionsRequest$, () => ListMonitoringExecutionsResponse$
];
export var ListMonitoringSchedules$ = [9, n0, _LMS,
    0, () => ListMonitoringSchedulesRequest$, () => ListMonitoringSchedulesResponse$
];
export var ListNotebookInstanceLifecycleConfigs$ = [9, n0, _LNILC,
    0, () => ListNotebookInstanceLifecycleConfigsInput$, () => ListNotebookInstanceLifecycleConfigsOutput$
];
export var ListNotebookInstances$ = [9, n0, _LNI,
    0, () => ListNotebookInstancesInput$, () => ListNotebookInstancesOutput$
];
export var ListOptimizationJobs$ = [9, n0, _LOJ,
    0, () => ListOptimizationJobsRequest$, () => ListOptimizationJobsResponse$
];
export var ListPartnerApps$ = [9, n0, _LPA,
    0, () => ListPartnerAppsRequest$, () => ListPartnerAppsResponse$
];
export var ListPipelineExecutions$ = [9, n0, _LPE,
    0, () => ListPipelineExecutionsRequest$, () => ListPipelineExecutionsResponse$
];
export var ListPipelineExecutionSteps$ = [9, n0, _LPES,
    0, () => ListPipelineExecutionStepsRequest$, () => ListPipelineExecutionStepsResponse$
];
export var ListPipelineParametersForExecution$ = [9, n0, _LPPFE,
    0, () => ListPipelineParametersForExecutionRequest$, () => ListPipelineParametersForExecutionResponse$
];
export var ListPipelines$ = [9, n0, _LPi,
    0, () => ListPipelinesRequest$, () => ListPipelinesResponse$
];
export var ListPipelineVersions$ = [9, n0, _LPV,
    0, () => ListPipelineVersionsRequest$, () => ListPipelineVersionsResponse$
];
export var ListProcessingJobs$ = [9, n0, _LPJ,
    0, () => ListProcessingJobsRequest$, () => ListProcessingJobsResponse$
];
export var ListProjects$ = [9, n0, _LPis,
    0, () => ListProjectsInput$, () => ListProjectsOutput$
];
export var ListResourceCatalogs$ = [9, n0, _LRC,
    0, () => ListResourceCatalogsRequest$, () => ListResourceCatalogsResponse$
];
export var ListSpaces$ = [9, n0, _LS,
    0, () => ListSpacesRequest$, () => ListSpacesResponse$
];
export var ListStageDevices$ = [9, n0, _LSD,
    0, () => ListStageDevicesRequest$, () => ListStageDevicesResponse$
];
export var ListStudioLifecycleConfigs$ = [9, n0, _LSLC,
    0, () => ListStudioLifecycleConfigsRequest$, () => ListStudioLifecycleConfigsResponse$
];
export var ListSubscribedWorkteams$ = [9, n0, _LSW,
    0, () => ListSubscribedWorkteamsRequest$, () => ListSubscribedWorkteamsResponse$
];
export var ListTags$ = [9, n0, _LTis,
    0, () => ListTagsInput$, () => ListTagsOutput$
];
export var ListTrainingJobs$ = [9, n0, _LTJ,
    0, () => ListTrainingJobsRequest$, () => ListTrainingJobsResponse$
];
export var ListTrainingJobsForHyperParameterTuningJob$ = [9, n0, _LTJFHPTJ,
    0, () => ListTrainingJobsForHyperParameterTuningJobRequest$, () => ListTrainingJobsForHyperParameterTuningJobResponse$
];
export var ListTrainingPlans$ = [9, n0, _LTP,
    0, () => ListTrainingPlansRequest$, () => ListTrainingPlansResponse$
];
export var ListTransformJobs$ = [9, n0, _LTJi,
    0, () => ListTransformJobsRequest$, () => ListTransformJobsResponse$
];
export var ListTrialComponents$ = [9, n0, _LTC,
    0, () => ListTrialComponentsRequest$, () => ListTrialComponentsResponse$
];
export var ListTrials$ = [9, n0, _LTist,
    0, () => ListTrialsRequest$, () => ListTrialsResponse$
];
export var ListUltraServersByReservedCapacity$ = [9, n0, _LUSBRC,
    0, () => ListUltraServersByReservedCapacityRequest$, () => ListUltraServersByReservedCapacityResponse$
];
export var ListUserProfiles$ = [9, n0, _LUP,
    0, () => ListUserProfilesRequest$, () => ListUserProfilesResponse$
];
export var ListWorkforces$ = [9, n0, _LW,
    0, () => ListWorkforcesRequest$, () => ListWorkforcesResponse$
];
export var ListWorkteams$ = [9, n0, _LWi,
    0, () => ListWorkteamsRequest$, () => ListWorkteamsResponse$
];
export var PutModelPackageGroupPolicy$ = [9, n0, _PMPGP,
    0, () => PutModelPackageGroupPolicyInput$, () => PutModelPackageGroupPolicyOutput$
];
export var QueryLineage$ = [9, n0, _QL,
    0, () => QueryLineageRequest$, () => QueryLineageResponse$
];
export var RegisterDevices$ = [9, n0, _RDe,
    0, () => RegisterDevicesRequest$, () => __Unit
];
export var RenderUiTemplate$ = [9, n0, _RUT,
    0, () => RenderUiTemplateRequest$, () => RenderUiTemplateResponse$
];
export var RetryPipelineExecution$ = [9, n0, _RPE,
    0, () => RetryPipelineExecutionRequest$, () => RetryPipelineExecutionResponse$
];
export var Search$ = [9, n0, _Sea,
    0, () => SearchRequest$, () => SearchResponse$
];
export var SearchTrainingPlanOfferings$ = [9, n0, _STPO,
    0, () => SearchTrainingPlanOfferingsRequest$, () => SearchTrainingPlanOfferingsResponse$
];
export var SendPipelineExecutionStepFailure$ = [9, n0, _SPESF,
    0, () => SendPipelineExecutionStepFailureRequest$, () => SendPipelineExecutionStepFailureResponse$
];
export var SendPipelineExecutionStepSuccess$ = [9, n0, _SPESS,
    0, () => SendPipelineExecutionStepSuccessRequest$, () => SendPipelineExecutionStepSuccessResponse$
];
export var StartEdgeDeploymentStage$ = [9, n0, _SEDS,
    0, () => StartEdgeDeploymentStageRequest$, () => __Unit
];
export var StartInferenceExperiment$ = [9, n0, _SIE,
    0, () => StartInferenceExperimentRequest$, () => StartInferenceExperimentResponse$
];
export var StartMlflowTrackingServer$ = [9, n0, _SMTS,
    0, () => StartMlflowTrackingServerRequest$, () => StartMlflowTrackingServerResponse$
];
export var StartMonitoringSchedule$ = [9, n0, _SMS,
    0, () => StartMonitoringScheduleRequest$, () => __Unit
];
export var StartNotebookInstance$ = [9, n0, _SNI,
    0, () => StartNotebookInstanceInput$, () => __Unit
];
export var StartPipelineExecution$ = [9, n0, _SPE,
    0, () => StartPipelineExecutionRequest$, () => StartPipelineExecutionResponse$
];
export var StartSession$ = [9, n0, _SSta,
    0, () => StartSessionRequest$, () => StartSessionResponse$
];
export var StopAutoMLJob$ = [9, n0, _SAMLJ,
    0, () => StopAutoMLJobRequest$, () => __Unit
];
export var StopCompilationJob$ = [9, n0, _SCJ,
    0, () => StopCompilationJobRequest$, () => __Unit
];
export var StopEdgeDeploymentStage$ = [9, n0, _SEDSt,
    0, () => StopEdgeDeploymentStageRequest$, () => __Unit
];
export var StopEdgePackagingJob$ = [9, n0, _SEPJ,
    0, () => StopEdgePackagingJobRequest$, () => __Unit
];
export var StopHyperParameterTuningJob$ = [9, n0, _SHPTJ,
    0, () => StopHyperParameterTuningJobRequest$, () => __Unit
];
export var StopInferenceExperiment$ = [9, n0, _SIEt,
    0, () => StopInferenceExperimentRequest$, () => StopInferenceExperimentResponse$
];
export var StopInferenceRecommendationsJob$ = [9, n0, _SIRJ,
    0, () => StopInferenceRecommendationsJobRequest$, () => __Unit
];
export var StopLabelingJob$ = [9, n0, _SLJ,
    0, () => StopLabelingJobRequest$, () => __Unit
];
export var StopMlflowTrackingServer$ = [9, n0, _SMTSt,
    0, () => StopMlflowTrackingServerRequest$, () => StopMlflowTrackingServerResponse$
];
export var StopMonitoringSchedule$ = [9, n0, _SMSt,
    0, () => StopMonitoringScheduleRequest$, () => __Unit
];
export var StopNotebookInstance$ = [9, n0, _SNIt,
    0, () => StopNotebookInstanceInput$, () => __Unit
];
export var StopOptimizationJob$ = [9, n0, _SOJ,
    0, () => StopOptimizationJobRequest$, () => __Unit
];
export var StopPipelineExecution$ = [9, n0, _SPEt,
    0, () => StopPipelineExecutionRequest$, () => StopPipelineExecutionResponse$
];
export var StopProcessingJob$ = [9, n0, _SPJ,
    0, () => StopProcessingJobRequest$, () => __Unit
];
export var StopTrainingJob$ = [9, n0, _STJ,
    0, () => StopTrainingJobRequest$, () => __Unit
];
export var StopTransformJob$ = [9, n0, _STJt,
    0, () => StopTransformJobRequest$, () => __Unit
];
export var UpdateAction$ = [9, n0, _UA,
    0, () => UpdateActionRequest$, () => UpdateActionResponse$
];
export var UpdateAppImageConfig$ = [9, n0, _UAIC,
    0, () => UpdateAppImageConfigRequest$, () => UpdateAppImageConfigResponse$
];
export var UpdateArtifact$ = [9, n0, _UAp,
    0, () => UpdateArtifactRequest$, () => UpdateArtifactResponse$
];
export var UpdateCluster$ = [9, n0, _UCp,
    0, () => UpdateClusterRequest$, () => UpdateClusterResponse$
];
export var UpdateClusterSchedulerConfig$ = [9, n0, _UCSC,
    0, () => UpdateClusterSchedulerConfigRequest$, () => UpdateClusterSchedulerConfigResponse$
];
export var UpdateClusterSoftware$ = [9, n0, _UCS,
    0, () => UpdateClusterSoftwareRequest$, () => UpdateClusterSoftwareResponse$
];
export var UpdateCodeRepository$ = [9, n0, _UCRpdat,
    0, () => UpdateCodeRepositoryInput$, () => UpdateCodeRepositoryOutput$
];
export var UpdateComputeQuota$ = [9, n0, _UCQ,
    0, () => UpdateComputeQuotaRequest$, () => UpdateComputeQuotaResponse$
];
export var UpdateContext$ = [9, n0, _UCpd,
    0, () => UpdateContextRequest$, () => UpdateContextResponse$
];
export var UpdateDeviceFleet$ = [9, n0, _UDF,
    0, () => UpdateDeviceFleetRequest$, () => __Unit
];
export var UpdateDevices$ = [9, n0, _UD,
    0, () => UpdateDevicesRequest$, () => __Unit
];
export var UpdateDomain$ = [9, n0, _UDp,
    0, () => UpdateDomainRequest$, () => UpdateDomainResponse$
];
export var UpdateEndpoint$ = [9, n0, _UE,
    0, () => UpdateEndpointInput$, () => UpdateEndpointOutput$
];
export var UpdateEndpointWeightsAndCapacities$ = [9, n0, _UEWAC,
    0, () => UpdateEndpointWeightsAndCapacitiesInput$, () => UpdateEndpointWeightsAndCapacitiesOutput$
];
export var UpdateExperiment$ = [9, n0, _UEp,
    0, () => UpdateExperimentRequest$, () => UpdateExperimentResponse$
];
export var UpdateFeatureGroup$ = [9, n0, _UFG,
    0, () => UpdateFeatureGroupRequest$, () => UpdateFeatureGroupResponse$
];
export var UpdateFeatureMetadata$ = [9, n0, _UFM,
    0, () => UpdateFeatureMetadataRequest$, () => __Unit
];
export var UpdateHub$ = [9, n0, _UH,
    0, () => UpdateHubRequest$, () => UpdateHubResponse$
];
export var UpdateHubContent$ = [9, n0, _UHC,
    0, () => UpdateHubContentRequest$, () => UpdateHubContentResponse$
];
export var UpdateHubContentReference$ = [9, n0, _UHCRpd,
    0, () => UpdateHubContentReferenceRequest$, () => UpdateHubContentReferenceResponse$
];
export var UpdateImage$ = [9, n0, _UI,
    0, () => UpdateImageRequest$, () => UpdateImageResponse$
];
export var UpdateImageVersion$ = [9, n0, _UIV,
    0, () => UpdateImageVersionRequest$, () => UpdateImageVersionResponse$
];
export var UpdateInferenceComponent$ = [9, n0, _UICp,
    0, () => UpdateInferenceComponentInput$, () => UpdateInferenceComponentOutput$
];
export var UpdateInferenceComponentRuntimeConfig$ = [9, n0, _UICRC,
    0, () => UpdateInferenceComponentRuntimeConfigInput$, () => UpdateInferenceComponentRuntimeConfigOutput$
];
export var UpdateInferenceExperiment$ = [9, n0, _UIEp,
    0, () => UpdateInferenceExperimentRequest$, () => UpdateInferenceExperimentResponse$
];
export var UpdateMlflowApp$ = [9, n0, _UMA,
    0, () => UpdateMlflowAppRequest$, () => UpdateMlflowAppResponse$
];
export var UpdateMlflowTrackingServer$ = [9, n0, _UMTS,
    0, () => UpdateMlflowTrackingServerRequest$, () => UpdateMlflowTrackingServerResponse$
];
export var UpdateModelCard$ = [9, n0, _UMC,
    0, () => UpdateModelCardRequest$, () => UpdateModelCardResponse$
];
export var UpdateModelPackage$ = [9, n0, _UMP,
    0, () => UpdateModelPackageInput$, () => UpdateModelPackageOutput$
];
export var UpdateMonitoringAlert$ = [9, n0, _UMAp,
    0, () => UpdateMonitoringAlertRequest$, () => UpdateMonitoringAlertResponse$
];
export var UpdateMonitoringSchedule$ = [9, n0, _UMS,
    0, () => UpdateMonitoringScheduleRequest$, () => UpdateMonitoringScheduleResponse$
];
export var UpdateNotebookInstance$ = [9, n0, _UNI,
    0, () => UpdateNotebookInstanceInput$, () => UpdateNotebookInstanceOutput$
];
export var UpdateNotebookInstanceLifecycleConfig$ = [9, n0, _UNILC,
    0, () => UpdateNotebookInstanceLifecycleConfigInput$, () => UpdateNotebookInstanceLifecycleConfigOutput$
];
export var UpdatePartnerApp$ = [9, n0, _UPAp,
    0, () => UpdatePartnerAppRequest$, () => UpdatePartnerAppResponse$
];
export var UpdatePipeline$ = [9, n0, _UPp,
    0, () => UpdatePipelineRequest$, () => UpdatePipelineResponse$
];
export var UpdatePipelineExecution$ = [9, n0, _UPE,
    0, () => UpdatePipelineExecutionRequest$, () => UpdatePipelineExecutionResponse$
];
export var UpdatePipelineVersion$ = [9, n0, _UPV,
    0, () => UpdatePipelineVersionRequest$, () => UpdatePipelineVersionResponse$
];
export var UpdateProject$ = [9, n0, _UPpd,
    0, () => UpdateProjectInput$, () => UpdateProjectOutput$
];
export var UpdateSpace$ = [9, n0, _USp,
    0, () => UpdateSpaceRequest$, () => UpdateSpaceResponse$
];
export var UpdateTrainingJob$ = [9, n0, _UTJ,
    0, () => UpdateTrainingJobRequest$, () => UpdateTrainingJobResponse$
];
export var UpdateTrial$ = [9, n0, _UTp,
    0, () => UpdateTrialRequest$, () => UpdateTrialResponse$
];
export var UpdateTrialComponent$ = [9, n0, _UTC,
    0, () => UpdateTrialComponentRequest$, () => UpdateTrialComponentResponse$
];
export var UpdateUserProfile$ = [9, n0, _UUP,
    0, () => UpdateUserProfileRequest$, () => UpdateUserProfileResponse$
];
export var UpdateWorkforce$ = [9, n0, _UW,
    0, () => UpdateWorkforceRequest$, () => UpdateWorkforceResponse$
];
export var UpdateWorkteam$ = [9, n0, _UWp,
    0, () => UpdateWorkteamRequest$, () => UpdateWorkteamResponse$
];
